Author: Brian B. Avants and Nicholas J. Tustison

# ANTsPyMM processing summary and data dictionary

#### Brian B. Avants and Nicholas J. Tustison

## ANTsPyMM imaging-derived phenotypes and associated coordinate systems / neuroanatomy

A quick overview of the labels used/generated by this framework: .

An example annotated output tree is here. This shows the results of a real run of ANTsPyMM on multiple modality MRI (M3RI).

The `ANTsPyMM` system takes advantage of templates, core T1 processing and super-resolution described in this paper.

- We quantify cortex with the Desikan-Killiany-Tourville parcellation (DKT).

  - `*dktregions` refers to the segmentation label directly from the deep learning method.

  - `*dktcortex` refers to the segmentation label restricted to the cortical segmentation that is provided by the tissue segmentation method.

- Subcortical segmentation with deep learning and also SyN registration leverages the CIT168 atlas 10.1101/211201.

- A medial temporal lobe parcellation is based on manual labels derived from M. Yassa’s research group (preprint) and described here.

- A cerebellum parcellation based on a template from the CoBrALab with additional manual editing by the Tustison family (publication in progress). The parcellation scheme is defined using the Schmahmann nomenclature (reviewed here). The core tool is named `cerebellum_morphology` and based on a concatentation of two U-nets.

- Brain stem is subdivided into the mid-brain, pons and medulla; This segmentation derives from registration between the individual T1w and the manually labeled CIT168 template. The protocol is based on this used in Freesurfer.

- We segment anatomy related to the basal forebrain and associated cholinergic neurons with a deep learning method (`deepNBM`) derived from manual labeling of ADNI data.

  - This approach is based on anatomical landmarks proposed in Liu, A. et al. (2015). The `deepNBM` method uses super-resolution segmentation to take advantage of manual labels performed on super-resolution training data.

  - The classic Zaborszky, L. et al. (2008) “Stereotaxic probabilistic maps of the magnocellular cell groups in human basal forebrain.” Neuroimage 42: 1127–1141 also informed the manual labeling.

  - Presented at Human Brain Mapping conference 2022.

- The Mori JHU white matter atlas provides a parcellation of white matter regions (paper here) which are applied to diffusion weighted images.

- Jonathan Power’s coordinates from “Functional Network Organization of the Human Brain” 10.1016/j.neuron.2011.09.006 were previously used to guide our analysis of resting state function MRI (rsfMRI). We also based our processing evaluation on these data. However, we now use the homotopic coordinates described below.

- Yeo’s Homotopic local-global parcellation of the human cerebral cortex from resting-state functional connectivity is the new default that we use for rsfMRI instead of the JP coordinates. Additional details about the parcellation are here. We use the variant with 500 homotopic parcels i.e. 250 per hemisphere.

  - these parcels are used to generate inter and intra network correlations using the following networks (which are further subdivided s.t. 17 network names are available)

    - Visual Network: Processes visual information, including spatial and motion processing.

    - Somatomotor Network: Involved in the control of movement and processing of somatosensory information.

    - Dorsal Attention Network: Plays a key role in top-down attentional control and spatial orientation.

    - Ventral Attention Network: Involved in detecting unexpected stimuli and bottom-up attention.

    - Limbic Network: Associated with emotion processing, memory, and autonomic functions.

    - Frontoparietal Network: Important for cognitive functions including working memory and executive control.

    - Default Mode Network (DMN): Active during rest and involved in self-referential thought, memory retrieval, and planning for the future.

  - The 17 Network abbreviations are adapted from Ru Kong’s work.

  - rsfMRI phenotype variables like “fcnxpro129” indicate that parameter set 129 was used; currently 122 is considered “best” but 129 and 134 are also provided. they differ in the censoring and nuisance variables used in the processing.

  - we also provide voxel-wise measurements within each parcel including:

    - fALFF and ALFF each divided by the global mean of the brain (mfALFF and mALFF)

    - percent absolute fluctuation divided by the global PerAF mean of the brain (mPerAF)

## ANTsPyMM data dictionary

The `ANTsPyMM` data dictionary labels associates each column name with each of the above anatomical references. Table 1 below summarizes the number of variables associated with each modality and anatomical prior space. DTI-derived connectivity yields the largest number of variables because we pairwise map each DKT cortical region as well as the primary CIT168 regions.

### Table 1

| DTI | Flair | Neuromelanin | restingStatefMRI | rs-fMRI | T1 DiReCT thickness processing | T1 hierarchical processing | unique id | Unknown | p
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| (N=907) | (N=52) | (N=45) | (N=6477) | (N=1) | (N=94) | (N=1036) | (N=2) | (N=153)
Label | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 | unique values:8980 |
Description | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 | unique values:1069 |
Measurement | unique values:23 | unique values:23 | unique values:23 | unique values:23 | unique values:23 | unique values:23 | unique values:23 | unique values:23 | unique values:23 |
Atlas |  |  |  |  |  |  |  |  |  | < 0.001
ANTs | 721 (79.5%) | 52 (100.0%) | 45 (100.0%) | 0 ( 0.0%) | 1 (100.0%) | 94 (100.0%) | 195 (18.8%) | 0 ( 0.0%) | 153 (100.0%) |
BF | 40 ( 4.4%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 32 ( 3.1%) | 0 ( 0.0%) | 0 ( 0.0%) |
CIT168 | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 198 (19.1%) | 0 ( 0.0%) | 0 ( 0.0%) |
desikan-killiany-tourville | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 548 (52.9%) | 0 ( 0.0%) | 0 ( 0.0%) |
johns hopkins white matter | 146 (16.1%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
MTL | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 63 ( 6.1%) | 0 ( 0.0%) | 0 ( 0.0%) |
power peterson fMRI meta-analyses | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 6477 (100.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
unique id | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2 (100.0%) | 0 ( 0.0%) |
rsf.pipeline |  |  |  |  |  |  |  |  |  | 1.000
122 | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2159 (33.3%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
129 | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2159 (33.3%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
134 | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2159 (33.3%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |

## Quality control metrics

Automated (blind) QC is part of standard ANTsPyMM processing. QC metrics are therefore present in the standard output tables. Notes on the meaning of these metrics, along with examples of the metrics on images, are here.

The most important QC metric is `T1Hier_resnetGrade` which rejects truly bad images. We recommend rejecting images with `T1Hier_resnetGrade < 1.01` where higher thresholds may be useful in some cases. This grading function uses deep learning to generate a pseudocontinuous measurement of aggregate T1w image quality. Several factors will contribute to these scores and it is not a perfect approach but it is well-defined and evaluated based on manual ratings here.

The `outlierness` function produces additional blind QC measurements via automated outlierness calculations. These measurements are denoted by Local Outlier Probability (LOOP `*loop*` ) and local outlier factor ( LOF `*lof*` ) column names.

Time series images may have additional QC metrics such as:

- TSNR: temporal signal to noise ratio

- SSNR: spatial signal to noise ratio on the mean image (different from TSNR)

- DVARS: the spatial root mean square of the data after temporal differencing

- Neuromelanin (NM) has its own set of variables including:

  - count: the number of acquisitions at that date

  - min/max/mean/sd: a statistic on the raw image signal after averaging the acquisitions

  - `avg/std_refregion` : average and standard deviation of signal in the reference region

  - `avg/std_substantianigra` : average and standard deviation of signal in the substantia nigra or a related CIT168 region (determined by deepCIT168)

  - `NM2DMT_NM_substantianigra_z_coordinate`: estimate of the normalized (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab.

- the framewise displacement (FD) values are 10x in DTI data compared to rsfMRI data. E.g. if 0.3 were a reasonable high motion threshold in rsfMRI; then 3.0 would be a comparable threshold for DTI.

## the full data dictionary

A sortable version of the data dictionary is below (if viewing on local machine).

### Table 2

Label
Description
Modality
Measurement
Atlas
rsf.pipeline
side
tidynames
X
​
​
ignore
ANTs
​
​
x
filename
​
​
​
ANTs
​
​
filename
dimensionality
​
​
​
ANTs
​
​
dimensionality
noise
​
​
QC - noise/contrast
ANTs
​
​
noise
snr
​
​
QC - noise/contrast
ANTs
​
​
snr
cnr
​
​
QC - noise/contrast
ANTs
​
​
cnr
psnr
​
​
QC - similarity measurements
ANTs
​
​
psnr
ssim
​
​
QC - similarity measurements
ANTs
​
​
ssim
mi
​
​
QC - similarity measurements
ANTs
​
​
mi
reflection_err
​
​
QC - similarity measurements
ANTs
​
​
reflection.err
EVR
​
​
QC - eigenvalue ratio
ANTs
​
​
evr
msk_vol
​
​
geometry.volume
ANTs
​
​
msk.vol
spc0
​
​
QC - physical space
ANTs
​
​
spc0
spc1
​
​
QC - physical space
ANTs
​
​
spc1
spc2
​
​
QC - physical space
ANTs
​
​
spc2
org0
​
​
QC - physical space
ANTs
​
​
org0
org1
​
​
QC - physical space
ANTs
​
​
org1
org2
​
​
QC - physical space
ANTs
​
​
org2
dimx
​
​
QC - physical space
ANTs
​
​
dimx
dimy
​
​
QC - physical space
ANTs
​
​
dimy
dimz
​
​
QC - physical space
ANTs
​
​
dimz
dimt
​
​
QC - physical space
ANTs
​
​
dimt
slice
​
​
slice number in time series (ignore)
ANTs
​
​
slice
modality
​
​
generic modality name
ANTs
​
​
modality
mriseries
​
​
​
ANTs
​
​
mriseries
mrimfg
​
​
MRI manufacturer (often missing)
ANTs
​
​
mrimfg
mrimodel
​
​
MRI model (often missing)
ANTs
​
​
mrimodel
mriMagneticFieldStrength
​
​
MRI field strength (often missing)
ANTs
​
​
mrimagneticfieldstrength
mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
mrisar
mriPixelBandwidth
Unknown Core: mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
mripixelbandwidth
mriPixelBandwidthPE
Unknown Core: mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
mripixelbandwidthpe
dti_bvalueMax
Unknown Core: bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti.bvaluemax
dti_bvecnorm
Unknown Core: bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
dti.bvecnorm
ol_loop
​
​
QC
ANTs
​
​
ol.loop
ol_lof
​
​
QC
ANTs
​
​
ol.lof
ol_lof_decision
​
​
QC
ANTs
​
​
ol.lof.decision
dti_failed
Unknown Core: failed
DTI
heuristic decision about dti usability (eg its 3D)
ANTs
​
​
dti.failed
rsf_failed
Unknown Core: failed
rs-fMRI
heuristic decision about rsfMRI usability (eg its 3D)
ANTs
​
​
rsf.failed
subjectID
​
​
unique subject ID
ANTs
​
​
subjectid
date
​
​
image acquisition date
ANTs
​
​
date
subjectIDdate
​
​
concatenation of subject ID and date
ANTs
​
​
subjectiddate
imageID
​
​
unique image ID (ideally unique but not always)
ANTs
​
​
imageid
negol
​
​
negative outlier variable (higher is better)
ANTs
​
​
negol
repeat.
​
​
​
ANTs
​
​
repeat.
flairfn
​
Flair
original source data filename
ANTs
​
​
flairfn
T2Flair_dimensionality
Unknown Core: dimensionality
Flair
Unknown
ANTs
​
​
t2flair.dimensionality
T2Flair_noise
Unknown Core: noise
Flair
QC
ANTs
​
​
t2flair.noise
T2Flair_snr
Global
Flair
QC
ANTs
​
​
t2flair.snr
T2Flair_cnr
Global
Flair
QC
ANTs
​
​
t2flair.cnr
T2Flair_psnr
Global
Flair
QC
ANTs
​
​
t2flair.psnr
T2Flair_ssim
Global
Flair
QC
ANTs
​
​
t2flair.ssim
T2Flair_mi
Global
Flair
Mutual Information
ANTs
​
​
t2flair.mi
T2Flair_reflection_err
Unknown Core: reflection err
Flair
Unknown
ANTs
​
​
t2flair.reflection.err
T2Flair_EVR
Global
Flair
Explained Variance Ratio
ANTs
​
​
t2flair.evr
T2Flair_msk_vol
Unknown Core: msk
Flair
geometry.volume
ANTs
​
​
t2flair.msk.vol
T2Flair_spc0
Unknown Core: spc0
Flair
Unknown
ANTs
​
​
t2flair.spc0
T2Flair_spc1
Unknown Core: spc1
Flair
Unknown
ANTs
​
​
t2flair.spc1
T2Flair_spc2
Unknown Core: spc2
Flair
Unknown
ANTs
​
​
t2flair.spc2
T2Flair_org0
Unknown Core: org0
Flair
Unknown
ANTs
​
​
t2flair.org0
T2Flair_org1
Unknown Core: org1
Flair
Unknown
ANTs
​
​
t2flair.org1
T2Flair_org2
Unknown Core: org2
Flair
Unknown
ANTs
​
​
t2flair.org2
T2Flair_dimx
Unknown Core: dimx
Flair
Unknown
ANTs
​
​
t2flair.dimx
T2Flair_dimy
Unknown Core: dimy
Flair
Unknown
ANTs
​
​
t2flair.dimy
T2Flair_dimz
Unknown Core: dimz
Flair
Unknown
ANTs
​
​
t2flair.dimz
T2Flair_dimt
Unknown Core: dimt
Flair
Unknown
ANTs
​
​
t2flair.dimt
T2Flair_slice
Unknown Core: slice
Flair
slice number in time series (ignore)
ANTs
​
​
t2flair.slice
T2Flair_modality
Unknown Core: modality
Flair
Unknown
ANTs
​
​
t2flair.modality
T2Flair_mriseries
Unknown Core: mriseries
Flair
Unknown
ANTs
​
​
t2flair.mriseries
T2Flair_mriSAR
Unknown Core: mrisar
Flair
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
t2flair.mrisar
T2Flair_mriPixelBandwidth
Unknown Core: mripixelbandwidth
Flair
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
t2flair.mripixelbandwidth
T2Flair_mriPixelBandwidthPE
Unknown Core: mripixelbandwidthpe
Flair
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
t2flair.mripixelbandwidthpe
T2Flair_dti_bvalueMax
Unknown Core: dti bvaluemax
Flair
MRI DTI maximum bvalue (often missing)
ANTs
​
​
t2flair.dti.bvaluemax
T2Flair_dti_bvecnorm
Unknown Core: dti bvecnorm
Flair
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
t2flair.dti.bvecnorm
T2Flair_ol_loop
Global
Flair
QC
ANTs
​
​
t2flair.ol.loop
T2Flair_ol_lof
Global
Flair
QC
ANTs
​
​
t2flair.ol.lof
T2Flair_ol_lof_decision
Unknown Core: decision
Flair
QC
ANTs
​
​
t2flair.ol.lof.decision
flairid
​
Flair
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
flairid
T2Flair_negol
Negative Outlier
Flair
Unknown
ANTs
​
​
t2flair.negol
T2Flair_score_ol_loop
Unknown Core: ol loop
Flair
QC
ANTs
​
​
t2flair.score.ol.loop
T2Flair_score_noise
Unknown Core: noise
Flair
QC
ANTs
​
​
t2flair.score.noise
T2Flair_score_snr
Unknown Core: snr
Flair
QC
ANTs
​
​
t2flair.score.snr
T2Flair_score_EVR
Unknown Core: evr
Flair
Score
ANTs
​
​
t2flair.score.evr
T2Flair_score_reflection_err
Unknown Core: reflection err
Flair
Score
ANTs
​
​
t2flair.score.reflection.err
T2Flair_best_score
Unknown Core: best
Flair
Score
ANTs
​
​
t2flair.best.score
nmfn1
​
​
original source data filename
ANTs
​
​
nmfn1
NM1_dimensionality
​
​
​
ANTs
​
​
nm1.dimensionality
NM1_noise
​
​
QC
ANTs
​
​
nm1.noise
NM1_snr
​
​
QC
ANTs
​
​
nm1.snr
NM1_cnr
​
​
QC
ANTs
​
​
nm1.cnr
NM1_psnr
​
​
QC
ANTs
​
​
nm1.psnr
NM1_ssim
​
​
QC
ANTs
​
​
nm1.ssim
NM1_mi
​
​
​
ANTs
​
​
nm1.mi
NM1_reflection_err
​
​
​
ANTs
​
​
nm1.reflection.err
NM1_EVR
​
​
​
ANTs
​
​
nm1.evr
NM1_msk_vol
​
​
geometry.volume
ANTs
​
​
nm1.msk.vol
NM1_spc0
​
​
​
ANTs
​
​
nm1.spc0
NM1_spc1
​
​
​
ANTs
​
​
nm1.spc1
NM1_spc2
​
​
​
ANTs
​
​
nm1.spc2
NM1_org0
​
​
​
ANTs
​
​
nm1.org0
NM1_org1
​
​
​
ANTs
​
​
nm1.org1
NM1_org2
​
​
​
ANTs
​
​
nm1.org2
NM1_dimx
​
​
​
ANTs
​
​
nm1.dimx
NM1_dimy
​
​
​
ANTs
​
​
nm1.dimy
NM1_dimz
​
​
​
ANTs
​
​
nm1.dimz
NM1_dimt
​
​
​
ANTs
​
​
nm1.dimt
NM1_slice
​
​
slice number in time series (ignore)
ANTs
​
​
nm1.slice
NM1_modality
​
​
​
ANTs
​
​
nm1.modality
NM1_mriseries
​
​
​
ANTs
​
​
nm1.mriseries
NM1_mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm1.mrisar
NM1_mriPixelBandwidth
Unknown Core: nm1 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm1.mripixelbandwidth
NM1_mriPixelBandwidthPE
Unknown Core: nm1 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm1.mripixelbandwidthpe
NM1_dti_bvalueMax
Unknown Core: nm1 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm1.dti.bvaluemax
NM1_dti_bvecnorm
Unknown Core: nm1 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm1.dti.bvecnorm
NM1_ol_loop
​
​
QC
ANTs
​
​
nm1.ol.loop
NM1_ol_lof
​
​
QC
ANTs
​
​
nm1.ol.lof
NM1_ol_lof_decision
​
​
QC
ANTs
​
​
nm1.ol.lof.decision
nmid1
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
nmid1
NM1_negol
​
​
​
ANTs
​
​
nm1.negol
NM1_score_ol_loop
​
​
QC
ANTs
​
​
nm1.score.ol.loop
NM1_score_noise
​
​
QC
ANTs
​
​
nm1.score.noise
NM1_score_snr
​
​
QC
ANTs
​
​
nm1.score.snr
NM1_score_EVR
​
​
​
ANTs
​
​
nm1.score.evr
NM1_score_reflection_err
​
​
​
ANTs
​
​
nm1.score.reflection.err
NM1_best_score
​
​
​
ANTs
​
​
nm1.best.score
nmfn2
​
​
original source data filename
ANTs
​
​
nmfn2
NM2_dimensionality
Unknown Core: nm2 dimensionality
Unknown
Unknown
ANTs
​
​
nm2.dimensionality
NM2_noise
Unknown Core: nm2 noise
Unknown
QC
ANTs
​
​
nm2.noise
NM2_snr
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.snr
NM2_cnr
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.cnr
NM2_psnr
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.psnr
NM2_ssim
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.ssim
NM2_mi
Unknown Core: nm2
Unknown
Mutual Information
ANTs
​
​
nm2.mi
NM2_reflection_err
Unknown Core: nm2 reflection err
Unknown
Unknown
ANTs
​
​
nm2.reflection.err
NM2_EVR
Unknown Core: nm2
Unknown
Explained Variance Ratio
ANTs
​
​
nm2.evr
NM2_msk_vol
Unknown Core: nm2 msk
Unknown
geometry.volume
ANTs
​
​
nm2.msk.vol
NM2_spc0
Unknown Core: nm2 spc0
Unknown
Unknown
ANTs
​
​
nm2.spc0
NM2_spc1
Unknown Core: nm2 spc1
Unknown
Unknown
ANTs
​
​
nm2.spc1
NM2_spc2
Unknown Core: nm2 spc2
Unknown
Unknown
ANTs
​
​
nm2.spc2
NM2_org0
Unknown Core: nm2 org0
Unknown
Unknown
ANTs
​
​
nm2.org0
NM2_org1
Unknown Core: nm2 org1
Unknown
Unknown
ANTs
​
​
nm2.org1
NM2_org2
Unknown Core: nm2 org2
Unknown
Unknown
ANTs
​
​
nm2.org2
NM2_dimx
Unknown Core: nm2 dimx
Unknown
Unknown
ANTs
​
​
nm2.dimx
NM2_dimy
Unknown Core: nm2 dimy
Unknown
Unknown
ANTs
​
​
nm2.dimy
NM2_dimz
Unknown Core: nm2 dimz
Unknown
Unknown
ANTs
​
​
nm2.dimz
NM2_dimt
Unknown Core: nm2 dimt
Unknown
Unknown
ANTs
​
​
nm2.dimt
NM2_slice
Unknown Core: nm2 slice
Unknown
slice number in time series (ignore)
ANTs
​
​
nm2.slice
NM2_modality
Unknown Core: nm2 modality
Unknown
Unknown
ANTs
​
​
nm2.modality
NM2_mriseries
Unknown Core: nm2 mriseries
Unknown
Unknown
ANTs
​
​
nm2.mriseries
NM2_mriSAR
Unknown Core: nm2 mrisar
Unknown
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm2.mrisar
NM2_mriPixelBandwidth
Unknown Core: nm2 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm2.mripixelbandwidth
NM2_mriPixelBandwidthPE
Unknown Core: nm2 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm2.mripixelbandwidthpe
NM2_dti_bvalueMax
Unknown Core: nm2 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm2.dti.bvaluemax
NM2_dti_bvecnorm
Unknown Core: nm2 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm2.dti.bvecnorm
NM2_ol_loop
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.ol.loop
NM2_ol_lof
Unknown Core: nm2
Unknown
QC
ANTs
​
​
nm2.ol.lof
NM2_ol_lof_decision
Unknown Core: nm2 decision
Unknown
QC
ANTs
​
​
nm2.ol.lof.decision
nmid2
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
nmid2
NM2_negol
Negative Outlier
Unknown
Unknown
ANTs
​
​
nm2.negol
NM2_score_ol_loop
Unknown Core: nm2 ol loop
Unknown
QC
ANTs
​
​
nm2.score.ol.loop
NM2_score_noise
Unknown Core: nm2 noise
Unknown
QC
ANTs
​
​
nm2.score.noise
NM2_score_snr
Unknown Core: nm2 snr
Unknown
QC
ANTs
​
​
nm2.score.snr
NM2_score_EVR
Unknown Core: nm2 evr
Unknown
Score
ANTs
​
​
nm2.score.evr
NM2_score_reflection_err
Unknown Core: nm2 reflection err
Unknown
Score
ANTs
​
​
nm2.score.reflection.err
NM2_best_score
Unknown Core: nm2 best
Unknown
Score
ANTs
​
​
nm2.best.score
nmfn3
​
​
original source data filename
ANTs
​
​
nmfn3
NM3_dimensionality
​
​
​
ANTs
​
​
nm3.dimensionality
NM3_noise
​
​
QC
ANTs
​
​
nm3.noise
NM3_snr
​
​
QC
ANTs
​
​
nm3.snr
NM3_cnr
​
​
QC
ANTs
​
​
nm3.cnr
NM3_psnr
​
​
QC
ANTs
​
​
nm3.psnr
NM3_ssim
​
​
QC
ANTs
​
​
nm3.ssim
NM3_mi
​
​
​
ANTs
​
​
nm3.mi
NM3_reflection_err
​
​
​
ANTs
​
​
nm3.reflection.err
NM3_EVR
​
​
​
ANTs
​
​
nm3.evr
NM3_msk_vol
​
​
geometry.volume
ANTs
​
​
nm3.msk.vol
NM3_spc0
​
​
​
ANTs
​
​
nm3.spc0
NM3_spc1
​
​
​
ANTs
​
​
nm3.spc1
NM3_spc2
​
​
​
ANTs
​
​
nm3.spc2
NM3_org0
​
​
​
ANTs
​
​
nm3.org0
NM3_org1
​
​
​
ANTs
​
​
nm3.org1
NM3_org2
​
​
​
ANTs
​
​
nm3.org2
NM3_dimx
​
​
​
ANTs
​
​
nm3.dimx
NM3_dimy
​
​
​
ANTs
​
​
nm3.dimy
NM3_dimz
​
​
​
ANTs
​
​
nm3.dimz
NM3_dimt
​
​
​
ANTs
​
​
nm3.dimt
NM3_slice
​
​
slice number in time series (ignore)
ANTs
​
​
nm3.slice
NM3_modality
​
​
​
ANTs
​
​
nm3.modality
NM3_mriseries
​
​
​
ANTs
​
​
nm3.mriseries
NM3_mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm3.mrisar
NM3_mriPixelBandwidth
Unknown Core: nm3 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm3.mripixelbandwidth
NM3_mriPixelBandwidthPE
Unknown Core: nm3 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm3.mripixelbandwidthpe
NM3_dti_bvalueMax
Unknown Core: nm3 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm3.dti.bvaluemax
NM3_dti_bvecnorm
Unknown Core: nm3 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm3.dti.bvecnorm
NM3_ol_loop
​
​
QC
ANTs
​
​
nm3.ol.loop
NM3_ol_lof
​
​
QC
ANTs
​
​
nm3.ol.lof
NM3_ol_lof_decision
​
​
QC
ANTs
​
​
nm3.ol.lof.decision
nmid3
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
nmid3
NM3_negol
​
​
​
ANTs
​
​
nm3.negol
NM3_score_ol_loop
​
​
QC
ANTs
​
​
nm3.score.ol.loop
NM3_score_noise
​
​
QC
ANTs
​
​
nm3.score.noise
NM3_score_snr
​
​
QC
ANTs
​
​
nm3.score.snr
NM3_score_EVR
​
​
​
ANTs
​
​
nm3.score.evr
NM3_score_reflection_err
​
​
​
ANTs
​
​
nm3.score.reflection.err
NM3_best_score
​
​
​
ANTs
​
​
nm3.best.score
nmfn4
​
​
original source data filename
ANTs
​
​
nmfn4
NM4_dimensionality
​
​
​
ANTs
​
​
nm4.dimensionality
NM4_noise
​
​
QC
ANTs
​
​
nm4.noise
NM4_snr
​
​
QC
ANTs
​
​
nm4.snr
NM4_cnr
​
​
QC
ANTs
​
​
nm4.cnr
NM4_psnr
​
​
QC
ANTs
​
​
nm4.psnr
NM4_ssim
​
​
QC
ANTs
​
​
nm4.ssim
NM4_mi
​
​
​
ANTs
​
​
nm4.mi
NM4_reflection_err
​
​
​
ANTs
​
​
nm4.reflection.err
NM4_EVR
​
​
​
ANTs
​
​
nm4.evr
NM4_msk_vol
​
​
geometry.volume
ANTs
​
​
nm4.msk.vol
NM4_spc0
​
​
​
ANTs
​
​
nm4.spc0
NM4_spc1
​
​
​
ANTs
​
​
nm4.spc1
NM4_spc2
​
​
​
ANTs
​
​
nm4.spc2
NM4_org0
​
​
​
ANTs
​
​
nm4.org0
NM4_org1
​
​
​
ANTs
​
​
nm4.org1
NM4_org2
​
​
​
ANTs
​
​
nm4.org2
NM4_dimx
​
​
​
ANTs
​
​
nm4.dimx
NM4_dimy
​
​
​
ANTs
​
​
nm4.dimy
NM4_dimz
​
​
​
ANTs
​
​
nm4.dimz
NM4_dimt
​
​
​
ANTs
​
​
nm4.dimt
NM4_slice
​
​
slice number in time series (ignore)
ANTs
​
​
nm4.slice
NM4_modality
​
​
​
ANTs
​
​
nm4.modality
NM4_mriseries
​
​
​
ANTs
​
​
nm4.mriseries
NM4_mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm4.mrisar
NM4_mriPixelBandwidth
Unknown Core: nm4 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm4.mripixelbandwidth
NM4_mriPixelBandwidthPE
Unknown Core: nm4 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm4.mripixelbandwidthpe
NM4_dti_bvalueMax
Unknown Core: nm4 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm4.dti.bvaluemax
NM4_dti_bvecnorm
Unknown Core: nm4 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm4.dti.bvecnorm
NM4_ol_loop
​
​
QC
ANTs
​
​
nm4.ol.loop
NM4_ol_lof
​
​
QC
ANTs
​
​
nm4.ol.lof
NM4_ol_lof_decision
​
​
QC
ANTs
​
​
nm4.ol.lof.decision
nmid4
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
nmid4
NM4_negol
​
​
​
ANTs
​
​
nm4.negol
NM4_score_ol_loop
​
​
QC
ANTs
​
​
nm4.score.ol.loop
NM4_score_noise
​
​
QC
ANTs
​
​
nm4.score.noise
NM4_score_snr
​
​
QC
ANTs
​
​
nm4.score.snr
NM4_score_EVR
​
​
​
ANTs
​
​
nm4.score.evr
NM4_score_reflection_err
​
​
​
ANTs
​
​
nm4.score.reflection.err
NM4_best_score
​
​
​
ANTs
​
​
nm4.best.score
nmfn5
​
​
original source data filename
ANTs
​
​
nmfn5
NM5_dimensionality
​
​
​
ANTs
​
​
nm5.dimensionality
NM5_noise
​
​
QC
ANTs
​
​
nm5.noise
NM5_snr
​
​
QC
ANTs
​
​
nm5.snr
NM5_cnr
​
​
QC
ANTs
​
​
nm5.cnr
NM5_psnr
​
​
QC
ANTs
​
​
nm5.psnr
NM5_ssim
​
​
QC
ANTs
​
​
nm5.ssim
NM5_mi
​
​
​
ANTs
​
​
nm5.mi
NM5_reflection_err
​
​
​
ANTs
​
​
nm5.reflection.err
NM5_EVR
​
​
​
ANTs
​
​
nm5.evr
NM5_msk_vol
​
​
geometry.volume
ANTs
​
​
nm5.msk.vol
NM5_spc0
​
​
​
ANTs
​
​
nm5.spc0
NM5_spc1
​
​
​
ANTs
​
​
nm5.spc1
NM5_spc2
​
​
​
ANTs
​
​
nm5.spc2
NM5_org0
​
​
​
ANTs
​
​
nm5.org0
NM5_org1
​
​
​
ANTs
​
​
nm5.org1
NM5_org2
​
​
​
ANTs
​
​
nm5.org2
NM5_dimx
​
​
​
ANTs
​
​
nm5.dimx
NM5_dimy
​
​
​
ANTs
​
​
nm5.dimy
NM5_dimz
​
​
​
ANTs
​
​
nm5.dimz
NM5_dimt
​
​
​
ANTs
​
​
nm5.dimt
NM5_slice
​
​
slice number in time series (ignore)
ANTs
​
​
nm5.slice
NM5_modality
​
​
​
ANTs
​
​
nm5.modality
NM5_mriseries
​
​
​
ANTs
​
​
nm5.mriseries
NM5_mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm5.mrisar
NM5_mriPixelBandwidth
Unknown Core: nm5 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm5.mripixelbandwidth
NM5_mriPixelBandwidthPE
Unknown Core: nm5 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm5.mripixelbandwidthpe
NM5_dti_bvalueMax
Unknown Core: nm5 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm5.dti.bvaluemax
NM5_dti_bvecnorm
Unknown Core: nm5 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm5.dti.bvecnorm
NM5_ol_loop
​
​
QC
ANTs
​
​
nm5.ol.loop
NM5_ol_lof
​
​
QC
ANTs
​
​
nm5.ol.lof
NM5_ol_lof_decision
​
​
QC
ANTs
​
​
nm5.ol.lof.decision
nmid5
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
nmid5
NM5_negol
​
​
​
ANTs
​
​
nm5.negol
NM5_score_ol_loop
​
​
QC
ANTs
​
​
nm5.score.ol.loop
NM5_score_noise
​
​
QC
ANTs
​
​
nm5.score.noise
NM5_score_snr
​
​
QC
ANTs
​
​
nm5.score.snr
NM5_score_EVR
​
​
​
ANTs
​
​
nm5.score.evr
NM5_score_reflection_err
​
​
​
ANTs
​
​
nm5.score.reflection.err
NM5_best_score
​
​
​
ANTs
​
​
nm5.best.score
NM6_filename
​
​
​
ANTs
​
​
nm6.filename
NM6_dimensionality
​
​
​
ANTs
​
​
nm6.dimensionality
NM6_noise
​
​
QC
ANTs
​
​
nm6.noise
NM6_snr
​
​
QC
ANTs
​
​
nm6.snr
NM6_cnr
​
​
QC
ANTs
​
​
nm6.cnr
NM6_psnr
​
​
QC
ANTs
​
​
nm6.psnr
NM6_ssim
​
​
QC
ANTs
​
​
nm6.ssim
NM6_mi
​
​
​
ANTs
​
​
nm6.mi
NM6_reflection_err
​
​
​
ANTs
​
​
nm6.reflection.err
NM6_EVR
​
​
​
ANTs
​
​
nm6.evr
NM6_msk_vol
​
​
geometry.volume
ANTs
​
​
nm6.msk.vol
NM6_spc0
​
​
​
ANTs
​
​
nm6.spc0
NM6_spc1
​
​
​
ANTs
​
​
nm6.spc1
NM6_spc2
​
​
​
ANTs
​
​
nm6.spc2
NM6_org0
​
​
​
ANTs
​
​
nm6.org0
NM6_org1
​
​
​
ANTs
​
​
nm6.org1
NM6_org2
​
​
​
ANTs
​
​
nm6.org2
NM6_dimx
​
​
​
ANTs
​
​
nm6.dimx
NM6_dimy
​
​
​
ANTs
​
​
nm6.dimy
NM6_dimz
​
​
​
ANTs
​
​
nm6.dimz
NM6_dimt
​
​
​
ANTs
​
​
nm6.dimt
NM6_slice
​
​
slice number in time series (ignore)
ANTs
​
​
nm6.slice
NM6_modality
​
​
​
ANTs
​
​
nm6.modality
NM6_mriseries
​
​
​
ANTs
​
​
nm6.mriseries
NM6_mriSAR
​
​
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
nm6.mrisar
NM6_mriPixelBandwidth
Unknown Core: nm6 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
nm6.mripixelbandwidth
NM6_mriPixelBandwidthPE
Unknown Core: nm6 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
nm6.mripixelbandwidthpe
NM6_dti_bvalueMax
Unknown Core: nm6 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
nm6.dti.bvaluemax
NM6_dti_bvecnorm
Unknown Core: nm6 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
nm6.dti.bvecnorm
NM6_ol_loop
​
​
QC
ANTs
​
​
nm6.ol.loop
NM6_ol_lof
​
​
QC
ANTs
​
​
nm6.ol.lof
NM6_ol_lof_decision
​
​
QC
ANTs
​
​
nm6.ol.lof.decision
NM6_imageID
​
​
​
ANTs
​
​
nm6.imageid
NM6_negol
​
​
​
ANTs
​
​
nm6.negol
NM6_score_ol_loop
​
​
QC
ANTs
​
​
nm6.score.ol.loop
NM6_score_noise
​
​
QC
ANTs
​
​
nm6.score.noise
NM6_score_snr
​
​
QC
ANTs
​
​
nm6.score.snr
NM6_score_EVR
​
​
​
ANTs
​
​
nm6.score.evr
NM6_score_reflection_err
​
​
​
ANTs
​
​
nm6.score.reflection.err
NM6_best_score
​
​
​
ANTs
​
​
nm6.best.score
dtfn1
​
​
original source data filename
ANTs
​
​
dtfn1
DTI1_dimensionality
Unknown Core: dti1 dimensionality
DTI
Unknown
ANTs
​
​
dti1.dimensionality
DTI1_noise
Unknown Core: dti1 noise
DTI
QC
ANTs
​
​
dti1.noise
DTI1_snr
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.snr
DTI1_cnr
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.cnr
DTI1_psnr
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.psnr
DTI1_ssim
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.ssim
DTI1_mi
Unknown Core: dti1
DTI
Mutual Information
ANTs
​
​
dti1.mi
DTI1_reflection_err
Unknown Core: dti1 reflection err
DTI
Unknown
ANTs
​
​
dti1.reflection.err
DTI1_EVR
Unknown Core: dti1
DTI
Explained Variance Ratio
ANTs
​
​
dti1.evr
DTI1_msk_vol
Unknown Core: dti1 msk
DTI
geometry.volume
ANTs
​
​
dti1.msk.vol
DTI1_spc0
Unknown Core: dti1 spc0
DTI
Unknown
ANTs
​
​
dti1.spc0
DTI1_spc1
Unknown Core: dti1 spc1
DTI
Unknown
ANTs
​
​
dti1.spc1
DTI1_spc2
Unknown Core: dti1 spc2
DTI
Unknown
ANTs
​
​
dti1.spc2
DTI1_org0
Unknown Core: dti1 org0
DTI
Unknown
ANTs
​
​
dti1.org0
DTI1_org1
Unknown Core: dti1 org1
DTI
Unknown
ANTs
​
​
dti1.org1
DTI1_org2
Unknown Core: dti1 org2
DTI
Unknown
ANTs
​
​
dti1.org2
DTI1_dimx
Unknown Core: dti1 dimx
DTI
Unknown
ANTs
​
​
dti1.dimx
DTI1_dimy
Unknown Core: dti1 dimy
DTI
Unknown
ANTs
​
​
dti1.dimy
DTI1_dimz
Unknown Core: dti1 dimz
DTI
Unknown
ANTs
​
​
dti1.dimz
DTI1_dimt
Unknown Core: dti1 dimt
DTI
Unknown
ANTs
​
​
dti1.dimt
DTI1_slice
Unknown Core: dti1 slice
DTI
slice number in time series (ignore)
ANTs
​
​
dti1.slice
DTI1_modality
Unknown Core: dti1 modality
DTI
Unknown
ANTs
​
​
dti1.modality
DTI1_mriseries
Unknown Core: dti1 mriseries
DTI
Unknown
ANTs
​
​
dti1.mriseries
DTI1_mriSAR
Unknown Core: dti1 mrisar
DTI
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
dti1.mrisar
DTI1_mriPixelBandwidth
Unknown Core: dti1 mripixelbandwidth
DTI
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
dti1.mripixelbandwidth
DTI1_mriPixelBandwidthPE
Unknown Core: dti1 mripixelbandwidthpe
DTI
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
dti1.mripixelbandwidthpe
DTI1_dti_bvalueMax
Unknown Core: 1 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti1.dti.bvaluemax
DTI1_dti_bvecnorm
Unknown Core: 1 dti bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
dti1.dti.bvecnorm
DTI1_ol_loop
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.ol.loop
DTI1_ol_lof
Unknown Core: dti1
DTI
QC
ANTs
​
​
dti1.ol.lof
DTI1_ol_lof_decision
Unknown Core: dti1 decision
DTI
QC
ANTs
​
​
dti1.ol.lof.decision
dtid1
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
dtid1
DTI1_negol
Negative Outlier
DTI
Unknown
ANTs
​
​
dti1.negol
DTI1_score_ol_loop
Unknown Core: dti1 ol loop
DTI
QC
ANTs
​
​
dti1.score.ol.loop
DTI1_score_noise
Unknown Core: dti1 noise
DTI
QC
ANTs
​
​
dti1.score.noise
DTI1_score_dti_bvalueMax
Unknown Core: 1 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti1.score.dti.bvaluemax
DTI1_score_dimt
Unknown Core: dti1 dimt
DTI
Score
ANTs
​
​
dti1.score.dimt
DTI1_best_score
Unknown Core: dti1 best
DTI
Score
ANTs
​
​
dti1.best.score
dtfn2
​
​
original source data filename
ANTs
​
​
dtfn2
DTI2_dimensionality
Unknown Core: dti2 dimensionality
DTI
Unknown
ANTs
​
​
dti2.dimensionality
DTI2_noise
Unknown Core: dti2 noise
DTI
QC
ANTs
​
​
dti2.noise
DTI2_snr
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.snr
DTI2_cnr
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.cnr
DTI2_psnr
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.psnr
DTI2_ssim
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.ssim
DTI2_mi
Unknown Core: dti2
DTI
Mutual Information
ANTs
​
​
dti2.mi
DTI2_reflection_err
Unknown Core: dti2 reflection err
DTI
Unknown
ANTs
​
​
dti2.reflection.err
DTI2_EVR
Unknown Core: dti2
DTI
Explained Variance Ratio
ANTs
​
​
dti2.evr
DTI2_msk_vol
Unknown Core: dti2 msk
DTI
geometry.volume
ANTs
​
​
dti2.msk.vol
DTI2_spc0
Unknown Core: dti2 spc0
DTI
Unknown
ANTs
​
​
dti2.spc0
DTI2_spc1
Unknown Core: dti2 spc1
DTI
Unknown
ANTs
​
​
dti2.spc1
DTI2_spc2
Unknown Core: dti2 spc2
DTI
Unknown
ANTs
​
​
dti2.spc2
DTI2_org0
Unknown Core: dti2 org0
DTI
Unknown
ANTs
​
​
dti2.org0
DTI2_org1
Unknown Core: dti2 org1
DTI
Unknown
ANTs
​
​
dti2.org1
DTI2_org2
Unknown Core: dti2 org2
DTI
Unknown
ANTs
​
​
dti2.org2
DTI2_dimx
Unknown Core: dti2 dimx
DTI
Unknown
ANTs
​
​
dti2.dimx
DTI2_dimy
Unknown Core: dti2 dimy
DTI
Unknown
ANTs
​
​
dti2.dimy
DTI2_dimz
Unknown Core: dti2 dimz
DTI
Unknown
ANTs
​
​
dti2.dimz
DTI2_dimt
Unknown Core: dti2 dimt
DTI
Unknown
ANTs
​
​
dti2.dimt
DTI2_slice
Unknown Core: dti2 slice
DTI
slice number in time series (ignore)
ANTs
​
​
dti2.slice
DTI2_modality
Unknown Core: dti2 modality
DTI
Unknown
ANTs
​
​
dti2.modality
DTI2_mriseries
Unknown Core: dti2 mriseries
DTI
Unknown
ANTs
​
​
dti2.mriseries
DTI2_mriSAR
Unknown Core: dti2 mrisar
DTI
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
dti2.mrisar
DTI2_mriPixelBandwidth
Unknown Core: dti2 mripixelbandwidth
DTI
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
dti2.mripixelbandwidth
DTI2_mriPixelBandwidthPE
Unknown Core: dti2 mripixelbandwidthpe
DTI
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
dti2.mripixelbandwidthpe
DTI2_dti_bvalueMax
Unknown Core: 2 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti2.dti.bvaluemax
DTI2_dti_bvecnorm
Unknown Core: 2 dti bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
dti2.dti.bvecnorm
DTI2_ol_loop
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.ol.loop
DTI2_ol_lof
Unknown Core: dti2
DTI
QC
ANTs
​
​
dti2.ol.lof
DTI2_ol_lof_decision
Unknown Core: dti2 decision
DTI
QC
ANTs
​
​
dti2.ol.lof.decision
dtid2
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
dtid2
DTI2_negol
Negative Outlier
DTI
Unknown
ANTs
​
​
dti2.negol
DTI2_score_ol_loop
Unknown Core: dti2 ol loop
DTI
QC
ANTs
​
​
dti2.score.ol.loop
DTI2_score_noise
Unknown Core: dti2 noise
DTI
QC
ANTs
​
​
dti2.score.noise
DTI2_score_dti_bvalueMax
Unknown Core: 2 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti2.score.dti.bvaluemax
DTI2_score_dimt
Unknown Core: dti2 dimt
DTI
Score
ANTs
​
​
dti2.score.dimt
DTI2_best_score
Unknown Core: dti2 best
DTI
Score
ANTs
​
​
dti2.best.score
dtfn3
Filename
DTI
original source data filename
ANTs
​
​
dtfn3
DTI3_dimensionality
Unknown Core: dti3 dimensionality
DTI
Unknown
ANTs
​
​
dti3.dimensionality
DTI3_noise
Unknown Core: dti3 noise
DTI
QC
ANTs
​
​
dti3.noise
DTI3_snr
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.snr
DTI3_cnr
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.cnr
DTI3_psnr
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.psnr
DTI3_ssim
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.ssim
DTI3_mi
Unknown Core: dti3
DTI
Mutual Information
ANTs
​
​
dti3.mi
DTI3_reflection_err
Unknown Core: dti3 reflection err
DTI
Unknown
ANTs
​
​
dti3.reflection.err
DTI3_EVR
Unknown Core: dti3
DTI
Explained Variance Ratio
ANTs
​
​
dti3.evr
DTI3_msk_vol
Unknown Core: dti3 msk
DTI
geometry.volume
ANTs
​
​
dti3.msk.vol
DTI3_spc0
Unknown Core: dti3 spc0
DTI
Unknown
ANTs
​
​
dti3.spc0
DTI3_spc1
Unknown Core: dti3 spc1
DTI
Unknown
ANTs
​
​
dti3.spc1
DTI3_spc2
Unknown Core: dti3 spc2
DTI
Unknown
ANTs
​
​
dti3.spc2
DTI3_org0
Unknown Core: dti3 org0
DTI
Unknown
ANTs
​
​
dti3.org0
DTI3_org1
Unknown Core: dti3 org1
DTI
Unknown
ANTs
​
​
dti3.org1
DTI3_org2
Unknown Core: dti3 org2
DTI
Unknown
ANTs
​
​
dti3.org2
DTI3_dimx
Unknown Core: dti3 dimx
DTI
Unknown
ANTs
​
​
dti3.dimx
DTI3_dimy
Unknown Core: dti3 dimy
DTI
Unknown
ANTs
​
​
dti3.dimy
DTI3_dimz
Unknown Core: dti3 dimz
DTI
Unknown
ANTs
​
​
dti3.dimz
DTI3_dimt
Unknown Core: dti3 dimt
DTI
Unknown
ANTs
​
​
dti3.dimt
DTI3_slice
Unknown Core: dti3 slice
DTI
slice number in time series (ignore)
ANTs
​
​
dti3.slice
DTI3_modality
Unknown Core: dti3 modality
DTI
Unknown
ANTs
​
​
dti3.modality
DTI3_mriseries
Unknown Core: dti3 mriseries
DTI
Unknown
ANTs
​
​
dti3.mriseries
DTI3_mriSAR
Unknown Core: dti3 mrisar
DTI
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
dti3.mrisar
DTI3_mriPixelBandwidth
Unknown Core: dti3 mripixelbandwidth
DTI
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
dti3.mripixelbandwidth
DTI3_mriPixelBandwidthPE
Unknown Core: dti3 mripixelbandwidthpe
DTI
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
dti3.mripixelbandwidthpe
DTI3_dti_bvalueMax
Unknown Core: 3 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti3.dti.bvaluemax
DTI3_dti_bvecnorm
Unknown Core: 3 dti bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
dti3.dti.bvecnorm
DTI3_ol_loop
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.ol.loop
DTI3_ol_lof
Unknown Core: dti3
DTI
QC
ANTs
​
​
dti3.ol.lof
DTI3_ol_lof_decision
Unknown Core: dti3 decision
DTI
QC
ANTs
​
​
dti3.ol.lof.decision
dtid3
Image ID
DTI
Unknown
ANTs
​
​
dtid3
DTI3_negol
Negative Outlier
DTI
Unknown
ANTs
​
​
dti3.negol
DTI3_score_ol_loop
Unknown Core: dti3 ol loop
DTI
QC
ANTs
​
​
dti3.score.ol.loop
DTI3_score_noise
Unknown Core: dti3 noise
DTI
QC
ANTs
​
​
dti3.score.noise
DTI3_score_dti_bvalueMax
Unknown Core: 3 dti bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
dti3.score.dti.bvaluemax
DTI3_score_dimt
Unknown Core: dti3 dimt
DTI
Score
ANTs
​
​
dti3.score.dimt
DTI3_best_score
Unknown Core: dti3 best
DTI
Score
ANTs
​
​
dti3.best.score
rsffn1
​
​
original source data filename
ANTs
​
​
rsffn1
rsf1_dimensionality
Unknown Core: rsf1 dimensionality
Unknown
Unknown
ANTs
​
​
rsf1.dimensionality
rsf1_noise
Unknown Core: rsf1 noise
Unknown
QC
ANTs
​
​
rsf1.noise
rsf1_snr
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.snr
rsf1_cnr
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.cnr
rsf1_psnr
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.psnr
rsf1_ssim
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.ssim
rsf1_mi
Unknown Core: rsf1
Unknown
Mutual Information
ANTs
​
​
rsf1.mi
rsf1_reflection_err
Unknown Core: rsf1 reflection err
Unknown
Unknown
ANTs
​
​
rsf1.reflection.err
rsf1_EVR
Unknown Core: rsf1
Unknown
Explained Variance Ratio
ANTs
​
​
rsf1.evr
rsf1_msk_vol
Unknown Core: rsf1 msk
Unknown
geometry.volume
ANTs
​
​
rsf1.msk.vol
rsf1_spc0
Unknown Core: rsf1 spc0
Unknown
Unknown
ANTs
​
​
rsf1.spc0
rsf1_spc1
Unknown Core: rsf1 spc1
Unknown
Unknown
ANTs
​
​
rsf1.spc1
rsf1_spc2
Unknown Core: rsf1 spc2
Unknown
Unknown
ANTs
​
​
rsf1.spc2
rsf1_org0
Unknown Core: rsf1 org0
Unknown
Unknown
ANTs
​
​
rsf1.org0
rsf1_org1
Unknown Core: rsf1 org1
Unknown
Unknown
ANTs
​
​
rsf1.org1
rsf1_org2
Unknown Core: rsf1 org2
Unknown
Unknown
ANTs
​
​
rsf1.org2
rsf1_dimx
Unknown Core: rsf1 dimx
Unknown
Unknown
ANTs
​
​
rsf1.dimx
rsf1_dimy
Unknown Core: rsf1 dimy
Unknown
Unknown
ANTs
​
​
rsf1.dimy
rsf1_dimz
Unknown Core: rsf1 dimz
Unknown
Unknown
ANTs
​
​
rsf1.dimz
rsf1_dimt
Unknown Core: rsf1 dimt
Unknown
Unknown
ANTs
​
​
rsf1.dimt
rsf1_slice
Unknown Core: rsf1 slice
Unknown
slice number in time series (ignore)
ANTs
​
​
rsf1.slice
rsf1_modality
Unknown Core: rsf1 modality
Unknown
Unknown
ANTs
​
​
rsf1.modality
rsf1_mriseries
Unknown Core: rsf1 mriseries
Unknown
Unknown
ANTs
​
​
rsf1.mriseries
rsf1_mriSAR
Unknown Core: rsf1 mrisar
Unknown
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
rsf1.mrisar
rsf1_mriPixelBandwidth
Unknown Core: rsf1 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
rsf1.mripixelbandwidth
rsf1_mriPixelBandwidthPE
Unknown Core: rsf1 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
rsf1.mripixelbandwidthpe
rsf1_dti_bvalueMax
Unknown Core: rsf1 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf1.dti.bvaluemax
rsf1_dti_bvecnorm
Unknown Core: rsf1 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
rsf1.dti.bvecnorm
rsf1_ol_loop
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.ol.loop
rsf1_ol_lof
Unknown Core: rsf1
Unknown
QC
ANTs
​
​
rsf1.ol.lof
rsf1_ol_lof_decision
Unknown Core: rsf1 decision
Unknown
QC
ANTs
​
​
rsf1.ol.lof.decision
rsfid1
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
rsfid1
rsf1_negol
Negative Outlier
Unknown
Unknown
ANTs
​
​
rsf1.negol
rsf1_score_ol_loop
Unknown Core: rsf1 ol loop
Unknown
QC
ANTs
​
​
rsf1.score.ol.loop
rsf1_score_noise
Unknown Core: rsf1 noise
Unknown
QC
ANTs
​
​
rsf1.score.noise
rsf1_score_dti_bvalueMax
Unknown Core: rsf1 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf1.score.dti.bvaluemax
rsf1_score_dimt
Unknown Core: rsf1 dimt
Unknown
Score
ANTs
​
​
rsf1.score.dimt
rsf1_best_score
Unknown Core: rsf1 best
Unknown
Score
ANTs
​
​
rsf1.best.score
rsffn2
​
​
original source data filename
ANTs
​
​
rsffn2
rsf2_dimensionality
Unknown Core: rsf2 dimensionality
Unknown
Unknown
ANTs
​
​
rsf2.dimensionality
rsf2_noise
Unknown Core: rsf2 noise
Unknown
QC
ANTs
​
​
rsf2.noise
rsf2_snr
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.snr
rsf2_cnr
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.cnr
rsf2_psnr
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.psnr
rsf2_ssim
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.ssim
rsf2_mi
Unknown Core: rsf2
Unknown
Mutual Information
ANTs
​
​
rsf2.mi
rsf2_reflection_err
Unknown Core: rsf2 reflection err
Unknown
Unknown
ANTs
​
​
rsf2.reflection.err
rsf2_EVR
Unknown Core: rsf2
Unknown
Explained Variance Ratio
ANTs
​
​
rsf2.evr
rsf2_msk_vol
Unknown Core: rsf2 msk
Unknown
geometry.volume
ANTs
​
​
rsf2.msk.vol
rsf2_spc0
Unknown Core: rsf2 spc0
Unknown
Unknown
ANTs
​
​
rsf2.spc0
rsf2_spc1
Unknown Core: rsf2 spc1
Unknown
Unknown
ANTs
​
​
rsf2.spc1
rsf2_spc2
Unknown Core: rsf2 spc2
Unknown
Unknown
ANTs
​
​
rsf2.spc2
rsf2_org0
Unknown Core: rsf2 org0
Unknown
Unknown
ANTs
​
​
rsf2.org0
rsf2_org1
Unknown Core: rsf2 org1
Unknown
Unknown
ANTs
​
​
rsf2.org1
rsf2_org2
Unknown Core: rsf2 org2
Unknown
Unknown
ANTs
​
​
rsf2.org2
rsf2_dimx
Unknown Core: rsf2 dimx
Unknown
Unknown
ANTs
​
​
rsf2.dimx
rsf2_dimy
Unknown Core: rsf2 dimy
Unknown
Unknown
ANTs
​
​
rsf2.dimy
rsf2_dimz
Unknown Core: rsf2 dimz
Unknown
Unknown
ANTs
​
​
rsf2.dimz
rsf2_dimt
Unknown Core: rsf2 dimt
Unknown
Unknown
ANTs
​
​
rsf2.dimt
rsf2_slice
Unknown Core: rsf2 slice
Unknown
slice number in time series (ignore)
ANTs
​
​
rsf2.slice
rsf2_modality
Unknown Core: rsf2 modality
Unknown
Unknown
ANTs
​
​
rsf2.modality
rsf2_mriseries
Unknown Core: rsf2 mriseries
Unknown
Unknown
ANTs
​
​
rsf2.mriseries
rsf2_mriSAR
Unknown Core: rsf2 mrisar
Unknown
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
rsf2.mrisar
rsf2_mriPixelBandwidth
Unknown Core: rsf2 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
rsf2.mripixelbandwidth
rsf2_mriPixelBandwidthPE
Unknown Core: rsf2 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
rsf2.mripixelbandwidthpe
rsf2_dti_bvalueMax
Unknown Core: rsf2 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf2.dti.bvaluemax
rsf2_dti_bvecnorm
Unknown Core: rsf2 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
rsf2.dti.bvecnorm
rsf2_ol_loop
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.ol.loop
rsf2_ol_lof
Unknown Core: rsf2
Unknown
QC
ANTs
​
​
rsf2.ol.lof
rsf2_ol_lof_decision
Unknown Core: rsf2 decision
Unknown
QC
ANTs
​
​
rsf2.ol.lof.decision
rsfid2
​
​
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
ANTs
​
​
rsfid2
rsf2_negol
Negative Outlier
Unknown
Unknown
ANTs
​
​
rsf2.negol
rsf2_score_ol_loop
Unknown Core: rsf2 ol loop
Unknown
QC
ANTs
​
​
rsf2.score.ol.loop
rsf2_score_noise
Unknown Core: rsf2 noise
Unknown
QC
ANTs
​
​
rsf2.score.noise
rsf2_score_dti_bvalueMax
Unknown Core: rsf2 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf2.score.dti.bvaluemax
rsf2_score_dimt
Unknown Core: rsf2 dimt
Unknown
Score
ANTs
​
​
rsf2.score.dimt
rsf2_best_score
Unknown Core: rsf2 best
Unknown
Score
ANTs
​
​
rsf2.best.score
rsf3_filename
Filename
Unknown
Unknown
ANTs
​
​
rsf3.filename
rsf3_dimensionality
Unknown Core: rsf3 dimensionality
Unknown
Unknown
ANTs
​
​
rsf3.dimensionality
rsf3_noise
Unknown Core: rsf3 noise
Unknown
QC
ANTs
​
​
rsf3.noise
rsf3_snr
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.snr
rsf3_cnr
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.cnr
rsf3_psnr
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.psnr
rsf3_ssim
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.ssim
rsf3_mi
Unknown Core: rsf3
Unknown
Mutual Information
ANTs
​
​
rsf3.mi
rsf3_reflection_err
Unknown Core: rsf3 reflection err
Unknown
Unknown
ANTs
​
​
rsf3.reflection.err
rsf3_EVR
Unknown Core: rsf3
Unknown
Explained Variance Ratio
ANTs
​
​
rsf3.evr
rsf3_msk_vol
Unknown Core: rsf3 msk
Unknown
geometry.volume
ANTs
​
​
rsf3.msk.vol
rsf3_spc0
Unknown Core: rsf3 spc0
Unknown
Unknown
ANTs
​
​
rsf3.spc0
rsf3_spc1
Unknown Core: rsf3 spc1
Unknown
Unknown
ANTs
​
​
rsf3.spc1
rsf3_spc2
Unknown Core: rsf3 spc2
Unknown
Unknown
ANTs
​
​
rsf3.spc2
rsf3_org0
Unknown Core: rsf3 org0
Unknown
Unknown
ANTs
​
​
rsf3.org0
rsf3_org1
Unknown Core: rsf3 org1
Unknown
Unknown
ANTs
​
​
rsf3.org1
rsf3_org2
Unknown Core: rsf3 org2
Unknown
Unknown
ANTs
​
​
rsf3.org2
rsf3_dimx
Unknown Core: rsf3 dimx
Unknown
Unknown
ANTs
​
​
rsf3.dimx
rsf3_dimy
Unknown Core: rsf3 dimy
Unknown
Unknown
ANTs
​
​
rsf3.dimy
rsf3_dimz
Unknown Core: rsf3 dimz
Unknown
Unknown
ANTs
​
​
rsf3.dimz
rsf3_dimt
Unknown Core: rsf3 dimt
Unknown
Unknown
ANTs
​
​
rsf3.dimt
rsf3_slice
Unknown Core: rsf3 slice
Unknown
slice number in time series (ignore)
ANTs
​
​
rsf3.slice
rsf3_modality
Unknown Core: rsf3 modality
Unknown
Unknown
ANTs
​
​
rsf3.modality
rsf3_mriseries
Unknown Core: rsf3 mriseries
Unknown
Unknown
ANTs
​
​
rsf3.mriseries
rsf3_mriSAR
Unknown Core: rsf3 mrisar
Unknown
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
ANTs
​
​
rsf3.mrisar
rsf3_mriPixelBandwidth
Unknown Core: rsf3 mripixelbandwidth
Unknown
MRI range of frequencies encoded in each pixel of an image (often missing)
ANTs
​
​
rsf3.mripixelbandwidth
rsf3_mriPixelBandwidthPE
Unknown Core: rsf3 mripixelbandwidthpe
Unknown
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
ANTs
​
​
rsf3.mripixelbandwidthpe
rsf3_dti_bvalueMax
Unknown Core: rsf3 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf3.dti.bvaluemax
rsf3_dti_bvecnorm
Unknown Core: rsf3 bvecnorm
DTI
MRI DTI bvec norm (usually close to 1, often missing)
ANTs
​
​
rsf3.dti.bvecnorm
rsf3_ol_loop
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.ol.loop
rsf3_ol_lof
Unknown Core: rsf3
Unknown
QC
ANTs
​
​
rsf3.ol.lof
rsf3_ol_lof_decision
Unknown Core: rsf3 decision
Unknown
QC
ANTs
​
​
rsf3.ol.lof.decision
rsf3_imageID
Image ID
Unknown
Unknown
ANTs
​
​
rsf3.imageid
rsf3_negol
Negative Outlier
Unknown
Unknown
ANTs
​
​
rsf3.negol
rsf3_score_ol_loop
Unknown Core: rsf3 ol loop
Unknown
QC
ANTs
​
​
rsf3.score.ol.loop
rsf3_score_noise
Unknown Core: rsf3 noise
Unknown
QC
ANTs
​
​
rsf3.score.noise
rsf3_score_dti_bvalueMax
Unknown Core: rsf3 bvaluemax
DTI
MRI DTI maximum bvalue (often missing)
ANTs
​
​
rsf3.score.dti.bvaluemax
rsf3_score_dimt
Unknown Core: rsf3 dimt
Unknown
Score
ANTs
​
​
rsf3.score.dimt
rsf3_best_score
Unknown Core: rsf3 best
Unknown
Score
ANTs
​
​
rsf3.best.score
projectID
​
​
project ID or name eg ADNI
ANTs
​
​
projectid
perfid
Image ID
Unknown
Unknown
ANTs
​
​
perfid
T1Hier_u_hier_id
unique id
unique id
unique id
unique id
​
​
t1.u.hier.id
T1Hier_u_hier_id.1
unique id
unique id
unique id
unique id
​
​
t1.u.hier.id.1
T1Hier_vol_hemisphere_lefthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.hemisphere.lefthemispheres
T1Hier_vol_hemisphere_righthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.hemisphere.righthemispheres
T1Hier_area_hemisphere_lefthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.hemisphere.lefthemispheres
T1Hier_area_hemisphere_righthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.hemisphere.righthemispheres
T1Hier_thk_hemisphere_lefthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.hemisphere.lefthemispheres
T1Hier_thk_hemisphere_righthemispheres
Cerebral Hemisphere
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.hemisphere.righthemispheres
T1Hier_vol_brainstemtissues
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bsttissues
T1Hier_vol_csftissues
Cerebrospinal Fluid
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.csftissues
T1Hier_vol_cerebellumtissues
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.cerebellumtissues
T1Hier_vol_deepgraytissues
Unknown Core: hier deepgray tissues
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.deepgraytissues
T1Hier_vol_gmtissues
Unknown Core: hier gm tissues
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.gmtissues
T1Hier_vol_wmtissues
Unknown Core: hier wm tissues
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.wmtissues
T1Hier_area_brainstemtissues
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bsttissues
T1Hier_area_csftissues
Cerebrospinal Fluid
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.csftissues
T1Hier_area_cerebellumtissues
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.cerebellumtissues
T1Hier_area_deepgraytissues
Unknown Core: hier deepgray tissues
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.deepgraytissues
T1Hier_area_gmtissues
Unknown Core: hier gm tissues
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.gmtissues
T1Hier_area_wmtissues
Unknown Core: hier wm tissues
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.wmtissues
T1Hier_thk_brainstemtissues
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bsttissues
T1Hier_thk_csftissues
Cerebrospinal Fluid
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.csftissues
T1Hier_thk_cerebellumtissues
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.cerebellumtissues
T1Hier_thk_deepgraytissues
Unknown Core: hier deepgray tissues
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.deepgraytissues
T1Hier_thk_gmtissues
Unknown Core: hier gm tissues
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.gmtissues
T1Hier_thk_wmtissues
Unknown Core: hier wm tissues
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.wmtissues
T1Hier_vol_brainstem_ldktlobes
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bst.ldktlobes
T1Hier_vol_brainstem_rdktlobes
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bst.rdktlobes
T1Hier_vol_cerebellum_ldktlobes
Cerebellum
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cerebellum.ldktlobes
T1Hier_vol_cerebellum_rdktlobes
Cerebellum
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cerebellum.rdktlobes
T1Hier_vol_frontal_ldktlobes
Frontal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.frontal.ldktlobes
T1Hier_vol_frontal_rdktlobes
Frontal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.frontal.rdktlobes
T1Hier_vol_occipital_ldktlobes
Occipital Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.occipital.ldktlobes
T1Hier_vol_occipital_rdktlobes
Occipital Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.occipital.rdktlobes
T1Hier_vol_parietal_ldktlobes
Parietal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.parietal.ldktlobes
T1Hier_vol_parietal_rdktlobes
Parietal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.parietal.rdktlobes
T1Hier_vol_temporal_ldktlobes
Temporal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.temporal.ldktlobes
T1Hier_vol_temporal_rdktlobes
Temporal Lobe
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.temporal.rdktlobes
T1Hier_area_brainstem_ldktlobes
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bst.ldktlobes
T1Hier_area_brainstem_rdktlobes
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bst.rdktlobes
T1Hier_area_cerebellum_ldktlobes
Cerebellum
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.cerebellum.ldktlobes
T1Hier_area_cerebellum_rdktlobes
Cerebellum
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.cerebellum.rdktlobes
T1Hier_area_frontal_ldktlobes
Frontal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.frontal.ldktlobes
T1Hier_area_frontal_rdktlobes
Frontal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.frontal.rdktlobes
T1Hier_area_occipital_ldktlobes
Occipital Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.occipital.ldktlobes
T1Hier_area_occipital_rdktlobes
Occipital Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.occipital.rdktlobes
T1Hier_area_parietal_ldktlobes
Parietal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.parietal.ldktlobes
T1Hier_area_parietal_rdktlobes
Parietal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.parietal.rdktlobes
T1Hier_area_temporal_ldktlobes
Temporal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.temporal.ldktlobes
T1Hier_area_temporal_rdktlobes
Temporal Lobe
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.temporal.rdktlobes
T1Hier_thk_brainstem_ldktlobes
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bst.ldktlobes
T1Hier_thk_brainstem_rdktlobes
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bst.rdktlobes
T1Hier_thk_cerebellum_ldktlobes
Cerebellum
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cerebellum.ldktlobes
T1Hier_thk_cerebellum_rdktlobes
Cerebellum
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cerebellum.rdktlobes
T1Hier_thk_frontal_ldktlobes
Frontal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.frontal.ldktlobes
T1Hier_thk_frontal_rdktlobes
Frontal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.frontal.rdktlobes
T1Hier_thk_occipital_ldktlobes
Occipital Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.occipital.ldktlobes
T1Hier_thk_occipital_rdktlobes
Occipital Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.occipital.rdktlobes
T1Hier_thk_parietal_ldktlobes
Parietal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.parietal.ldktlobes
T1Hier_thk_parietal_rdktlobes
Parietal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.parietal.rdktlobes
T1Hier_thk_temporal_ldktlobes
Temporal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.temporal.ldktlobes
T1Hier_thk_temporal_rdktlobes
Temporal Lobe
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.temporal.rdktlobes
T1Hier_vol_4th_ventricledktregions
4th Ventricle
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.4th.ventricledktregions
T1Hier_vol_csfdktregions
Cerebrospinal Fluid
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.csfdktregions
T1Hier_vol_brain_stemdktregions
Unknown Core: hier brain stem dktregions
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.brain.stemdktregions
T1Hier_vol_cerebellar_vermal_lobules_i.vdktregions
Cerebellar Vermal Lobules I-V
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cerebellar.vermal.lobules.i.vdktregions
T1Hier_vol_cerebellar_vermal_lobules_vi.viidktregions
Cerebellar Vermal Lobules VI-VII
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_vol_cerebellar_vermal_lobules_viii.xdktregions
Cerebellar Vermal Lobules VIII-X
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_vol_left_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.amygdaladktregions
T1Hier_vol_left_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.caudal.ant.cingulatedktregions
T1Hier_vol_left_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.caudal.middle.frontaldktregions
T1Hier_vol_left_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.caudatedktregions
T1Hier_vol_left_cerebellem_exteriordktregions
Unknown Core: hier cerebellem exterior dktregions
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.cerebellem.exteriordktregions
T1Hier_vol_left_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.cerebellum.white.matterdktregions
T1Hier_vol_left_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.cuneusdktregions
T1Hier_vol_left_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.entorhinaldktregions
T1Hier_vol_left_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.fusiformdktregions
T1Hier_vol_left_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.hippocampusdktregions
T1Hier_vol_left_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.inf.parietaldktregions
T1Hier_vol_left_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.inf.temporaldktregions
T1Hier_vol_left_insuladktregions
Insula
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.insuladktregions
T1Hier_vol_left_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.isthmus.cingulatedktregions
T1Hier_vol_left_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lateral.occipitaldktregions
T1Hier_vol_left_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lateral.orbitofrontaldktregions
T1Hier_vol_left_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lateral.ventricledktregions
T1Hier_vol_left_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lingualdktregions
T1Hier_vol_left_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.medial.orbitofrontaldktregions
T1Hier_vol_left_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.middle.temporaldktregions
T1Hier_vol_left_pallidiumdktregions
Pallidum
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pallidiumdktregions
T1Hier_vol_left_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.paracentdktregions
T1Hier_vol_left_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.parahippocampaldktregions
T1Hier_vol_left_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.opercularisdktregions
T1Hier_vol_left_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.orbitalisdktregions
T1Hier_vol_left_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.triangularisdktregions
T1Hier_vol_left_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pericalcarinedktregions
T1Hier_vol_left_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.postcentdktregions
T1Hier_vol_left_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.post.cingulatedktregions
T1Hier_vol_left_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.precentdktregions
T1Hier_vol_left_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.precuneusdktregions
T1Hier_vol_left_putamendktregions
Putamen
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.putamendktregions
T1Hier_vol_left_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.rostral.ant.cingulatedktregions
T1Hier_vol_left_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.rostral.middle.frontaldktregions
T1Hier_vol_left_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.frontaldktregions
T1Hier_vol_left_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.parietaldktregions
T1Hier_vol_left_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.temporaldktregions
T1Hier_vol_left_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.supramarginaldktregions
T1Hier_vol_left_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.thalamus.properdktregions
T1Hier_vol_left_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.transverse.temporaldktregions
T1Hier_vol_left_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.ventral.dcdktregions
T1Hier_vol_right_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.amygdaladktregions
T1Hier_vol_right_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.caudal.ant.cingulatedktregions
T1Hier_vol_right_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.caudal.middle.frontaldktregions
T1Hier_vol_right_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.caudatedktregions
T1Hier_vol_right_cerebellum_exteriordktregions
Cerebellum Exterior
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.cerebellum.exteriordktregions
T1Hier_vol_right_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.cerebellum.white.matterdktregions
T1Hier_vol_right_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.cuneusdktregions
T1Hier_vol_right_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.entorhinaldktregions
T1Hier_vol_right_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.fusiformdktregions
T1Hier_vol_right_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.hippocampusdktregions
T1Hier_vol_right_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.inf.parietaldktregions
T1Hier_vol_right_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.inf.temporaldktregions
T1Hier_vol_right_insuladktregions
Insula
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.insuladktregions
T1Hier_vol_right_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.isthmus.cingulatedktregions
T1Hier_vol_right_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lateral.occipitaldktregions
T1Hier_vol_right_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lateral.orbitofrontaldktregions
T1Hier_vol_right_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lateral.ventricledktregions
T1Hier_vol_right_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lingualdktregions
T1Hier_vol_right_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.medial.orbitofrontaldktregions
T1Hier_vol_right_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.middle.temporaldktregions
T1Hier_vol_right_palladiumdktregions
Unknown Core: hier palladium dktregions
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.palladiumdktregions
T1Hier_vol_right_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.paracentdktregions
T1Hier_vol_right_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.parahippocampaldktregions
T1Hier_vol_right_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.opercularisdktregions
T1Hier_vol_right_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.orbitalisdktregions
T1Hier_vol_right_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.triangularisdktregions
T1Hier_vol_right_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pericalcarinedktregions
T1Hier_vol_right_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.postcentdktregions
T1Hier_vol_right_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.post.cingulatedktregions
T1Hier_vol_right_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.precentdktregions
T1Hier_vol_right_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.precuneusdktregions
T1Hier_vol_right_putamendktregions
Putamen
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.putamendktregions
T1Hier_vol_right_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.rostral.ant.cingulatedktregions
T1Hier_vol_right_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.rostral.middle.frontaldktregions
T1Hier_vol_right_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.frontaldktregions
T1Hier_vol_right_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.parietaldktregions
T1Hier_vol_right_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.temporaldktregions
T1Hier_vol_right_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.supramarginaldktregions
T1Hier_vol_right_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.thalamus.properdktregions
T1Hier_vol_right_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.transverse.temporaldktregions
T1Hier_vol_right_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.ventral.dcdktregions
T1Hier_area_4th_ventricledktregions
4th Ventricle
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.4th.ventricledktregions
T1Hier_area_csfdktregions
Cerebrospinal Fluid
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.csfdktregions
T1Hier_area_brain_stemdktregions
Unknown Core: hier brain stem dktregions
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.brain.stemdktregions
T1Hier_area_cerebellar_vermal_lobules_i.vdktregions
Cerebellar Vermal Lobules I-V
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.cerebellar.vermal.lobules.i.vdktregions
T1Hier_area_cerebellar_vermal_lobules_vi.viidktregions
Cerebellar Vermal Lobules VI-VII
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_area_cerebellar_vermal_lobules_viii.xdktregions
Cerebellar Vermal Lobules VIII-X
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_area_left_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.amygdaladktregions
T1Hier_area_left_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.caudal.ant.cingulatedktregions
T1Hier_area_left_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.caudal.middle.frontaldktregions
T1Hier_area_left_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.caudatedktregions
T1Hier_area_left_cerebellem_exteriordktregions
Unknown Core: hier cerebellem exterior dktregions
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.cerebellem.exteriordktregions
T1Hier_area_left_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.cerebellum.white.matterdktregions
T1Hier_area_left_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.cuneusdktregions
T1Hier_area_left_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.entorhinaldktregions
T1Hier_area_left_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.fusiformdktregions
T1Hier_area_left_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.hippocampusdktregions
T1Hier_area_left_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.inf.parietaldktregions
T1Hier_area_left_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.inf.temporaldktregions
T1Hier_area_left_insuladktregions
Insula
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.insuladktregions
T1Hier_area_left_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.isthmus.cingulatedktregions
T1Hier_area_left_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lateral.occipitaldktregions
T1Hier_area_left_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lateral.orbitofrontaldktregions
T1Hier_area_left_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lateral.ventricledktregions
T1Hier_area_left_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lingualdktregions
T1Hier_area_left_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.medial.orbitofrontaldktregions
T1Hier_area_left_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.middle.temporaldktregions
T1Hier_area_left_pallidiumdktregions
Pallidum
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pallidiumdktregions
T1Hier_area_left_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.paracentdktregions
T1Hier_area_left_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.parahippocampaldktregions
T1Hier_area_left_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.opercularisdktregions
T1Hier_area_left_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.orbitalisdktregions
T1Hier_area_left_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.triangularisdktregions
T1Hier_area_left_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pericalcarinedktregions
T1Hier_area_left_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.postcentdktregions
T1Hier_area_left_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.post.cingulatedktregions
T1Hier_area_left_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.precentdktregions
T1Hier_area_left_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.precuneusdktregions
T1Hier_area_left_putamendktregions
Putamen
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.putamendktregions
T1Hier_area_left_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.rostral.ant.cingulatedktregions
T1Hier_area_left_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.rostral.middle.frontaldktregions
T1Hier_area_left_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.frontaldktregions
T1Hier_area_left_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.parietaldktregions
T1Hier_area_left_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.temporaldktregions
T1Hier_area_left_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.supramarginaldktregions
T1Hier_area_left_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.thalamus.properdktregions
T1Hier_area_left_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.transverse.temporaldktregions
T1Hier_area_left_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.ventral.dcdktregions
T1Hier_area_right_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.amygdaladktregions
T1Hier_area_right_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.caudal.ant.cingulatedktregions
T1Hier_area_right_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.caudal.middle.frontaldktregions
T1Hier_area_right_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.caudatedktregions
T1Hier_area_right_cerebellum_exteriordktregions
Cerebellum Exterior
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.cerebellum.exteriordktregions
T1Hier_area_right_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.cerebellum.white.matterdktregions
T1Hier_area_right_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.cuneusdktregions
T1Hier_area_right_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.entorhinaldktregions
T1Hier_area_right_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.fusiformdktregions
T1Hier_area_right_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.hippocampusdktregions
T1Hier_area_right_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.inf.parietaldktregions
T1Hier_area_right_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.inf.temporaldktregions
T1Hier_area_right_insuladktregions
Insula
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.insuladktregions
T1Hier_area_right_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.isthmus.cingulatedktregions
T1Hier_area_right_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lateral.occipitaldktregions
T1Hier_area_right_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lateral.orbitofrontaldktregions
T1Hier_area_right_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lateral.ventricledktregions
T1Hier_area_right_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lingualdktregions
T1Hier_area_right_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.medial.orbitofrontaldktregions
T1Hier_area_right_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.middle.temporaldktregions
T1Hier_area_right_palladiumdktregions
Unknown Core: hier palladium dktregions
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.palladiumdktregions
T1Hier_area_right_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.paracentdktregions
T1Hier_area_right_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.parahippocampaldktregions
T1Hier_area_right_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.opercularisdktregions
T1Hier_area_right_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.orbitalisdktregions
T1Hier_area_right_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.triangularisdktregions
T1Hier_area_right_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pericalcarinedktregions
T1Hier_area_right_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.postcentdktregions
T1Hier_area_right_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.post.cingulatedktregions
T1Hier_area_right_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.precentdktregions
T1Hier_area_right_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.precuneusdktregions
T1Hier_area_right_putamendktregions
Putamen
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.putamendktregions
T1Hier_area_right_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.rostral.ant.cingulatedktregions
T1Hier_area_right_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.rostral.middle.frontaldktregions
T1Hier_area_right_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.frontaldktregions
T1Hier_area_right_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.parietaldktregions
T1Hier_area_right_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.temporaldktregions
T1Hier_area_right_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.supramarginaldktregions
T1Hier_area_right_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.thalamus.properdktregions
T1Hier_area_right_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.transverse.temporaldktregions
T1Hier_area_right_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.ventral.dcdktregions
T1Hier_thk_4th_ventricledktregions
4th Ventricle
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.4th.ventricledktregions
T1Hier_thk_csfdktregions
Cerebrospinal Fluid
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.csfdktregions
T1Hier_thk_brain_stemdktregions
Unknown Core: hier brain stem dktregions
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.brain.stemdktregions
T1Hier_thk_cerebellar_vermal_lobules_i.vdktregions
Cerebellar Vermal Lobules I-V
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cerebellar.vermal.lobules.i.vdktregions
T1Hier_thk_cerebellar_vermal_lobules_vi.viidktregions
Cerebellar Vermal Lobules VI-VII
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_thk_cerebellar_vermal_lobules_viii.xdktregions
Cerebellar Vermal Lobules VIII-X
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_thk_left_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.amygdaladktregions
T1Hier_thk_left_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.caudal.ant.cingulatedktregions
T1Hier_thk_left_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.caudal.middle.frontaldktregions
T1Hier_thk_left_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.caudatedktregions
T1Hier_thk_left_cerebellem_exteriordktregions
Unknown Core: hier cerebellem exterior dktregions
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.cerebellem.exteriordktregions
T1Hier_thk_left_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.cerebellum.white.matterdktregions
T1Hier_thk_left_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.cuneusdktregions
T1Hier_thk_left_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.entorhinaldktregions
T1Hier_thk_left_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.fusiformdktregions
T1Hier_thk_left_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.hippocampusdktregions
T1Hier_thk_left_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.inf.parietaldktregions
T1Hier_thk_left_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.inf.temporaldktregions
T1Hier_thk_left_insuladktregions
Insula
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.insuladktregions
T1Hier_thk_left_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.isthmus.cingulatedktregions
T1Hier_thk_left_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lateral.occipitaldktregions
T1Hier_thk_left_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lateral.orbitofrontaldktregions
T1Hier_thk_left_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lateral.ventricledktregions
T1Hier_thk_left_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lingualdktregions
T1Hier_thk_left_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.medial.orbitofrontaldktregions
T1Hier_thk_left_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.middle.temporaldktregions
T1Hier_thk_left_pallidiumdktregions
Pallidum
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pallidiumdktregions
T1Hier_thk_left_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.paracentdktregions
T1Hier_thk_left_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.parahippocampaldktregions
T1Hier_thk_left_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.opercularisdktregions
T1Hier_thk_left_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.orbitalisdktregions
T1Hier_thk_left_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.triangularisdktregions
T1Hier_thk_left_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pericalcarinedktregions
T1Hier_thk_left_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.postcentdktregions
T1Hier_thk_left_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.post.cingulatedktregions
T1Hier_thk_left_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.precentdktregions
T1Hier_thk_left_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.precuneusdktregions
T1Hier_thk_left_putamendktregions
Putamen
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.putamendktregions
T1Hier_thk_left_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.rostral.ant.cingulatedktregions
T1Hier_thk_left_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.rostral.middle.frontaldktregions
T1Hier_thk_left_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.frontaldktregions
T1Hier_thk_left_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.parietaldktregions
T1Hier_thk_left_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.temporaldktregions
T1Hier_thk_left_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.supramarginaldktregions
T1Hier_thk_left_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.thalamus.properdktregions
T1Hier_thk_left_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.transverse.temporaldktregions
T1Hier_thk_left_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.ventral.dcdktregions
T1Hier_thk_right_amygdaladktregions
Amygdala
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.amygdaladktregions
T1Hier_thk_right_caudal_anterior_cingulatedktregions
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.caudal.ant.cingulatedktregions
T1Hier_thk_right_caudal_middle_frontaldktregions
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.caudal.middle.frontaldktregions
T1Hier_thk_right_caudatedktregions
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.caudatedktregions
T1Hier_thk_right_cerebellum_exteriordktregions
Cerebellum Exterior
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.cerebellum.exteriordktregions
T1Hier_thk_right_cerebellum_white_matterdktregions
Cerebellum White Matter
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.cerebellum.white.matterdktregions
T1Hier_thk_right_cuneusdktregions
Cuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.cuneusdktregions
T1Hier_thk_right_entorhinaldktregions
Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.entorhinaldktregions
T1Hier_thk_right_fusiformdktregions
Fusiform Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.fusiformdktregions
T1Hier_thk_right_hippocampusdktregions
Hippocampus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.hippocampusdktregions
T1Hier_thk_right_inferior_parietaldktregions
Inferior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.inf.parietaldktregions
T1Hier_thk_right_inferior_temporaldktregions
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.inf.temporaldktregions
T1Hier_thk_right_insuladktregions
Insula
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.insuladktregions
T1Hier_thk_right_isthmus_cingulatedktregions
Isthmus Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.isthmus.cingulatedktregions
T1Hier_thk_right_lateral_occipitaldktregions
Lateral Occipital Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lateral.occipitaldktregions
T1Hier_thk_right_lateral_orbitofrontaldktregions
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lateral.orbitofrontaldktregions
T1Hier_thk_right_lateral_ventricledktregions
Lateral Ventricle
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lateral.ventricledktregions
T1Hier_thk_right_lingualdktregions
Lingual Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lingualdktregions
T1Hier_thk_right_medial_orbitofrontaldktregions
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.medial.orbitofrontaldktregions
T1Hier_thk_right_middle_temporaldktregions
Middle Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.middle.temporaldktregions
T1Hier_thk_right_palladiumdktregions
Unknown Core: hier palladium dktregions
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.palladiumdktregions
T1Hier_thk_right_paracentraldktregions
Paracentral Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.paracentdktregions
T1Hier_thk_right_parahippocampaldktregions
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.parahippocampaldktregions
T1Hier_thk_right_pars_opercularisdktregions
Pars Opercularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.opercularisdktregions
T1Hier_thk_right_pars_orbitalisdktregions
Pars Orbitalis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.orbitalisdktregions
T1Hier_thk_right_pars_triangularisdktregions
Pars Triangularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.triangularisdktregions
T1Hier_thk_right_pericalcarinedktregions
Pericalcarine Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pericalcarinedktregions
T1Hier_thk_right_postcentraldktregions
Postcentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.postcentdktregions
T1Hier_thk_right_posterior_cingulatedktregions
Posterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.post.cingulatedktregions
T1Hier_thk_right_precentraldktregions
Precentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.precentdktregions
T1Hier_thk_right_precuneusdktregions
Precuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.precuneusdktregions
T1Hier_thk_right_putamendktregions
Putamen
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.putamendktregions
T1Hier_thk_right_rostral_anterior_cingulatedktregions
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.rostral.ant.cingulatedktregions
T1Hier_thk_right_rostral_middle_frontaldktregions
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.rostral.middle.frontaldktregions
T1Hier_thk_right_superior_frontaldktregions
Superior Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.frontaldktregions
T1Hier_thk_right_superior_parietaldktregions
Superior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.parietaldktregions
T1Hier_thk_right_superior_temporaldktregions
Superior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.temporaldktregions
T1Hier_thk_right_supramarginaldktregions
Supramarginal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.supramarginaldktregions
T1Hier_thk_right_thalamus_properdktregions
Thalamus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.thalamus.properdktregions
T1Hier_thk_right_transverse_temporaldktregions
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.transverse.temporaldktregions
T1Hier_thk_right_ventral_dcdktregions
Ventral Diencephalon
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.ventral.dcdktregions
T1Hier_vol_left_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.caudal.ant.cingulate.ctx
T1Hier_vol_left_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.caudal.middle.frontal.ctx
T1Hier_vol_left_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.cuneus.ctx
T1Hier_vol_left_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.entorhinal.ctx
T1Hier_vol_left_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.fusiform.ctx
T1Hier_vol_left_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.inf.parietal.ctx
T1Hier_vol_left_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.inf.temporal.ctx
T1Hier_vol_left_insuladktcortex
Insula
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.insula.ctx
T1Hier_vol_left_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.isthmus.cingulate.ctx
T1Hier_vol_left_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lateral.occipital.ctx
T1Hier_vol_left_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lateral.orbitofrontal.ctx
T1Hier_vol_left_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.lingual.ctx
T1Hier_vol_left_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.medial.orbitofrontal.ctx
T1Hier_vol_left_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.middle.temporal.ctx
T1Hier_vol_left_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.paracent.ctx
T1Hier_vol_left_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.parahippocampal.ctx
T1Hier_vol_left_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.opercularis.ctx
T1Hier_vol_left_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.orbitalis.ctx
T1Hier_vol_left_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pars.triangularis.ctx
T1Hier_vol_left_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.pericalcarine.ctx
T1Hier_vol_left_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.postcent.ctx
T1Hier_vol_left_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.post.cingulate.ctx
T1Hier_vol_left_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.precent.ctx
T1Hier_vol_left_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.precuneus.ctx
T1Hier_vol_left_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.rostral.ant.cingulate.ctx
T1Hier_vol_left_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.rostral.middle.frontal.ctx
T1Hier_vol_left_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.frontal.ctx
T1Hier_vol_left_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.parietal.ctx
T1Hier_vol_left_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.sup.temporal.ctx
T1Hier_vol_left_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.supramarginal.ctx
T1Hier_vol_left_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.left.transverse.temporal.ctx
T1Hier_vol_right_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.caudal.ant.cingulate.ctx
T1Hier_vol_right_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.caudal.middle.frontal.ctx
T1Hier_vol_right_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.cuneus.ctx
T1Hier_vol_right_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.entorhinal.ctx
T1Hier_vol_right_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.fusiform.ctx
T1Hier_vol_right_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.inf.parietal.ctx
T1Hier_vol_right_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.inf.temporal.ctx
T1Hier_vol_right_insuladktcortex
Insula
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.insula.ctx
T1Hier_vol_right_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.isthmus.cingulate.ctx
T1Hier_vol_right_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lateral.occipital.ctx
T1Hier_vol_right_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lateral.orbitofrontal.ctx
T1Hier_vol_right_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.lingual.ctx
T1Hier_vol_right_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.medial.orbitofrontal.ctx
T1Hier_vol_right_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.middle.temporal.ctx
T1Hier_vol_right_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.paracent.ctx
T1Hier_vol_right_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.parahippocampal.ctx
T1Hier_vol_right_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.opercularis.ctx
T1Hier_vol_right_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.orbitalis.ctx
T1Hier_vol_right_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pars.triangularis.ctx
T1Hier_vol_right_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.pericalcarine.ctx
T1Hier_vol_right_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.postcent.ctx
T1Hier_vol_right_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.post.cingulate.ctx
T1Hier_vol_right_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.precent.ctx
T1Hier_vol_right_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.precuneus.ctx
T1Hier_vol_right_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.rostral.ant.cingulate.ctx
T1Hier_vol_right_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.rostral.middle.frontal.ctx
T1Hier_vol_right_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.frontal.ctx
T1Hier_vol_right_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.parietal.ctx
T1Hier_vol_right_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.sup.temporal.ctx
T1Hier_vol_right_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.supramarginal.ctx
T1Hier_vol_right_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.right.transverse.temporal.ctx
T1Hier_area_left_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.caudal.ant.cingulate.ctx
T1Hier_area_left_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.caudal.middle.frontal.ctx
T1Hier_area_left_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.cuneus.ctx
T1Hier_area_left_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.entorhinal.ctx
T1Hier_area_left_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.fusiform.ctx
T1Hier_area_left_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.inf.parietal.ctx
T1Hier_area_left_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.inf.temporal.ctx
T1Hier_area_left_insuladktcortex
Insula
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.insula.ctx
T1Hier_area_left_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.isthmus.cingulate.ctx
T1Hier_area_left_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lateral.occipital.ctx
T1Hier_area_left_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lateral.orbitofrontal.ctx
T1Hier_area_left_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.lingual.ctx
T1Hier_area_left_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.medial.orbitofrontal.ctx
T1Hier_area_left_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.middle.temporal.ctx
T1Hier_area_left_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.paracent.ctx
T1Hier_area_left_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.parahippocampal.ctx
T1Hier_area_left_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.opercularis.ctx
T1Hier_area_left_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.orbitalis.ctx
T1Hier_area_left_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pars.triangularis.ctx
T1Hier_area_left_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.pericalcarine.ctx
T1Hier_area_left_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.postcent.ctx
T1Hier_area_left_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.post.cingulate.ctx
T1Hier_area_left_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.precent.ctx
T1Hier_area_left_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.precuneus.ctx
T1Hier_area_left_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.rostral.ant.cingulate.ctx
T1Hier_area_left_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.rostral.middle.frontal.ctx
T1Hier_area_left_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.frontal.ctx
T1Hier_area_left_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.parietal.ctx
T1Hier_area_left_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.sup.temporal.ctx
T1Hier_area_left_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.supramarginal.ctx
T1Hier_area_left_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.left.transverse.temporal.ctx
T1Hier_area_right_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.caudal.ant.cingulate.ctx
T1Hier_area_right_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.caudal.middle.frontal.ctx
T1Hier_area_right_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.cuneus.ctx
T1Hier_area_right_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.entorhinal.ctx
T1Hier_area_right_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.fusiform.ctx
T1Hier_area_right_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.inf.parietal.ctx
T1Hier_area_right_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.inf.temporal.ctx
T1Hier_area_right_insuladktcortex
Insula
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.insula.ctx
T1Hier_area_right_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.isthmus.cingulate.ctx
T1Hier_area_right_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lateral.occipital.ctx
T1Hier_area_right_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lateral.orbitofrontal.ctx
T1Hier_area_right_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.lingual.ctx
T1Hier_area_right_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.medial.orbitofrontal.ctx
T1Hier_area_right_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.middle.temporal.ctx
T1Hier_area_right_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.paracent.ctx
T1Hier_area_right_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.parahippocampal.ctx
T1Hier_area_right_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.opercularis.ctx
T1Hier_area_right_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.orbitalis.ctx
T1Hier_area_right_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pars.triangularis.ctx
T1Hier_area_right_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.pericalcarine.ctx
T1Hier_area_right_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.postcent.ctx
T1Hier_area_right_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.post.cingulate.ctx
T1Hier_area_right_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.precent.ctx
T1Hier_area_right_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.precuneus.ctx
T1Hier_area_right_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.rostral.ant.cingulate.ctx
T1Hier_area_right_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.rostral.middle.frontal.ctx
T1Hier_area_right_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.frontal.ctx
T1Hier_area_right_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.parietal.ctx
T1Hier_area_right_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.sup.temporal.ctx
T1Hier_area_right_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.supramarginal.ctx
T1Hier_area_right_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.area
desikan-killiany-tourville
​
​
t1.area.right.transverse.temporal.ctx
T1Hier_thk_left_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.caudal.ant.cingulate.ctx
T1Hier_thk_left_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.caudal.middle.frontal.ctx
T1Hier_thk_left_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.cuneus.ctx
T1Hier_thk_left_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.entorhinal.ctx
T1Hier_thk_left_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.fusiform.ctx
T1Hier_thk_left_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.inf.parietal.ctx
T1Hier_thk_left_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.inf.temporal.ctx
T1Hier_thk_left_insuladktcortex
Insula
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.insula.ctx
T1Hier_thk_left_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.isthmus.cingulate.ctx
T1Hier_thk_left_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lateral.occipital.ctx
T1Hier_thk_left_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lateral.orbitofrontal.ctx
T1Hier_thk_left_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.lingual.ctx
T1Hier_thk_left_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.medial.orbitofrontal.ctx
T1Hier_thk_left_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.middle.temporal.ctx
T1Hier_thk_left_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.paracent.ctx
T1Hier_thk_left_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.parahippocampal.ctx
T1Hier_thk_left_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.opercularis.ctx
T1Hier_thk_left_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.orbitalis.ctx
T1Hier_thk_left_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pars.triangularis.ctx
T1Hier_thk_left_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.pericalcarine.ctx
T1Hier_thk_left_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.postcent.ctx
T1Hier_thk_left_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.post.cingulate.ctx
T1Hier_thk_left_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.precent.ctx
T1Hier_thk_left_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.precuneus.ctx
T1Hier_thk_left_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.rostral.ant.cingulate.ctx
T1Hier_thk_left_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.rostral.middle.frontal.ctx
T1Hier_thk_left_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.frontal.ctx
T1Hier_thk_left_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.parietal.ctx
T1Hier_thk_left_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.sup.temporal.ctx
T1Hier_thk_left_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.supramarginal.ctx
T1Hier_thk_left_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.left.transverse.temporal.ctx
T1Hier_thk_right_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.caudal.ant.cingulate.ctx
T1Hier_thk_right_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.caudal.middle.frontal.ctx
T1Hier_thk_right_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.cuneus.ctx
T1Hier_thk_right_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.entorhinal.ctx
T1Hier_thk_right_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.fusiform.ctx
T1Hier_thk_right_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.inf.parietal.ctx
T1Hier_thk_right_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.inf.temporal.ctx
T1Hier_thk_right_insuladktcortex
Insula
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.insula.ctx
T1Hier_thk_right_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.isthmus.cingulate.ctx
T1Hier_thk_right_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lateral.occipital.ctx
T1Hier_thk_right_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lateral.orbitofrontal.ctx
T1Hier_thk_right_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.lingual.ctx
T1Hier_thk_right_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.medial.orbitofrontal.ctx
T1Hier_thk_right_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.middle.temporal.ctx
T1Hier_thk_right_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.paracent.ctx
T1Hier_thk_right_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.parahippocampal.ctx
T1Hier_thk_right_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.opercularis.ctx
T1Hier_thk_right_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.orbitalis.ctx
T1Hier_thk_right_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pars.triangularis.ctx
T1Hier_thk_right_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.pericalcarine.ctx
T1Hier_thk_right_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.postcent.ctx
T1Hier_thk_right_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.post.cingulate.ctx
T1Hier_thk_right_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.precent.ctx
T1Hier_thk_right_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.precuneus.ctx
T1Hier_thk_right_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.rostral.ant.cingulate.ctx
T1Hier_thk_right_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.rostral.middle.frontal.ctx
T1Hier_thk_right_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.frontal.ctx
T1Hier_thk_right_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.parietal.ctx
T1Hier_thk_right_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.sup.temporal.ctx
T1Hier_thk_right_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.supramarginal.ctx
T1Hier_thk_right_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.right.transverse.temporal.ctx
T1Hier_vol_left_ca1mtl
CA1
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.ca1mtl
T1Hier_vol_left_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.dg.ca3mtl
T1Hier_vol_left_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.alecmtl
T1Hier_vol_left_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.pmecmtl
T1Hier_vol_left_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.parahippocampalmtl
T1Hier_vol_left_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.perirhinalmtl
T1Hier_vol_left_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.left.subiculummtl
T1Hier_vol_right_ca1mtl
CA1
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.ca1mtl
T1Hier_vol_right_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.dg.ca3mtl
T1Hier_vol_right_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.alecmtl
T1Hier_vol_right_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.pmecmtl
T1Hier_vol_right_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.parahippocampalmtl
T1Hier_vol_right_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.perirhinalmtl
T1Hier_vol_right_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.right.subiculummtl
T1Hier_area_left_ca1mtl
CA1
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.ca1mtl
T1Hier_area_left_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.dg.ca3mtl
T1Hier_area_left_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.alecmtl
T1Hier_area_left_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.pmecmtl
T1Hier_area_left_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.parahippocampalmtl
T1Hier_area_left_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.perirhinalmtl
T1Hier_area_left_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.left.subiculummtl
T1Hier_area_right_ca1mtl
CA1
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.ca1mtl
T1Hier_area_right_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.dg.ca3mtl
T1Hier_area_right_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.alecmtl
T1Hier_area_right_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.pmecmtl
T1Hier_area_right_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.parahippocampalmtl
T1Hier_area_right_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.perirhinalmtl
T1Hier_area_right_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.right.subiculummtl
T1Hier_thk_left_ca1mtl
CA1
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.ca1mtl
T1Hier_thk_left_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.dg.ca3mtl
T1Hier_thk_left_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.alecmtl
T1Hier_thk_left_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.pmecmtl
T1Hier_thk_left_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.parahippocampalmtl
T1Hier_thk_left_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.perirhinalmtl
T1Hier_thk_left_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.left.subiculummtl
T1Hier_thk_right_ca1mtl
CA1
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.ca1mtl
T1Hier_thk_right_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.dg.ca3mtl
T1Hier_thk_right_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.alecmtl
T1Hier_thk_right_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.pmecmtl
T1Hier_thk_right_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.parahippocampalmtl
T1Hier_thk_right_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.perirhinalmtl
T1Hier_thk_right_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.right.subiculummtl
T1Hier_vol_ch13_leftbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.ch13.leftbf
T1Hier_vol_ch13_rightbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.ch13.rightbf
T1Hier_vol_nbm_left_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.left.antbf
T1Hier_vol_nbm_left_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.left.midbf
T1Hier_vol_nbm_left_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.left.posbf
T1Hier_vol_nbm_right_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.right.antbf
T1Hier_vol_nbm_right_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.right.midbf
T1Hier_vol_nbm_right_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.right.posbf
T1Hier_area_ch13_leftbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.ch13.leftbf
T1Hier_area_ch13_rightbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.ch13.rightbf
T1Hier_area_nbm_left_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.left.antbf
T1Hier_area_nbm_left_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.left.midbf
T1Hier_area_nbm_left_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.left.posbf
T1Hier_area_nbm_right_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.right.antbf
T1Hier_area_nbm_right_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.right.midbf
T1Hier_area_nbm_right_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.area
BF
​
​
t1.area.nbm.right.posbf
T1Hier_thk_ch13_leftbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.ch13.leftbf
T1Hier_thk_ch13_rightbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.ch13.rightbf
T1Hier_thk_nbm_left_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.left.antbf
T1Hier_thk_nbm_left_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.left.midbf
T1Hier_thk_nbm_left_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.left.posbf
T1Hier_thk_nbm_right_antbf
Anterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.right.antbf
T1Hier_thk_nbm_right_midbf
Middle Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.right.midbf
T1Hier_thk_nbm_right_posbf
Posterior Basal Nucleus of Meynert
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.right.posbf
T1Hier_vol_bn_gp_gpe_leftcit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpe.left
T1Hier_vol_bn_gp_gpe_rightcit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpe.right
T1Hier_vol_bn_gp_gpi_leftcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpi.left
T1Hier_vol_bn_gp_gpi_rightcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpi.right
T1Hier_vol_bn_gp_vep_leftcit168
Ventral Pallidum
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.vep.left
T1Hier_vol_bn_gp_vep_rightcit168
Ventral Pallidum
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.vep.right
T1Hier_vol_bn_str_ca_leftcit168
Caudate Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.ca.left
T1Hier_vol_bn_str_ca_rightcit168
Caudate Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.ca.right
T1Hier_vol_bn_str_nac_leftcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.nac.left
T1Hier_vol_bn_str_nac_rightcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.nac.right
T1Hier_vol_bn_str_pu_leftcit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pu.left
T1Hier_vol_bn_str_pu_rightcit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pu.right
T1Hier_vol_die_hth_leftcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth.left
T1Hier_vol_die_hth_mn_leftcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth.mn.left
T1Hier_vol_die_hth_mn_rightcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth.mn.right
T1Hier_vol_die_hth_rightcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth.right
T1Hier_vol_die_sth_leftcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.sth.left
T1Hier_vol_die_sth_rightcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.sth.right
T1Hier_vol_exa_leftcit168
Extended Amygdala
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.exa.left
T1Hier_vol_exa_rightcit168
Extended Amygdala
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.exa.right
T1Hier_vol_mtg_rn_leftcit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rn.left
T1Hier_vol_mtg_rn_rightcit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rn.right
T1Hier_vol_mtg_sn_snc_leftcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.snc.left
T1Hier_vol_mtg_sn_snc_rightcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.snc.right
T1Hier_vol_mtg_sn_snr_leftcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snr.left
T1Hier_vol_mtg_sn_snr_rightcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snr.right
T1Hier_vol_mtg_vtr_pbp_leftcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.pbp.left
T1Hier_vol_mtg_vtr_pbp_rightcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.pbp.right
T1Hier_vol_mtg_vtr_vta_leftcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.vta.left
T1Hier_vol_mtg_vtr_vta_rightcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.vta.right
T1Hier_vol_referenceregion_leftcit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregion.left
T1Hier_vol_referenceregion_rightcit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregion.right
T1Hier_vol_thm_eth_hn_leftcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.thm.eth.hn.left
T1Hier_vol_thm_eth_hn_rightcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.thm.eth.hn.right
T1Hier_area_bn_gp_gpe_leftcit168
Globus Pallidus External
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpe.left
T1Hier_area_bn_gp_gpe_rightcit168
Globus Pallidus External
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpe.right
T1Hier_area_bn_gp_gpi_leftcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpi.left
T1Hier_area_bn_gp_gpi_rightcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpi.right
T1Hier_area_bn_gp_vep_leftcit168
Ventral Pallidum
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.vep.left
T1Hier_area_bn_gp_vep_rightcit168
Ventral Pallidum
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.vep.right
T1Hier_area_bn_str_ca_leftcit168
Caudate Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.ca.left
T1Hier_area_bn_str_ca_rightcit168
Caudate Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.ca.right
T1Hier_area_bn_str_nac_leftcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.nac.left
T1Hier_area_bn_str_nac_rightcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.nac.right
T1Hier_area_bn_str_pu_leftcit168
Putamen
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.pu.left
T1Hier_area_bn_str_pu_rightcit168
Putamen
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.pu.right
T1Hier_area_die_hth_leftcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.hth.left
T1Hier_area_die_hth_mn_leftcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.hth.mn.left
T1Hier_area_die_hth_mn_rightcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.hth.mn.right
T1Hier_area_die_hth_rightcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.hth.right
T1Hier_area_die_sth_leftcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.sth.left
T1Hier_area_die_sth_rightcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.die.sth.right
T1Hier_area_exa_leftcit168
Extended Amygdala
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.exa.left
T1Hier_area_exa_rightcit168
Extended Amygdala
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.exa.right
T1Hier_area_mtg_rn_leftcit168
Red Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.rn.left
T1Hier_area_mtg_rn_rightcit168
Red Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.rn.right
T1Hier_area_mtg_sn_snc_leftcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.snc.left
T1Hier_area_mtg_sn_snc_rightcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.snc.right
T1Hier_area_mtg_sn_snr_leftcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.area.snr.left
T1Hier_area_mtg_sn_snr_rightcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.area.snr.right
T1Hier_area_mtg_vtr_pbp_leftcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.vtr.pbp.left
T1Hier_area_mtg_vtr_pbp_rightcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.vtr.pbp.right
T1Hier_area_mtg_vtr_vta_leftcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.vtr.vta.left
T1Hier_area_mtg_vtr_vta_rightcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.vtr.vta.right
T1Hier_area_referenceregion_leftcit168
Reference Region
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.referenceregion.left
T1Hier_area_referenceregion_rightcit168
Reference Region
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.referenceregion.right
T1Hier_area_thm_eth_hn_leftcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.thm.eth.hn.left
T1Hier_area_thm_eth_hn_rightcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.thm.eth.hn.right
T1Hier_thk_bn_gp_gpe_leftcit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpe.left
T1Hier_thk_bn_gp_gpe_rightcit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpe.right
T1Hier_thk_bn_gp_gpi_leftcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpi.left
T1Hier_thk_bn_gp_gpi_rightcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpi.right
T1Hier_thk_bn_gp_vep_leftcit168
Ventral Pallidum
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.vep.left
T1Hier_thk_bn_gp_vep_rightcit168
Ventral Pallidum
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.vep.right
T1Hier_thk_bn_str_ca_leftcit168
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.ca.left
T1Hier_thk_bn_str_ca_rightcit168
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.ca.right
T1Hier_thk_bn_str_nac_leftcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.nac.left
T1Hier_thk_bn_str_nac_rightcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.nac.right
T1Hier_thk_bn_str_pu_leftcit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pu.left
T1Hier_thk_bn_str_pu_rightcit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pu.right
T1Hier_thk_die_hth_leftcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth.left
T1Hier_thk_die_hth_mn_leftcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth.mn.left
T1Hier_thk_die_hth_mn_rightcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth.mn.right
T1Hier_thk_die_hth_rightcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth.right
T1Hier_thk_die_sth_leftcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.sth.left
T1Hier_thk_die_sth_rightcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.sth.right
T1Hier_thk_exa_leftcit168
Extended Amygdala
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.exa.left
T1Hier_thk_exa_rightcit168
Extended Amygdala
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.exa.right
T1Hier_thk_mtg_rn_leftcit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rn.left
T1Hier_thk_mtg_rn_rightcit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rn.right
T1Hier_thk_mtg_sn_snc_leftcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.snc.left
T1Hier_thk_mtg_sn_snc_rightcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.snc.right
T1Hier_thk_mtg_sn_snr_leftcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snr.left
T1Hier_thk_mtg_sn_snr_rightcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snr.right
T1Hier_thk_mtg_vtr_pbp_leftcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.pbp.left
T1Hier_thk_mtg_vtr_pbp_rightcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.pbp.right
T1Hier_thk_mtg_vtr_vta_leftcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.vta.left
T1Hier_thk_mtg_vtr_vta_rightcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.vta.right
T1Hier_thk_referenceregion_leftcit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregion.left
T1Hier_thk_referenceregion_rightcit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregion.right
T1Hier_thk_thm_eth_hn_leftcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.thm.eth.hn.left
T1Hier_thk_thm_eth_hn_rightcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.thm.eth.hn.right
T1Hier_vol_bn_gp_gpe_leftdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpe.leftdp.
T1Hier_vol_bn_gp_gpe_rightdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpe.rightdp.
T1Hier_vol_bn_gp_gpi_leftdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpi.leftdp.
T1Hier_vol_bn_gp_gpi_rightdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpi.rightdp.
T1Hier_vol_bn_str_ca_leftdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.ca.leftdp.
T1Hier_vol_bn_str_ca_rightdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.ca.rightdp.
T1Hier_vol_bn_str_pu_leftdeep_cit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pu.leftdp.
T1Hier_vol_bn_str_pu_rightdeep_cit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pu.rightdp.
T1Hier_vol_mtg_rn_leftdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rn.leftdp.
T1Hier_vol_mtg_rn_rightdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rn.rightdp.
T1Hier_vol_mtg_sn_snc_leftdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.snc.leftdp.
T1Hier_vol_mtg_sn_snc_rightdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.snc.rightdp.
T1Hier_vol_mtg_sn_snr_leftdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snr.leftdp.
T1Hier_vol_mtg_sn_snr_rightdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snr.rightdp.
T1Hier_vol_referenceregion_leftdeep_cit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregion.leftdp.
T1Hier_vol_referenceregion_rightdeep_cit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregion.rightdp.
T1Hier_area_bn_gp_gpe_leftdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpe.leftdp.
T1Hier_area_bn_gp_gpe_rightdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpe.rightdp.
T1Hier_area_bn_gp_gpi_leftdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpi.leftdp.
T1Hier_area_bn_gp_gpi_rightdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.gp.gpi.rightdp.
T1Hier_area_bn_str_ca_leftdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.ca.leftdp.
T1Hier_area_bn_str_ca_rightdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.ca.rightdp.
T1Hier_area_bn_str_pu_leftdeep_cit168
Putamen
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.pu.leftdp.
T1Hier_area_bn_str_pu_rightdeep_cit168
Putamen
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.bn.str.pu.rightdp.
T1Hier_area_mtg_rn_leftdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.rn.leftdp.
T1Hier_area_mtg_rn_rightdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.mtg.rn.rightdp.
T1Hier_area_mtg_sn_snc_leftdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.snc.leftdp.
T1Hier_area_mtg_sn_snc_rightdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.snc.rightdp.
T1Hier_area_mtg_sn_snr_leftdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.area.snr.leftdp.
T1Hier_area_mtg_sn_snr_rightdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.area.snr.rightdp.
T1Hier_area_referenceregion_leftdeep_cit168
Reference Region
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.referenceregion.leftdp.
T1Hier_area_referenceregion_rightdeep_cit168
Reference Region
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.referenceregion.rightdp.
T1Hier_thk_bn_gp_gpe_leftdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpe.leftdp.
T1Hier_thk_bn_gp_gpe_rightdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpe.rightdp.
T1Hier_thk_bn_gp_gpi_leftdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpi.leftdp.
T1Hier_thk_bn_gp_gpi_rightdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpi.rightdp.
T1Hier_thk_bn_str_ca_leftdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.ca.leftdp.
T1Hier_thk_bn_str_ca_rightdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.ca.rightdp.
T1Hier_thk_bn_str_pu_leftdeep_cit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pu.leftdp.
T1Hier_thk_bn_str_pu_rightdeep_cit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pu.rightdp.
T1Hier_thk_mtg_rn_leftdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rn.leftdp.
T1Hier_thk_mtg_rn_rightdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rn.rightdp.
T1Hier_thk_mtg_sn_snc_leftdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.snc.leftdp.
T1Hier_thk_mtg_sn_snc_rightdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.snc.rightdp.
T1Hier_thk_mtg_sn_snr_leftdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snr.leftdp.
T1Hier_thk_mtg_sn_snr_rightdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snr.rightdp.
T1Hier_thk_referenceregion_leftdeep_cit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregion.leftdp.
T1Hier_thk_referenceregion_rightdeep_cit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregion.rightdp.
T1Hier_vol_mtg_sn_snc_leftsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.snc.leftsnseg
T1Hier_vol_mtg_sn_snc_rightsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.snc.rightsnseg
T1Hier_vol_mtg_sn_snr_leftsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.vol.snr.leftsnseg
T1Hier_vol_mtg_sn_snr_rightsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.vol.snr.rightsnseg
T1Hier_vol_referenceregion_leftsnseg
Reference Region
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.referenceregion.leftsnseg
T1Hier_vol_referenceregion_rightsnseg
Reference Region
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.referenceregion.rightsnseg
T1Hier_area_mtg_sn_snc_leftsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.snc.leftsnseg
T1Hier_area_mtg_sn_snc_rightsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.snc.rightsnseg
T1Hier_area_mtg_sn_snr_leftsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.area.snr.leftsnseg
T1Hier_area_mtg_sn_snr_rightsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.area.snr.rightsnseg
T1Hier_area_referenceregion_leftsnseg
Reference Region
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.referenceregion.leftsnseg
T1Hier_area_referenceregion_rightsnseg
Reference Region
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.area.referenceregion.rightsnseg
T1Hier_thk_mtg_sn_snc_leftsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.snc.leftsnseg
T1Hier_thk_mtg_sn_snc_rightsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.snc.rightsnseg
T1Hier_thk_mtg_sn_snr_leftsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.thk.snr.leftsnseg
T1Hier_thk_mtg_sn_snr_rightsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.thk.snr.rightsnseg
T1Hier_thk_referenceregion_leftsnseg
Reference Region
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.referenceregion.leftsnseg
T1Hier_thk_referenceregion_rightsnseg
Reference Region
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.referenceregion.rightsnseg
T1Hier_vol_cleanupbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.cleanup.bst
T1Hier_vol_medullabrainstem
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.medulla.bst
T1Hier_vol_midbrainbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.midbrain.bst
T1Hier_vol_ponsbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.pons.bst
T1Hier_area_cleanupbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.cleanup.bst
T1Hier_area_medullabrainstem
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.medulla.bst
T1Hier_area_midbrainbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.midbrain.bst
T1Hier_area_ponsbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.area
CIT168
​
​
t1.area.pons.bst
T1Hier_thk_cleanupbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.cleanup.bst
T1Hier_thk_medullabrainstem
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.medulla.bst
T1Hier_thk_midbrainbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.midbrain.bst
T1Hier_thk_ponsbrainstem
brainstem subdivision
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.pons.bst
T1Hier_vol_l_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.crus.icerebellum
T1Hier_vol_l_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.crus.iicerebellum
T1Hier_vol_l_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.iiicerebellum
T1Hier_vol_l_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.ivcerebellum
T1Hier_vol_l_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.ixcerebellum
T1Hier_vol_l_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.i.iicerebellum
T1Hier_vol_l_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.vcerebellum
T1Hier_vol_l_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.vicerebellum
T1Hier_vol_l_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.viibcerebellum
T1Hier_vol_l_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.viiiacerebellum
T1Hier_vol_l_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.viiibcerebellum
T1Hier_vol_l_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
left
t1.vol.l.xcerebellum
T1Hier_vol_r_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.crus.icerebellum
T1Hier_vol_r_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.crus.iicerebellum
T1Hier_vol_r_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.iiicerebellum
T1Hier_vol_r_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.ivcerebellum
T1Hier_vol_r_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.ixcerebellum
T1Hier_vol_r_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.i.iicerebellum
T1Hier_vol_r_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.vcerebellum
T1Hier_vol_r_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.vicerebellum
T1Hier_vol_r_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.viibcerebellum
T1Hier_vol_r_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.viiiacerebellum
T1Hier_vol_r_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.viiibcerebellum
T1Hier_vol_r_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.volume
TustisonCobra
​
right
t1.vol.r.xcerebellum
T1Hier_area_l_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.crus.icerebellum
T1Hier_area_l_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.crus.iicerebellum
T1Hier_area_l_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.iiicerebellum
T1Hier_area_l_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.ivcerebellum
T1Hier_area_l_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.ixcerebellum
T1Hier_area_l_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.i.iicerebellum
T1Hier_area_l_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.vcerebellum
T1Hier_area_l_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.vicerebellum
T1Hier_area_l_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.viibcerebellum
T1Hier_area_l_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.viiiacerebellum
T1Hier_area_l_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.viiibcerebellum
T1Hier_area_l_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
left
t1.area.l.xcerebellum
T1Hier_area_r_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.crus.icerebellum
T1Hier_area_r_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.crus.iicerebellum
T1Hier_area_r_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.iiicerebellum
T1Hier_area_r_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.ivcerebellum
T1Hier_area_r_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.ixcerebellum
T1Hier_area_r_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.i.iicerebellum
T1Hier_area_r_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.vcerebellum
T1Hier_area_r_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.vicerebellum
T1Hier_area_r_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.viibcerebellum
T1Hier_area_r_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.viiiacerebellum
T1Hier_area_r_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.viiibcerebellum
T1Hier_area_r_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.area
TustisonCobra
​
right
t1.area.r.xcerebellum
T1Hier_thk_l_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.crus.icerebellum
T1Hier_thk_l_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.crus.iicerebellum
T1Hier_thk_l_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.iiicerebellum
T1Hier_thk_l_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.ivcerebellum
T1Hier_thk_l_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.ixcerebellum
T1Hier_thk_l_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.i.iicerebellum
T1Hier_thk_l_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.vcerebellum
T1Hier_thk_l_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.vicerebellum
T1Hier_thk_l_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.viibcerebellum
T1Hier_thk_l_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.viiiacerebellum
T1Hier_thk_l_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.viiibcerebellum
T1Hier_thk_l_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
left
t1.thk.l.xcerebellum
T1Hier_thk_r_crus_icerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.crus.icerebellum
T1Hier_thk_r_crus_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.crus.iicerebellum
T1Hier_thk_r_iiicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.iiicerebellum
T1Hier_thk_r_ivcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.ivcerebellum
T1Hier_thk_r_ixcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.ixcerebellum
T1Hier_thk_r_i_iicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.i.iicerebellum
T1Hier_thk_r_vcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.vcerebellum
T1Hier_thk_r_vicerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.vicerebellum
T1Hier_thk_r_viibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.viibcerebellum
T1Hier_thk_r_viiiacerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.viiiacerebellum
T1Hier_thk_r_viiibcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.viiibcerebellum
T1Hier_thk_r_xcerebellum
cerebellum label using Schmahmann nomenclature
T1 hierarchical processing
geometry.thickness
TustisonCobra
​
right
t1.thk.r.xcerebellum
T1Hier_RandBasisProj01
Unknown Core: hier randbasisproj01
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj01
T1Hier_RandBasisProj02
Unknown Core: hier randbasisproj02
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj02
T1Hier_RandBasisProj03
Unknown Core: hier randbasisproj03
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj03
T1Hier_RandBasisProj04
Unknown Core: hier randbasisproj04
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj04
T1Hier_RandBasisProj05
Unknown Core: hier randbasisproj05
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj05
T1Hier_RandBasisProj06
Unknown Core: hier randbasisproj06
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj06
T1Hier_RandBasisProj07
Unknown Core: hier randbasisproj07
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj07
T1Hier_RandBasisProj08
Unknown Core: hier randbasisproj08
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj08
T1Hier_RandBasisProj09
Unknown Core: hier randbasisproj09
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj09
T1Hier_RandBasisProj10
Unknown Core: hier randbasisproj10
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisproj10
T1Hier_RandBasisProjPos01
Unknown Core: hier randbasisprojpos01
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos01
T1Hier_RandBasisProjPos02
Unknown Core: hier randbasisprojpos02
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos02
T1Hier_RandBasisProjPos03
Unknown Core: hier randbasisprojpos03
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos03
T1Hier_RandBasisProjPos04
Unknown Core: hier randbasisprojpos04
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos04
T1Hier_RandBasisProjPos05
Unknown Core: hier randbasisprojpos05
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos05
T1Hier_RandBasisProjPos06
Unknown Core: hier randbasisprojpos06
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos06
T1Hier_RandBasisProjPos07
Unknown Core: hier randbasisprojpos07
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos07
T1Hier_RandBasisProjPos08
Unknown Core: hier randbasisprojpos08
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos08
T1Hier_RandBasisProjPos09
Unknown Core: hier randbasisprojpos09
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos09
T1Hier_RandBasisProjPos10
Unknown Core: hier randbasisprojpos10
T1 hierarchical processing
Unknown
ANTs
​
​
t1.randbasisprojpos10
T1Hier_loop_outlier_probability
Unknown Core: hier loop outlier probability
T1 hierarchical processing
QC
ANTs
​
​
t1.loop.outlier.probability
T1Hier_mhdist
Unknown Core: hier mhdist
T1 hierarchical processing
Unknown
ANTs
​
​
t1.mhdist
T1Hier_templateL1
Unknown Core: hier templatel1
T1 hierarchical processing
Unknown
ANTs
​
​
t1.templatel1
T1Hier_evratio
Unknown Core: hier evratio
T1 hierarchical processing
QC
ANTs
​
​
t1.evratio
T1Hier_resnetGrade
Unknown Core: hier resnetgrade
T1 hierarchical processing
Unknown
ANTs
​
​
t1.resnetgrade
T1w_mean_background
Background Signal
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.background
T1w_mean_left_caudal_anterior_cingulate
Caudal Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.caudal.ant.cingulate
T1w_mean_left_caudal_middle_frontal
Caudal Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.caudal.middle.frontal
T1w_mean_left_cuneus
Cuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.cuneus
T1w_mean_left_entorhinal
Entorhinal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.entorhinal
T1w_mean_left_fusiform
Fusiform Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.fusiform
T1w_mean_left_inferior_parietal
Inferior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.inf.parietal
T1w_mean_left_inferior_temporal
Inferior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.inf.temporal
T1w_mean_left_insula
Insula
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.insula
T1w_mean_left_isthmus_cingulate
Isthmus Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.isthmus.cingulate
T1w_mean_left_lateral_occipital
Lateral Occipital Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.lateral.occipital
T1w_mean_left_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.lateral.orbitofrontal
T1w_mean_left_lingual
Lingual Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.lingual
T1w_mean_left_medial_orbitofrontal
Medial Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.medial.orbitofrontal
T1w_mean_left_middle_temporal
Middle Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.middle.temporal
T1w_mean_left_paracentral
Paracentral Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.paracent
T1w_mean_left_parahippocampal
Parahippocampal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.parahippocampal
T1w_mean_left_pars_opercularis
Pars Opercularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.pars.opercularis
T1w_mean_left_pars_orbitalis
Pars Orbitalis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.pars.orbitalis
T1w_mean_left_pars_triangularis
Pars Triangularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.pars.triangularis
T1w_mean_left_pericalcarine
Pericalcarine Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.pericalcarine
T1w_mean_left_postcentral
Postcentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.postcent
T1w_mean_left_posterior_cingulate
Posterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.post.cingulate
T1w_mean_left_precentral
Precentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.precent
T1w_mean_left_precuneus
Precuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.precuneus
T1w_mean_left_rostral_anterior_cingulate
Rostral Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.rostral.ant.cingulate
T1w_mean_left_rostral_middle_frontal
Rostral Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.rostral.middle.frontal
T1w_mean_left_superior_frontal
Superior Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.sup.frontal
T1w_mean_left_superior_parietal
Superior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.sup.parietal
T1w_mean_left_superior_temporal
Superior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.sup.temporal
T1w_mean_left_supramarginal
Supramarginal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.supramarginal
T1w_mean_left_transverse_temporal
Transverse Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.left.transverse.temporal
T1w_mean_right_caudal_anterior_cingulate
Caudal Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.caudal.ant.cingulate
T1w_mean_right_caudal_middle_frontal
Caudal Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.caudal.middle.frontal
T1w_mean_right_cuneus
Cuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.cuneus
T1w_mean_right_entorhinal
Entorhinal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.entorhinal
T1w_mean_right_fusiform
Fusiform Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.fusiform
T1w_mean_right_inferior_parietal
Inferior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.inf.parietal
T1w_mean_right_inferior_temporal
Inferior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.inf.temporal
T1w_mean_right_insula
Insula
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.insula
T1w_mean_right_isthmus_cingulate
Isthmus Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.isthmus.cingulate
T1w_mean_right_lateral_occipital
Lateral Occipital Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.lateral.occipital
T1w_mean_right_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.lateral.orbitofrontal
T1w_mean_right_lingual
Lingual Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.lingual
T1w_mean_right_medial_orbitofrontal
Medial Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.medial.orbitofrontal
T1w_mean_right_middle_temporal
Middle Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.middle.temporal
T1w_mean_right_paracentral
Paracentral Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.paracent
T1w_mean_right_parahippocampal
Parahippocampal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.parahippocampal
T1w_mean_right_pars_opercularis
Pars Opercularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.pars.opercularis
T1w_mean_right_pars_orbitalis
Pars Orbitalis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.pars.orbitalis
T1w_mean_right_pars_triangularis
Pars Triangularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.pars.triangularis
T1w_mean_right_pericalcarine
Pericalcarine Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.pericalcarine
T1w_mean_right_postcentral
Postcentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.postcent
T1w_mean_right_posterior_cingulate
Posterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.post.cingulate
T1w_mean_right_precentral
Precentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.precent
T1w_mean_right_precuneus
Precuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.precuneus
T1w_mean_right_rostral_anterior_cingulate
Rostral Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.rostral.ant.cingulate
T1w_mean_right_rostral_middle_frontal
Rostral Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.rostral.middle.frontal
T1w_mean_right_superior_frontal
Superior Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.sup.frontal
T1w_mean_right_superior_parietal
Superior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.sup.parietal
T1w_mean_right_superior_temporal
Superior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.sup.temporal
T1w_mean_right_supramarginal
Supramarginal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.supramarginal
T1w_mean_right_transverse_temporal
Transverse Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.right.transverse.temporal
T2Flair_flair_mean
Unknown Core: flair
Flair
Mean Intensity
ANTs
​
​
t2flair.flair.mean
T2Flair_WMH_probability_map_mean
Unknown Core: wmh probability map
Flair
Mean Intensity
ANTs
​
​
t2flair.wmh.probability.map.mean
T2Flair_WMH_posterior_probability_map_mean
Unknown Core: wmh posterior probability map
Flair
Mean Intensity
ANTs
​
​
t2flair.wmh.post.probability.map.mean
T2Flair_wmh_mass
Unknown Core: wmh mass
Flair
Unknown
ANTs
​
​
t2flair.wmh.mass
T2Flair_wmh_mass_prior
Unknown Core: wmh mass prior
Flair
Unknown
ANTs
​
​
t2flair.wmh.mass.prior
T2Flair_wmh_evr
Unknown Core: wmh
Flair
QC
ANTs
​
​
t2flair.wmh.evr
rsfMRI_fcnxpro134_paramset
​
restingStatefMRI
parameter id
power peterson fMRI meta-analyses
134
​
rsf.p3.paramset
rsfMRI_fcnxpro134_upsampling
Unknown Core: upsampling
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.upsampling
rsfMRI_fcnxpro134_meanBold_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.meanbold.mean
rsfMRI_fcnxpro134_TempPar_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.mean
rsfMRI_fcnxpro134_DefaultC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.mean
rsfMRI_fcnxpro134_DefaultB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.mean
rsfMRI_fcnxpro134_DefaultA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.mean
rsfMRI_fcnxpro134_ContC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.mean
rsfMRI_fcnxpro134_ContB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.mean
rsfMRI_fcnxpro134_ContA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.mean
rsfMRI_fcnxpro134_LimbicA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.mean
rsfMRI_fcnxpro134_LimbicB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.mean
rsfMRI_fcnxpro134_SalVentAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.mean
rsfMRI_fcnxpro134_SalVentAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.mean
rsfMRI_fcnxpro134_DorsAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.mean
rsfMRI_fcnxpro134_DorsAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.mean
rsfMRI_fcnxpro134_SomMotB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.mean
rsfMRI_fcnxpro134_SomMotA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.mean
rsfMRI_fcnxpro134_VisPeri_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.mean
rsfMRI_fcnxpro134_VisCent_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.mean
rsfMRI_fcnxpro134_Striatum_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.mean
rsfMRI_fcnxpro134_Dopamine_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.mean
rsfMRI_fcnxpro134_CITLimbic_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.mean
rsfMRI_fcnxpro134_BasalGanglia_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.mean
rsfMRI_fcnxpro134_MidBrain_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.mean
rsfMRI_fcnxpro134_fmri_template_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.fmri.template.mean
rsfMRI_fcnxpro134_brainmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.brainmask.mean
rsfMRI_fcnxpro134_gmmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.gmmask.mean
rsfMRI_fcnxpro134_alff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.alff.mean
rsfMRI_fcnxpro134_alff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
134
​
rsf.p3.alff.sd
rsfMRI_fcnxpro134_falff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.falff.mean
rsfMRI_fcnxpro134_falff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
134
​
rsf.p3.falff.sd
rsfMRI_fcnxpro134_falffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint000.iplleft
rsfMRI_fcnxpro134_alffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint000.iplleft
rsfMRI_fcnxpro134_perafPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint000.iplleft
rsfMRI_fcnxpro134_falffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint001.stleft
rsfMRI_fcnxpro134_alffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint001.stleft
rsfMRI_fcnxpro134_perafPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint001.stleft
rsfMRI_fcnxpro134_falffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint002.stleft
rsfMRI_fcnxpro134_alffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint002.stleft
rsfMRI_fcnxpro134_perafPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint002.stleft
rsfMRI_fcnxpro134_falffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint003.tempoccleft
rsfMRI_fcnxpro134_alffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint003.tempoccleft
rsfMRI_fcnxpro134_perafPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint003.tempoccleft
rsfMRI_fcnxpro134_falffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint004.templeft
rsfMRI_fcnxpro134_alffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint004.templeft
rsfMRI_fcnxpro134_perafPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint004.templeft
rsfMRI_fcnxpro134_falffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint005.templeft
rsfMRI_fcnxpro134_alffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint005.templeft
rsfMRI_fcnxpro134_perafPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint005.templeft
rsfMRI_fcnxpro134_falffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint006.exstrinfleft
rsfMRI_fcnxpro134_alffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint006.exstrinfleft
rsfMRI_fcnxpro134_perafPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint006.exstrinfleft
rsfMRI_fcnxpro134_falffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint007.iplleft
rsfMRI_fcnxpro134_alffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint007.iplleft
rsfMRI_fcnxpro134_perafPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint007.iplleft
rsfMRI_fcnxpro134_falffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint008.phcleft
rsfMRI_fcnxpro134_alffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint008.phcleft
rsfMRI_fcnxpro134_perafPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint008.phcleft
rsfMRI_fcnxpro134_falffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint009.phcleft
rsfMRI_fcnxpro134_alffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint009.phcleft
rsfMRI_fcnxpro134_perafPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint009.phcleft
rsfMRI_fcnxpro134_falffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint010.phcleft
rsfMRI_fcnxpro134_alffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint010.phcleft
rsfMRI_fcnxpro134_perafPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint010.phcleft
rsfMRI_fcnxpro134_falffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint011.rscleft
rsfMRI_fcnxpro134_alffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint011.rscleft
rsfMRI_fcnxpro134_perafPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint011.rscleft
rsfMRI_fcnxpro134_falffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint012.rscleft
rsfMRI_fcnxpro134_alffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint012.rscleft
rsfMRI_fcnxpro134_perafPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint012.rscleft
rsfMRI_fcnxpro134_falffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint013.iplleft
rsfMRI_fcnxpro134_alffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint013.iplleft
rsfMRI_fcnxpro134_perafPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint013.iplleft
rsfMRI_fcnxpro134_falffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint014.iplleft
rsfMRI_fcnxpro134_alffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint014.iplleft
rsfMRI_fcnxpro134_perafPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint014.iplleft
rsfMRI_fcnxpro134_falffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint015.iplleft
rsfMRI_fcnxpro134_alffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint015.iplleft
rsfMRI_fcnxpro134_perafPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint015.iplleft
rsfMRI_fcnxpro134_falffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint016.iplleft
rsfMRI_fcnxpro134_alffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint016.iplleft
rsfMRI_fcnxpro134_perafPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint016.iplleft
rsfMRI_fcnxpro134_falffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint017.pfcdleft
rsfMRI_fcnxpro134_alffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint017.pfcdleft
rsfMRI_fcnxpro134_perafPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint017.pfcdleft
rsfMRI_fcnxpro134_falffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint018.pfcdleft
rsfMRI_fcnxpro134_alffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint018.pfcdleft
rsfMRI_fcnxpro134_perafPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint018.pfcdleft
rsfMRI_fcnxpro134_falffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint019.pfcdleft
rsfMRI_fcnxpro134_alffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint019.pfcdleft
rsfMRI_fcnxpro134_perafPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint019.pfcdleft
rsfMRI_fcnxpro134_falffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint020.pfcdleft
rsfMRI_fcnxpro134_alffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint020.pfcdleft
rsfMRI_fcnxpro134_perafPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint020.pfcdleft
rsfMRI_fcnxpro134_falffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint021.pfcdleft
rsfMRI_fcnxpro134_alffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint021.pfcdleft
rsfMRI_fcnxpro134_perafPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint021.pfcdleft
rsfMRI_fcnxpro134_falffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint022.pfcdleft
rsfMRI_fcnxpro134_alffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint022.pfcdleft
rsfMRI_fcnxpro134_perafPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint022.pfcdleft
rsfMRI_fcnxpro134_falffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint023.pfcdleft
rsfMRI_fcnxpro134_alffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint023.pfcdleft
rsfMRI_fcnxpro134_perafPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint023.pfcdleft
rsfMRI_fcnxpro134_falffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint024.pfclleft
rsfMRI_fcnxpro134_alffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint024.pfclleft
rsfMRI_fcnxpro134_perafPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint024.pfclleft
rsfMRI_fcnxpro134_falffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint025.pfclleft
rsfMRI_fcnxpro134_alffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint025.pfclleft
rsfMRI_fcnxpro134_perafPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint025.pfclleft
rsfMRI_fcnxpro134_falffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint026.pfcvleft
rsfMRI_fcnxpro134_alffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint026.pfcvleft
rsfMRI_fcnxpro134_perafPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint026.pfcvleft
rsfMRI_fcnxpro134_falffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint027.pfcvleft
rsfMRI_fcnxpro134_alffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint027.pfcvleft
rsfMRI_fcnxpro134_perafPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint027.pfcvleft
rsfMRI_fcnxpro134_falffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint028.pfcvleft
rsfMRI_fcnxpro134_alffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint028.pfcvleft
rsfMRI_fcnxpro134_perafPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint028.pfcvleft
rsfMRI_fcnxpro134_falffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint029.pfcvleft
rsfMRI_fcnxpro134_alffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint029.pfcvleft
rsfMRI_fcnxpro134_perafPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint029.pfcvleft
rsfMRI_fcnxpro134_falffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint030.temppoleleft
rsfMRI_fcnxpro134_alffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint030.temppoleleft
rsfMRI_fcnxpro134_perafPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint030.temppoleleft
rsfMRI_fcnxpro134_falffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint031.templeft
rsfMRI_fcnxpro134_alffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint031.templeft
rsfMRI_fcnxpro134_perafPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint031.templeft
rsfMRI_fcnxpro134_falffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint032.templeft
rsfMRI_fcnxpro134_alffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint032.templeft
rsfMRI_fcnxpro134_perafPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint032.templeft
rsfMRI_fcnxpro134_falffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint033.templeft
rsfMRI_fcnxpro134_alffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint033.templeft
rsfMRI_fcnxpro134_perafPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint033.templeft
rsfMRI_fcnxpro134_falffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint034.templeft
rsfMRI_fcnxpro134_alffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint034.templeft
rsfMRI_fcnxpro134_perafPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint034.templeft
rsfMRI_fcnxpro134_falffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint035.templeft
rsfMRI_fcnxpro134_alffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint035.templeft
rsfMRI_fcnxpro134_perafPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint035.templeft
rsfMRI_fcnxpro134_falffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint036.templeft
rsfMRI_fcnxpro134_alffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint036.templeft
rsfMRI_fcnxpro134_perafPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint036.templeft
rsfMRI_fcnxpro134_falffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint037.templeft
rsfMRI_fcnxpro134_alffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint037.templeft
rsfMRI_fcnxpro134_perafPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint037.templeft
rsfMRI_fcnxpro134_falffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint038.templeft
rsfMRI_fcnxpro134_alffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint038.templeft
rsfMRI_fcnxpro134_perafPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint038.templeft
rsfMRI_fcnxpro134_falffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint039.templeft
rsfMRI_fcnxpro134_alffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint039.templeft
rsfMRI_fcnxpro134_perafPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint039.templeft
rsfMRI_fcnxpro134_falffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint040.templeft
rsfMRI_fcnxpro134_alffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint040.templeft
rsfMRI_fcnxpro134_perafPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint040.templeft
rsfMRI_fcnxpro134_falffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint041.fpoleleft
rsfMRI_fcnxpro134_alffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint041.fpoleleft
rsfMRI_fcnxpro134_perafPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint041.fpoleleft
rsfMRI_fcnxpro134_falffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint042.iplleft
rsfMRI_fcnxpro134_alffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint042.iplleft
rsfMRI_fcnxpro134_perafPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint042.iplleft
rsfMRI_fcnxpro134_falffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint043.iplleft
rsfMRI_fcnxpro134_alffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint043.iplleft
rsfMRI_fcnxpro134_perafPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint043.iplleft
rsfMRI_fcnxpro134_falffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint044.iplleft
rsfMRI_fcnxpro134_alffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint044.iplleft
rsfMRI_fcnxpro134_perafPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint044.iplleft
rsfMRI_fcnxpro134_falffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint045.pccleft
rsfMRI_fcnxpro134_alffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint045.pccleft
rsfMRI_fcnxpro134_perafPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint045.pccleft
rsfMRI_fcnxpro134_falffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint046.pccleft
rsfMRI_fcnxpro134_alffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint046.pccleft
rsfMRI_fcnxpro134_perafPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint046.pccleft
rsfMRI_fcnxpro134_falffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint047.pccleft
rsfMRI_fcnxpro134_alffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint047.pccleft
rsfMRI_fcnxpro134_perafPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint047.pccleft
rsfMRI_fcnxpro134_falffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint048.pccleft
rsfMRI_fcnxpro134_alffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint048.pccleft
rsfMRI_fcnxpro134_perafPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint048.pccleft
rsfMRI_fcnxpro134_falffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint049.pccleft
rsfMRI_fcnxpro134_alffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint049.pccleft
rsfMRI_fcnxpro134_perafPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint049.pccleft
rsfMRI_fcnxpro134_falffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint050.pccleft
rsfMRI_fcnxpro134_alffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint050.pccleft
rsfMRI_fcnxpro134_perafPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint050.pccleft
rsfMRI_fcnxpro134_falffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint051.pccleft
rsfMRI_fcnxpro134_alffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint051.pccleft
rsfMRI_fcnxpro134_perafPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint051.pccleft
rsfMRI_fcnxpro134_falffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint052.pfcdleft
rsfMRI_fcnxpro134_alffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint052.pfcdleft
rsfMRI_fcnxpro134_perafPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint052.pfcdleft
rsfMRI_fcnxpro134_falffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint053.pfcdleft
rsfMRI_fcnxpro134_alffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint053.pfcdleft
rsfMRI_fcnxpro134_perafPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint053.pfcdleft
rsfMRI_fcnxpro134_falffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint054.pfcdleft
rsfMRI_fcnxpro134_alffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint054.pfcdleft
rsfMRI_fcnxpro134_perafPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint054.pfcdleft
rsfMRI_fcnxpro134_falffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint055.pfcdleft
rsfMRI_fcnxpro134_alffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint055.pfcdleft
rsfMRI_fcnxpro134_perafPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint055.pfcdleft
rsfMRI_fcnxpro134_falffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint056.pfcmleft
rsfMRI_fcnxpro134_alffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint056.pfcmleft
rsfMRI_fcnxpro134_perafPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint056.pfcmleft
rsfMRI_fcnxpro134_falffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint057.pfcmleft
rsfMRI_fcnxpro134_alffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint057.pfcmleft
rsfMRI_fcnxpro134_perafPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint057.pfcmleft
rsfMRI_fcnxpro134_falffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint058.pfcmleft
rsfMRI_fcnxpro134_alffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint058.pfcmleft
rsfMRI_fcnxpro134_perafPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint058.pfcmleft
rsfMRI_fcnxpro134_falffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint059.pfcmleft
rsfMRI_fcnxpro134_alffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint059.pfcmleft
rsfMRI_fcnxpro134_perafPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint059.pfcmleft
rsfMRI_fcnxpro134_falffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint060.pfcmleft
rsfMRI_fcnxpro134_alffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint060.pfcmleft
rsfMRI_fcnxpro134_perafPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint060.pfcmleft
rsfMRI_fcnxpro134_falffPoint061_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint061.pcunleft
rsfMRI_fcnxpro134_alffPoint061_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint061.pcunleft
rsfMRI_fcnxpro134_perafPoint061_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint061.pcunleft
rsfMRI_fcnxpro134_falffPoint062_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint062.pcunleft
rsfMRI_fcnxpro134_alffPoint062_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint062.pcunleft
rsfMRI_fcnxpro134_perafPoint062_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint062.pcunleft
rsfMRI_fcnxpro134_falffPoint063_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint063.pcunleft
rsfMRI_fcnxpro134_alffPoint063_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint063.pcunleft
rsfMRI_fcnxpro134_perafPoint063_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint063.pcunleft
rsfMRI_fcnxpro134_falffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint064.pccleft
rsfMRI_fcnxpro134_alffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint064.pccleft
rsfMRI_fcnxpro134_perafPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint064.pccleft
rsfMRI_fcnxpro134_falffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint065.splleft
rsfMRI_fcnxpro134_alffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint065.splleft
rsfMRI_fcnxpro134_perafPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint065.splleft
rsfMRI_fcnxpro134_falffPoint066_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint066.pcunleft
rsfMRI_fcnxpro134_alffPoint066_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint066.pcunleft
rsfMRI_fcnxpro134_perafPoint066_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint066.pcunleft
rsfMRI_fcnxpro134_falffPoint067_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint067.pcunleft
rsfMRI_fcnxpro134_alffPoint067_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint067.pcunleft
rsfMRI_fcnxpro134_perafPoint067_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint067.pcunleft
rsfMRI_fcnxpro134_falffPoint068_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint068.pcunleft
rsfMRI_fcnxpro134_alffPoint068_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint068.pcunleft
rsfMRI_fcnxpro134_perafPoint068_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint068.pcunleft
rsfMRI_fcnxpro134_falffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint069.fpoleleft
rsfMRI_fcnxpro134_alffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint069.fpoleleft
rsfMRI_fcnxpro134_perafPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint069.fpoleleft
rsfMRI_fcnxpro134_falffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint070.fpoleleft
rsfMRI_fcnxpro134_alffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint070.fpoleleft
rsfMRI_fcnxpro134_perafPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint070.fpoleleft
rsfMRI_fcnxpro134_falffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint071.frmedleft
rsfMRI_fcnxpro134_alffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint071.frmedleft
rsfMRI_fcnxpro134_perafPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint071.frmedleft
rsfMRI_fcnxpro134_falffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint072.iplleft
rsfMRI_fcnxpro134_alffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint072.iplleft
rsfMRI_fcnxpro134_perafPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint072.iplleft
rsfMRI_fcnxpro134_falffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint073.ipsleft
rsfMRI_fcnxpro134_alffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint073.ipsleft
rsfMRI_fcnxpro134_perafPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint073.ipsleft
rsfMRI_fcnxpro134_falffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint074.ipsleft
rsfMRI_fcnxpro134_alffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint074.ipsleft
rsfMRI_fcnxpro134_perafPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint074.ipsleft
rsfMRI_fcnxpro134_falffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint075.pfcdleft
rsfMRI_fcnxpro134_alffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint075.pfcdleft
rsfMRI_fcnxpro134_perafPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint075.pfcdleft
rsfMRI_fcnxpro134_falffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint076.pfclleft
rsfMRI_fcnxpro134_alffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint076.pfclleft
rsfMRI_fcnxpro134_perafPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint076.pfclleft
rsfMRI_fcnxpro134_falffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint077.pfcvleft
rsfMRI_fcnxpro134_alffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint077.pfcvleft
rsfMRI_fcnxpro134_perafPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint077.pfcvleft
rsfMRI_fcnxpro134_falffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint078.templeft
rsfMRI_fcnxpro134_alffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint078.templeft
rsfMRI_fcnxpro134_perafPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint078.templeft
rsfMRI_fcnxpro134_falffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint079.templeft
rsfMRI_fcnxpro134_alffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint079.templeft
rsfMRI_fcnxpro134_perafPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint079.templeft
rsfMRI_fcnxpro134_falffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint080.cingmleft
rsfMRI_fcnxpro134_alffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint080.cingmleft
rsfMRI_fcnxpro134_perafPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint080.cingmleft
rsfMRI_fcnxpro134_falffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint081.ipsleft
rsfMRI_fcnxpro134_alffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint081.ipsleft
rsfMRI_fcnxpro134_perafPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint081.ipsleft
rsfMRI_fcnxpro134_falffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint082.ipsleft
rsfMRI_fcnxpro134_alffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint082.ipsleft
rsfMRI_fcnxpro134_perafPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint082.ipsleft
rsfMRI_fcnxpro134_falffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint083.ipsleft
rsfMRI_fcnxpro134_alffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint083.ipsleft
rsfMRI_fcnxpro134_perafPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint083.ipsleft
rsfMRI_fcnxpro134_falffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint084.ipsleft
rsfMRI_fcnxpro134_alffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint084.ipsleft
rsfMRI_fcnxpro134_perafPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint084.ipsleft
rsfMRI_fcnxpro134_falffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint085.ipsleft
rsfMRI_fcnxpro134_alffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint085.ipsleft
rsfMRI_fcnxpro134_perafPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint085.ipsleft
rsfMRI_fcnxpro134_falffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint086.pfcdleft
rsfMRI_fcnxpro134_alffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint086.pfcdleft
rsfMRI_fcnxpro134_perafPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint086.pfcdleft
rsfMRI_fcnxpro134_falffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint087.pfclleft
rsfMRI_fcnxpro134_alffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint087.pfclleft
rsfMRI_fcnxpro134_perafPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint087.pfclleft
rsfMRI_fcnxpro134_falffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint088.pfclleft
rsfMRI_fcnxpro134_alffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint088.pfclleft
rsfMRI_fcnxpro134_perafPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint088.pfclleft
rsfMRI_fcnxpro134_falffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint089.pfclleft
rsfMRI_fcnxpro134_alffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint089.pfclleft
rsfMRI_fcnxpro134_perafPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint089.pfclleft
rsfMRI_fcnxpro134_falffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint090.pfclleft
rsfMRI_fcnxpro134_alffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint090.pfclleft
rsfMRI_fcnxpro134_perafPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint090.pfclleft
rsfMRI_fcnxpro134_falffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint091.pfclleft
rsfMRI_fcnxpro134_alffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint091.pfclleft
rsfMRI_fcnxpro134_perafPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint091.pfclleft
rsfMRI_fcnxpro134_falffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint092.pfclleft
rsfMRI_fcnxpro134_alffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint092.pfclleft
rsfMRI_fcnxpro134_perafPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint092.pfclleft
rsfMRI_fcnxpro134_falffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint093.prcvleft
rsfMRI_fcnxpro134_alffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint093.prcvleft
rsfMRI_fcnxpro134_perafPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint093.prcvleft
rsfMRI_fcnxpro134_falffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint094.prcvleft
rsfMRI_fcnxpro134_alffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint094.prcvleft
rsfMRI_fcnxpro134_perafPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint094.prcvleft
rsfMRI_fcnxpro134_falffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint095.prcvleft
rsfMRI_fcnxpro134_alffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint095.prcvleft
rsfMRI_fcnxpro134_perafPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint095.prcvleft
rsfMRI_fcnxpro134_falffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint096.splleft
rsfMRI_fcnxpro134_alffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint096.splleft
rsfMRI_fcnxpro134_perafPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint096.splleft
rsfMRI_fcnxpro134_falffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint097.tempoccleft
rsfMRI_fcnxpro134_alffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint097.tempoccleft
rsfMRI_fcnxpro134_perafPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint097.tempoccleft
rsfMRI_fcnxpro134_falffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint098.insleft
rsfMRI_fcnxpro134_alffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint098.insleft
rsfMRI_fcnxpro134_perafPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint098.insleft
rsfMRI_fcnxpro134_falffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint099.phcleft
rsfMRI_fcnxpro134_alffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint099.phcleft
rsfMRI_fcnxpro134_perafPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint099.phcleft
rsfMRI_fcnxpro134_falffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint100.phcleft
rsfMRI_fcnxpro134_alffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint100.phcleft
rsfMRI_fcnxpro134_perafPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint100.phcleft
rsfMRI_fcnxpro134_falffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint101.stleft
rsfMRI_fcnxpro134_alffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint101.stleft
rsfMRI_fcnxpro134_perafPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint101.stleft
rsfMRI_fcnxpro134_falffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint102.temppoleleft
rsfMRI_fcnxpro134_alffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint102.temppoleleft
rsfMRI_fcnxpro134_perafPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint102.temppoleleft
rsfMRI_fcnxpro134_falffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint103.temppoleleft
rsfMRI_fcnxpro134_alffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint103.temppoleleft
rsfMRI_fcnxpro134_perafPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint103.temppoleleft
rsfMRI_fcnxpro134_falffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint104.temppoleleft
rsfMRI_fcnxpro134_alffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint104.temppoleleft
rsfMRI_fcnxpro134_perafPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint104.temppoleleft
rsfMRI_fcnxpro134_falffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint105.temppoleleft
rsfMRI_fcnxpro134_alffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint105.temppoleleft
rsfMRI_fcnxpro134_perafPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint105.temppoleleft
rsfMRI_fcnxpro134_falffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint106.temppoleleft
rsfMRI_fcnxpro134_alffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint106.temppoleleft
rsfMRI_fcnxpro134_perafPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint106.temppoleleft
rsfMRI_fcnxpro134_falffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint107.templeft
rsfMRI_fcnxpro134_alffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint107.templeft
rsfMRI_fcnxpro134_perafPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint107.templeft
rsfMRI_fcnxpro134_falffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint108.templeft
rsfMRI_fcnxpro134_alffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint108.templeft
rsfMRI_fcnxpro134_perafPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint108.templeft
rsfMRI_fcnxpro134_falffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint109.templeft
rsfMRI_fcnxpro134_alffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint109.templeft
rsfMRI_fcnxpro134_perafPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint109.templeft
rsfMRI_fcnxpro134_falffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint110.templeft
rsfMRI_fcnxpro134_alffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint110.templeft
rsfMRI_fcnxpro134_perafPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint110.templeft
rsfMRI_fcnxpro134_falffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint111.fpoleleft
rsfMRI_fcnxpro134_alffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint111.fpoleleft
rsfMRI_fcnxpro134_perafPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint111.fpoleleft
rsfMRI_fcnxpro134_falffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint112.ofcleft
rsfMRI_fcnxpro134_alffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint112.ofcleft
rsfMRI_fcnxpro134_perafPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint112.ofcleft
rsfMRI_fcnxpro134_falffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint113.ofcleft
rsfMRI_fcnxpro134_alffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint113.ofcleft
rsfMRI_fcnxpro134_perafPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint113.ofcleft
rsfMRI_fcnxpro134_falffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint114.ofcleft
rsfMRI_fcnxpro134_alffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint114.ofcleft
rsfMRI_fcnxpro134_perafPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint114.ofcleft
rsfMRI_fcnxpro134_falffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint115.ofcleft
rsfMRI_fcnxpro134_alffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint115.ofcleft
rsfMRI_fcnxpro134_perafPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint115.ofcleft
rsfMRI_fcnxpro134_falffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint116.ofcleft
rsfMRI_fcnxpro134_alffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint116.ofcleft
rsfMRI_fcnxpro134_perafPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint116.ofcleft
rsfMRI_fcnxpro134_falffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint117.ofcleft
rsfMRI_fcnxpro134_alffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint117.ofcleft
rsfMRI_fcnxpro134_perafPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint117.ofcleft
rsfMRI_fcnxpro134_falffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint118.pfcmleft
rsfMRI_fcnxpro134_alffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint118.pfcmleft
rsfMRI_fcnxpro134_perafPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint118.pfcmleft
rsfMRI_fcnxpro134_falffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint119.pfcmleft
rsfMRI_fcnxpro134_alffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint119.pfcmleft
rsfMRI_fcnxpro134_perafPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint119.pfcmleft
rsfMRI_fcnxpro134_falffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint120.frmedleft
rsfMRI_fcnxpro134_alffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint120.frmedleft
rsfMRI_fcnxpro134_perafPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint120.frmedleft
rsfMRI_fcnxpro134_falffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint121.insleft
rsfMRI_fcnxpro134_alffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint121.insleft
rsfMRI_fcnxpro134_perafPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint121.insleft
rsfMRI_fcnxpro134_falffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint122.insleft
rsfMRI_fcnxpro134_alffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint122.insleft
rsfMRI_fcnxpro134_perafPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint122.insleft
rsfMRI_fcnxpro134_falffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint123.insleft
rsfMRI_fcnxpro134_alffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint123.insleft
rsfMRI_fcnxpro134_perafPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint123.insleft
rsfMRI_fcnxpro134_falffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint124.pfclleft
rsfMRI_fcnxpro134_alffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint124.pfclleft
rsfMRI_fcnxpro134_perafPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint124.pfclleft
rsfMRI_fcnxpro134_falffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint125.pfclleft
rsfMRI_fcnxpro134_alffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint125.pfclleft
rsfMRI_fcnxpro134_perafPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint125.pfclleft
rsfMRI_fcnxpro134_falffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint126.pfcmleft
rsfMRI_fcnxpro134_alffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint126.pfcmleft
rsfMRI_fcnxpro134_perafPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint126.pfcmleft
rsfMRI_fcnxpro134_falffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint127.frmedleft
rsfMRI_fcnxpro134_alffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint127.frmedleft
rsfMRI_fcnxpro134_perafPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint127.frmedleft
rsfMRI_fcnxpro134_falffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint128.frmedleft
rsfMRI_fcnxpro134_alffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint128.frmedleft
rsfMRI_fcnxpro134_perafPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint128.frmedleft
rsfMRI_fcnxpro134_falffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint129.frmedleft
rsfMRI_fcnxpro134_alffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint129.frmedleft
rsfMRI_fcnxpro134_perafPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint129.frmedleft
rsfMRI_fcnxpro134_falffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint130.froperleft
rsfMRI_fcnxpro134_alffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint130.froperleft
rsfMRI_fcnxpro134_perafPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint130.froperleft
rsfMRI_fcnxpro134_falffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint131.froperleft
rsfMRI_fcnxpro134_alffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint131.froperleft
rsfMRI_fcnxpro134_perafPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint131.froperleft
rsfMRI_fcnxpro134_falffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint132.iplleft
rsfMRI_fcnxpro134_alffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint132.iplleft
rsfMRI_fcnxpro134_perafPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint132.iplleft
rsfMRI_fcnxpro134_falffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint133.iplleft
rsfMRI_fcnxpro134_alffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint133.iplleft
rsfMRI_fcnxpro134_perafPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint133.iplleft
rsfMRI_fcnxpro134_falffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint134.insleft
rsfMRI_fcnxpro134_alffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint134.insleft
rsfMRI_fcnxpro134_perafPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint134.insleft
rsfMRI_fcnxpro134_falffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint135.insleft
rsfMRI_fcnxpro134_alffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint135.insleft
rsfMRI_fcnxpro134_perafPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint135.insleft
rsfMRI_fcnxpro134_falffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint136.insleft
rsfMRI_fcnxpro134_alffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint136.insleft
rsfMRI_fcnxpro134_perafPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint136.insleft
rsfMRI_fcnxpro134_falffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint137.insleft
rsfMRI_fcnxpro134_alffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint137.insleft
rsfMRI_fcnxpro134_perafPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint137.insleft
rsfMRI_fcnxpro134_falffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint138.insleft
rsfMRI_fcnxpro134_alffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint138.insleft
rsfMRI_fcnxpro134_perafPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint138.insleft
rsfMRI_fcnxpro134_falffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint139.splleft
rsfMRI_fcnxpro134_alffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint139.splleft
rsfMRI_fcnxpro134_perafPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint139.splleft
rsfMRI_fcnxpro134_falffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint140.splleft
rsfMRI_fcnxpro134_alffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint140.splleft
rsfMRI_fcnxpro134_perafPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint140.splleft
rsfMRI_fcnxpro134_falffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint141.splleft
rsfMRI_fcnxpro134_alffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint141.splleft
rsfMRI_fcnxpro134_perafPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint141.splleft
rsfMRI_fcnxpro134_falffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint142.iplleft
rsfMRI_fcnxpro134_alffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint142.iplleft
rsfMRI_fcnxpro134_perafPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint142.iplleft
rsfMRI_fcnxpro134_falffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint143.iplleft
rsfMRI_fcnxpro134_alffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint143.iplleft
rsfMRI_fcnxpro134_perafPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint143.iplleft
rsfMRI_fcnxpro134_falffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint144.pfcdleft
rsfMRI_fcnxpro134_alffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint144.pfcdleft
rsfMRI_fcnxpro134_perafPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint144.pfcdleft
rsfMRI_fcnxpro134_falffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint145.postcleft
rsfMRI_fcnxpro134_alffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint145.postcleft
rsfMRI_fcnxpro134_perafPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint145.postcleft
rsfMRI_fcnxpro134_falffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint146.postcleft
rsfMRI_fcnxpro134_alffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint146.postcleft
rsfMRI_fcnxpro134_perafPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint146.postcleft
rsfMRI_fcnxpro134_falffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint147.postcleft
rsfMRI_fcnxpro134_alffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint147.postcleft
rsfMRI_fcnxpro134_perafPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint147.postcleft
rsfMRI_fcnxpro134_falffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint148.prcdleft
rsfMRI_fcnxpro134_alffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint148.prcdleft
rsfMRI_fcnxpro134_perafPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint148.prcdleft
rsfMRI_fcnxpro134_falffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint149.prcdleft
rsfMRI_fcnxpro134_alffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint149.prcdleft
rsfMRI_fcnxpro134_perafPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint149.prcdleft
rsfMRI_fcnxpro134_falffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint150.prcdleft
rsfMRI_fcnxpro134_alffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint150.prcdleft
rsfMRI_fcnxpro134_perafPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint150.prcdleft
rsfMRI_fcnxpro134_falffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint151.splleft
rsfMRI_fcnxpro134_alffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint151.splleft
rsfMRI_fcnxpro134_perafPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint151.splleft
rsfMRI_fcnxpro134_falffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint152.splleft
rsfMRI_fcnxpro134_alffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint152.splleft
rsfMRI_fcnxpro134_perafPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint152.splleft
rsfMRI_fcnxpro134_falffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint153.splleft
rsfMRI_fcnxpro134_alffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint153.splleft
rsfMRI_fcnxpro134_perafPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint153.splleft
rsfMRI_fcnxpro134_falffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint154.splleft
rsfMRI_fcnxpro134_alffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint154.splleft
rsfMRI_fcnxpro134_perafPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint154.splleft
rsfMRI_fcnxpro134_falffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint155.tempoccleft
rsfMRI_fcnxpro134_alffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint155.tempoccleft
rsfMRI_fcnxpro134_perafPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint155.tempoccleft
rsfMRI_fcnxpro134_falffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint156.exstrleft
rsfMRI_fcnxpro134_alffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint156.exstrleft
rsfMRI_fcnxpro134_perafPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint156.exstrleft
rsfMRI_fcnxpro134_falffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint157.exstrleft
rsfMRI_fcnxpro134_alffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint157.exstrleft
rsfMRI_fcnxpro134_perafPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint157.exstrleft
rsfMRI_fcnxpro134_falffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint158.exstrleft
rsfMRI_fcnxpro134_alffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint158.exstrleft
rsfMRI_fcnxpro134_perafPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint158.exstrleft
rsfMRI_fcnxpro134_falffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint159.exstrleft
rsfMRI_fcnxpro134_alffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint159.exstrleft
rsfMRI_fcnxpro134_perafPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint159.exstrleft
rsfMRI_fcnxpro134_falffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint160.ipsleft
rsfMRI_fcnxpro134_alffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint160.ipsleft
rsfMRI_fcnxpro134_perafPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint160.ipsleft
rsfMRI_fcnxpro134_falffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint161.splleft
rsfMRI_fcnxpro134_alffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint161.splleft
rsfMRI_fcnxpro134_perafPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint161.splleft
rsfMRI_fcnxpro134_falffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint162.splleft
rsfMRI_fcnxpro134_alffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint162.splleft
rsfMRI_fcnxpro134_perafPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint162.splleft
rsfMRI_fcnxpro134_falffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint163.splleft
rsfMRI_fcnxpro134_alffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint163.splleft
rsfMRI_fcnxpro134_perafPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint163.splleft
rsfMRI_fcnxpro134_falffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint164.splleft
rsfMRI_fcnxpro134_alffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint164.splleft
rsfMRI_fcnxpro134_perafPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint164.splleft
rsfMRI_fcnxpro134_falffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint165.splleft
rsfMRI_fcnxpro134_alffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint165.splleft
rsfMRI_fcnxpro134_perafPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint165.splleft
rsfMRI_fcnxpro134_falffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint166.splleft
rsfMRI_fcnxpro134_alffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint166.splleft
rsfMRI_fcnxpro134_perafPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint166.splleft
rsfMRI_fcnxpro134_falffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint167.tempoccleft
rsfMRI_fcnxpro134_alffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint167.tempoccleft
rsfMRI_fcnxpro134_perafPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint167.tempoccleft
rsfMRI_fcnxpro134_falffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint168.tempoccleft
rsfMRI_fcnxpro134_alffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint168.tempoccleft
rsfMRI_fcnxpro134_perafPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint168.tempoccleft
rsfMRI_fcnxpro134_falffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint169.tempoccleft
rsfMRI_fcnxpro134_alffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint169.tempoccleft
rsfMRI_fcnxpro134_perafPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint169.tempoccleft
rsfMRI_fcnxpro134_falffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint170.tempoccleft
rsfMRI_fcnxpro134_alffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint170.tempoccleft
rsfMRI_fcnxpro134_perafPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint170.tempoccleft
rsfMRI_fcnxpro134_falffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint171.tempoccleft
rsfMRI_fcnxpro134_alffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint171.tempoccleft
rsfMRI_fcnxpro134_perafPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint171.tempoccleft
rsfMRI_fcnxpro134_falffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint172.tempoccleft
rsfMRI_fcnxpro134_alffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint172.tempoccleft
rsfMRI_fcnxpro134_perafPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint172.tempoccleft
rsfMRI_fcnxpro134_falffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint173.tempoccleft
rsfMRI_fcnxpro134_alffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint173.tempoccleft
rsfMRI_fcnxpro134_perafPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint173.tempoccleft
rsfMRI_fcnxpro134_falffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint174.tempoccleft
rsfMRI_fcnxpro134_alffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint174.tempoccleft
rsfMRI_fcnxpro134_perafPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint174.tempoccleft
rsfMRI_fcnxpro134_falffPoint175_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint175.1left
rsfMRI_fcnxpro134_alffPoint175_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint175.1left
rsfMRI_fcnxpro134_perafPoint175_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint175.1left
rsfMRI_fcnxpro134_falffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint176.2left
rsfMRI_fcnxpro134_alffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint176.2left
rsfMRI_fcnxpro134_perafPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint176.2left
rsfMRI_fcnxpro134_falffPoint177_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint177.3left
rsfMRI_fcnxpro134_alffPoint177_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint177.3left
rsfMRI_fcnxpro134_perafPoint177_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint177.3left
rsfMRI_fcnxpro134_falffPoint178_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint178.4left
rsfMRI_fcnxpro134_alffPoint178_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint178.4left
rsfMRI_fcnxpro134_perafPoint178_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint178.4left
rsfMRI_fcnxpro134_falffPoint179_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint179.5left
rsfMRI_fcnxpro134_alffPoint179_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint179.5left
rsfMRI_fcnxpro134_perafPoint179_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint179.5left
rsfMRI_fcnxpro134_falffPoint180_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint180.6left
rsfMRI_fcnxpro134_alffPoint180_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint180.6left
rsfMRI_fcnxpro134_perafPoint180_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint180.6left
rsfMRI_fcnxpro134_falffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint181.iplleft
rsfMRI_fcnxpro134_alffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint181.iplleft
rsfMRI_fcnxpro134_perafPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint181.iplleft
rsfMRI_fcnxpro134_falffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint182.insleft
rsfMRI_fcnxpro134_alffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint182.insleft
rsfMRI_fcnxpro134_perafPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint182.insleft
rsfMRI_fcnxpro134_falffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint183.insleft
rsfMRI_fcnxpro134_alffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint183.insleft
rsfMRI_fcnxpro134_perafPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint183.insleft
rsfMRI_fcnxpro134_falffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint184.paroperleft
rsfMRI_fcnxpro134_alffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint184.paroperleft
rsfMRI_fcnxpro134_perafPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint184.paroperleft
rsfMRI_fcnxpro134_falffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint185.paroperleft
rsfMRI_fcnxpro134_alffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint185.paroperleft
rsfMRI_fcnxpro134_perafPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint185.paroperleft
rsfMRI_fcnxpro134_falffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint186.paroperleft
rsfMRI_fcnxpro134_alffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint186.paroperleft
rsfMRI_fcnxpro134_perafPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint186.paroperleft
rsfMRI_fcnxpro134_falffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint187.stleft
rsfMRI_fcnxpro134_alffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint187.stleft
rsfMRI_fcnxpro134_perafPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint187.stleft
rsfMRI_fcnxpro134_falffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint188.stleft
rsfMRI_fcnxpro134_alffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint188.stleft
rsfMRI_fcnxpro134_perafPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint188.stleft
rsfMRI_fcnxpro134_falffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint189.stleft
rsfMRI_fcnxpro134_alffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint189.stleft
rsfMRI_fcnxpro134_perafPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint189.stleft
rsfMRI_fcnxpro134_falffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint190.stleft
rsfMRI_fcnxpro134_alffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint190.stleft
rsfMRI_fcnxpro134_perafPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint190.stleft
rsfMRI_fcnxpro134_falffPoint191_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint191.1left
rsfMRI_fcnxpro134_alffPoint191_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint191.1left
rsfMRI_fcnxpro134_perafPoint191_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint191.1left
rsfMRI_fcnxpro134_falffPoint192_10left
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint192.10left
rsfMRI_fcnxpro134_alffPoint192_10left
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint192.10left
rsfMRI_fcnxpro134_perafPoint192_10left
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint192.10left
rsfMRI_fcnxpro134_falffPoint193_11left
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint193.11left
rsfMRI_fcnxpro134_alffPoint193_11left
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint193.11left
rsfMRI_fcnxpro134_perafPoint193_11left
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint193.11left
rsfMRI_fcnxpro134_falffPoint194_12left
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint194.12left
rsfMRI_fcnxpro134_alffPoint194_12left
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint194.12left
rsfMRI_fcnxpro134_perafPoint194_12left
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint194.12left
rsfMRI_fcnxpro134_falffPoint195_13left
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint195.13left
rsfMRI_fcnxpro134_alffPoint195_13left
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint195.13left
rsfMRI_fcnxpro134_perafPoint195_13left
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint195.13left
rsfMRI_fcnxpro134_falffPoint196_14left
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint196.14left
rsfMRI_fcnxpro134_alffPoint196_14left
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint196.14left
rsfMRI_fcnxpro134_perafPoint196_14left
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint196.14left
rsfMRI_fcnxpro134_falffPoint197_15left
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint197.15left
rsfMRI_fcnxpro134_alffPoint197_15left
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint197.15left
rsfMRI_fcnxpro134_perafPoint197_15left
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint197.15left
rsfMRI_fcnxpro134_falffPoint198_16left
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint198.16left
rsfMRI_fcnxpro134_alffPoint198_16left
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint198.16left
rsfMRI_fcnxpro134_perafPoint198_16left
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint198.16left
rsfMRI_fcnxpro134_falffPoint199_17left
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint199.17left
rsfMRI_fcnxpro134_alffPoint199_17left
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint199.17left
rsfMRI_fcnxpro134_perafPoint199_17left
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint199.17left
rsfMRI_fcnxpro134_falffPoint200_18left
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint200.18left
rsfMRI_fcnxpro134_alffPoint200_18left
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint200.18left
rsfMRI_fcnxpro134_perafPoint200_18left
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint200.18left
rsfMRI_fcnxpro134_falffPoint201_19left
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint201.19left
rsfMRI_fcnxpro134_alffPoint201_19left
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint201.19left
rsfMRI_fcnxpro134_perafPoint201_19left
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint201.19left
rsfMRI_fcnxpro134_falffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint202.2left
rsfMRI_fcnxpro134_alffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint202.2left
rsfMRI_fcnxpro134_perafPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint202.2left
rsfMRI_fcnxpro134_falffPoint203_20left
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint203.20left
rsfMRI_fcnxpro134_alffPoint203_20left
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint203.20left
rsfMRI_fcnxpro134_perafPoint203_20left
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint203.20left
rsfMRI_fcnxpro134_falffPoint204_21left
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint204.21left
rsfMRI_fcnxpro134_alffPoint204_21left
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint204.21left
rsfMRI_fcnxpro134_perafPoint204_21left
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint204.21left
rsfMRI_fcnxpro134_falffPoint205_22left
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint205.22left
rsfMRI_fcnxpro134_alffPoint205_22left
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint205.22left
rsfMRI_fcnxpro134_perafPoint205_22left
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint205.22left
rsfMRI_fcnxpro134_falffPoint206_23left
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint206.23left
rsfMRI_fcnxpro134_alffPoint206_23left
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint206.23left
rsfMRI_fcnxpro134_perafPoint206_23left
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint206.23left
rsfMRI_fcnxpro134_falffPoint207_24left
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint207.24left
rsfMRI_fcnxpro134_alffPoint207_24left
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint207.24left
rsfMRI_fcnxpro134_perafPoint207_24left
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint207.24left
rsfMRI_fcnxpro134_falffPoint208_25left
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint208.25left
rsfMRI_fcnxpro134_alffPoint208_25left
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint208.25left
rsfMRI_fcnxpro134_perafPoint208_25left
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint208.25left
rsfMRI_fcnxpro134_falffPoint209_26left
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint209.26left
rsfMRI_fcnxpro134_alffPoint209_26left
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint209.26left
rsfMRI_fcnxpro134_perafPoint209_26left
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint209.26left
rsfMRI_fcnxpro134_falffPoint210_27left
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint210.27left
rsfMRI_fcnxpro134_alffPoint210_27left
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint210.27left
rsfMRI_fcnxpro134_perafPoint210_27left
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint210.27left
rsfMRI_fcnxpro134_falffPoint211_28left
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint211.28left
rsfMRI_fcnxpro134_alffPoint211_28left
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint211.28left
rsfMRI_fcnxpro134_perafPoint211_28left
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint211.28left
rsfMRI_fcnxpro134_falffPoint212_29left
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint212.29left
rsfMRI_fcnxpro134_alffPoint212_29left
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint212.29left
rsfMRI_fcnxpro134_perafPoint212_29left
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint212.29left
rsfMRI_fcnxpro134_falffPoint213_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint213.3left
rsfMRI_fcnxpro134_alffPoint213_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint213.3left
rsfMRI_fcnxpro134_perafPoint213_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint213.3left
rsfMRI_fcnxpro134_falffPoint214_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint214.4left
rsfMRI_fcnxpro134_alffPoint214_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint214.4left
rsfMRI_fcnxpro134_perafPoint214_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint214.4left
rsfMRI_fcnxpro134_falffPoint215_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint215.5left
rsfMRI_fcnxpro134_alffPoint215_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint215.5left
rsfMRI_fcnxpro134_perafPoint215_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint215.5left
rsfMRI_fcnxpro134_falffPoint216_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint216.6left
rsfMRI_fcnxpro134_alffPoint216_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint216.6left
rsfMRI_fcnxpro134_perafPoint216_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint216.6left
rsfMRI_fcnxpro134_falffPoint217_7left
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint217.7left
rsfMRI_fcnxpro134_alffPoint217_7left
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint217.7left
rsfMRI_fcnxpro134_perafPoint217_7left
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint217.7left
rsfMRI_fcnxpro134_falffPoint218_8left
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint218.8left
rsfMRI_fcnxpro134_alffPoint218_8left
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint218.8left
rsfMRI_fcnxpro134_perafPoint218_8left
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint218.8left
rsfMRI_fcnxpro134_falffPoint219_9left
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint219.9left
rsfMRI_fcnxpro134_alffPoint219_9left
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint219.9left
rsfMRI_fcnxpro134_perafPoint219_9left
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint219.9left
rsfMRI_fcnxpro134_falffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint220.splleft
rsfMRI_fcnxpro134_alffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint220.splleft
rsfMRI_fcnxpro134_perafPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint220.splleft
rsfMRI_fcnxpro134_falffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint221.exstrleft
rsfMRI_fcnxpro134_alffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint221.exstrleft
rsfMRI_fcnxpro134_perafPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint221.exstrleft
rsfMRI_fcnxpro134_falffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint222.exstrinfleft
rsfMRI_fcnxpro134_alffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint222.exstrinfleft
rsfMRI_fcnxpro134_perafPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint222.exstrinfleft
rsfMRI_fcnxpro134_falffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint223.exstrinfleft
rsfMRI_fcnxpro134_alffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint223.exstrinfleft
rsfMRI_fcnxpro134_perafPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint223.exstrinfleft
rsfMRI_fcnxpro134_falffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint224.exstrinfleft
rsfMRI_fcnxpro134_alffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint224.exstrinfleft
rsfMRI_fcnxpro134_perafPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint224.exstrinfleft
rsfMRI_fcnxpro134_falffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint225.exstrinfleft
rsfMRI_fcnxpro134_alffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint225.exstrinfleft
rsfMRI_fcnxpro134_perafPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint225.exstrinfleft
rsfMRI_fcnxpro134_falffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint226.exstrinfleft
rsfMRI_fcnxpro134_alffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint226.exstrinfleft
rsfMRI_fcnxpro134_perafPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint226.exstrinfleft
rsfMRI_fcnxpro134_falffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint227.exstrsupleft
rsfMRI_fcnxpro134_alffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint227.exstrsupleft
rsfMRI_fcnxpro134_perafPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint227.exstrsupleft
rsfMRI_fcnxpro134_falffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint228.exstrsupleft
rsfMRI_fcnxpro134_alffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint228.exstrsupleft
rsfMRI_fcnxpro134_perafPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint228.exstrsupleft
rsfMRI_fcnxpro134_falffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint229.exstrsupleft
rsfMRI_fcnxpro134_alffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint229.exstrsupleft
rsfMRI_fcnxpro134_perafPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint229.exstrsupleft
rsfMRI_fcnxpro134_falffPoint230_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint230.striateleft
rsfMRI_fcnxpro134_alffPoint230_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint230.striateleft
rsfMRI_fcnxpro134_perafPoint230_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint230.striateleft
rsfMRI_fcnxpro134_falffPoint231_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint231.striateleft
rsfMRI_fcnxpro134_alffPoint231_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint231.striateleft
rsfMRI_fcnxpro134_perafPoint231_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint231.striateleft
rsfMRI_fcnxpro134_falffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint232.exstrinfleft
rsfMRI_fcnxpro134_alffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint232.exstrinfleft
rsfMRI_fcnxpro134_perafPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint232.exstrinfleft
rsfMRI_fcnxpro134_falffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint233.exstrleft
rsfMRI_fcnxpro134_alffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint233.exstrleft
rsfMRI_fcnxpro134_perafPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint233.exstrleft
rsfMRI_fcnxpro134_falffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint234.exstrleft
rsfMRI_fcnxpro134_alffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint234.exstrleft
rsfMRI_fcnxpro134_perafPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint234.exstrleft
rsfMRI_fcnxpro134_falffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint235.exstrleft
rsfMRI_fcnxpro134_alffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint235.exstrleft
rsfMRI_fcnxpro134_perafPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint235.exstrleft
rsfMRI_fcnxpro134_falffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint236.exstrleft
rsfMRI_fcnxpro134_alffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint236.exstrleft
rsfMRI_fcnxpro134_perafPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint236.exstrleft
rsfMRI_fcnxpro134_falffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint237.exstrleft
rsfMRI_fcnxpro134_alffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint237.exstrleft
rsfMRI_fcnxpro134_perafPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint237.exstrleft
rsfMRI_fcnxpro134_falffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint238.exstrleft
rsfMRI_fcnxpro134_alffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint238.exstrleft
rsfMRI_fcnxpro134_perafPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint238.exstrleft
rsfMRI_fcnxpro134_falffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint239.exstrleft
rsfMRI_fcnxpro134_alffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint239.exstrleft
rsfMRI_fcnxpro134_perafPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint239.exstrleft
rsfMRI_fcnxpro134_falffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint240.exstrleft
rsfMRI_fcnxpro134_alffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint240.exstrleft
rsfMRI_fcnxpro134_perafPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint240.exstrleft
rsfMRI_fcnxpro134_falffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint241.exstrleft
rsfMRI_fcnxpro134_alffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint241.exstrleft
rsfMRI_fcnxpro134_perafPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint241.exstrleft
rsfMRI_fcnxpro134_falffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint242.exstrleft
rsfMRI_fcnxpro134_alffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint242.exstrleft
rsfMRI_fcnxpro134_perafPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint242.exstrleft
rsfMRI_fcnxpro134_falffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint243.exstrleft
rsfMRI_fcnxpro134_alffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint243.exstrleft
rsfMRI_fcnxpro134_perafPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint243.exstrleft
rsfMRI_fcnxpro134_falffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint244.exstrleft
rsfMRI_fcnxpro134_alffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint244.exstrleft
rsfMRI_fcnxpro134_perafPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint244.exstrleft
rsfMRI_fcnxpro134_falffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint245.exstrleft
rsfMRI_fcnxpro134_alffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint245.exstrleft
rsfMRI_fcnxpro134_perafPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint245.exstrleft
rsfMRI_fcnxpro134_falffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint246.exstrleft
rsfMRI_fcnxpro134_alffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint246.exstrleft
rsfMRI_fcnxpro134_perafPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint246.exstrleft
rsfMRI_fcnxpro134_falffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint247.exstrleft
rsfMRI_fcnxpro134_alffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint247.exstrleft
rsfMRI_fcnxpro134_perafPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint247.exstrleft
rsfMRI_fcnxpro134_falffPoint248_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint248.striateleft
rsfMRI_fcnxpro134_alffPoint248_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint248.striateleft
rsfMRI_fcnxpro134_perafPoint248_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint248.striateleft
rsfMRI_fcnxpro134_falffPoint249_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint249.striateleft
rsfMRI_fcnxpro134_alffPoint249_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint249.striateleft
rsfMRI_fcnxpro134_perafPoint249_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint249.striateleft
rsfMRI_fcnxpro134_falffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint250.iplright
rsfMRI_fcnxpro134_alffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint250.iplright
rsfMRI_fcnxpro134_perafPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint250.iplright
rsfMRI_fcnxpro134_falffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint251.stright
rsfMRI_fcnxpro134_alffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint251.stright
rsfMRI_fcnxpro134_perafPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint251.stright
rsfMRI_fcnxpro134_falffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint252.stright
rsfMRI_fcnxpro134_alffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint252.stright
rsfMRI_fcnxpro134_perafPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint252.stright
rsfMRI_fcnxpro134_falffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint253.tempoccright
rsfMRI_fcnxpro134_alffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint253.tempoccright
rsfMRI_fcnxpro134_perafPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint253.tempoccright
rsfMRI_fcnxpro134_falffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint254.tempright
rsfMRI_fcnxpro134_alffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint254.tempright
rsfMRI_fcnxpro134_perafPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint254.tempright
rsfMRI_fcnxpro134_falffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint255.tempright
rsfMRI_fcnxpro134_alffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint255.tempright
rsfMRI_fcnxpro134_perafPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint255.tempright
rsfMRI_fcnxpro134_falffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint256.exstrinfright
rsfMRI_fcnxpro134_alffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint256.exstrinfright
rsfMRI_fcnxpro134_perafPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint256.exstrinfright
rsfMRI_fcnxpro134_falffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint257.iplright
rsfMRI_fcnxpro134_alffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint257.iplright
rsfMRI_fcnxpro134_perafPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint257.iplright
rsfMRI_fcnxpro134_falffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint258.phcright
rsfMRI_fcnxpro134_alffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint258.phcright
rsfMRI_fcnxpro134_perafPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint258.phcright
rsfMRI_fcnxpro134_falffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint259.phcright
rsfMRI_fcnxpro134_alffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint259.phcright
rsfMRI_fcnxpro134_perafPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint259.phcright
rsfMRI_fcnxpro134_falffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint260.phcright
rsfMRI_fcnxpro134_alffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint260.phcright
rsfMRI_fcnxpro134_perafPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint260.phcright
rsfMRI_fcnxpro134_falffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint261.rscright
rsfMRI_fcnxpro134_alffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint261.rscright
rsfMRI_fcnxpro134_perafPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint261.rscright
rsfMRI_fcnxpro134_falffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint262.rscright
rsfMRI_fcnxpro134_alffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint262.rscright
rsfMRI_fcnxpro134_perafPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint262.rscright
rsfMRI_fcnxpro134_falffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint263.iplright
rsfMRI_fcnxpro134_alffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint263.iplright
rsfMRI_fcnxpro134_perafPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint263.iplright
rsfMRI_fcnxpro134_falffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint264.iplright
rsfMRI_fcnxpro134_alffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint264.iplright
rsfMRI_fcnxpro134_perafPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint264.iplright
rsfMRI_fcnxpro134_falffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint265.iplright
rsfMRI_fcnxpro134_alffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint265.iplright
rsfMRI_fcnxpro134_perafPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint265.iplright
rsfMRI_fcnxpro134_falffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint266.iplright
rsfMRI_fcnxpro134_alffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint266.iplright
rsfMRI_fcnxpro134_perafPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint266.iplright
rsfMRI_fcnxpro134_falffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint000.pfcdright
rsfMRI_fcnxpro134_alffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint000.pfcdright
rsfMRI_fcnxpro134_perafPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint000.pfcdright
rsfMRI_fcnxpro134_falffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint001.pfcdright
rsfMRI_fcnxpro134_alffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint001.pfcdright
rsfMRI_fcnxpro134_perafPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint001.pfcdright
rsfMRI_fcnxpro134_falffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint002.pfcdright
rsfMRI_fcnxpro134_alffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint002.pfcdright
rsfMRI_fcnxpro134_perafPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint002.pfcdright
rsfMRI_fcnxpro134_falffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint003.pfcdright
rsfMRI_fcnxpro134_alffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint003.pfcdright
rsfMRI_fcnxpro134_perafPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint003.pfcdright
rsfMRI_fcnxpro134_falffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint004.pfcdright
rsfMRI_fcnxpro134_alffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint004.pfcdright
rsfMRI_fcnxpro134_perafPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint004.pfcdright
rsfMRI_fcnxpro134_falffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint005.pfcdright
rsfMRI_fcnxpro134_alffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint005.pfcdright
rsfMRI_fcnxpro134_perafPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint005.pfcdright
rsfMRI_fcnxpro134_falffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint006.pfcdright
rsfMRI_fcnxpro134_alffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint006.pfcdright
rsfMRI_fcnxpro134_perafPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint006.pfcdright
rsfMRI_fcnxpro134_falffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint007.pfclright
rsfMRI_fcnxpro134_alffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint007.pfclright
rsfMRI_fcnxpro134_perafPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint007.pfclright
rsfMRI_fcnxpro134_falffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint008.pfclright
rsfMRI_fcnxpro134_alffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint008.pfclright
rsfMRI_fcnxpro134_perafPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint008.pfclright
rsfMRI_fcnxpro134_falffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint009.pfcvright
rsfMRI_fcnxpro134_alffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint009.pfcvright
rsfMRI_fcnxpro134_perafPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint009.pfcvright
rsfMRI_fcnxpro134_falffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint010.pfcvright
rsfMRI_fcnxpro134_alffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint010.pfcvright
rsfMRI_fcnxpro134_perafPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint010.pfcvright
rsfMRI_fcnxpro134_falffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint011.pfcvright
rsfMRI_fcnxpro134_alffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint011.pfcvright
rsfMRI_fcnxpro134_perafPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint011.pfcvright
rsfMRI_fcnxpro134_falffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint012.pfcvright
rsfMRI_fcnxpro134_alffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint012.pfcvright
rsfMRI_fcnxpro134_perafPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint012.pfcvright
rsfMRI_fcnxpro134_falffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint013.temppoleright
rsfMRI_fcnxpro134_alffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint013.temppoleright
rsfMRI_fcnxpro134_perafPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint013.temppoleright
rsfMRI_fcnxpro134_falffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint014.tempright
rsfMRI_fcnxpro134_alffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint014.tempright
rsfMRI_fcnxpro134_perafPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint014.tempright
rsfMRI_fcnxpro134_falffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint015.tempright
rsfMRI_fcnxpro134_alffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint015.tempright
rsfMRI_fcnxpro134_perafPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint015.tempright
rsfMRI_fcnxpro134_falffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint016.tempright
rsfMRI_fcnxpro134_alffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint016.tempright
rsfMRI_fcnxpro134_perafPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint016.tempright
rsfMRI_fcnxpro134_falffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint017.tempright
rsfMRI_fcnxpro134_alffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint017.tempright
rsfMRI_fcnxpro134_perafPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint017.tempright
rsfMRI_fcnxpro134_falffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint018.tempright
rsfMRI_fcnxpro134_alffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint018.tempright
rsfMRI_fcnxpro134_perafPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint018.tempright
rsfMRI_fcnxpro134_falffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint019.tempright
rsfMRI_fcnxpro134_alffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint019.tempright
rsfMRI_fcnxpro134_perafPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint019.tempright
rsfMRI_fcnxpro134_falffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint020.tempright
rsfMRI_fcnxpro134_alffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint020.tempright
rsfMRI_fcnxpro134_perafPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint020.tempright
rsfMRI_fcnxpro134_falffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint021.tempright
rsfMRI_fcnxpro134_alffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint021.tempright
rsfMRI_fcnxpro134_perafPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint021.tempright
rsfMRI_fcnxpro134_falffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint022.tempright
rsfMRI_fcnxpro134_alffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint022.tempright
rsfMRI_fcnxpro134_perafPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint022.tempright
rsfMRI_fcnxpro134_falffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint023.tempright
rsfMRI_fcnxpro134_alffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint023.tempright
rsfMRI_fcnxpro134_perafPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint023.tempright
rsfMRI_fcnxpro134_falffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint024.fpoleright
rsfMRI_fcnxpro134_alffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint024.fpoleright
rsfMRI_fcnxpro134_perafPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint024.fpoleright
rsfMRI_fcnxpro134_falffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint025.iplright
rsfMRI_fcnxpro134_alffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint025.iplright
rsfMRI_fcnxpro134_perafPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint025.iplright
rsfMRI_fcnxpro134_falffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint026.iplright
rsfMRI_fcnxpro134_alffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint026.iplright
rsfMRI_fcnxpro134_perafPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint026.iplright
rsfMRI_fcnxpro134_falffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint027.iplright
rsfMRI_fcnxpro134_alffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint027.iplright
rsfMRI_fcnxpro134_perafPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint027.iplright
rsfMRI_fcnxpro134_falffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint028.pccright
rsfMRI_fcnxpro134_alffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint028.pccright
rsfMRI_fcnxpro134_perafPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint028.pccright
rsfMRI_fcnxpro134_falffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint029.pccright
rsfMRI_fcnxpro134_alffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint029.pccright
rsfMRI_fcnxpro134_perafPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint029.pccright
rsfMRI_fcnxpro134_falffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint030.pccright
rsfMRI_fcnxpro134_alffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint030.pccright
rsfMRI_fcnxpro134_perafPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint030.pccright
rsfMRI_fcnxpro134_falffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint031.pccright
rsfMRI_fcnxpro134_alffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint031.pccright
rsfMRI_fcnxpro134_perafPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint031.pccright
rsfMRI_fcnxpro134_falffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint032.pccright
rsfMRI_fcnxpro134_alffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint032.pccright
rsfMRI_fcnxpro134_perafPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint032.pccright
rsfMRI_fcnxpro134_falffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint033.pccright
rsfMRI_fcnxpro134_alffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint033.pccright
rsfMRI_fcnxpro134_perafPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint033.pccright
rsfMRI_fcnxpro134_falffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint034.pccright
rsfMRI_fcnxpro134_alffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint034.pccright
rsfMRI_fcnxpro134_perafPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint034.pccright
rsfMRI_fcnxpro134_falffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint035.pfcdright
rsfMRI_fcnxpro134_alffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint035.pfcdright
rsfMRI_fcnxpro134_perafPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint035.pfcdright
rsfMRI_fcnxpro134_falffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint036.pfcdright
rsfMRI_fcnxpro134_alffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint036.pfcdright
rsfMRI_fcnxpro134_perafPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint036.pfcdright
rsfMRI_fcnxpro134_falffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint037.pfcdright
rsfMRI_fcnxpro134_alffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint037.pfcdright
rsfMRI_fcnxpro134_perafPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint037.pfcdright
rsfMRI_fcnxpro134_falffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint038.pfcdright
rsfMRI_fcnxpro134_alffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint038.pfcdright
rsfMRI_fcnxpro134_perafPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint038.pfcdright
rsfMRI_fcnxpro134_falffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint039.pfcmright
rsfMRI_fcnxpro134_alffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint039.pfcmright
rsfMRI_fcnxpro134_perafPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint039.pfcmright
rsfMRI_fcnxpro134_falffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint040.pfcmright
rsfMRI_fcnxpro134_alffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint040.pfcmright
rsfMRI_fcnxpro134_perafPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint040.pfcmright
rsfMRI_fcnxpro134_falffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint041.pfcmright
rsfMRI_fcnxpro134_alffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint041.pfcmright
rsfMRI_fcnxpro134_perafPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint041.pfcmright
rsfMRI_fcnxpro134_falffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint042.pfcmright
rsfMRI_fcnxpro134_alffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint042.pfcmright
rsfMRI_fcnxpro134_perafPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint042.pfcmright
rsfMRI_fcnxpro134_falffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint043.pfcmright
rsfMRI_fcnxpro134_alffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint043.pfcmright
rsfMRI_fcnxpro134_perafPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint043.pfcmright
rsfMRI_fcnxpro134_falffPoint044_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint044.pcunright
rsfMRI_fcnxpro134_alffPoint044_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint044.pcunright
rsfMRI_fcnxpro134_perafPoint044_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint044.pcunright
rsfMRI_fcnxpro134_falffPoint045_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint045.pcunright
rsfMRI_fcnxpro134_alffPoint045_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint045.pcunright
rsfMRI_fcnxpro134_perafPoint045_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint045.pcunright
rsfMRI_fcnxpro134_falffPoint046_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint046.pcunright
rsfMRI_fcnxpro134_alffPoint046_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint046.pcunright
rsfMRI_fcnxpro134_perafPoint046_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint046.pcunright
rsfMRI_fcnxpro134_falffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint047.pccright
rsfMRI_fcnxpro134_alffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint047.pccright
rsfMRI_fcnxpro134_perafPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint047.pccright
rsfMRI_fcnxpro134_falffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint048.splright
rsfMRI_fcnxpro134_alffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint048.splright
rsfMRI_fcnxpro134_perafPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint048.splright
rsfMRI_fcnxpro134_falffPoint049_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint049.pcunright
rsfMRI_fcnxpro134_alffPoint049_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint049.pcunright
rsfMRI_fcnxpro134_perafPoint049_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint049.pcunright
rsfMRI_fcnxpro134_falffPoint050_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint050.pcunright
rsfMRI_fcnxpro134_alffPoint050_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint050.pcunright
rsfMRI_fcnxpro134_perafPoint050_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint050.pcunright
rsfMRI_fcnxpro134_falffPoint051_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint051.pcunright
rsfMRI_fcnxpro134_alffPoint051_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint051.pcunright
rsfMRI_fcnxpro134_perafPoint051_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint051.pcunright
rsfMRI_fcnxpro134_falffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint052.fpoleright
rsfMRI_fcnxpro134_alffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint052.fpoleright
rsfMRI_fcnxpro134_perafPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint052.fpoleright
rsfMRI_fcnxpro134_falffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint053.fpoleright
rsfMRI_fcnxpro134_alffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint053.fpoleright
rsfMRI_fcnxpro134_perafPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint053.fpoleright
rsfMRI_fcnxpro134_falffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint054.frmedright
rsfMRI_fcnxpro134_alffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint054.frmedright
rsfMRI_fcnxpro134_perafPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint054.frmedright
rsfMRI_fcnxpro134_falffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint055.iplright
rsfMRI_fcnxpro134_alffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint055.iplright
rsfMRI_fcnxpro134_perafPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint055.iplright
rsfMRI_fcnxpro134_falffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint056.ipsright
rsfMRI_fcnxpro134_alffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint056.ipsright
rsfMRI_fcnxpro134_perafPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint056.ipsright
rsfMRI_fcnxpro134_falffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint057.ipsright
rsfMRI_fcnxpro134_alffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint057.ipsright
rsfMRI_fcnxpro134_perafPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint057.ipsright
rsfMRI_fcnxpro134_falffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint058.pfcdright
rsfMRI_fcnxpro134_alffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint058.pfcdright
rsfMRI_fcnxpro134_perafPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint058.pfcdright
rsfMRI_fcnxpro134_falffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint059.pfclright
rsfMRI_fcnxpro134_alffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint059.pfclright
rsfMRI_fcnxpro134_perafPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint059.pfclright
rsfMRI_fcnxpro134_falffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint060.pfcvright
rsfMRI_fcnxpro134_alffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint060.pfcvright
rsfMRI_fcnxpro134_perafPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint060.pfcvright
rsfMRI_fcnxpro134_falffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint061.tempright
rsfMRI_fcnxpro134_alffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint061.tempright
rsfMRI_fcnxpro134_perafPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint061.tempright
rsfMRI_fcnxpro134_falffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint062.tempright
rsfMRI_fcnxpro134_alffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint062.tempright
rsfMRI_fcnxpro134_perafPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint062.tempright
rsfMRI_fcnxpro134_falffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint063.cingmright
rsfMRI_fcnxpro134_alffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint063.cingmright
rsfMRI_fcnxpro134_perafPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint063.cingmright
rsfMRI_fcnxpro134_falffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint064.ipsright
rsfMRI_fcnxpro134_alffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint064.ipsright
rsfMRI_fcnxpro134_perafPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint064.ipsright
rsfMRI_fcnxpro134_falffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint065.ipsright
rsfMRI_fcnxpro134_alffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint065.ipsright
rsfMRI_fcnxpro134_perafPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint065.ipsright
rsfMRI_fcnxpro134_falffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint066.ipsright
rsfMRI_fcnxpro134_alffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint066.ipsright
rsfMRI_fcnxpro134_perafPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint066.ipsright
rsfMRI_fcnxpro134_falffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint067.ipsright
rsfMRI_fcnxpro134_alffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint067.ipsright
rsfMRI_fcnxpro134_perafPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint067.ipsright
rsfMRI_fcnxpro134_falffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint068.ipsright
rsfMRI_fcnxpro134_alffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint068.ipsright
rsfMRI_fcnxpro134_perafPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint068.ipsright
rsfMRI_fcnxpro134_falffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint069.pfcdright
rsfMRI_fcnxpro134_alffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint069.pfcdright
rsfMRI_fcnxpro134_perafPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint069.pfcdright
rsfMRI_fcnxpro134_falffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint070.pfclright
rsfMRI_fcnxpro134_alffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint070.pfclright
rsfMRI_fcnxpro134_perafPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint070.pfclright
rsfMRI_fcnxpro134_falffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint071.pfclright
rsfMRI_fcnxpro134_alffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint071.pfclright
rsfMRI_fcnxpro134_perafPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint071.pfclright
rsfMRI_fcnxpro134_falffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint072.pfclright
rsfMRI_fcnxpro134_alffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint072.pfclright
rsfMRI_fcnxpro134_perafPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint072.pfclright
rsfMRI_fcnxpro134_falffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint073.pfclright
rsfMRI_fcnxpro134_alffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint073.pfclright
rsfMRI_fcnxpro134_perafPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint073.pfclright
rsfMRI_fcnxpro134_falffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint074.pfclright
rsfMRI_fcnxpro134_alffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint074.pfclright
rsfMRI_fcnxpro134_perafPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint074.pfclright
rsfMRI_fcnxpro134_falffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint075.pfclright
rsfMRI_fcnxpro134_alffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint075.pfclright
rsfMRI_fcnxpro134_perafPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint075.pfclright
rsfMRI_fcnxpro134_falffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint076.prcvright
rsfMRI_fcnxpro134_alffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint076.prcvright
rsfMRI_fcnxpro134_perafPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint076.prcvright
rsfMRI_fcnxpro134_falffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint077.prcvright
rsfMRI_fcnxpro134_alffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint077.prcvright
rsfMRI_fcnxpro134_perafPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint077.prcvright
rsfMRI_fcnxpro134_falffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint078.prcvright
rsfMRI_fcnxpro134_alffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint078.prcvright
rsfMRI_fcnxpro134_perafPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint078.prcvright
rsfMRI_fcnxpro134_falffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint079.splright
rsfMRI_fcnxpro134_alffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint079.splright
rsfMRI_fcnxpro134_perafPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint079.splright
rsfMRI_fcnxpro134_falffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint080.tempoccright
rsfMRI_fcnxpro134_alffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint080.tempoccright
rsfMRI_fcnxpro134_perafPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint080.tempoccright
rsfMRI_fcnxpro134_falffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint081.insright
rsfMRI_fcnxpro134_alffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint081.insright
rsfMRI_fcnxpro134_perafPoint081_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint081.insright
rsfMRI_fcnxpro134_falffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint082.phcright
rsfMRI_fcnxpro134_alffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint082.phcright
rsfMRI_fcnxpro134_perafPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint082.phcright
rsfMRI_fcnxpro134_falffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint083.phcright
rsfMRI_fcnxpro134_alffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint083.phcright
rsfMRI_fcnxpro134_perafPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint083.phcright
rsfMRI_fcnxpro134_falffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint084.stright
rsfMRI_fcnxpro134_alffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint084.stright
rsfMRI_fcnxpro134_perafPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint084.stright
rsfMRI_fcnxpro134_falffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint085.temppoleright
rsfMRI_fcnxpro134_alffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint085.temppoleright
rsfMRI_fcnxpro134_perafPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint085.temppoleright
rsfMRI_fcnxpro134_falffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint086.temppoleright
rsfMRI_fcnxpro134_alffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint086.temppoleright
rsfMRI_fcnxpro134_perafPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint086.temppoleright
rsfMRI_fcnxpro134_falffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint087.temppoleright
rsfMRI_fcnxpro134_alffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint087.temppoleright
rsfMRI_fcnxpro134_perafPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint087.temppoleright
rsfMRI_fcnxpro134_falffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint088.temppoleright
rsfMRI_fcnxpro134_alffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint088.temppoleright
rsfMRI_fcnxpro134_perafPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint088.temppoleright
rsfMRI_fcnxpro134_falffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint089.temppoleright
rsfMRI_fcnxpro134_alffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint089.temppoleright
rsfMRI_fcnxpro134_perafPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint089.temppoleright
rsfMRI_fcnxpro134_falffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint090.tempright
rsfMRI_fcnxpro134_alffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint090.tempright
rsfMRI_fcnxpro134_perafPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint090.tempright
rsfMRI_fcnxpro134_falffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint091.tempright
rsfMRI_fcnxpro134_alffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint091.tempright
rsfMRI_fcnxpro134_perafPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint091.tempright
rsfMRI_fcnxpro134_falffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint092.tempright
rsfMRI_fcnxpro134_alffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint092.tempright
rsfMRI_fcnxpro134_perafPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint092.tempright
rsfMRI_fcnxpro134_falffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint093.tempright
rsfMRI_fcnxpro134_alffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint093.tempright
rsfMRI_fcnxpro134_perafPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint093.tempright
rsfMRI_fcnxpro134_falffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint094.fpoleright
rsfMRI_fcnxpro134_alffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint094.fpoleright
rsfMRI_fcnxpro134_perafPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint094.fpoleright
rsfMRI_fcnxpro134_falffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint095.ofcright
rsfMRI_fcnxpro134_alffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint095.ofcright
rsfMRI_fcnxpro134_perafPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint095.ofcright
rsfMRI_fcnxpro134_falffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint096.ofcright
rsfMRI_fcnxpro134_alffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint096.ofcright
rsfMRI_fcnxpro134_perafPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint096.ofcright
rsfMRI_fcnxpro134_falffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint097.ofcright
rsfMRI_fcnxpro134_alffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint097.ofcright
rsfMRI_fcnxpro134_perafPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint097.ofcright
rsfMRI_fcnxpro134_falffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint098.ofcright
rsfMRI_fcnxpro134_alffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint098.ofcright
rsfMRI_fcnxpro134_perafPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint098.ofcright
rsfMRI_fcnxpro134_falffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint099.ofcright
rsfMRI_fcnxpro134_alffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint099.ofcright
rsfMRI_fcnxpro134_perafPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint099.ofcright
rsfMRI_fcnxpro134_falffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint100.ofcright
rsfMRI_fcnxpro134_alffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint100.ofcright
rsfMRI_fcnxpro134_perafPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint100.ofcright
rsfMRI_fcnxpro134_falffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint101.pfcmright
rsfMRI_fcnxpro134_alffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint101.pfcmright
rsfMRI_fcnxpro134_perafPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint101.pfcmright
rsfMRI_fcnxpro134_falffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint102.pfcmright
rsfMRI_fcnxpro134_alffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint102.pfcmright
rsfMRI_fcnxpro134_perafPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint102.pfcmright
rsfMRI_fcnxpro134_falffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint103.frmedright
rsfMRI_fcnxpro134_alffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint103.frmedright
rsfMRI_fcnxpro134_perafPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint103.frmedright
rsfMRI_fcnxpro134_falffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint104.insright
rsfMRI_fcnxpro134_alffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint104.insright
rsfMRI_fcnxpro134_perafPoint104_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint104.insright
rsfMRI_fcnxpro134_falffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint105.insright
rsfMRI_fcnxpro134_alffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint105.insright
rsfMRI_fcnxpro134_perafPoint105_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint105.insright
rsfMRI_fcnxpro134_falffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint106.insright
rsfMRI_fcnxpro134_alffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint106.insright
rsfMRI_fcnxpro134_perafPoint106_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint106.insright
rsfMRI_fcnxpro134_falffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint107.pfclright
rsfMRI_fcnxpro134_alffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint107.pfclright
rsfMRI_fcnxpro134_perafPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint107.pfclright
rsfMRI_fcnxpro134_falffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint108.pfclright
rsfMRI_fcnxpro134_alffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint108.pfclright
rsfMRI_fcnxpro134_perafPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint108.pfclright
rsfMRI_fcnxpro134_falffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint109.pfcmright
rsfMRI_fcnxpro134_alffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint109.pfcmright
rsfMRI_fcnxpro134_perafPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint109.pfcmright
rsfMRI_fcnxpro134_falffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint110.frmedright
rsfMRI_fcnxpro134_alffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint110.frmedright
rsfMRI_fcnxpro134_perafPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint110.frmedright
rsfMRI_fcnxpro134_falffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint111.frmedright
rsfMRI_fcnxpro134_alffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint111.frmedright
rsfMRI_fcnxpro134_perafPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint111.frmedright
rsfMRI_fcnxpro134_falffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint112.frmedright
rsfMRI_fcnxpro134_alffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint112.frmedright
rsfMRI_fcnxpro134_perafPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint112.frmedright
rsfMRI_fcnxpro134_falffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint113.froperright
rsfMRI_fcnxpro134_alffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint113.froperright
rsfMRI_fcnxpro134_perafPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint113.froperright
rsfMRI_fcnxpro134_falffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint114.froperright
rsfMRI_fcnxpro134_alffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint114.froperright
rsfMRI_fcnxpro134_perafPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint114.froperright
rsfMRI_fcnxpro134_falffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint115.iplright
rsfMRI_fcnxpro134_alffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint115.iplright
rsfMRI_fcnxpro134_perafPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint115.iplright
rsfMRI_fcnxpro134_falffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint116.iplright
rsfMRI_fcnxpro134_alffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint116.iplright
rsfMRI_fcnxpro134_perafPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint116.iplright
rsfMRI_fcnxpro134_falffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint117.insright
rsfMRI_fcnxpro134_alffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint117.insright
rsfMRI_fcnxpro134_perafPoint117_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint117.insright
rsfMRI_fcnxpro134_falffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint118.insright
rsfMRI_fcnxpro134_alffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint118.insright
rsfMRI_fcnxpro134_perafPoint118_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint118.insright
rsfMRI_fcnxpro134_falffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint119.insright
rsfMRI_fcnxpro134_alffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint119.insright
rsfMRI_fcnxpro134_perafPoint119_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint119.insright
rsfMRI_fcnxpro134_falffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint120.insright
rsfMRI_fcnxpro134_alffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint120.insright
rsfMRI_fcnxpro134_perafPoint120_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint120.insright
rsfMRI_fcnxpro134_falffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint121.insright
rsfMRI_fcnxpro134_alffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint121.insright
rsfMRI_fcnxpro134_perafPoint121_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint121.insright
rsfMRI_fcnxpro134_falffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint122.splright
rsfMRI_fcnxpro134_alffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint122.splright
rsfMRI_fcnxpro134_perafPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint122.splright
rsfMRI_fcnxpro134_falffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint123.splright
rsfMRI_fcnxpro134_alffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint123.splright
rsfMRI_fcnxpro134_perafPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint123.splright
rsfMRI_fcnxpro134_falffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint124.splright
rsfMRI_fcnxpro134_alffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint124.splright
rsfMRI_fcnxpro134_perafPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint124.splright
rsfMRI_fcnxpro134_falffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint125.iplright
rsfMRI_fcnxpro134_alffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint125.iplright
rsfMRI_fcnxpro134_perafPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint125.iplright
rsfMRI_fcnxpro134_falffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint126.iplright
rsfMRI_fcnxpro134_alffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint126.iplright
rsfMRI_fcnxpro134_perafPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint126.iplright
rsfMRI_fcnxpro134_falffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint127.pfcdright
rsfMRI_fcnxpro134_alffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint127.pfcdright
rsfMRI_fcnxpro134_perafPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint127.pfcdright
rsfMRI_fcnxpro134_falffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint128.postcright
rsfMRI_fcnxpro134_alffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint128.postcright
rsfMRI_fcnxpro134_perafPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint128.postcright
rsfMRI_fcnxpro134_falffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint129.postcright
rsfMRI_fcnxpro134_alffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint129.postcright
rsfMRI_fcnxpro134_perafPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint129.postcright
rsfMRI_fcnxpro134_falffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint130.postcright
rsfMRI_fcnxpro134_alffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint130.postcright
rsfMRI_fcnxpro134_perafPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint130.postcright
rsfMRI_fcnxpro134_falffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint131.prcdright
rsfMRI_fcnxpro134_alffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint131.prcdright
rsfMRI_fcnxpro134_perafPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint131.prcdright
rsfMRI_fcnxpro134_falffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint132.prcdright
rsfMRI_fcnxpro134_alffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint132.prcdright
rsfMRI_fcnxpro134_perafPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint132.prcdright
rsfMRI_fcnxpro134_falffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint133.prcdright
rsfMRI_fcnxpro134_alffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint133.prcdright
rsfMRI_fcnxpro134_perafPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint133.prcdright
rsfMRI_fcnxpro134_falffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint134.splright
rsfMRI_fcnxpro134_alffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint134.splright
rsfMRI_fcnxpro134_perafPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint134.splright
rsfMRI_fcnxpro134_falffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint135.splright
rsfMRI_fcnxpro134_alffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint135.splright
rsfMRI_fcnxpro134_perafPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint135.splright
rsfMRI_fcnxpro134_falffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint136.splright
rsfMRI_fcnxpro134_alffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint136.splright
rsfMRI_fcnxpro134_perafPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint136.splright
rsfMRI_fcnxpro134_falffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint137.splright
rsfMRI_fcnxpro134_alffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint137.splright
rsfMRI_fcnxpro134_perafPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint137.splright
rsfMRI_fcnxpro134_falffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint138.tempoccright
rsfMRI_fcnxpro134_alffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint138.tempoccright
rsfMRI_fcnxpro134_perafPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint138.tempoccright
rsfMRI_fcnxpro134_falffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint139.exstrright
rsfMRI_fcnxpro134_alffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint139.exstrright
rsfMRI_fcnxpro134_perafPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint139.exstrright
rsfMRI_fcnxpro134_falffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint140.exstrright
rsfMRI_fcnxpro134_alffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint140.exstrright
rsfMRI_fcnxpro134_perafPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint140.exstrright
rsfMRI_fcnxpro134_falffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint141.exstrright
rsfMRI_fcnxpro134_alffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint141.exstrright
rsfMRI_fcnxpro134_perafPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint141.exstrright
rsfMRI_fcnxpro134_falffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint142.exstrright
rsfMRI_fcnxpro134_alffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint142.exstrright
rsfMRI_fcnxpro134_perafPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint142.exstrright
rsfMRI_fcnxpro134_falffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint143.ipsright
rsfMRI_fcnxpro134_alffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint143.ipsright
rsfMRI_fcnxpro134_perafPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint143.ipsright
rsfMRI_fcnxpro134_falffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint144.splright
rsfMRI_fcnxpro134_alffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint144.splright
rsfMRI_fcnxpro134_perafPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint144.splright
rsfMRI_fcnxpro134_falffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint145.splright
rsfMRI_fcnxpro134_alffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint145.splright
rsfMRI_fcnxpro134_perafPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint145.splright
rsfMRI_fcnxpro134_falffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint146.splright
rsfMRI_fcnxpro134_alffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint146.splright
rsfMRI_fcnxpro134_perafPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint146.splright
rsfMRI_fcnxpro134_falffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint147.splright
rsfMRI_fcnxpro134_alffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint147.splright
rsfMRI_fcnxpro134_perafPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint147.splright
rsfMRI_fcnxpro134_falffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint148.splright
rsfMRI_fcnxpro134_alffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint148.splright
rsfMRI_fcnxpro134_perafPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint148.splright
rsfMRI_fcnxpro134_falffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint149.splright
rsfMRI_fcnxpro134_alffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint149.splright
rsfMRI_fcnxpro134_perafPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint149.splright
rsfMRI_fcnxpro134_falffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint150.tempoccright
rsfMRI_fcnxpro134_alffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint150.tempoccright
rsfMRI_fcnxpro134_perafPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint150.tempoccright
rsfMRI_fcnxpro134_falffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint151.tempoccright
rsfMRI_fcnxpro134_alffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint151.tempoccright
rsfMRI_fcnxpro134_perafPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint151.tempoccright
rsfMRI_fcnxpro134_falffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint152.tempoccright
rsfMRI_fcnxpro134_alffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint152.tempoccright
rsfMRI_fcnxpro134_perafPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint152.tempoccright
rsfMRI_fcnxpro134_falffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint153.tempoccright
rsfMRI_fcnxpro134_alffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint153.tempoccright
rsfMRI_fcnxpro134_perafPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint153.tempoccright
rsfMRI_fcnxpro134_falffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint154.tempoccright
rsfMRI_fcnxpro134_alffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint154.tempoccright
rsfMRI_fcnxpro134_perafPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint154.tempoccright
rsfMRI_fcnxpro134_falffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint155.tempoccright
rsfMRI_fcnxpro134_alffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint155.tempoccright
rsfMRI_fcnxpro134_perafPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint155.tempoccright
rsfMRI_fcnxpro134_falffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint156.tempoccright
rsfMRI_fcnxpro134_alffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint156.tempoccright
rsfMRI_fcnxpro134_perafPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint156.tempoccright
rsfMRI_fcnxpro134_falffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint157.tempoccright
rsfMRI_fcnxpro134_alffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint157.tempoccright
rsfMRI_fcnxpro134_perafPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint157.tempoccright
rsfMRI_fcnxpro134_falffPoint158_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint158.1right
rsfMRI_fcnxpro134_alffPoint158_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint158.1right
rsfMRI_fcnxpro134_perafPoint158_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint158.1right
rsfMRI_fcnxpro134_falffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint159.2right
rsfMRI_fcnxpro134_alffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint159.2right
rsfMRI_fcnxpro134_perafPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint159.2right
rsfMRI_fcnxpro134_falffPoint160_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint160.3right
rsfMRI_fcnxpro134_alffPoint160_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint160.3right
rsfMRI_fcnxpro134_perafPoint160_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint160.3right
rsfMRI_fcnxpro134_falffPoint161_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint161.4right
rsfMRI_fcnxpro134_alffPoint161_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint161.4right
rsfMRI_fcnxpro134_perafPoint161_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint161.4right
rsfMRI_fcnxpro134_falffPoint162_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint162.5right
rsfMRI_fcnxpro134_alffPoint162_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint162.5right
rsfMRI_fcnxpro134_perafPoint162_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint162.5right
rsfMRI_fcnxpro134_falffPoint163_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint163.6right
rsfMRI_fcnxpro134_alffPoint163_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint163.6right
rsfMRI_fcnxpro134_perafPoint163_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint163.6right
rsfMRI_fcnxpro134_falffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint164.iplright
rsfMRI_fcnxpro134_alffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint164.iplright
rsfMRI_fcnxpro134_perafPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint164.iplright
rsfMRI_fcnxpro134_falffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint165.insright
rsfMRI_fcnxpro134_alffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint165.insright
rsfMRI_fcnxpro134_perafPoint165_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint165.insright
rsfMRI_fcnxpro134_falffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint166.insright
rsfMRI_fcnxpro134_alffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint166.insright
rsfMRI_fcnxpro134_perafPoint166_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint166.insright
rsfMRI_fcnxpro134_falffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint167.paroperright
rsfMRI_fcnxpro134_alffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint167.paroperright
rsfMRI_fcnxpro134_perafPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint167.paroperright
rsfMRI_fcnxpro134_falffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint168.paroperright
rsfMRI_fcnxpro134_alffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint168.paroperright
rsfMRI_fcnxpro134_perafPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint168.paroperright
rsfMRI_fcnxpro134_falffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint169.paroperright
rsfMRI_fcnxpro134_alffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint169.paroperright
rsfMRI_fcnxpro134_perafPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint169.paroperright
rsfMRI_fcnxpro134_falffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint170.stright
rsfMRI_fcnxpro134_alffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint170.stright
rsfMRI_fcnxpro134_perafPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint170.stright
rsfMRI_fcnxpro134_falffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint171.stright
rsfMRI_fcnxpro134_alffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint171.stright
rsfMRI_fcnxpro134_perafPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint171.stright
rsfMRI_fcnxpro134_falffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint172.stright
rsfMRI_fcnxpro134_alffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint172.stright
rsfMRI_fcnxpro134_perafPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint172.stright
rsfMRI_fcnxpro134_falffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint173.stright
rsfMRI_fcnxpro134_alffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint173.stright
rsfMRI_fcnxpro134_perafPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint173.stright
rsfMRI_fcnxpro134_falffPoint174_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint174.1right
rsfMRI_fcnxpro134_alffPoint174_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint174.1right
rsfMRI_fcnxpro134_perafPoint174_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint174.1right
rsfMRI_fcnxpro134_falffPoint175_10right
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint175.10right
rsfMRI_fcnxpro134_alffPoint175_10right
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint175.10right
rsfMRI_fcnxpro134_perafPoint175_10right
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint175.10right
rsfMRI_fcnxpro134_falffPoint176_11right
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint176.11right
rsfMRI_fcnxpro134_alffPoint176_11right
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint176.11right
rsfMRI_fcnxpro134_perafPoint176_11right
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint176.11right
rsfMRI_fcnxpro134_falffPoint177_12right
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint177.12right
rsfMRI_fcnxpro134_alffPoint177_12right
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint177.12right
rsfMRI_fcnxpro134_perafPoint177_12right
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint177.12right
rsfMRI_fcnxpro134_falffPoint178_13right
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint178.13right
rsfMRI_fcnxpro134_alffPoint178_13right
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint178.13right
rsfMRI_fcnxpro134_perafPoint178_13right
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint178.13right
rsfMRI_fcnxpro134_falffPoint179_14right
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint179.14right
rsfMRI_fcnxpro134_alffPoint179_14right
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint179.14right
rsfMRI_fcnxpro134_perafPoint179_14right
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint179.14right
rsfMRI_fcnxpro134_falffPoint180_15right
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint180.15right
rsfMRI_fcnxpro134_alffPoint180_15right
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint180.15right
rsfMRI_fcnxpro134_perafPoint180_15right
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint180.15right
rsfMRI_fcnxpro134_falffPoint181_16right
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint181.16right
rsfMRI_fcnxpro134_alffPoint181_16right
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint181.16right
rsfMRI_fcnxpro134_perafPoint181_16right
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint181.16right
rsfMRI_fcnxpro134_falffPoint182_17right
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint182.17right
rsfMRI_fcnxpro134_alffPoint182_17right
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint182.17right
rsfMRI_fcnxpro134_perafPoint182_17right
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint182.17right
rsfMRI_fcnxpro134_falffPoint183_18right
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint183.18right
rsfMRI_fcnxpro134_alffPoint183_18right
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint183.18right
rsfMRI_fcnxpro134_perafPoint183_18right
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint183.18right
rsfMRI_fcnxpro134_falffPoint184_19right
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint184.19right
rsfMRI_fcnxpro134_alffPoint184_19right
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint184.19right
rsfMRI_fcnxpro134_perafPoint184_19right
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint184.19right
rsfMRI_fcnxpro134_falffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint185.2right
rsfMRI_fcnxpro134_alffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint185.2right
rsfMRI_fcnxpro134_perafPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint185.2right
rsfMRI_fcnxpro134_falffPoint186_20right
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint186.20right
rsfMRI_fcnxpro134_alffPoint186_20right
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint186.20right
rsfMRI_fcnxpro134_perafPoint186_20right
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint186.20right
rsfMRI_fcnxpro134_falffPoint187_21right
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint187.21right
rsfMRI_fcnxpro134_alffPoint187_21right
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint187.21right
rsfMRI_fcnxpro134_perafPoint187_21right
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint187.21right
rsfMRI_fcnxpro134_falffPoint188_22right
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint188.22right
rsfMRI_fcnxpro134_alffPoint188_22right
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint188.22right
rsfMRI_fcnxpro134_perafPoint188_22right
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint188.22right
rsfMRI_fcnxpro134_falffPoint189_23right
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint189.23right
rsfMRI_fcnxpro134_alffPoint189_23right
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint189.23right
rsfMRI_fcnxpro134_perafPoint189_23right
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint189.23right
rsfMRI_fcnxpro134_falffPoint190_24right
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint190.24right
rsfMRI_fcnxpro134_alffPoint190_24right
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint190.24right
rsfMRI_fcnxpro134_perafPoint190_24right
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint190.24right
rsfMRI_fcnxpro134_falffPoint191_25right
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint191.25right
rsfMRI_fcnxpro134_alffPoint191_25right
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint191.25right
rsfMRI_fcnxpro134_perafPoint191_25right
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint191.25right
rsfMRI_fcnxpro134_falffPoint192_26right
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint192.26right
rsfMRI_fcnxpro134_alffPoint192_26right
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint192.26right
rsfMRI_fcnxpro134_perafPoint192_26right
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint192.26right
rsfMRI_fcnxpro134_falffPoint193_27right
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint193.27right
rsfMRI_fcnxpro134_alffPoint193_27right
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint193.27right
rsfMRI_fcnxpro134_perafPoint193_27right
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint193.27right
rsfMRI_fcnxpro134_falffPoint194_28right
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint194.28right
rsfMRI_fcnxpro134_alffPoint194_28right
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint194.28right
rsfMRI_fcnxpro134_perafPoint194_28right
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint194.28right
rsfMRI_fcnxpro134_falffPoint195_29right
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint195.29right
rsfMRI_fcnxpro134_alffPoint195_29right
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint195.29right
rsfMRI_fcnxpro134_perafPoint195_29right
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint195.29right
rsfMRI_fcnxpro134_falffPoint196_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint196.3right
rsfMRI_fcnxpro134_alffPoint196_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint196.3right
rsfMRI_fcnxpro134_perafPoint196_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint196.3right
rsfMRI_fcnxpro134_falffPoint197_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint197.4right
rsfMRI_fcnxpro134_alffPoint197_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint197.4right
rsfMRI_fcnxpro134_perafPoint197_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint197.4right
rsfMRI_fcnxpro134_falffPoint198_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint198.5right
rsfMRI_fcnxpro134_alffPoint198_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint198.5right
rsfMRI_fcnxpro134_perafPoint198_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint198.5right
rsfMRI_fcnxpro134_falffPoint199_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint199.6right
rsfMRI_fcnxpro134_alffPoint199_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint199.6right
rsfMRI_fcnxpro134_perafPoint199_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint199.6right
rsfMRI_fcnxpro134_falffPoint200_7right
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint200.7right
rsfMRI_fcnxpro134_alffPoint200_7right
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint200.7right
rsfMRI_fcnxpro134_perafPoint200_7right
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint200.7right
rsfMRI_fcnxpro134_falffPoint201_8right
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint201.8right
rsfMRI_fcnxpro134_alffPoint201_8right
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint201.8right
rsfMRI_fcnxpro134_perafPoint201_8right
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint201.8right
rsfMRI_fcnxpro134_falffPoint202_9right
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint202.9right
rsfMRI_fcnxpro134_alffPoint202_9right
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint202.9right
rsfMRI_fcnxpro134_perafPoint202_9right
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint202.9right
rsfMRI_fcnxpro134_falffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint203.splright
rsfMRI_fcnxpro134_alffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint203.splright
rsfMRI_fcnxpro134_perafPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint203.splright
rsfMRI_fcnxpro134_falffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint204.exstrright
rsfMRI_fcnxpro134_alffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint204.exstrright
rsfMRI_fcnxpro134_perafPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint204.exstrright
rsfMRI_fcnxpro134_falffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint205.exstrinfright
rsfMRI_fcnxpro134_alffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint205.exstrinfright
rsfMRI_fcnxpro134_perafPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint205.exstrinfright
rsfMRI_fcnxpro134_falffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint206.exstrinfright
rsfMRI_fcnxpro134_alffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint206.exstrinfright
rsfMRI_fcnxpro134_perafPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint206.exstrinfright
rsfMRI_fcnxpro134_falffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint207.exstrinfright
rsfMRI_fcnxpro134_alffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint207.exstrinfright
rsfMRI_fcnxpro134_perafPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint207.exstrinfright
rsfMRI_fcnxpro134_falffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint208.exstrinfright
rsfMRI_fcnxpro134_alffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint208.exstrinfright
rsfMRI_fcnxpro134_perafPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint208.exstrinfright
rsfMRI_fcnxpro134_falffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint209.exstrinfright
rsfMRI_fcnxpro134_alffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint209.exstrinfright
rsfMRI_fcnxpro134_perafPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint209.exstrinfright
rsfMRI_fcnxpro134_falffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint210.exstrsupright
rsfMRI_fcnxpro134_alffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint210.exstrsupright
rsfMRI_fcnxpro134_perafPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint210.exstrsupright
rsfMRI_fcnxpro134_falffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint211.exstrsupright
rsfMRI_fcnxpro134_alffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint211.exstrsupright
rsfMRI_fcnxpro134_perafPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint211.exstrsupright
rsfMRI_fcnxpro134_falffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint212.exstrsupright
rsfMRI_fcnxpro134_alffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint212.exstrsupright
rsfMRI_fcnxpro134_perafPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint212.exstrsupright
rsfMRI_fcnxpro134_falffPoint213_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint213.striateright
rsfMRI_fcnxpro134_alffPoint213_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint213.striateright
rsfMRI_fcnxpro134_perafPoint213_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint213.striateright
rsfMRI_fcnxpro134_falffPoint214_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint214.striateright
rsfMRI_fcnxpro134_alffPoint214_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint214.striateright
rsfMRI_fcnxpro134_perafPoint214_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint214.striateright
rsfMRI_fcnxpro134_falffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint215.exstrinfright
rsfMRI_fcnxpro134_alffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint215.exstrinfright
rsfMRI_fcnxpro134_perafPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint215.exstrinfright
rsfMRI_fcnxpro134_falffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint216.exstrright
rsfMRI_fcnxpro134_alffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint216.exstrright
rsfMRI_fcnxpro134_perafPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint216.exstrright
rsfMRI_fcnxpro134_falffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint217.exstrright
rsfMRI_fcnxpro134_alffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint217.exstrright
rsfMRI_fcnxpro134_perafPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint217.exstrright
rsfMRI_fcnxpro134_falffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint218.exstrright
rsfMRI_fcnxpro134_alffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint218.exstrright
rsfMRI_fcnxpro134_perafPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint218.exstrright
rsfMRI_fcnxpro134_falffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint219.exstrright
rsfMRI_fcnxpro134_alffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint219.exstrright
rsfMRI_fcnxpro134_perafPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint219.exstrright
rsfMRI_fcnxpro134_falffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint220.exstrright
rsfMRI_fcnxpro134_alffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint220.exstrright
rsfMRI_fcnxpro134_perafPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint220.exstrright
rsfMRI_fcnxpro134_falffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint221.exstrright
rsfMRI_fcnxpro134_alffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint221.exstrright
rsfMRI_fcnxpro134_perafPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint221.exstrright
rsfMRI_fcnxpro134_falffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint222.exstrright
rsfMRI_fcnxpro134_alffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint222.exstrright
rsfMRI_fcnxpro134_perafPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint222.exstrright
rsfMRI_fcnxpro134_falffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint223.exstrright
rsfMRI_fcnxpro134_alffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint223.exstrright
rsfMRI_fcnxpro134_perafPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint223.exstrright
rsfMRI_fcnxpro134_falffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint224.exstrright
rsfMRI_fcnxpro134_alffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint224.exstrright
rsfMRI_fcnxpro134_perafPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint224.exstrright
rsfMRI_fcnxpro134_falffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint225.exstrright
rsfMRI_fcnxpro134_alffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint225.exstrright
rsfMRI_fcnxpro134_perafPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint225.exstrright
rsfMRI_fcnxpro134_falffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint226.exstrright
rsfMRI_fcnxpro134_alffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint226.exstrright
rsfMRI_fcnxpro134_perafPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint226.exstrright
rsfMRI_fcnxpro134_falffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint227.exstrright
rsfMRI_fcnxpro134_alffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint227.exstrright
rsfMRI_fcnxpro134_perafPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint227.exstrright
rsfMRI_fcnxpro134_falffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint228.exstrright
rsfMRI_fcnxpro134_alffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint228.exstrright
rsfMRI_fcnxpro134_perafPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint228.exstrright
rsfMRI_fcnxpro134_falffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint229.exstrright
rsfMRI_fcnxpro134_alffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint229.exstrright
rsfMRI_fcnxpro134_perafPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint229.exstrright
rsfMRI_fcnxpro134_falffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint230.exstrright
rsfMRI_fcnxpro134_alffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint230.exstrright
rsfMRI_fcnxpro134_perafPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint230.exstrright
rsfMRI_fcnxpro134_falffPoint231_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint231.striateright
rsfMRI_fcnxpro134_alffPoint231_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint231.striateright
rsfMRI_fcnxpro134_perafPoint231_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint231.striateright
rsfMRI_fcnxpro134_falffPoint232_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint232.striateright
rsfMRI_fcnxpro134_alffPoint232_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint232.striateright
rsfMRI_fcnxpro134_perafPoint232_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint232.striateright
rsfMRI_fcnxpro134_falffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint233.bnstrpuleft
rsfMRI_fcnxpro134_alffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint233.bnstrpuleft
rsfMRI_fcnxpro134_perafPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint233.bnstrpuleft
rsfMRI_fcnxpro134_falffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint234.bnstrcaleft
rsfMRI_fcnxpro134_alffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint234.bnstrcaleft
rsfMRI_fcnxpro134_perafPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint234.bnstrcaleft
rsfMRI_fcnxpro134_falffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint235.bnstrnacleft
rsfMRI_fcnxpro134_alffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint235.bnstrnacleft
rsfMRI_fcnxpro134_perafPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint235.bnstrnacleft
rsfMRI_fcnxpro134_falffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint236.exaleft
rsfMRI_fcnxpro134_alffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint236.exaleft
rsfMRI_fcnxpro134_perafPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint236.exaleft
rsfMRI_fcnxpro134_falffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint237.bngpgpeleft
rsfMRI_fcnxpro134_alffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint237.bngpgpeleft
rsfMRI_fcnxpro134_perafPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint237.bngpgpeleft
rsfMRI_fcnxpro134_falffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint238.bngpgpileft
rsfMRI_fcnxpro134_alffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint238.bngpgpileft
rsfMRI_fcnxpro134_perafPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint238.bngpgpileft
rsfMRI_fcnxpro134_falffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint239.mtgsnsncleft
rsfMRI_fcnxpro134_alffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint239.mtgsnsncleft
rsfMRI_fcnxpro134_perafPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint239.mtgsnsncleft
rsfMRI_fcnxpro134_falffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint240.mtgrnleft
rsfMRI_fcnxpro134_alffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint240.mtgrnleft
rsfMRI_fcnxpro134_perafPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint240.mtgrnleft
rsfMRI_fcnxpro134_falffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro134_alffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro134_perafPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint241.mtgsnsnrleft
rsfMRI_fcnxpro134_falffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro134_alffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro134_perafPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro134_falffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro134_alffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro134_perafPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro134_falffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint244.bngpvepleft
rsfMRI_fcnxpro134_alffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint244.bngpvepleft
rsfMRI_fcnxpro134_perafPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint244.bngpvepleft
rsfMRI_fcnxpro134_falffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint245.thmethhnleft
rsfMRI_fcnxpro134_alffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint245.thmethhnleft
rsfMRI_fcnxpro134_perafPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint245.thmethhnleft
rsfMRI_fcnxpro134_falffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint246.diehthleft
rsfMRI_fcnxpro134_alffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint246.diehthleft
rsfMRI_fcnxpro134_perafPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint246.diehthleft
rsfMRI_fcnxpro134_falffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint247.diehthmnleft
rsfMRI_fcnxpro134_alffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint247.diehthmnleft
rsfMRI_fcnxpro134_perafPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint247.diehthmnleft
rsfMRI_fcnxpro134_falffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint248.diesthleft
rsfMRI_fcnxpro134_alffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint248.diesthleft
rsfMRI_fcnxpro134_perafPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint248.diesthleft
rsfMRI_fcnxpro134_falffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint249.bnstrpuright
rsfMRI_fcnxpro134_alffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint249.bnstrpuright
rsfMRI_fcnxpro134_perafPoint249_BNSTRPuright
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint249.bnstrpuright
rsfMRI_fcnxpro134_falffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint250.bnstrcaright
rsfMRI_fcnxpro134_alffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint250.bnstrcaright
rsfMRI_fcnxpro134_perafPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint250.bnstrcaright
rsfMRI_fcnxpro134_falffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint251.bnstrnacright
rsfMRI_fcnxpro134_alffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint251.bnstrnacright
rsfMRI_fcnxpro134_perafPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint251.bnstrnacright
rsfMRI_fcnxpro134_falffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint252.exaright
rsfMRI_fcnxpro134_alffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint252.exaright
rsfMRI_fcnxpro134_perafPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint252.exaright
rsfMRI_fcnxpro134_falffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint253.bngpgperight
rsfMRI_fcnxpro134_alffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint253.bngpgperight
rsfMRI_fcnxpro134_perafPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint253.bngpgperight
rsfMRI_fcnxpro134_falffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint254.bngpgpiright
rsfMRI_fcnxpro134_alffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint254.bngpgpiright
rsfMRI_fcnxpro134_perafPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint254.bngpgpiright
rsfMRI_fcnxpro134_falffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint255.mtgsnsncright
rsfMRI_fcnxpro134_alffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint255.mtgsnsncright
rsfMRI_fcnxpro134_perafPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint255.mtgsnsncright
rsfMRI_fcnxpro134_falffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint256.mtgrnright
rsfMRI_fcnxpro134_alffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint256.mtgrnright
rsfMRI_fcnxpro134_perafPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint256.mtgrnright
rsfMRI_fcnxpro134_falffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint257.mtgsnsnrright
rsfMRI_fcnxpro134_alffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint257.mtgsnsnrright
rsfMRI_fcnxpro134_perafPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint257.mtgsnsnrright
rsfMRI_fcnxpro134_falffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro134_alffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro134_perafPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint258.mtgvtrpbpright
rsfMRI_fcnxpro134_falffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro134_alffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro134_perafPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint259.mtgvtrvtaright
rsfMRI_fcnxpro134_falffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint260.bngpvepright
rsfMRI_fcnxpro134_alffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint260.bngpvepright
rsfMRI_fcnxpro134_perafPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint260.bngpvepright
rsfMRI_fcnxpro134_falffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint261.thmethhnright
rsfMRI_fcnxpro134_alffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint261.thmethhnright
rsfMRI_fcnxpro134_perafPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint261.thmethhnright
rsfMRI_fcnxpro134_falffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint262.diehthright
rsfMRI_fcnxpro134_alffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint262.diehthright
rsfMRI_fcnxpro134_perafPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint262.diehthright
rsfMRI_fcnxpro134_falffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint263.diehthmnright
rsfMRI_fcnxpro134_alffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint263.diehthmnright
rsfMRI_fcnxpro134_perafPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint263.diehthmnright
rsfMRI_fcnxpro134_falffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint264.diesthright
rsfMRI_fcnxpro134_alffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint264.diesthright
rsfMRI_fcnxpro134_perafPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint264.diesthright
rsfMRI_fcnxpro134_falffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.falffpoint265.referenceregionleft
rsfMRI_fcnxpro134_alffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
left
rsf.p3.alffpoint265.referenceregionleft
rsfMRI_fcnxpro134_perafPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
left
rsf.p3.perafpoint265.referenceregionleft
rsfMRI_fcnxpro134_falffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.falffpoint266.referenceregionright
rsfMRI_fcnxpro134_alffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
right
rsf.p3.alffpoint266.referenceregionright
rsfMRI_fcnxpro134_perafPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
right
rsf.p3.perafpoint266.referenceregionright
rsfMRI_fcnxpro134_DefaultMode_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultmode.mean
rsfMRI_fcnxpro134_Visual_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.visual.mean
rsfMRI_fcnxpro134_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.motion.corrected.mean
rsfMRI_fcnxpro134_PerAF_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.peraf.mean
rsfMRI_fcnxpro134_tsnr_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.tsnr.mean
rsfMRI_fcnxpro134_ssnr_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.ssnr.mean
rsfMRI_fcnxpro134_dvars_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.dvars.mean
rsfMRI_fcnxpro134_bandpass_freq_0
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
134
​
rsf.p3.bandpass.freq.0
rsfMRI_fcnxpro134_bandpass_freq_1
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
134
​
rsf.p3.bandpass.freq.1
rsfMRI_fcnxpro134_censor
Unknown Core: censor
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.censor
rsfMRI_fcnxpro134_spatial_smoothing
Unknown Core: spatial smoothing
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.spatial.smoothing
rsfMRI_fcnxpro134_outlier_threshold
Unknown Core: outlier threshold
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.outlier.threshold
rsfMRI_fcnxpro134_FD_threshold
Unknown Core: threshold
restingStatefMRI
motion statistic on framewise displacement
power peterson fMRI meta-analyses
134
​
rsf.p3.fd.threshold
rsfMRI_fcnxpro134_high_motion_count
Unknown Core: high motion count
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.high.motion.count
rsfMRI_fcnxpro134_high_motion_pct
Unknown Core: high motion pct
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.high.motion.pct
rsfMRI_fcnxpro134_despiking_count_summary
Unknown Core: despiking count summary
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.despiking.count.summary
rsfMRI_fcnxpro134_FD_max
​
restingStatefMRI
max framewise displacement
power peterson fMRI meta-analyses
134
​
rsf.p3.fd.max
rsfMRI_fcnxpro134_FD_mean
​
restingStatefMRI
mean framewise displacement
power peterson fMRI meta-analyses
134
​
rsf.p3.fd.mean
rsfMRI_fcnxpro134_FD_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
134
​
rsf.p3.fd.sd
rsfMRI_fcnxpro134_bold_evr
Unknown Core: bold
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.bold.evr
rsfMRI_fcnxpro134_n_outliers
Unknown Core: n outliers
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.n.outliers
rsfMRI_fcnxpro134_nc_wm
Unknown Core: nc wm
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.nc.wm
rsfMRI_fcnxpro134_nc_csf
Cerebrospinal Fluid
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.nc.csf
rsfMRI_fcnxpro134_minutes_original_data
Unknown Core: minutes original data
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.minutes.original.data
rsfMRI_fcnxpro134_minutes_censored_data
Unknown Core: minutes censored data
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
134
​
rsf.p3.minutes.censored.data
rsfMRI_fcnxpro134_TempPar_2_TempPar
Temporo-Parietal to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.temppar
rsfMRI_fcnxpro134_TempPar_2_DefaultC
Temporo-Parietal to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.defaultc
rsfMRI_fcnxpro134_TempPar_2_DefaultB
Temporo-Parietal to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.defaultb
rsfMRI_fcnxpro134_TempPar_2_DefaultA
Temporo-Parietal to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.defaulta
rsfMRI_fcnxpro134_TempPar_2_ContC
Temporo-Parietal to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.contc
rsfMRI_fcnxpro134_TempPar_2_ContB
Temporo-Parietal to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.contb
rsfMRI_fcnxpro134_TempPar_2_ContA
Temporo-Parietal to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.conta
rsfMRI_fcnxpro134_TempPar_2_LimbicA
Temporo-Parietal to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.limbica
rsfMRI_fcnxpro134_TempPar_2_LimbicB
Temporo-Parietal to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.limbicb
rsfMRI_fcnxpro134_TempPar_2_SalVentAttnB
Temporo-Parietal to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.salventattnb
rsfMRI_fcnxpro134_TempPar_2_SalVentAttnA
Temporo-Parietal to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.salventattna
rsfMRI_fcnxpro134_TempPar_2_DorsAttnB
Temporo-Parietal to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.dorsattnb
rsfMRI_fcnxpro134_TempPar_2_DorsAttnA
Temporo-Parietal to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.dorsattna
rsfMRI_fcnxpro134_TempPar_2_SomMotB
Temporo-Parietal to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.sommotb
rsfMRI_fcnxpro134_TempPar_2_SomMotA
Temporo-Parietal to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.sommota
rsfMRI_fcnxpro134_TempPar_2_VisPeri
Temporo-Parietal to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.visperi
rsfMRI_fcnxpro134_TempPar_2_VisCent
Temporo-Parietal to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.viscent
rsfMRI_fcnxpro134_TempPar_2_Striatum
Temporo-Parietal to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.striatum
rsfMRI_fcnxpro134_TempPar_2_Dopamine
Temporo-Parietal to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.dopamine
rsfMRI_fcnxpro134_TempPar_2_CITLimbic
Temporo-Parietal to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.citlimbic
rsfMRI_fcnxpro134_TempPar_2_BasalGanglia
Temporo-Parietal to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.basalganglia
rsfMRI_fcnxpro134_TempPar_2_MidBrain
Temporo-Parietal to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.temppar.2.midbrain
rsfMRI_fcnxpro134_DefaultC_2_TempPar
Default Mode Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.temppar
rsfMRI_fcnxpro134_DefaultC_2_DefaultC
Default Mode Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.defaultc
rsfMRI_fcnxpro134_DefaultC_2_DefaultB
Default Mode Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.defaultb
rsfMRI_fcnxpro134_DefaultC_2_DefaultA
Default Mode Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.defaulta
rsfMRI_fcnxpro134_DefaultC_2_ContC
Default Mode Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.contc
rsfMRI_fcnxpro134_DefaultC_2_ContB
Default Mode Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.contb
rsfMRI_fcnxpro134_DefaultC_2_ContA
Default Mode Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.conta
rsfMRI_fcnxpro134_DefaultC_2_LimbicA
Default Mode Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.limbica
rsfMRI_fcnxpro134_DefaultC_2_LimbicB
Default Mode Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.limbicb
rsfMRI_fcnxpro134_DefaultC_2_SalVentAttnB
Default Mode Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.salventattnb
rsfMRI_fcnxpro134_DefaultC_2_SalVentAttnA
Default Mode Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.salventattna
rsfMRI_fcnxpro134_DefaultC_2_DorsAttnB
Default Mode Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.dorsattnb
rsfMRI_fcnxpro134_DefaultC_2_DorsAttnA
Default Mode Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.dorsattna
rsfMRI_fcnxpro134_DefaultC_2_SomMotB
Default Mode Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.sommotb
rsfMRI_fcnxpro134_DefaultC_2_SomMotA
Default Mode Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.sommota
rsfMRI_fcnxpro134_DefaultC_2_VisPeri
Default Mode Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.visperi
rsfMRI_fcnxpro134_DefaultC_2_VisCent
Default Mode Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.viscent
rsfMRI_fcnxpro134_DefaultC_2_Striatum
Default Mode Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.striatum
rsfMRI_fcnxpro134_DefaultC_2_Dopamine
Default Mode Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.dopamine
rsfMRI_fcnxpro134_DefaultC_2_CITLimbic
Default Mode Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.citlimbic
rsfMRI_fcnxpro134_DefaultC_2_BasalGanglia
Default Mode Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.basalganglia
rsfMRI_fcnxpro134_DefaultC_2_MidBrain
Default Mode Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultc.2.midbrain
rsfMRI_fcnxpro134_DefaultB_2_TempPar
Default Mode Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.temppar
rsfMRI_fcnxpro134_DefaultB_2_DefaultC
Default Mode Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.defaultc
rsfMRI_fcnxpro134_DefaultB_2_DefaultB
Default Mode Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.defaultb
rsfMRI_fcnxpro134_DefaultB_2_DefaultA
Default Mode Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.defaulta
rsfMRI_fcnxpro134_DefaultB_2_ContC
Default Mode Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.contc
rsfMRI_fcnxpro134_DefaultB_2_ContB
Default Mode Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.contb
rsfMRI_fcnxpro134_DefaultB_2_ContA
Default Mode Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.conta
rsfMRI_fcnxpro134_DefaultB_2_LimbicA
Default Mode Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.limbica
rsfMRI_fcnxpro134_DefaultB_2_LimbicB
Default Mode Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.limbicb
rsfMRI_fcnxpro134_DefaultB_2_SalVentAttnB
Default Mode Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.salventattnb
rsfMRI_fcnxpro134_DefaultB_2_SalVentAttnA
Default Mode Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.salventattna
rsfMRI_fcnxpro134_DefaultB_2_DorsAttnB
Default Mode Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.dorsattnb
rsfMRI_fcnxpro134_DefaultB_2_DorsAttnA
Default Mode Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.dorsattna
rsfMRI_fcnxpro134_DefaultB_2_SomMotB
Default Mode Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.sommotb
rsfMRI_fcnxpro134_DefaultB_2_SomMotA
Default Mode Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.sommota
rsfMRI_fcnxpro134_DefaultB_2_VisPeri
Default Mode Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.visperi
rsfMRI_fcnxpro134_DefaultB_2_VisCent
Default Mode Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.viscent
rsfMRI_fcnxpro134_DefaultB_2_Striatum
Default Mode Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.striatum
rsfMRI_fcnxpro134_DefaultB_2_Dopamine
Default Mode Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.dopamine
rsfMRI_fcnxpro134_DefaultB_2_CITLimbic
Default Mode Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.citlimbic
rsfMRI_fcnxpro134_DefaultB_2_BasalGanglia
Default Mode Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.basalganglia
rsfMRI_fcnxpro134_DefaultB_2_MidBrain
Default Mode Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaultb.2.midbrain
rsfMRI_fcnxpro134_DefaultA_2_TempPar
Default Mode Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.temppar
rsfMRI_fcnxpro134_DefaultA_2_DefaultC
Default Mode Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.defaultc
rsfMRI_fcnxpro134_DefaultA_2_DefaultB
Default Mode Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.defaultb
rsfMRI_fcnxpro134_DefaultA_2_DefaultA
Default Mode Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.defaulta
rsfMRI_fcnxpro134_DefaultA_2_ContC
Default Mode Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.contc
rsfMRI_fcnxpro134_DefaultA_2_ContB
Default Mode Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.contb
rsfMRI_fcnxpro134_DefaultA_2_ContA
Default Mode Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.conta
rsfMRI_fcnxpro134_DefaultA_2_LimbicA
Default Mode Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.limbica
rsfMRI_fcnxpro134_DefaultA_2_LimbicB
Default Mode Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.limbicb
rsfMRI_fcnxpro134_DefaultA_2_SalVentAttnB
Default Mode Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.salventattnb
rsfMRI_fcnxpro134_DefaultA_2_SalVentAttnA
Default Mode Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.salventattna
rsfMRI_fcnxpro134_DefaultA_2_DorsAttnB
Default Mode Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.dorsattnb
rsfMRI_fcnxpro134_DefaultA_2_DorsAttnA
Default Mode Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.dorsattna
rsfMRI_fcnxpro134_DefaultA_2_SomMotB
Default Mode Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.sommotb
rsfMRI_fcnxpro134_DefaultA_2_SomMotA
Default Mode Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.sommota
rsfMRI_fcnxpro134_DefaultA_2_VisPeri
Default Mode Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.visperi
rsfMRI_fcnxpro134_DefaultA_2_VisCent
Default Mode Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.viscent
rsfMRI_fcnxpro134_DefaultA_2_Striatum
Default Mode Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.striatum
rsfMRI_fcnxpro134_DefaultA_2_Dopamine
Default Mode Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.dopamine
rsfMRI_fcnxpro134_DefaultA_2_CITLimbic
Default Mode Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.citlimbic
rsfMRI_fcnxpro134_DefaultA_2_BasalGanglia
Default Mode Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.basalganglia
rsfMRI_fcnxpro134_DefaultA_2_MidBrain
Default Mode Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.defaulta.2.midbrain
rsfMRI_fcnxpro134_ContC_2_TempPar
Frontoparietal Control Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.temppar
rsfMRI_fcnxpro134_ContC_2_DefaultC
Frontoparietal Control Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.defaultc
rsfMRI_fcnxpro134_ContC_2_DefaultB
Frontoparietal Control Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.defaultb
rsfMRI_fcnxpro134_ContC_2_DefaultA
Frontoparietal Control Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.defaulta
rsfMRI_fcnxpro134_ContC_2_ContC
Frontoparietal Control Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.contc
rsfMRI_fcnxpro134_ContC_2_ContB
Frontoparietal Control Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.contb
rsfMRI_fcnxpro134_ContC_2_ContA
Frontoparietal Control Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.conta
rsfMRI_fcnxpro134_ContC_2_LimbicA
Frontoparietal Control Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.limbica
rsfMRI_fcnxpro134_ContC_2_LimbicB
Frontoparietal Control Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.limbicb
rsfMRI_fcnxpro134_ContC_2_SalVentAttnB
Frontoparietal Control Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.salventattnb
rsfMRI_fcnxpro134_ContC_2_SalVentAttnA
Frontoparietal Control Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.salventattna
rsfMRI_fcnxpro134_ContC_2_DorsAttnB
Frontoparietal Control Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.dorsattnb
rsfMRI_fcnxpro134_ContC_2_DorsAttnA
Frontoparietal Control Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.dorsattna
rsfMRI_fcnxpro134_ContC_2_SomMotB
Frontoparietal Control Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.sommotb
rsfMRI_fcnxpro134_ContC_2_SomMotA
Frontoparietal Control Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.sommota
rsfMRI_fcnxpro134_ContC_2_VisPeri
Frontoparietal Control Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.visperi
rsfMRI_fcnxpro134_ContC_2_VisCent
Frontoparietal Control Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.viscent
rsfMRI_fcnxpro134_ContC_2_Striatum
Frontoparietal Control Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.striatum
rsfMRI_fcnxpro134_ContC_2_Dopamine
Frontoparietal Control Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.dopamine
rsfMRI_fcnxpro134_ContC_2_CITLimbic
Frontoparietal Control Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.citlimbic
rsfMRI_fcnxpro134_ContC_2_BasalGanglia
Frontoparietal Control Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.basalganglia
rsfMRI_fcnxpro134_ContC_2_MidBrain
Frontoparietal Control Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contc.2.midbrain
rsfMRI_fcnxpro134_ContB_2_TempPar
Frontoparietal Control Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.temppar
rsfMRI_fcnxpro134_ContB_2_DefaultC
Frontoparietal Control Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.defaultc
rsfMRI_fcnxpro134_ContB_2_DefaultB
Frontoparietal Control Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.defaultb
rsfMRI_fcnxpro134_ContB_2_DefaultA
Frontoparietal Control Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.defaulta
rsfMRI_fcnxpro134_ContB_2_ContC
Frontoparietal Control Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.contc
rsfMRI_fcnxpro134_ContB_2_ContB
Frontoparietal Control Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.contb
rsfMRI_fcnxpro134_ContB_2_ContA
Frontoparietal Control Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.conta
rsfMRI_fcnxpro134_ContB_2_LimbicA
Frontoparietal Control Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.limbica
rsfMRI_fcnxpro134_ContB_2_LimbicB
Frontoparietal Control Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.limbicb
rsfMRI_fcnxpro134_ContB_2_SalVentAttnB
Frontoparietal Control Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.salventattnb
rsfMRI_fcnxpro134_ContB_2_SalVentAttnA
Frontoparietal Control Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.salventattna
rsfMRI_fcnxpro134_ContB_2_DorsAttnB
Frontoparietal Control Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.dorsattnb
rsfMRI_fcnxpro134_ContB_2_DorsAttnA
Frontoparietal Control Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.dorsattna
rsfMRI_fcnxpro134_ContB_2_SomMotB
Frontoparietal Control Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.sommotb
rsfMRI_fcnxpro134_ContB_2_SomMotA
Frontoparietal Control Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.sommota
rsfMRI_fcnxpro134_ContB_2_VisPeri
Frontoparietal Control Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.visperi
rsfMRI_fcnxpro134_ContB_2_VisCent
Frontoparietal Control Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.viscent
rsfMRI_fcnxpro134_ContB_2_Striatum
Frontoparietal Control Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.striatum
rsfMRI_fcnxpro134_ContB_2_Dopamine
Frontoparietal Control Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.dopamine
rsfMRI_fcnxpro134_ContB_2_CITLimbic
Frontoparietal Control Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.citlimbic
rsfMRI_fcnxpro134_ContB_2_BasalGanglia
Frontoparietal Control Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.basalganglia
rsfMRI_fcnxpro134_ContB_2_MidBrain
Frontoparietal Control Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.contb.2.midbrain
rsfMRI_fcnxpro134_ContA_2_TempPar
Frontoparietal Control Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.temppar
rsfMRI_fcnxpro134_ContA_2_DefaultC
Frontoparietal Control Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.defaultc
rsfMRI_fcnxpro134_ContA_2_DefaultB
Frontoparietal Control Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.defaultb
rsfMRI_fcnxpro134_ContA_2_DefaultA
Frontoparietal Control Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.defaulta
rsfMRI_fcnxpro134_ContA_2_ContC
Frontoparietal Control Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.contc
rsfMRI_fcnxpro134_ContA_2_ContB
Frontoparietal Control Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.contb
rsfMRI_fcnxpro134_ContA_2_ContA
Frontoparietal Control Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.conta
rsfMRI_fcnxpro134_ContA_2_LimbicA
Frontoparietal Control Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.limbica
rsfMRI_fcnxpro134_ContA_2_LimbicB
Frontoparietal Control Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.limbicb
rsfMRI_fcnxpro134_ContA_2_SalVentAttnB
Frontoparietal Control Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.salventattnb
rsfMRI_fcnxpro134_ContA_2_SalVentAttnA
Frontoparietal Control Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.salventattna
rsfMRI_fcnxpro134_ContA_2_DorsAttnB
Frontoparietal Control Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.dorsattnb
rsfMRI_fcnxpro134_ContA_2_DorsAttnA
Frontoparietal Control Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.dorsattna
rsfMRI_fcnxpro134_ContA_2_SomMotB
Frontoparietal Control Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.sommotb
rsfMRI_fcnxpro134_ContA_2_SomMotA
Frontoparietal Control Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.sommota
rsfMRI_fcnxpro134_ContA_2_VisPeri
Frontoparietal Control Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.visperi
rsfMRI_fcnxpro134_ContA_2_VisCent
Frontoparietal Control Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.viscent
rsfMRI_fcnxpro134_ContA_2_Striatum
Frontoparietal Control Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.striatum
rsfMRI_fcnxpro134_ContA_2_Dopamine
Frontoparietal Control Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.dopamine
rsfMRI_fcnxpro134_ContA_2_CITLimbic
Frontoparietal Control Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.citlimbic
rsfMRI_fcnxpro134_ContA_2_BasalGanglia
Frontoparietal Control Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.basalganglia
rsfMRI_fcnxpro134_ContA_2_MidBrain
Frontoparietal Control Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.conta.2.midbrain
rsfMRI_fcnxpro134_LimbicA_2_TempPar
Limbic Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.temppar
rsfMRI_fcnxpro134_LimbicA_2_DefaultC
Limbic Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.defaultc
rsfMRI_fcnxpro134_LimbicA_2_DefaultB
Limbic Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.defaultb
rsfMRI_fcnxpro134_LimbicA_2_DefaultA
Limbic Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.defaulta
rsfMRI_fcnxpro134_LimbicA_2_ContC
Limbic Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.contc
rsfMRI_fcnxpro134_LimbicA_2_ContB
Limbic Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.contb
rsfMRI_fcnxpro134_LimbicA_2_ContA
Limbic Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.conta
rsfMRI_fcnxpro134_LimbicA_2_LimbicA
Limbic Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.limbica
rsfMRI_fcnxpro134_LimbicA_2_LimbicB
Limbic Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.limbicb
rsfMRI_fcnxpro134_LimbicA_2_SalVentAttnB
Limbic Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.salventattnb
rsfMRI_fcnxpro134_LimbicA_2_SalVentAttnA
Limbic Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.salventattna
rsfMRI_fcnxpro134_LimbicA_2_DorsAttnB
Limbic Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.dorsattnb
rsfMRI_fcnxpro134_LimbicA_2_DorsAttnA
Limbic Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.dorsattna
rsfMRI_fcnxpro134_LimbicA_2_SomMotB
Limbic Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.sommotb
rsfMRI_fcnxpro134_LimbicA_2_SomMotA
Limbic Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.sommota
rsfMRI_fcnxpro134_LimbicA_2_VisPeri
Limbic Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.visperi
rsfMRI_fcnxpro134_LimbicA_2_VisCent
Limbic Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.viscent
rsfMRI_fcnxpro134_LimbicA_2_Striatum
Limbic Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.striatum
rsfMRI_fcnxpro134_LimbicA_2_Dopamine
Limbic Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.dopamine
rsfMRI_fcnxpro134_LimbicA_2_CITLimbic
Limbic Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.citlimbic
rsfMRI_fcnxpro134_LimbicA_2_BasalGanglia
Limbic Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.basalganglia
rsfMRI_fcnxpro134_LimbicA_2_MidBrain
Limbic Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbica.2.midbrain
rsfMRI_fcnxpro134_LimbicB_2_TempPar
Limbic Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.temppar
rsfMRI_fcnxpro134_LimbicB_2_DefaultC
Limbic Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.defaultc
rsfMRI_fcnxpro134_LimbicB_2_DefaultB
Limbic Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.defaultb
rsfMRI_fcnxpro134_LimbicB_2_DefaultA
Limbic Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.defaulta
rsfMRI_fcnxpro134_LimbicB_2_ContC
Limbic Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.contc
rsfMRI_fcnxpro134_LimbicB_2_ContB
Limbic Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.contb
rsfMRI_fcnxpro134_LimbicB_2_ContA
Limbic Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.conta
rsfMRI_fcnxpro134_LimbicB_2_LimbicA
Limbic Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.limbica
rsfMRI_fcnxpro134_LimbicB_2_LimbicB
Limbic Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.limbicb
rsfMRI_fcnxpro134_LimbicB_2_SalVentAttnB
Limbic Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.salventattnb
rsfMRI_fcnxpro134_LimbicB_2_SalVentAttnA
Limbic Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.salventattna
rsfMRI_fcnxpro134_LimbicB_2_DorsAttnB
Limbic Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.dorsattnb
rsfMRI_fcnxpro134_LimbicB_2_DorsAttnA
Limbic Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.dorsattna
rsfMRI_fcnxpro134_LimbicB_2_SomMotB
Limbic Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.sommotb
rsfMRI_fcnxpro134_LimbicB_2_SomMotA
Limbic Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.sommota
rsfMRI_fcnxpro134_LimbicB_2_VisPeri
Limbic Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.visperi
rsfMRI_fcnxpro134_LimbicB_2_VisCent
Limbic Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.viscent
rsfMRI_fcnxpro134_LimbicB_2_Striatum
Limbic Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.striatum
rsfMRI_fcnxpro134_LimbicB_2_Dopamine
Limbic Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.dopamine
rsfMRI_fcnxpro134_LimbicB_2_CITLimbic
Limbic Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.citlimbic
rsfMRI_fcnxpro134_LimbicB_2_BasalGanglia
Limbic Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.basalganglia
rsfMRI_fcnxpro134_LimbicB_2_MidBrain
Limbic Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.limbicb.2.midbrain
rsfMRI_fcnxpro134_SalVentAttnB_2_TempPar
Salience/Ventral Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.temppar
rsfMRI_fcnxpro134_SalVentAttnB_2_DefaultC
Salience/Ventral Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.defaultc
rsfMRI_fcnxpro134_SalVentAttnB_2_DefaultB
Salience/Ventral Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.defaultb
rsfMRI_fcnxpro134_SalVentAttnB_2_DefaultA
Salience/Ventral Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.defaulta
rsfMRI_fcnxpro134_SalVentAttnB_2_ContC
Salience/Ventral Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.contc
rsfMRI_fcnxpro134_SalVentAttnB_2_ContB
Salience/Ventral Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.contb
rsfMRI_fcnxpro134_SalVentAttnB_2_ContA
Salience/Ventral Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.conta
rsfMRI_fcnxpro134_SalVentAttnB_2_LimbicA
Salience/Ventral Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.limbica
rsfMRI_fcnxpro134_SalVentAttnB_2_LimbicB
Salience/Ventral Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.limbicb
rsfMRI_fcnxpro134_SalVentAttnB_2_SalVentAttnB
Salience/Ventral Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.salventattnb
rsfMRI_fcnxpro134_SalVentAttnB_2_SalVentAttnA
Salience/Ventral Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.salventattna
rsfMRI_fcnxpro134_SalVentAttnB_2_DorsAttnB
Salience/Ventral Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.dorsattnb
rsfMRI_fcnxpro134_SalVentAttnB_2_DorsAttnA
Salience/Ventral Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.dorsattna
rsfMRI_fcnxpro134_SalVentAttnB_2_SomMotB
Salience/Ventral Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.sommotb
rsfMRI_fcnxpro134_SalVentAttnB_2_SomMotA
Salience/Ventral Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.sommota
rsfMRI_fcnxpro134_SalVentAttnB_2_VisPeri
Salience/Ventral Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.visperi
rsfMRI_fcnxpro134_SalVentAttnB_2_VisCent
Salience/Ventral Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.viscent
rsfMRI_fcnxpro134_SalVentAttnB_2_Striatum
Salience/Ventral Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.striatum
rsfMRI_fcnxpro134_SalVentAttnB_2_Dopamine
Salience/Ventral Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.dopamine
rsfMRI_fcnxpro134_SalVentAttnB_2_CITLimbic
Salience/Ventral Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.citlimbic
rsfMRI_fcnxpro134_SalVentAttnB_2_BasalGanglia
Salience/Ventral Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.basalganglia
rsfMRI_fcnxpro134_SalVentAttnB_2_MidBrain
Salience/Ventral Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattnb.2.midbrain
rsfMRI_fcnxpro134_SalVentAttnA_2_TempPar
Salience/Ventral Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.temppar
rsfMRI_fcnxpro134_SalVentAttnA_2_DefaultC
Salience/Ventral Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.defaultc
rsfMRI_fcnxpro134_SalVentAttnA_2_DefaultB
Salience/Ventral Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.defaultb
rsfMRI_fcnxpro134_SalVentAttnA_2_DefaultA
Salience/Ventral Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.defaulta
rsfMRI_fcnxpro134_SalVentAttnA_2_ContC
Salience/Ventral Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.contc
rsfMRI_fcnxpro134_SalVentAttnA_2_ContB
Salience/Ventral Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.contb
rsfMRI_fcnxpro134_SalVentAttnA_2_ContA
Salience/Ventral Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.conta
rsfMRI_fcnxpro134_SalVentAttnA_2_LimbicA
Salience/Ventral Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.limbica
rsfMRI_fcnxpro134_SalVentAttnA_2_LimbicB
Salience/Ventral Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.limbicb
rsfMRI_fcnxpro134_SalVentAttnA_2_SalVentAttnB
Salience/Ventral Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.salventattnb
rsfMRI_fcnxpro134_SalVentAttnA_2_SalVentAttnA
Salience/Ventral Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.salventattna
rsfMRI_fcnxpro134_SalVentAttnA_2_DorsAttnB
Salience/Ventral Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.dorsattnb
rsfMRI_fcnxpro134_SalVentAttnA_2_DorsAttnA
Salience/Ventral Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.dorsattna
rsfMRI_fcnxpro134_SalVentAttnA_2_SomMotB
Salience/Ventral Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.sommotb
rsfMRI_fcnxpro134_SalVentAttnA_2_SomMotA
Salience/Ventral Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.sommota
rsfMRI_fcnxpro134_SalVentAttnA_2_VisPeri
Salience/Ventral Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.visperi
rsfMRI_fcnxpro134_SalVentAttnA_2_VisCent
Salience/Ventral Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.viscent
rsfMRI_fcnxpro134_SalVentAttnA_2_Striatum
Salience/Ventral Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.striatum
rsfMRI_fcnxpro134_SalVentAttnA_2_Dopamine
Salience/Ventral Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.dopamine
rsfMRI_fcnxpro134_SalVentAttnA_2_CITLimbic
Salience/Ventral Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.citlimbic
rsfMRI_fcnxpro134_SalVentAttnA_2_BasalGanglia
Salience/Ventral Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.basalganglia
rsfMRI_fcnxpro134_SalVentAttnA_2_MidBrain
Salience/Ventral Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.salventattna.2.midbrain
rsfMRI_fcnxpro134_DorsAttnB_2_TempPar
Dorsal Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.temppar
rsfMRI_fcnxpro134_DorsAttnB_2_DefaultC
Dorsal Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.defaultc
rsfMRI_fcnxpro134_DorsAttnB_2_DefaultB
Dorsal Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.defaultb
rsfMRI_fcnxpro134_DorsAttnB_2_DefaultA
Dorsal Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.defaulta
rsfMRI_fcnxpro134_DorsAttnB_2_ContC
Dorsal Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.contc
rsfMRI_fcnxpro134_DorsAttnB_2_ContB
Dorsal Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.contb
rsfMRI_fcnxpro134_DorsAttnB_2_ContA
Dorsal Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.conta
rsfMRI_fcnxpro134_DorsAttnB_2_LimbicA
Dorsal Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.limbica
rsfMRI_fcnxpro134_DorsAttnB_2_LimbicB
Dorsal Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.limbicb
rsfMRI_fcnxpro134_DorsAttnB_2_SalVentAttnB
Dorsal Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.salventattnb
rsfMRI_fcnxpro134_DorsAttnB_2_SalVentAttnA
Dorsal Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.salventattna
rsfMRI_fcnxpro134_DorsAttnB_2_DorsAttnB
Dorsal Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.dorsattnb
rsfMRI_fcnxpro134_DorsAttnB_2_DorsAttnA
Dorsal Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.dorsattna
rsfMRI_fcnxpro134_DorsAttnB_2_SomMotB
Dorsal Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.sommotb
rsfMRI_fcnxpro134_DorsAttnB_2_SomMotA
Dorsal Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.sommota
rsfMRI_fcnxpro134_DorsAttnB_2_VisPeri
Dorsal Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.visperi
rsfMRI_fcnxpro134_DorsAttnB_2_VisCent
Dorsal Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.viscent
rsfMRI_fcnxpro134_DorsAttnB_2_Striatum
Dorsal Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.striatum
rsfMRI_fcnxpro134_DorsAttnB_2_Dopamine
Dorsal Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.dopamine
rsfMRI_fcnxpro134_DorsAttnB_2_CITLimbic
Dorsal Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.citlimbic
rsfMRI_fcnxpro134_DorsAttnB_2_BasalGanglia
Dorsal Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.basalganglia
rsfMRI_fcnxpro134_DorsAttnB_2_MidBrain
Dorsal Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattnb.2.midbrain
rsfMRI_fcnxpro134_DorsAttnA_2_TempPar
Dorsal Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.temppar
rsfMRI_fcnxpro134_DorsAttnA_2_DefaultC
Dorsal Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.defaultc
rsfMRI_fcnxpro134_DorsAttnA_2_DefaultB
Dorsal Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.defaultb
rsfMRI_fcnxpro134_DorsAttnA_2_DefaultA
Dorsal Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.defaulta
rsfMRI_fcnxpro134_DorsAttnA_2_ContC
Dorsal Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.contc
rsfMRI_fcnxpro134_DorsAttnA_2_ContB
Dorsal Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.contb
rsfMRI_fcnxpro134_DorsAttnA_2_ContA
Dorsal Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.conta
rsfMRI_fcnxpro134_DorsAttnA_2_LimbicA
Dorsal Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.limbica
rsfMRI_fcnxpro134_DorsAttnA_2_LimbicB
Dorsal Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.limbicb
rsfMRI_fcnxpro134_DorsAttnA_2_SalVentAttnB
Dorsal Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.salventattnb
rsfMRI_fcnxpro134_DorsAttnA_2_SalVentAttnA
Dorsal Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.salventattna
rsfMRI_fcnxpro134_DorsAttnA_2_DorsAttnB
Dorsal Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.dorsattnb
rsfMRI_fcnxpro134_DorsAttnA_2_DorsAttnA
Dorsal Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.dorsattna
rsfMRI_fcnxpro134_DorsAttnA_2_SomMotB
Dorsal Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.sommotb
rsfMRI_fcnxpro134_DorsAttnA_2_SomMotA
Dorsal Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.sommota
rsfMRI_fcnxpro134_DorsAttnA_2_VisPeri
Dorsal Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.visperi
rsfMRI_fcnxpro134_DorsAttnA_2_VisCent
Dorsal Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.viscent
rsfMRI_fcnxpro134_DorsAttnA_2_Striatum
Dorsal Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.striatum
rsfMRI_fcnxpro134_DorsAttnA_2_Dopamine
Dorsal Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.dopamine
rsfMRI_fcnxpro134_DorsAttnA_2_CITLimbic
Dorsal Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.citlimbic
rsfMRI_fcnxpro134_DorsAttnA_2_BasalGanglia
Dorsal Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.basalganglia
rsfMRI_fcnxpro134_DorsAttnA_2_MidBrain
Dorsal Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dorsattna.2.midbrain
rsfMRI_fcnxpro134_SomMotB_2_TempPar
Somatomotor Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.temppar
rsfMRI_fcnxpro134_SomMotB_2_DefaultC
Somatomotor Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.defaultc
rsfMRI_fcnxpro134_SomMotB_2_DefaultB
Somatomotor Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.defaultb
rsfMRI_fcnxpro134_SomMotB_2_DefaultA
Somatomotor Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.defaulta
rsfMRI_fcnxpro134_SomMotB_2_ContC
Somatomotor Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.contc
rsfMRI_fcnxpro134_SomMotB_2_ContB
Somatomotor Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.contb
rsfMRI_fcnxpro134_SomMotB_2_ContA
Somatomotor Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.conta
rsfMRI_fcnxpro134_SomMotB_2_LimbicA
Somatomotor Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.limbica
rsfMRI_fcnxpro134_SomMotB_2_LimbicB
Somatomotor Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.limbicb
rsfMRI_fcnxpro134_SomMotB_2_SalVentAttnB
Somatomotor Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.salventattnb
rsfMRI_fcnxpro134_SomMotB_2_SalVentAttnA
Somatomotor Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.salventattna
rsfMRI_fcnxpro134_SomMotB_2_DorsAttnB
Somatomotor Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.dorsattnb
rsfMRI_fcnxpro134_SomMotB_2_DorsAttnA
Somatomotor Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.dorsattna
rsfMRI_fcnxpro134_SomMotB_2_SomMotB
Somatomotor Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.sommotb
rsfMRI_fcnxpro134_SomMotB_2_SomMotA
Somatomotor Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.sommota
rsfMRI_fcnxpro134_SomMotB_2_VisPeri
Somatomotor Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.visperi
rsfMRI_fcnxpro134_SomMotB_2_VisCent
Somatomotor Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.viscent
rsfMRI_fcnxpro134_SomMotB_2_Striatum
Somatomotor Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.striatum
rsfMRI_fcnxpro134_SomMotB_2_Dopamine
Somatomotor Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.dopamine
rsfMRI_fcnxpro134_SomMotB_2_CITLimbic
Somatomotor Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.citlimbic
rsfMRI_fcnxpro134_SomMotB_2_BasalGanglia
Somatomotor Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.basalganglia
rsfMRI_fcnxpro134_SomMotB_2_MidBrain
Somatomotor Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommotb.2.midbrain
rsfMRI_fcnxpro134_SomMotA_2_TempPar
Somatomotor Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.temppar
rsfMRI_fcnxpro134_SomMotA_2_DefaultC
Somatomotor Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.defaultc
rsfMRI_fcnxpro134_SomMotA_2_DefaultB
Somatomotor Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.defaultb
rsfMRI_fcnxpro134_SomMotA_2_DefaultA
Somatomotor Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.defaulta
rsfMRI_fcnxpro134_SomMotA_2_ContC
Somatomotor Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.contc
rsfMRI_fcnxpro134_SomMotA_2_ContB
Somatomotor Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.contb
rsfMRI_fcnxpro134_SomMotA_2_ContA
Somatomotor Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.conta
rsfMRI_fcnxpro134_SomMotA_2_LimbicA
Somatomotor Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.limbica
rsfMRI_fcnxpro134_SomMotA_2_LimbicB
Somatomotor Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.limbicb
rsfMRI_fcnxpro134_SomMotA_2_SalVentAttnB
Somatomotor Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.salventattnb
rsfMRI_fcnxpro134_SomMotA_2_SalVentAttnA
Somatomotor Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.salventattna
rsfMRI_fcnxpro134_SomMotA_2_DorsAttnB
Somatomotor Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.dorsattnb
rsfMRI_fcnxpro134_SomMotA_2_DorsAttnA
Somatomotor Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.dorsattna
rsfMRI_fcnxpro134_SomMotA_2_SomMotB
Somatomotor Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.sommotb
rsfMRI_fcnxpro134_SomMotA_2_SomMotA
Somatomotor Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.sommota
rsfMRI_fcnxpro134_SomMotA_2_VisPeri
Somatomotor Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.visperi
rsfMRI_fcnxpro134_SomMotA_2_VisCent
Somatomotor Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.viscent
rsfMRI_fcnxpro134_SomMotA_2_Striatum
Somatomotor Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.striatum
rsfMRI_fcnxpro134_SomMotA_2_Dopamine
Somatomotor Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.dopamine
rsfMRI_fcnxpro134_SomMotA_2_CITLimbic
Somatomotor Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.citlimbic
rsfMRI_fcnxpro134_SomMotA_2_BasalGanglia
Somatomotor Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.basalganglia
rsfMRI_fcnxpro134_SomMotA_2_MidBrain
Somatomotor Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.sommota.2.midbrain
rsfMRI_fcnxpro134_VisPeri_2_TempPar
Visual Network Peripheral to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.temppar
rsfMRI_fcnxpro134_VisPeri_2_DefaultC
Visual Network Peripheral to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.defaultc
rsfMRI_fcnxpro134_VisPeri_2_DefaultB
Visual Network Peripheral to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.defaultb
rsfMRI_fcnxpro134_VisPeri_2_DefaultA
Visual Network Peripheral to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.defaulta
rsfMRI_fcnxpro134_VisPeri_2_ContC
Visual Network Peripheral to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.contc
rsfMRI_fcnxpro134_VisPeri_2_ContB
Visual Network Peripheral to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.contb
rsfMRI_fcnxpro134_VisPeri_2_ContA
Visual Network Peripheral to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.conta
rsfMRI_fcnxpro134_VisPeri_2_LimbicA
Visual Network Peripheral to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.limbica
rsfMRI_fcnxpro134_VisPeri_2_LimbicB
Visual Network Peripheral to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.limbicb
rsfMRI_fcnxpro134_VisPeri_2_SalVentAttnB
Visual Network Peripheral to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.salventattnb
rsfMRI_fcnxpro134_VisPeri_2_SalVentAttnA
Visual Network Peripheral to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.salventattna
rsfMRI_fcnxpro134_VisPeri_2_DorsAttnB
Visual Network Peripheral to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.dorsattnb
rsfMRI_fcnxpro134_VisPeri_2_DorsAttnA
Visual Network Peripheral to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.dorsattna
rsfMRI_fcnxpro134_VisPeri_2_SomMotB
Visual Network Peripheral to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.sommotb
rsfMRI_fcnxpro134_VisPeri_2_SomMotA
Visual Network Peripheral to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.sommota
rsfMRI_fcnxpro134_VisPeri_2_VisPeri
Visual Network Peripheral to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.visperi
rsfMRI_fcnxpro134_VisPeri_2_VisCent
Visual Network Peripheral to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.viscent
rsfMRI_fcnxpro134_VisPeri_2_Striatum
Visual Network Peripheral to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.striatum
rsfMRI_fcnxpro134_VisPeri_2_Dopamine
Visual Network Peripheral to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.dopamine
rsfMRI_fcnxpro134_VisPeri_2_CITLimbic
Visual Network Peripheral to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.citlimbic
rsfMRI_fcnxpro134_VisPeri_2_BasalGanglia
Visual Network Peripheral to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.basalganglia
rsfMRI_fcnxpro134_VisPeri_2_MidBrain
Visual Network Peripheral to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.visperi.2.midbrain
rsfMRI_fcnxpro134_VisCent_2_TempPar
Visual Network Central to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.temppar
rsfMRI_fcnxpro134_VisCent_2_DefaultC
Visual Network Central to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.defaultc
rsfMRI_fcnxpro134_VisCent_2_DefaultB
Visual Network Central to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.defaultb
rsfMRI_fcnxpro134_VisCent_2_DefaultA
Visual Network Central to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.defaulta
rsfMRI_fcnxpro134_VisCent_2_ContC
Visual Network Central to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.contc
rsfMRI_fcnxpro134_VisCent_2_ContB
Visual Network Central to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.contb
rsfMRI_fcnxpro134_VisCent_2_ContA
Visual Network Central to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.conta
rsfMRI_fcnxpro134_VisCent_2_LimbicA
Visual Network Central to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.limbica
rsfMRI_fcnxpro134_VisCent_2_LimbicB
Visual Network Central to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.limbicb
rsfMRI_fcnxpro134_VisCent_2_SalVentAttnB
Visual Network Central to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.salventattnb
rsfMRI_fcnxpro134_VisCent_2_SalVentAttnA
Visual Network Central to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.salventattna
rsfMRI_fcnxpro134_VisCent_2_DorsAttnB
Visual Network Central to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.dorsattnb
rsfMRI_fcnxpro134_VisCent_2_DorsAttnA
Visual Network Central to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.dorsattna
rsfMRI_fcnxpro134_VisCent_2_SomMotB
Visual Network Central to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.sommotb
rsfMRI_fcnxpro134_VisCent_2_SomMotA
Visual Network Central to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.sommota
rsfMRI_fcnxpro134_VisCent_2_VisPeri
Visual Network Central to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.visperi
rsfMRI_fcnxpro134_VisCent_2_VisCent
Visual Network Central to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.viscent
rsfMRI_fcnxpro134_VisCent_2_Striatum
Visual Network Central to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.striatum
rsfMRI_fcnxpro134_VisCent_2_Dopamine
Visual Network Central to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.dopamine
rsfMRI_fcnxpro134_VisCent_2_CITLimbic
Visual Network Central to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.citlimbic
rsfMRI_fcnxpro134_VisCent_2_BasalGanglia
Visual Network Central to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.basalganglia
rsfMRI_fcnxpro134_VisCent_2_MidBrain
Visual Network Central to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.viscent.2.midbrain
rsfMRI_fcnxpro134_Striatum_2_TempPar
Striatal Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.temppar
rsfMRI_fcnxpro134_Striatum_2_DefaultC
Striatal Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.defaultc
rsfMRI_fcnxpro134_Striatum_2_DefaultB
Striatal Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.defaultb
rsfMRI_fcnxpro134_Striatum_2_DefaultA
Striatal Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.defaulta
rsfMRI_fcnxpro134_Striatum_2_ContC
Striatal Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.contc
rsfMRI_fcnxpro134_Striatum_2_ContB
Striatal Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.contb
rsfMRI_fcnxpro134_Striatum_2_ContA
Striatal Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.conta
rsfMRI_fcnxpro134_Striatum_2_LimbicA
Striatal Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.limbica
rsfMRI_fcnxpro134_Striatum_2_LimbicB
Striatal Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.limbicb
rsfMRI_fcnxpro134_Striatum_2_SalVentAttnB
Striatal Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.salventattnb
rsfMRI_fcnxpro134_Striatum_2_SalVentAttnA
Striatal Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.salventattna
rsfMRI_fcnxpro134_Striatum_2_DorsAttnB
Striatal Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.dorsattnb
rsfMRI_fcnxpro134_Striatum_2_DorsAttnA
Striatal Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.dorsattna
rsfMRI_fcnxpro134_Striatum_2_SomMotB
Striatal Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.sommotb
rsfMRI_fcnxpro134_Striatum_2_SomMotA
Striatal Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.sommota
rsfMRI_fcnxpro134_Striatum_2_VisPeri
Striatal Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.visperi
rsfMRI_fcnxpro134_Striatum_2_VisCent
Striatal Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.viscent
rsfMRI_fcnxpro134_Striatum_2_Striatum
Striatal Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.striatum
rsfMRI_fcnxpro134_Striatum_2_Dopamine
Striatal Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.dopamine
rsfMRI_fcnxpro134_Striatum_2_CITLimbic
Striatal Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.citlimbic
rsfMRI_fcnxpro134_Striatum_2_BasalGanglia
Striatal Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.basalganglia
rsfMRI_fcnxpro134_Striatum_2_MidBrain
Striatal Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.striatum.2.midbrain
rsfMRI_fcnxpro134_Dopamine_2_TempPar
Dopaminergic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.temppar
rsfMRI_fcnxpro134_Dopamine_2_DefaultC
Dopaminergic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.defaultc
rsfMRI_fcnxpro134_Dopamine_2_DefaultB
Dopaminergic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.defaultb
rsfMRI_fcnxpro134_Dopamine_2_DefaultA
Dopaminergic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.defaulta
rsfMRI_fcnxpro134_Dopamine_2_ContC
Dopaminergic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.contc
rsfMRI_fcnxpro134_Dopamine_2_ContB
Dopaminergic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.contb
rsfMRI_fcnxpro134_Dopamine_2_ContA
Dopaminergic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.conta
rsfMRI_fcnxpro134_Dopamine_2_LimbicA
Dopaminergic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.limbica
rsfMRI_fcnxpro134_Dopamine_2_LimbicB
Dopaminergic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.limbicb
rsfMRI_fcnxpro134_Dopamine_2_SalVentAttnB
Dopaminergic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.salventattnb
rsfMRI_fcnxpro134_Dopamine_2_SalVentAttnA
Dopaminergic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.salventattna
rsfMRI_fcnxpro134_Dopamine_2_DorsAttnB
Dopaminergic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.dorsattnb
rsfMRI_fcnxpro134_Dopamine_2_DorsAttnA
Dopaminergic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.dorsattna
rsfMRI_fcnxpro134_Dopamine_2_SomMotB
Dopaminergic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.sommotb
rsfMRI_fcnxpro134_Dopamine_2_SomMotA
Dopaminergic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.sommota
rsfMRI_fcnxpro134_Dopamine_2_VisPeri
Dopaminergic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.visperi
rsfMRI_fcnxpro134_Dopamine_2_VisCent
Dopaminergic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.viscent
rsfMRI_fcnxpro134_Dopamine_2_Striatum
Dopaminergic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.striatum
rsfMRI_fcnxpro134_Dopamine_2_Dopamine
Dopaminergic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.dopamine
rsfMRI_fcnxpro134_Dopamine_2_CITLimbic
Dopaminergic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.citlimbic
rsfMRI_fcnxpro134_Dopamine_2_BasalGanglia
Dopaminergic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.basalganglia
rsfMRI_fcnxpro134_Dopamine_2_MidBrain
Dopaminergic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.dopamine.2.midbrain
rsfMRI_fcnxpro134_CITLimbic_2_TempPar
CIT Atlas Limbic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.temppar
rsfMRI_fcnxpro134_CITLimbic_2_DefaultC
CIT Atlas Limbic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.defaultc
rsfMRI_fcnxpro134_CITLimbic_2_DefaultB
CIT Atlas Limbic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.defaultb
rsfMRI_fcnxpro134_CITLimbic_2_DefaultA
CIT Atlas Limbic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.defaulta
rsfMRI_fcnxpro134_CITLimbic_2_ContC
CIT Atlas Limbic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.contc
rsfMRI_fcnxpro134_CITLimbic_2_ContB
CIT Atlas Limbic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.contb
rsfMRI_fcnxpro134_CITLimbic_2_ContA
CIT Atlas Limbic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.conta
rsfMRI_fcnxpro134_CITLimbic_2_LimbicA
CIT Atlas Limbic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.limbica
rsfMRI_fcnxpro134_CITLimbic_2_LimbicB
CIT Atlas Limbic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.limbicb
rsfMRI_fcnxpro134_CITLimbic_2_SalVentAttnB
CIT Atlas Limbic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.salventattnb
rsfMRI_fcnxpro134_CITLimbic_2_SalVentAttnA
CIT Atlas Limbic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.salventattna
rsfMRI_fcnxpro134_CITLimbic_2_DorsAttnB
CIT Atlas Limbic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.dorsattnb
rsfMRI_fcnxpro134_CITLimbic_2_DorsAttnA
CIT Atlas Limbic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.dorsattna
rsfMRI_fcnxpro134_CITLimbic_2_SomMotB
CIT Atlas Limbic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.sommotb
rsfMRI_fcnxpro134_CITLimbic_2_SomMotA
CIT Atlas Limbic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.sommota
rsfMRI_fcnxpro134_CITLimbic_2_VisPeri
CIT Atlas Limbic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.visperi
rsfMRI_fcnxpro134_CITLimbic_2_VisCent
CIT Atlas Limbic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.viscent
rsfMRI_fcnxpro134_CITLimbic_2_Striatum
CIT Atlas Limbic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.striatum
rsfMRI_fcnxpro134_CITLimbic_2_Dopamine
CIT Atlas Limbic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.dopamine
rsfMRI_fcnxpro134_CITLimbic_2_CITLimbic
CIT Atlas Limbic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.citlimbic
rsfMRI_fcnxpro134_CITLimbic_2_BasalGanglia
CIT Atlas Limbic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.basalganglia
rsfMRI_fcnxpro134_CITLimbic_2_MidBrain
CIT Atlas Limbic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.citlimbic.2.midbrain
rsfMRI_fcnxpro134_BasalGanglia_2_TempPar
Basal Ganglia Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.temppar
rsfMRI_fcnxpro134_BasalGanglia_2_DefaultC
Basal Ganglia Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.defaultc
rsfMRI_fcnxpro134_BasalGanglia_2_DefaultB
Basal Ganglia Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.defaultb
rsfMRI_fcnxpro134_BasalGanglia_2_DefaultA
Basal Ganglia Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.defaulta
rsfMRI_fcnxpro134_BasalGanglia_2_ContC
Basal Ganglia Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.contc
rsfMRI_fcnxpro134_BasalGanglia_2_ContB
Basal Ganglia Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.contb
rsfMRI_fcnxpro134_BasalGanglia_2_ContA
Basal Ganglia Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.conta
rsfMRI_fcnxpro134_BasalGanglia_2_LimbicA
Basal Ganglia Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.limbica
rsfMRI_fcnxpro134_BasalGanglia_2_LimbicB
Basal Ganglia Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.limbicb
rsfMRI_fcnxpro134_BasalGanglia_2_SalVentAttnB
Basal Ganglia Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.salventattnb
rsfMRI_fcnxpro134_BasalGanglia_2_SalVentAttnA
Basal Ganglia Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.salventattna
rsfMRI_fcnxpro134_BasalGanglia_2_DorsAttnB
Basal Ganglia Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.dorsattnb
rsfMRI_fcnxpro134_BasalGanglia_2_DorsAttnA
Basal Ganglia Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.dorsattna
rsfMRI_fcnxpro134_BasalGanglia_2_SomMotB
Basal Ganglia Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.sommotb
rsfMRI_fcnxpro134_BasalGanglia_2_SomMotA
Basal Ganglia Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.sommota
rsfMRI_fcnxpro134_BasalGanglia_2_VisPeri
Basal Ganglia Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.visperi
rsfMRI_fcnxpro134_BasalGanglia_2_VisCent
Basal Ganglia Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.viscent
rsfMRI_fcnxpro134_BasalGanglia_2_Striatum
Basal Ganglia Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.striatum
rsfMRI_fcnxpro134_BasalGanglia_2_Dopamine
Basal Ganglia Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.dopamine
rsfMRI_fcnxpro134_BasalGanglia_2_CITLimbic
Basal Ganglia Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.citlimbic
rsfMRI_fcnxpro134_BasalGanglia_2_BasalGanglia
Basal Ganglia Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.basalganglia
rsfMRI_fcnxpro134_BasalGanglia_2_MidBrain
Basal Ganglia Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.basalganglia.2.midbrain
rsfMRI_fcnxpro134_MidBrain_2_TempPar
Midbrain to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.temppar
rsfMRI_fcnxpro134_MidBrain_2_DefaultC
Midbrain to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.defaultc
rsfMRI_fcnxpro134_MidBrain_2_DefaultB
Midbrain to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.defaultb
rsfMRI_fcnxpro134_MidBrain_2_DefaultA
Midbrain to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.defaulta
rsfMRI_fcnxpro134_MidBrain_2_ContC
Midbrain to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.contc
rsfMRI_fcnxpro134_MidBrain_2_ContB
Midbrain to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.contb
rsfMRI_fcnxpro134_MidBrain_2_ContA
Midbrain to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.conta
rsfMRI_fcnxpro134_MidBrain_2_LimbicA
Midbrain to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.limbica
rsfMRI_fcnxpro134_MidBrain_2_LimbicB
Midbrain to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.limbicb
rsfMRI_fcnxpro134_MidBrain_2_SalVentAttnB
Midbrain to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.salventattnb
rsfMRI_fcnxpro134_MidBrain_2_SalVentAttnA
Midbrain to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.salventattna
rsfMRI_fcnxpro134_MidBrain_2_DorsAttnB
Midbrain to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.dorsattnb
rsfMRI_fcnxpro134_MidBrain_2_DorsAttnA
Midbrain to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.dorsattna
rsfMRI_fcnxpro134_MidBrain_2_SomMotB
Midbrain to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.sommotb
rsfMRI_fcnxpro134_MidBrain_2_SomMotA
Midbrain to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.sommota
rsfMRI_fcnxpro134_MidBrain_2_VisPeri
Midbrain to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.visperi
rsfMRI_fcnxpro134_MidBrain_2_VisCent
Midbrain to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.viscent
rsfMRI_fcnxpro134_MidBrain_2_Striatum
Midbrain to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.striatum
rsfMRI_fcnxpro134_MidBrain_2_Dopamine
Midbrain to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.dopamine
rsfMRI_fcnxpro134_MidBrain_2_CITLimbic
Midbrain to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.citlimbic
rsfMRI_fcnxpro134_MidBrain_2_BasalGanglia
Midbrain to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.basalganglia
rsfMRI_fcnxpro134_MidBrain_2_MidBrain
Midbrain to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
134
​
rsf.p3.midbrain.2.midbrain
rsfMRI_fcnxpro122_paramset
​
restingStatefMRI
parameter id
power peterson fMRI meta-analyses
122
​
rsf.p1.paramset
rsfMRI_fcnxpro122_upsampling
​
restingStatefMRI
upsampling parameter
power peterson fMRI meta-analyses
122
​
rsf.p1.upsampling
rsfMRI_fcnxpro122_meanBold_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.meanbold.mean
rsfMRI_fcnxpro122_TempPar_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.mean
rsfMRI_fcnxpro122_DefaultC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.mean
rsfMRI_fcnxpro122_DefaultB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.mean
rsfMRI_fcnxpro122_DefaultA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.mean
rsfMRI_fcnxpro122_ContC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.mean
rsfMRI_fcnxpro122_ContB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.mean
rsfMRI_fcnxpro122_ContA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.mean
rsfMRI_fcnxpro122_LimbicA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.mean
rsfMRI_fcnxpro122_LimbicB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.mean
rsfMRI_fcnxpro122_SalVentAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.mean
rsfMRI_fcnxpro122_SalVentAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.mean
rsfMRI_fcnxpro122_DorsAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.mean
rsfMRI_fcnxpro122_DorsAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.mean
rsfMRI_fcnxpro122_SomMotB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.mean
rsfMRI_fcnxpro122_SomMotA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.mean
rsfMRI_fcnxpro122_VisPeri_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.mean
rsfMRI_fcnxpro122_VisCent_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.mean
rsfMRI_fcnxpro122_Striatum_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.mean
rsfMRI_fcnxpro122_Dopamine_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.mean
rsfMRI_fcnxpro122_CITLimbic_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.mean
rsfMRI_fcnxpro122_BasalGanglia_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.mean
rsfMRI_fcnxpro122_MidBrain_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.mean
rsfMRI_fcnxpro122_fmri_template_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.fmri.template.mean
rsfMRI_fcnxpro122_brainmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.brainmask.mean
rsfMRI_fcnxpro122_gmmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.gmmask.mean
rsfMRI_fcnxpro122_alff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.alff.mean
rsfMRI_fcnxpro122_alff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
122
​
rsf.p1.alff.sd
rsfMRI_fcnxpro122_falff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.falff.mean
rsfMRI_fcnxpro122_falff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
122
​
rsf.p1.falff.sd
rsfMRI_fcnxpro122_falffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint000.iplleft
rsfMRI_fcnxpro122_alffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint000.iplleft
rsfMRI_fcnxpro122_perafPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint000.iplleft
rsfMRI_fcnxpro122_falffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint001.stleft
rsfMRI_fcnxpro122_alffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint001.stleft
rsfMRI_fcnxpro122_perafPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint001.stleft
rsfMRI_fcnxpro122_falffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint002.stleft
rsfMRI_fcnxpro122_alffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint002.stleft
rsfMRI_fcnxpro122_perafPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint002.stleft
rsfMRI_fcnxpro122_falffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint003.tempoccleft
rsfMRI_fcnxpro122_alffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint003.tempoccleft
rsfMRI_fcnxpro122_perafPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint003.tempoccleft
rsfMRI_fcnxpro122_falffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint004.templeft
rsfMRI_fcnxpro122_alffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint004.templeft
rsfMRI_fcnxpro122_perafPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint004.templeft
rsfMRI_fcnxpro122_falffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint005.templeft
rsfMRI_fcnxpro122_alffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint005.templeft
rsfMRI_fcnxpro122_perafPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint005.templeft
rsfMRI_fcnxpro122_falffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint006.exstrinfleft
rsfMRI_fcnxpro122_alffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint006.exstrinfleft
rsfMRI_fcnxpro122_perafPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint006.exstrinfleft
rsfMRI_fcnxpro122_falffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint007.iplleft
rsfMRI_fcnxpro122_alffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint007.iplleft
rsfMRI_fcnxpro122_perafPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint007.iplleft
rsfMRI_fcnxpro122_falffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint008.phcleft
rsfMRI_fcnxpro122_alffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint008.phcleft
rsfMRI_fcnxpro122_perafPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint008.phcleft
rsfMRI_fcnxpro122_falffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint009.phcleft
rsfMRI_fcnxpro122_alffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint009.phcleft
rsfMRI_fcnxpro122_perafPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint009.phcleft
rsfMRI_fcnxpro122_falffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint010.phcleft
rsfMRI_fcnxpro122_alffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint010.phcleft
rsfMRI_fcnxpro122_perafPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint010.phcleft
rsfMRI_fcnxpro122_falffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint011.rscleft
rsfMRI_fcnxpro122_alffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint011.rscleft
rsfMRI_fcnxpro122_perafPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint011.rscleft
rsfMRI_fcnxpro122_falffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint012.rscleft
rsfMRI_fcnxpro122_alffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint012.rscleft
rsfMRI_fcnxpro122_perafPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint012.rscleft
rsfMRI_fcnxpro122_falffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint013.iplleft
rsfMRI_fcnxpro122_alffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint013.iplleft
rsfMRI_fcnxpro122_perafPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint013.iplleft
rsfMRI_fcnxpro122_falffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint014.iplleft
rsfMRI_fcnxpro122_alffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint014.iplleft
rsfMRI_fcnxpro122_perafPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint014.iplleft
rsfMRI_fcnxpro122_falffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint015.iplleft
rsfMRI_fcnxpro122_alffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint015.iplleft
rsfMRI_fcnxpro122_perafPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint015.iplleft
rsfMRI_fcnxpro122_falffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint016.iplleft
rsfMRI_fcnxpro122_alffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint016.iplleft
rsfMRI_fcnxpro122_perafPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint016.iplleft
rsfMRI_fcnxpro122_falffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint017.pfcdleft
rsfMRI_fcnxpro122_alffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint017.pfcdleft
rsfMRI_fcnxpro122_perafPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint017.pfcdleft
rsfMRI_fcnxpro122_falffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint018.pfcdleft
rsfMRI_fcnxpro122_alffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint018.pfcdleft
rsfMRI_fcnxpro122_perafPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint018.pfcdleft
rsfMRI_fcnxpro122_falffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint019.pfcdleft
rsfMRI_fcnxpro122_alffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint019.pfcdleft
rsfMRI_fcnxpro122_perafPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint019.pfcdleft
rsfMRI_fcnxpro122_falffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint020.pfcdleft
rsfMRI_fcnxpro122_alffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint020.pfcdleft
rsfMRI_fcnxpro122_perafPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint020.pfcdleft
rsfMRI_fcnxpro122_falffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint021.pfcdleft
rsfMRI_fcnxpro122_alffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint021.pfcdleft
rsfMRI_fcnxpro122_perafPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint021.pfcdleft
rsfMRI_fcnxpro122_falffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint022.pfcdleft
rsfMRI_fcnxpro122_alffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint022.pfcdleft
rsfMRI_fcnxpro122_perafPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint022.pfcdleft
rsfMRI_fcnxpro122_falffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint023.pfcdleft
rsfMRI_fcnxpro122_alffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint023.pfcdleft
rsfMRI_fcnxpro122_perafPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint023.pfcdleft
rsfMRI_fcnxpro122_falffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint024.pfclleft
rsfMRI_fcnxpro122_alffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint024.pfclleft
rsfMRI_fcnxpro122_perafPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint024.pfclleft
rsfMRI_fcnxpro122_falffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint025.pfclleft
rsfMRI_fcnxpro122_alffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint025.pfclleft
rsfMRI_fcnxpro122_perafPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint025.pfclleft
rsfMRI_fcnxpro122_falffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint026.pfcvleft
rsfMRI_fcnxpro122_alffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint026.pfcvleft
rsfMRI_fcnxpro122_perafPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint026.pfcvleft
rsfMRI_fcnxpro122_falffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint027.pfcvleft
rsfMRI_fcnxpro122_alffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint027.pfcvleft
rsfMRI_fcnxpro122_perafPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint027.pfcvleft
rsfMRI_fcnxpro122_falffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint028.pfcvleft
rsfMRI_fcnxpro122_alffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint028.pfcvleft
rsfMRI_fcnxpro122_perafPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint028.pfcvleft
rsfMRI_fcnxpro122_falffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint029.pfcvleft
rsfMRI_fcnxpro122_alffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint029.pfcvleft
rsfMRI_fcnxpro122_perafPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint029.pfcvleft
rsfMRI_fcnxpro122_falffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint030.temppoleleft
rsfMRI_fcnxpro122_alffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint030.temppoleleft
rsfMRI_fcnxpro122_perafPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint030.temppoleleft
rsfMRI_fcnxpro122_falffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint031.templeft
rsfMRI_fcnxpro122_alffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint031.templeft
rsfMRI_fcnxpro122_perafPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint031.templeft
rsfMRI_fcnxpro122_falffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint032.templeft
rsfMRI_fcnxpro122_alffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint032.templeft
rsfMRI_fcnxpro122_perafPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint032.templeft
rsfMRI_fcnxpro122_falffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint033.templeft
rsfMRI_fcnxpro122_alffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint033.templeft
rsfMRI_fcnxpro122_perafPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint033.templeft
rsfMRI_fcnxpro122_falffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint034.templeft
rsfMRI_fcnxpro122_alffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint034.templeft
rsfMRI_fcnxpro122_perafPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint034.templeft
rsfMRI_fcnxpro122_falffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint035.templeft
rsfMRI_fcnxpro122_alffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint035.templeft
rsfMRI_fcnxpro122_perafPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint035.templeft
rsfMRI_fcnxpro122_falffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint036.templeft
rsfMRI_fcnxpro122_alffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint036.templeft
rsfMRI_fcnxpro122_perafPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint036.templeft
rsfMRI_fcnxpro122_falffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint037.templeft
rsfMRI_fcnxpro122_alffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint037.templeft
rsfMRI_fcnxpro122_perafPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint037.templeft
rsfMRI_fcnxpro122_falffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint038.templeft
rsfMRI_fcnxpro122_alffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint038.templeft
rsfMRI_fcnxpro122_perafPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint038.templeft
rsfMRI_fcnxpro122_falffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint039.templeft
rsfMRI_fcnxpro122_alffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint039.templeft
rsfMRI_fcnxpro122_perafPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint039.templeft
rsfMRI_fcnxpro122_falffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint040.templeft
rsfMRI_fcnxpro122_alffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint040.templeft
rsfMRI_fcnxpro122_perafPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint040.templeft
rsfMRI_fcnxpro122_falffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint041.fpoleleft
rsfMRI_fcnxpro122_alffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint041.fpoleleft
rsfMRI_fcnxpro122_perafPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint041.fpoleleft
rsfMRI_fcnxpro122_falffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint042.iplleft
rsfMRI_fcnxpro122_alffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint042.iplleft
rsfMRI_fcnxpro122_perafPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint042.iplleft
rsfMRI_fcnxpro122_falffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint043.iplleft
rsfMRI_fcnxpro122_alffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint043.iplleft
rsfMRI_fcnxpro122_perafPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint043.iplleft
rsfMRI_fcnxpro122_falffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint044.iplleft
rsfMRI_fcnxpro122_alffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint044.iplleft
rsfMRI_fcnxpro122_perafPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint044.iplleft
rsfMRI_fcnxpro122_falffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint045.pccleft
rsfMRI_fcnxpro122_alffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint045.pccleft
rsfMRI_fcnxpro122_perafPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint045.pccleft
rsfMRI_fcnxpro122_falffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint046.pccleft
rsfMRI_fcnxpro122_alffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint046.pccleft
rsfMRI_fcnxpro122_perafPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint046.pccleft
rsfMRI_fcnxpro122_falffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint047.pccleft
rsfMRI_fcnxpro122_alffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint047.pccleft
rsfMRI_fcnxpro122_perafPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint047.pccleft
rsfMRI_fcnxpro122_falffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint048.pccleft
rsfMRI_fcnxpro122_alffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint048.pccleft
rsfMRI_fcnxpro122_perafPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint048.pccleft
rsfMRI_fcnxpro122_falffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint049.pccleft
rsfMRI_fcnxpro122_alffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint049.pccleft
rsfMRI_fcnxpro122_perafPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint049.pccleft
rsfMRI_fcnxpro122_falffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint050.pccleft
rsfMRI_fcnxpro122_alffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint050.pccleft
rsfMRI_fcnxpro122_perafPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint050.pccleft
rsfMRI_fcnxpro122_falffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint051.pccleft
rsfMRI_fcnxpro122_alffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint051.pccleft
rsfMRI_fcnxpro122_perafPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint051.pccleft
rsfMRI_fcnxpro122_falffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint052.pfcdleft
rsfMRI_fcnxpro122_alffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint052.pfcdleft
rsfMRI_fcnxpro122_perafPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint052.pfcdleft
rsfMRI_fcnxpro122_falffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint053.pfcdleft
rsfMRI_fcnxpro122_alffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint053.pfcdleft
rsfMRI_fcnxpro122_perafPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint053.pfcdleft
rsfMRI_fcnxpro122_falffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint054.pfcdleft
rsfMRI_fcnxpro122_alffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint054.pfcdleft
rsfMRI_fcnxpro122_perafPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint054.pfcdleft
rsfMRI_fcnxpro122_falffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint055.pfcdleft
rsfMRI_fcnxpro122_alffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint055.pfcdleft
rsfMRI_fcnxpro122_perafPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint055.pfcdleft
rsfMRI_fcnxpro122_falffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint056.pfcmleft
rsfMRI_fcnxpro122_alffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint056.pfcmleft
rsfMRI_fcnxpro122_perafPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint056.pfcmleft
rsfMRI_fcnxpro122_falffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint057.pfcmleft
rsfMRI_fcnxpro122_alffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint057.pfcmleft
rsfMRI_fcnxpro122_perafPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint057.pfcmleft
rsfMRI_fcnxpro122_falffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint058.pfcmleft
rsfMRI_fcnxpro122_alffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint058.pfcmleft
rsfMRI_fcnxpro122_perafPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint058.pfcmleft
rsfMRI_fcnxpro122_falffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint059.pfcmleft
rsfMRI_fcnxpro122_alffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint059.pfcmleft
rsfMRI_fcnxpro122_perafPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint059.pfcmleft
rsfMRI_fcnxpro122_falffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint060.pfcmleft
rsfMRI_fcnxpro122_alffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint060.pfcmleft
rsfMRI_fcnxpro122_perafPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint060.pfcmleft
rsfMRI_fcnxpro122_falffPoint061_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint061.pcunleft
rsfMRI_fcnxpro122_alffPoint061_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint061.pcunleft
rsfMRI_fcnxpro122_perafPoint061_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint061.pcunleft
rsfMRI_fcnxpro122_falffPoint062_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint062.pcunleft
rsfMRI_fcnxpro122_alffPoint062_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint062.pcunleft
rsfMRI_fcnxpro122_perafPoint062_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint062.pcunleft
rsfMRI_fcnxpro122_falffPoint063_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint063.pcunleft
rsfMRI_fcnxpro122_alffPoint063_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint063.pcunleft
rsfMRI_fcnxpro122_perafPoint063_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint063.pcunleft
rsfMRI_fcnxpro122_falffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint064.pccleft
rsfMRI_fcnxpro122_alffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint064.pccleft
rsfMRI_fcnxpro122_perafPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint064.pccleft
rsfMRI_fcnxpro122_falffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint065.splleft
rsfMRI_fcnxpro122_alffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint065.splleft
rsfMRI_fcnxpro122_perafPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint065.splleft
rsfMRI_fcnxpro122_falffPoint066_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint066.pcunleft
rsfMRI_fcnxpro122_alffPoint066_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint066.pcunleft
rsfMRI_fcnxpro122_perafPoint066_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint066.pcunleft
rsfMRI_fcnxpro122_falffPoint067_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint067.pcunleft
rsfMRI_fcnxpro122_alffPoint067_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint067.pcunleft
rsfMRI_fcnxpro122_perafPoint067_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint067.pcunleft
rsfMRI_fcnxpro122_falffPoint068_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint068.pcunleft
rsfMRI_fcnxpro122_alffPoint068_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint068.pcunleft
rsfMRI_fcnxpro122_perafPoint068_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint068.pcunleft
rsfMRI_fcnxpro122_falffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint069.fpoleleft
rsfMRI_fcnxpro122_alffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint069.fpoleleft
rsfMRI_fcnxpro122_perafPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint069.fpoleleft
rsfMRI_fcnxpro122_falffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint070.fpoleleft
rsfMRI_fcnxpro122_alffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint070.fpoleleft
rsfMRI_fcnxpro122_perafPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint070.fpoleleft
rsfMRI_fcnxpro122_falffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint071.frmedleft
rsfMRI_fcnxpro122_alffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint071.frmedleft
rsfMRI_fcnxpro122_perafPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint071.frmedleft
rsfMRI_fcnxpro122_falffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint072.iplleft
rsfMRI_fcnxpro122_alffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint072.iplleft
rsfMRI_fcnxpro122_perafPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint072.iplleft
rsfMRI_fcnxpro122_falffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint073.ipsleft
rsfMRI_fcnxpro122_alffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint073.ipsleft
rsfMRI_fcnxpro122_perafPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint073.ipsleft
rsfMRI_fcnxpro122_falffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint074.ipsleft
rsfMRI_fcnxpro122_alffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint074.ipsleft
rsfMRI_fcnxpro122_perafPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint074.ipsleft
rsfMRI_fcnxpro122_falffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint075.pfcdleft
rsfMRI_fcnxpro122_alffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint075.pfcdleft
rsfMRI_fcnxpro122_perafPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint075.pfcdleft
rsfMRI_fcnxpro122_falffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint076.pfclleft
rsfMRI_fcnxpro122_alffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint076.pfclleft
rsfMRI_fcnxpro122_perafPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint076.pfclleft
rsfMRI_fcnxpro122_falffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint077.pfcvleft
rsfMRI_fcnxpro122_alffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint077.pfcvleft
rsfMRI_fcnxpro122_perafPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint077.pfcvleft
rsfMRI_fcnxpro122_falffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint078.templeft
rsfMRI_fcnxpro122_alffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint078.templeft
rsfMRI_fcnxpro122_perafPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint078.templeft
rsfMRI_fcnxpro122_falffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint079.templeft
rsfMRI_fcnxpro122_alffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint079.templeft
rsfMRI_fcnxpro122_perafPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint079.templeft
rsfMRI_fcnxpro122_falffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint080.cingmleft
rsfMRI_fcnxpro122_alffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint080.cingmleft
rsfMRI_fcnxpro122_perafPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint080.cingmleft
rsfMRI_fcnxpro122_falffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint081.ipsleft
rsfMRI_fcnxpro122_alffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint081.ipsleft
rsfMRI_fcnxpro122_perafPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint081.ipsleft
rsfMRI_fcnxpro122_falffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint082.ipsleft
rsfMRI_fcnxpro122_alffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint082.ipsleft
rsfMRI_fcnxpro122_perafPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint082.ipsleft
rsfMRI_fcnxpro122_falffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint083.ipsleft
rsfMRI_fcnxpro122_alffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint083.ipsleft
rsfMRI_fcnxpro122_perafPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint083.ipsleft
rsfMRI_fcnxpro122_falffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint084.ipsleft
rsfMRI_fcnxpro122_alffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint084.ipsleft
rsfMRI_fcnxpro122_perafPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint084.ipsleft
rsfMRI_fcnxpro122_falffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint085.ipsleft
rsfMRI_fcnxpro122_alffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint085.ipsleft
rsfMRI_fcnxpro122_perafPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint085.ipsleft
rsfMRI_fcnxpro122_falffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint086.pfcdleft
rsfMRI_fcnxpro122_alffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint086.pfcdleft
rsfMRI_fcnxpro122_perafPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint086.pfcdleft
rsfMRI_fcnxpro122_falffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint087.pfclleft
rsfMRI_fcnxpro122_alffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint087.pfclleft
rsfMRI_fcnxpro122_perafPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint087.pfclleft
rsfMRI_fcnxpro122_falffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint088.pfclleft
rsfMRI_fcnxpro122_alffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint088.pfclleft
rsfMRI_fcnxpro122_perafPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint088.pfclleft
rsfMRI_fcnxpro122_falffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint089.pfclleft
rsfMRI_fcnxpro122_alffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint089.pfclleft
rsfMRI_fcnxpro122_perafPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint089.pfclleft
rsfMRI_fcnxpro122_falffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint090.pfclleft
rsfMRI_fcnxpro122_alffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint090.pfclleft
rsfMRI_fcnxpro122_perafPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint090.pfclleft
rsfMRI_fcnxpro122_falffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint091.pfclleft
rsfMRI_fcnxpro122_alffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint091.pfclleft
rsfMRI_fcnxpro122_perafPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint091.pfclleft
rsfMRI_fcnxpro122_falffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint092.pfclleft
rsfMRI_fcnxpro122_alffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint092.pfclleft
rsfMRI_fcnxpro122_perafPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint092.pfclleft
rsfMRI_fcnxpro122_falffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint093.prcvleft
rsfMRI_fcnxpro122_alffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint093.prcvleft
rsfMRI_fcnxpro122_perafPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint093.prcvleft
rsfMRI_fcnxpro122_falffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint094.prcvleft
rsfMRI_fcnxpro122_alffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint094.prcvleft
rsfMRI_fcnxpro122_perafPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint094.prcvleft
rsfMRI_fcnxpro122_falffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint095.prcvleft
rsfMRI_fcnxpro122_alffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint095.prcvleft
rsfMRI_fcnxpro122_perafPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint095.prcvleft
rsfMRI_fcnxpro122_falffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint096.splleft
rsfMRI_fcnxpro122_alffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint096.splleft
rsfMRI_fcnxpro122_perafPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint096.splleft
rsfMRI_fcnxpro122_falffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint097.tempoccleft
rsfMRI_fcnxpro122_alffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint097.tempoccleft
rsfMRI_fcnxpro122_perafPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint097.tempoccleft
rsfMRI_fcnxpro122_falffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint098.insleft
rsfMRI_fcnxpro122_alffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint098.insleft
rsfMRI_fcnxpro122_perafPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint098.insleft
rsfMRI_fcnxpro122_falffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint099.phcleft
rsfMRI_fcnxpro122_alffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint099.phcleft
rsfMRI_fcnxpro122_perafPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint099.phcleft
rsfMRI_fcnxpro122_falffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint100.phcleft
rsfMRI_fcnxpro122_alffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint100.phcleft
rsfMRI_fcnxpro122_perafPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint100.phcleft
rsfMRI_fcnxpro122_falffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint101.stleft
rsfMRI_fcnxpro122_alffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint101.stleft
rsfMRI_fcnxpro122_perafPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint101.stleft
rsfMRI_fcnxpro122_falffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint102.temppoleleft
rsfMRI_fcnxpro122_alffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint102.temppoleleft
rsfMRI_fcnxpro122_perafPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint102.temppoleleft
rsfMRI_fcnxpro122_falffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint103.temppoleleft
rsfMRI_fcnxpro122_alffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint103.temppoleleft
rsfMRI_fcnxpro122_perafPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint103.temppoleleft
rsfMRI_fcnxpro122_falffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint104.temppoleleft
rsfMRI_fcnxpro122_alffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint104.temppoleleft
rsfMRI_fcnxpro122_perafPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint104.temppoleleft
rsfMRI_fcnxpro122_falffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint105.temppoleleft
rsfMRI_fcnxpro122_alffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint105.temppoleleft
rsfMRI_fcnxpro122_perafPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint105.temppoleleft
rsfMRI_fcnxpro122_falffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint106.temppoleleft
rsfMRI_fcnxpro122_alffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint106.temppoleleft
rsfMRI_fcnxpro122_perafPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint106.temppoleleft
rsfMRI_fcnxpro122_falffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint107.templeft
rsfMRI_fcnxpro122_alffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint107.templeft
rsfMRI_fcnxpro122_perafPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint107.templeft
rsfMRI_fcnxpro122_falffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint108.templeft
rsfMRI_fcnxpro122_alffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint108.templeft
rsfMRI_fcnxpro122_perafPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint108.templeft
rsfMRI_fcnxpro122_falffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint109.templeft
rsfMRI_fcnxpro122_alffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint109.templeft
rsfMRI_fcnxpro122_perafPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint109.templeft
rsfMRI_fcnxpro122_falffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint110.templeft
rsfMRI_fcnxpro122_alffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint110.templeft
rsfMRI_fcnxpro122_perafPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint110.templeft
rsfMRI_fcnxpro122_falffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint111.fpoleleft
rsfMRI_fcnxpro122_alffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint111.fpoleleft
rsfMRI_fcnxpro122_perafPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint111.fpoleleft
rsfMRI_fcnxpro122_falffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint112.ofcleft
rsfMRI_fcnxpro122_alffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint112.ofcleft
rsfMRI_fcnxpro122_perafPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint112.ofcleft
rsfMRI_fcnxpro122_falffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint113.ofcleft
rsfMRI_fcnxpro122_alffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint113.ofcleft
rsfMRI_fcnxpro122_perafPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint113.ofcleft
rsfMRI_fcnxpro122_falffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint114.ofcleft
rsfMRI_fcnxpro122_alffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint114.ofcleft
rsfMRI_fcnxpro122_perafPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint114.ofcleft
rsfMRI_fcnxpro122_falffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint115.ofcleft
rsfMRI_fcnxpro122_alffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint115.ofcleft
rsfMRI_fcnxpro122_perafPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint115.ofcleft
rsfMRI_fcnxpro122_falffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint116.ofcleft
rsfMRI_fcnxpro122_alffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint116.ofcleft
rsfMRI_fcnxpro122_perafPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint116.ofcleft
rsfMRI_fcnxpro122_falffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint117.ofcleft
rsfMRI_fcnxpro122_alffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint117.ofcleft
rsfMRI_fcnxpro122_perafPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint117.ofcleft
rsfMRI_fcnxpro122_falffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint118.pfcmleft
rsfMRI_fcnxpro122_alffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint118.pfcmleft
rsfMRI_fcnxpro122_perafPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint118.pfcmleft
rsfMRI_fcnxpro122_falffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint119.pfcmleft
rsfMRI_fcnxpro122_alffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint119.pfcmleft
rsfMRI_fcnxpro122_perafPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint119.pfcmleft
rsfMRI_fcnxpro122_falffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint120.frmedleft
rsfMRI_fcnxpro122_alffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint120.frmedleft
rsfMRI_fcnxpro122_perafPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint120.frmedleft
rsfMRI_fcnxpro122_falffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint121.insleft
rsfMRI_fcnxpro122_alffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint121.insleft
rsfMRI_fcnxpro122_perafPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint121.insleft
rsfMRI_fcnxpro122_falffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint122.insleft
rsfMRI_fcnxpro122_alffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint122.insleft
rsfMRI_fcnxpro122_perafPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint122.insleft
rsfMRI_fcnxpro122_falffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint123.insleft
rsfMRI_fcnxpro122_alffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint123.insleft
rsfMRI_fcnxpro122_perafPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint123.insleft
rsfMRI_fcnxpro122_falffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint124.pfclleft
rsfMRI_fcnxpro122_alffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint124.pfclleft
rsfMRI_fcnxpro122_perafPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint124.pfclleft
rsfMRI_fcnxpro122_falffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint125.pfclleft
rsfMRI_fcnxpro122_alffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint125.pfclleft
rsfMRI_fcnxpro122_perafPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint125.pfclleft
rsfMRI_fcnxpro122_falffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint126.pfcmleft
rsfMRI_fcnxpro122_alffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint126.pfcmleft
rsfMRI_fcnxpro122_perafPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint126.pfcmleft
rsfMRI_fcnxpro122_falffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint127.frmedleft
rsfMRI_fcnxpro122_alffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint127.frmedleft
rsfMRI_fcnxpro122_perafPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint127.frmedleft
rsfMRI_fcnxpro122_falffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint128.frmedleft
rsfMRI_fcnxpro122_alffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint128.frmedleft
rsfMRI_fcnxpro122_perafPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint128.frmedleft
rsfMRI_fcnxpro122_falffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint129.frmedleft
rsfMRI_fcnxpro122_alffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint129.frmedleft
rsfMRI_fcnxpro122_perafPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint129.frmedleft
rsfMRI_fcnxpro122_falffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint130.froperleft
rsfMRI_fcnxpro122_alffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint130.froperleft
rsfMRI_fcnxpro122_perafPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint130.froperleft
rsfMRI_fcnxpro122_falffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint131.froperleft
rsfMRI_fcnxpro122_alffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint131.froperleft
rsfMRI_fcnxpro122_perafPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint131.froperleft
rsfMRI_fcnxpro122_falffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint132.iplleft
rsfMRI_fcnxpro122_alffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint132.iplleft
rsfMRI_fcnxpro122_perafPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint132.iplleft
rsfMRI_fcnxpro122_falffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint133.iplleft
rsfMRI_fcnxpro122_alffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint133.iplleft
rsfMRI_fcnxpro122_perafPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint133.iplleft
rsfMRI_fcnxpro122_falffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint134.insleft
rsfMRI_fcnxpro122_alffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint134.insleft
rsfMRI_fcnxpro122_perafPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint134.insleft
rsfMRI_fcnxpro122_falffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint135.insleft
rsfMRI_fcnxpro122_alffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint135.insleft
rsfMRI_fcnxpro122_perafPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint135.insleft
rsfMRI_fcnxpro122_falffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint136.insleft
rsfMRI_fcnxpro122_alffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint136.insleft
rsfMRI_fcnxpro122_perafPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint136.insleft
rsfMRI_fcnxpro122_falffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint137.insleft
rsfMRI_fcnxpro122_alffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint137.insleft
rsfMRI_fcnxpro122_perafPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint137.insleft
rsfMRI_fcnxpro122_falffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint138.insleft
rsfMRI_fcnxpro122_alffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint138.insleft
rsfMRI_fcnxpro122_perafPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint138.insleft
rsfMRI_fcnxpro122_falffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint139.splleft
rsfMRI_fcnxpro122_alffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint139.splleft
rsfMRI_fcnxpro122_perafPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint139.splleft
rsfMRI_fcnxpro122_falffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint140.splleft
rsfMRI_fcnxpro122_alffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint140.splleft
rsfMRI_fcnxpro122_perafPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint140.splleft
rsfMRI_fcnxpro122_falffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint141.splleft
rsfMRI_fcnxpro122_alffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint141.splleft
rsfMRI_fcnxpro122_perafPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint141.splleft
rsfMRI_fcnxpro122_falffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint142.iplleft
rsfMRI_fcnxpro122_alffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint142.iplleft
rsfMRI_fcnxpro122_perafPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint142.iplleft
rsfMRI_fcnxpro122_falffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint143.iplleft
rsfMRI_fcnxpro122_alffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint143.iplleft
rsfMRI_fcnxpro122_perafPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint143.iplleft
rsfMRI_fcnxpro122_falffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint144.pfcdleft
rsfMRI_fcnxpro122_alffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint144.pfcdleft
rsfMRI_fcnxpro122_perafPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint144.pfcdleft
rsfMRI_fcnxpro122_falffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint145.postcleft
rsfMRI_fcnxpro122_alffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint145.postcleft
rsfMRI_fcnxpro122_perafPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint145.postcleft
rsfMRI_fcnxpro122_falffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint146.postcleft
rsfMRI_fcnxpro122_alffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint146.postcleft
rsfMRI_fcnxpro122_perafPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint146.postcleft
rsfMRI_fcnxpro122_falffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint147.postcleft
rsfMRI_fcnxpro122_alffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint147.postcleft
rsfMRI_fcnxpro122_perafPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint147.postcleft
rsfMRI_fcnxpro122_falffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint148.prcdleft
rsfMRI_fcnxpro122_alffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint148.prcdleft
rsfMRI_fcnxpro122_perafPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint148.prcdleft
rsfMRI_fcnxpro122_falffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint149.prcdleft
rsfMRI_fcnxpro122_alffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint149.prcdleft
rsfMRI_fcnxpro122_perafPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint149.prcdleft
rsfMRI_fcnxpro122_falffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint150.prcdleft
rsfMRI_fcnxpro122_alffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint150.prcdleft
rsfMRI_fcnxpro122_perafPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint150.prcdleft
rsfMRI_fcnxpro122_falffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint151.splleft
rsfMRI_fcnxpro122_alffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint151.splleft
rsfMRI_fcnxpro122_perafPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint151.splleft
rsfMRI_fcnxpro122_falffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint152.splleft
rsfMRI_fcnxpro122_alffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint152.splleft
rsfMRI_fcnxpro122_perafPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint152.splleft
rsfMRI_fcnxpro122_falffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint153.splleft
rsfMRI_fcnxpro122_alffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint153.splleft
rsfMRI_fcnxpro122_perafPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint153.splleft
rsfMRI_fcnxpro122_falffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint154.splleft
rsfMRI_fcnxpro122_alffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint154.splleft
rsfMRI_fcnxpro122_perafPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint154.splleft
rsfMRI_fcnxpro122_falffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint155.tempoccleft
rsfMRI_fcnxpro122_alffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint155.tempoccleft
rsfMRI_fcnxpro122_perafPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint155.tempoccleft
rsfMRI_fcnxpro122_falffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint156.exstrleft
rsfMRI_fcnxpro122_alffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint156.exstrleft
rsfMRI_fcnxpro122_perafPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint156.exstrleft
rsfMRI_fcnxpro122_falffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint157.exstrleft
rsfMRI_fcnxpro122_alffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint157.exstrleft
rsfMRI_fcnxpro122_perafPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint157.exstrleft
rsfMRI_fcnxpro122_falffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint158.exstrleft
rsfMRI_fcnxpro122_alffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint158.exstrleft
rsfMRI_fcnxpro122_perafPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint158.exstrleft
rsfMRI_fcnxpro122_falffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint159.exstrleft
rsfMRI_fcnxpro122_alffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint159.exstrleft
rsfMRI_fcnxpro122_perafPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint159.exstrleft
rsfMRI_fcnxpro122_falffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint160.ipsleft
rsfMRI_fcnxpro122_alffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint160.ipsleft
rsfMRI_fcnxpro122_perafPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint160.ipsleft
rsfMRI_fcnxpro122_falffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint161.splleft
rsfMRI_fcnxpro122_alffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint161.splleft
rsfMRI_fcnxpro122_perafPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint161.splleft
rsfMRI_fcnxpro122_falffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint162.splleft
rsfMRI_fcnxpro122_alffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint162.splleft
rsfMRI_fcnxpro122_perafPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint162.splleft
rsfMRI_fcnxpro122_falffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint163.splleft
rsfMRI_fcnxpro122_alffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint163.splleft
rsfMRI_fcnxpro122_perafPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint163.splleft
rsfMRI_fcnxpro122_falffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint164.splleft
rsfMRI_fcnxpro122_alffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint164.splleft
rsfMRI_fcnxpro122_perafPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint164.splleft
rsfMRI_fcnxpro122_falffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint165.splleft
rsfMRI_fcnxpro122_alffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint165.splleft
rsfMRI_fcnxpro122_perafPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint165.splleft
rsfMRI_fcnxpro122_falffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint166.splleft
rsfMRI_fcnxpro122_alffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint166.splleft
rsfMRI_fcnxpro122_perafPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint166.splleft
rsfMRI_fcnxpro122_falffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint167.tempoccleft
rsfMRI_fcnxpro122_alffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint167.tempoccleft
rsfMRI_fcnxpro122_perafPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint167.tempoccleft
rsfMRI_fcnxpro122_falffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint168.tempoccleft
rsfMRI_fcnxpro122_alffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint168.tempoccleft
rsfMRI_fcnxpro122_perafPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint168.tempoccleft
rsfMRI_fcnxpro122_falffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint169.tempoccleft
rsfMRI_fcnxpro122_alffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint169.tempoccleft
rsfMRI_fcnxpro122_perafPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint169.tempoccleft
rsfMRI_fcnxpro122_falffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint170.tempoccleft
rsfMRI_fcnxpro122_alffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint170.tempoccleft
rsfMRI_fcnxpro122_perafPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint170.tempoccleft
rsfMRI_fcnxpro122_falffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint171.tempoccleft
rsfMRI_fcnxpro122_alffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint171.tempoccleft
rsfMRI_fcnxpro122_perafPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint171.tempoccleft
rsfMRI_fcnxpro122_falffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint172.tempoccleft
rsfMRI_fcnxpro122_alffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint172.tempoccleft
rsfMRI_fcnxpro122_perafPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint172.tempoccleft
rsfMRI_fcnxpro122_falffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint173.tempoccleft
rsfMRI_fcnxpro122_alffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint173.tempoccleft
rsfMRI_fcnxpro122_perafPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint173.tempoccleft
rsfMRI_fcnxpro122_falffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint174.tempoccleft
rsfMRI_fcnxpro122_alffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint174.tempoccleft
rsfMRI_fcnxpro122_perafPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint174.tempoccleft
rsfMRI_fcnxpro122_falffPoint175_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint175.1left
rsfMRI_fcnxpro122_alffPoint175_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint175.1left
rsfMRI_fcnxpro122_perafPoint175_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint175.1left
rsfMRI_fcnxpro122_falffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint176.2left
rsfMRI_fcnxpro122_alffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint176.2left
rsfMRI_fcnxpro122_perafPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint176.2left
rsfMRI_fcnxpro122_falffPoint177_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint177.3left
rsfMRI_fcnxpro122_alffPoint177_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint177.3left
rsfMRI_fcnxpro122_perafPoint177_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint177.3left
rsfMRI_fcnxpro122_falffPoint178_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint178.4left
rsfMRI_fcnxpro122_alffPoint178_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint178.4left
rsfMRI_fcnxpro122_perafPoint178_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint178.4left
rsfMRI_fcnxpro122_falffPoint179_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint179.5left
rsfMRI_fcnxpro122_alffPoint179_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint179.5left
rsfMRI_fcnxpro122_perafPoint179_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint179.5left
rsfMRI_fcnxpro122_falffPoint180_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint180.6left
rsfMRI_fcnxpro122_alffPoint180_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint180.6left
rsfMRI_fcnxpro122_perafPoint180_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint180.6left
rsfMRI_fcnxpro122_falffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint181.iplleft
rsfMRI_fcnxpro122_alffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint181.iplleft
rsfMRI_fcnxpro122_perafPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint181.iplleft
rsfMRI_fcnxpro122_falffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint182.insleft
rsfMRI_fcnxpro122_alffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint182.insleft
rsfMRI_fcnxpro122_perafPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint182.insleft
rsfMRI_fcnxpro122_falffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint183.insleft
rsfMRI_fcnxpro122_alffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint183.insleft
rsfMRI_fcnxpro122_perafPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint183.insleft
rsfMRI_fcnxpro122_falffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint184.paroperleft
rsfMRI_fcnxpro122_alffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint184.paroperleft
rsfMRI_fcnxpro122_perafPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint184.paroperleft
rsfMRI_fcnxpro122_falffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint185.paroperleft
rsfMRI_fcnxpro122_alffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint185.paroperleft
rsfMRI_fcnxpro122_perafPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint185.paroperleft
rsfMRI_fcnxpro122_falffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint186.paroperleft
rsfMRI_fcnxpro122_alffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint186.paroperleft
rsfMRI_fcnxpro122_perafPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint186.paroperleft
rsfMRI_fcnxpro122_falffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint187.stleft
rsfMRI_fcnxpro122_alffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint187.stleft
rsfMRI_fcnxpro122_perafPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint187.stleft
rsfMRI_fcnxpro122_falffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint188.stleft
rsfMRI_fcnxpro122_alffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint188.stleft
rsfMRI_fcnxpro122_perafPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint188.stleft
rsfMRI_fcnxpro122_falffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint189.stleft
rsfMRI_fcnxpro122_alffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint189.stleft
rsfMRI_fcnxpro122_perafPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint189.stleft
rsfMRI_fcnxpro122_falffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint190.stleft
rsfMRI_fcnxpro122_alffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint190.stleft
rsfMRI_fcnxpro122_perafPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint190.stleft
rsfMRI_fcnxpro122_falffPoint191_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint191.1left
rsfMRI_fcnxpro122_alffPoint191_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint191.1left
rsfMRI_fcnxpro122_perafPoint191_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint191.1left
rsfMRI_fcnxpro122_falffPoint192_10left
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint192.10left
rsfMRI_fcnxpro122_alffPoint192_10left
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint192.10left
rsfMRI_fcnxpro122_perafPoint192_10left
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint192.10left
rsfMRI_fcnxpro122_falffPoint193_11left
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint193.11left
rsfMRI_fcnxpro122_alffPoint193_11left
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint193.11left
rsfMRI_fcnxpro122_perafPoint193_11left
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint193.11left
rsfMRI_fcnxpro122_falffPoint194_12left
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint194.12left
rsfMRI_fcnxpro122_alffPoint194_12left
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint194.12left
rsfMRI_fcnxpro122_perafPoint194_12left
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint194.12left
rsfMRI_fcnxpro122_falffPoint195_13left
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint195.13left
rsfMRI_fcnxpro122_alffPoint195_13left
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint195.13left
rsfMRI_fcnxpro122_perafPoint195_13left
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint195.13left
rsfMRI_fcnxpro122_falffPoint196_14left
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint196.14left
rsfMRI_fcnxpro122_alffPoint196_14left
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint196.14left
rsfMRI_fcnxpro122_perafPoint196_14left
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint196.14left
rsfMRI_fcnxpro122_falffPoint197_15left
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint197.15left
rsfMRI_fcnxpro122_alffPoint197_15left
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint197.15left
rsfMRI_fcnxpro122_perafPoint197_15left
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint197.15left
rsfMRI_fcnxpro122_falffPoint198_16left
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint198.16left
rsfMRI_fcnxpro122_alffPoint198_16left
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint198.16left
rsfMRI_fcnxpro122_perafPoint198_16left
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint198.16left
rsfMRI_fcnxpro122_falffPoint199_17left
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint199.17left
rsfMRI_fcnxpro122_alffPoint199_17left
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint199.17left
rsfMRI_fcnxpro122_perafPoint199_17left
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint199.17left
rsfMRI_fcnxpro122_falffPoint200_18left
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint200.18left
rsfMRI_fcnxpro122_alffPoint200_18left
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint200.18left
rsfMRI_fcnxpro122_perafPoint200_18left
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint200.18left
rsfMRI_fcnxpro122_falffPoint201_19left
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint201.19left
rsfMRI_fcnxpro122_alffPoint201_19left
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint201.19left
rsfMRI_fcnxpro122_perafPoint201_19left
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint201.19left
rsfMRI_fcnxpro122_falffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint202.2left
rsfMRI_fcnxpro122_alffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint202.2left
rsfMRI_fcnxpro122_perafPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint202.2left
rsfMRI_fcnxpro122_falffPoint203_20left
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint203.20left
rsfMRI_fcnxpro122_alffPoint203_20left
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint203.20left
rsfMRI_fcnxpro122_perafPoint203_20left
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint203.20left
rsfMRI_fcnxpro122_falffPoint204_21left
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint204.21left
rsfMRI_fcnxpro122_alffPoint204_21left
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint204.21left
rsfMRI_fcnxpro122_perafPoint204_21left
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint204.21left
rsfMRI_fcnxpro122_falffPoint205_22left
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint205.22left
rsfMRI_fcnxpro122_alffPoint205_22left
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint205.22left
rsfMRI_fcnxpro122_perafPoint205_22left
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint205.22left
rsfMRI_fcnxpro122_falffPoint206_23left
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint206.23left
rsfMRI_fcnxpro122_alffPoint206_23left
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint206.23left
rsfMRI_fcnxpro122_perafPoint206_23left
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint206.23left
rsfMRI_fcnxpro122_falffPoint207_24left
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint207.24left
rsfMRI_fcnxpro122_alffPoint207_24left
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint207.24left
rsfMRI_fcnxpro122_perafPoint207_24left
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint207.24left
rsfMRI_fcnxpro122_falffPoint208_25left
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint208.25left
rsfMRI_fcnxpro122_alffPoint208_25left
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint208.25left
rsfMRI_fcnxpro122_perafPoint208_25left
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint208.25left
rsfMRI_fcnxpro122_falffPoint209_26left
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint209.26left
rsfMRI_fcnxpro122_alffPoint209_26left
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint209.26left
rsfMRI_fcnxpro122_perafPoint209_26left
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint209.26left
rsfMRI_fcnxpro122_falffPoint210_27left
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint210.27left
rsfMRI_fcnxpro122_alffPoint210_27left
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint210.27left
rsfMRI_fcnxpro122_perafPoint210_27left
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint210.27left
rsfMRI_fcnxpro122_falffPoint211_28left
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint211.28left
rsfMRI_fcnxpro122_alffPoint211_28left
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint211.28left
rsfMRI_fcnxpro122_perafPoint211_28left
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint211.28left
rsfMRI_fcnxpro122_falffPoint212_29left
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint212.29left
rsfMRI_fcnxpro122_alffPoint212_29left
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint212.29left
rsfMRI_fcnxpro122_perafPoint212_29left
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint212.29left
rsfMRI_fcnxpro122_falffPoint213_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint213.3left
rsfMRI_fcnxpro122_alffPoint213_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint213.3left
rsfMRI_fcnxpro122_perafPoint213_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint213.3left
rsfMRI_fcnxpro122_falffPoint214_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint214.4left
rsfMRI_fcnxpro122_alffPoint214_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint214.4left
rsfMRI_fcnxpro122_perafPoint214_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint214.4left
rsfMRI_fcnxpro122_falffPoint215_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint215.5left
rsfMRI_fcnxpro122_alffPoint215_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint215.5left
rsfMRI_fcnxpro122_perafPoint215_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint215.5left
rsfMRI_fcnxpro122_falffPoint216_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint216.6left
rsfMRI_fcnxpro122_alffPoint216_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint216.6left
rsfMRI_fcnxpro122_perafPoint216_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint216.6left
rsfMRI_fcnxpro122_falffPoint217_7left
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint217.7left
rsfMRI_fcnxpro122_alffPoint217_7left
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint217.7left
rsfMRI_fcnxpro122_perafPoint217_7left
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint217.7left
rsfMRI_fcnxpro122_falffPoint218_8left
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint218.8left
rsfMRI_fcnxpro122_alffPoint218_8left
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint218.8left
rsfMRI_fcnxpro122_perafPoint218_8left
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint218.8left
rsfMRI_fcnxpro122_falffPoint219_9left
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint219.9left
rsfMRI_fcnxpro122_alffPoint219_9left
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint219.9left
rsfMRI_fcnxpro122_perafPoint219_9left
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint219.9left
rsfMRI_fcnxpro122_falffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint220.splleft
rsfMRI_fcnxpro122_alffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint220.splleft
rsfMRI_fcnxpro122_perafPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint220.splleft
rsfMRI_fcnxpro122_falffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint221.exstrleft
rsfMRI_fcnxpro122_alffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint221.exstrleft
rsfMRI_fcnxpro122_perafPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint221.exstrleft
rsfMRI_fcnxpro122_falffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint222.exstrinfleft
rsfMRI_fcnxpro122_alffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint222.exstrinfleft
rsfMRI_fcnxpro122_perafPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint222.exstrinfleft
rsfMRI_fcnxpro122_falffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint223.exstrinfleft
rsfMRI_fcnxpro122_alffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint223.exstrinfleft
rsfMRI_fcnxpro122_perafPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint223.exstrinfleft
rsfMRI_fcnxpro122_falffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint224.exstrinfleft
rsfMRI_fcnxpro122_alffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint224.exstrinfleft
rsfMRI_fcnxpro122_perafPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint224.exstrinfleft
rsfMRI_fcnxpro122_falffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint225.exstrinfleft
rsfMRI_fcnxpro122_alffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint225.exstrinfleft
rsfMRI_fcnxpro122_perafPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint225.exstrinfleft
rsfMRI_fcnxpro122_falffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint226.exstrinfleft
rsfMRI_fcnxpro122_alffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint226.exstrinfleft
rsfMRI_fcnxpro122_perafPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint226.exstrinfleft
rsfMRI_fcnxpro122_falffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint227.exstrsupleft
rsfMRI_fcnxpro122_alffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint227.exstrsupleft
rsfMRI_fcnxpro122_perafPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint227.exstrsupleft
rsfMRI_fcnxpro122_falffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint228.exstrsupleft
rsfMRI_fcnxpro122_alffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint228.exstrsupleft
rsfMRI_fcnxpro122_perafPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint228.exstrsupleft
rsfMRI_fcnxpro122_falffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint229.exstrsupleft
rsfMRI_fcnxpro122_alffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint229.exstrsupleft
rsfMRI_fcnxpro122_perafPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint229.exstrsupleft
rsfMRI_fcnxpro122_falffPoint230_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint230.striateleft
rsfMRI_fcnxpro122_alffPoint230_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint230.striateleft
rsfMRI_fcnxpro122_perafPoint230_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint230.striateleft
rsfMRI_fcnxpro122_falffPoint231_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint231.striateleft
rsfMRI_fcnxpro122_alffPoint231_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint231.striateleft
rsfMRI_fcnxpro122_perafPoint231_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint231.striateleft
rsfMRI_fcnxpro122_falffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint232.exstrinfleft
rsfMRI_fcnxpro122_alffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint232.exstrinfleft
rsfMRI_fcnxpro122_perafPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint232.exstrinfleft
rsfMRI_fcnxpro122_falffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint233.exstrleft
rsfMRI_fcnxpro122_alffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint233.exstrleft
rsfMRI_fcnxpro122_perafPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint233.exstrleft
rsfMRI_fcnxpro122_falffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint234.exstrleft
rsfMRI_fcnxpro122_alffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint234.exstrleft
rsfMRI_fcnxpro122_perafPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint234.exstrleft
rsfMRI_fcnxpro122_falffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint235.exstrleft
rsfMRI_fcnxpro122_alffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint235.exstrleft
rsfMRI_fcnxpro122_perafPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint235.exstrleft
rsfMRI_fcnxpro122_falffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint236.exstrleft
rsfMRI_fcnxpro122_alffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint236.exstrleft
rsfMRI_fcnxpro122_perafPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint236.exstrleft
rsfMRI_fcnxpro122_falffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint237.exstrleft
rsfMRI_fcnxpro122_alffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint237.exstrleft
rsfMRI_fcnxpro122_perafPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint237.exstrleft
rsfMRI_fcnxpro122_falffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint238.exstrleft
rsfMRI_fcnxpro122_alffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint238.exstrleft
rsfMRI_fcnxpro122_perafPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint238.exstrleft
rsfMRI_fcnxpro122_falffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint239.exstrleft
rsfMRI_fcnxpro122_alffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint239.exstrleft
rsfMRI_fcnxpro122_perafPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint239.exstrleft
rsfMRI_fcnxpro122_falffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint240.exstrleft
rsfMRI_fcnxpro122_alffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint240.exstrleft
rsfMRI_fcnxpro122_perafPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint240.exstrleft
rsfMRI_fcnxpro122_falffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint241.exstrleft
rsfMRI_fcnxpro122_alffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint241.exstrleft
rsfMRI_fcnxpro122_perafPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint241.exstrleft
rsfMRI_fcnxpro122_falffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint242.exstrleft
rsfMRI_fcnxpro122_alffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint242.exstrleft
rsfMRI_fcnxpro122_perafPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint242.exstrleft
rsfMRI_fcnxpro122_falffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint243.exstrleft
rsfMRI_fcnxpro122_alffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint243.exstrleft
rsfMRI_fcnxpro122_perafPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint243.exstrleft
rsfMRI_fcnxpro122_falffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint244.exstrleft
rsfMRI_fcnxpro122_alffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint244.exstrleft
rsfMRI_fcnxpro122_perafPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint244.exstrleft
rsfMRI_fcnxpro122_falffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint245.exstrleft
rsfMRI_fcnxpro122_alffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint245.exstrleft
rsfMRI_fcnxpro122_perafPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint245.exstrleft
rsfMRI_fcnxpro122_falffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint246.exstrleft
rsfMRI_fcnxpro122_alffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint246.exstrleft
rsfMRI_fcnxpro122_perafPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint246.exstrleft
rsfMRI_fcnxpro122_falffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint247.exstrleft
rsfMRI_fcnxpro122_alffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint247.exstrleft
rsfMRI_fcnxpro122_perafPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint247.exstrleft
rsfMRI_fcnxpro122_falffPoint248_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint248.striateleft
rsfMRI_fcnxpro122_alffPoint248_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint248.striateleft
rsfMRI_fcnxpro122_perafPoint248_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint248.striateleft
rsfMRI_fcnxpro122_falffPoint249_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint249.striateleft
rsfMRI_fcnxpro122_alffPoint249_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint249.striateleft
rsfMRI_fcnxpro122_perafPoint249_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint249.striateleft
rsfMRI_fcnxpro122_falffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint250.iplright
rsfMRI_fcnxpro122_alffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint250.iplright
rsfMRI_fcnxpro122_perafPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint250.iplright
rsfMRI_fcnxpro122_falffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint251.stright
rsfMRI_fcnxpro122_alffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint251.stright
rsfMRI_fcnxpro122_perafPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint251.stright
rsfMRI_fcnxpro122_falffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint252.stright
rsfMRI_fcnxpro122_alffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint252.stright
rsfMRI_fcnxpro122_perafPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint252.stright
rsfMRI_fcnxpro122_falffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint253.tempoccright
rsfMRI_fcnxpro122_alffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint253.tempoccright
rsfMRI_fcnxpro122_perafPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint253.tempoccright
rsfMRI_fcnxpro122_falffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint254.tempright
rsfMRI_fcnxpro122_alffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint254.tempright
rsfMRI_fcnxpro122_perafPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint254.tempright
rsfMRI_fcnxpro122_falffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint255.tempright
rsfMRI_fcnxpro122_alffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint255.tempright
rsfMRI_fcnxpro122_perafPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint255.tempright
rsfMRI_fcnxpro122_falffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint256.exstrinfright
rsfMRI_fcnxpro122_alffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint256.exstrinfright
rsfMRI_fcnxpro122_perafPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint256.exstrinfright
rsfMRI_fcnxpro122_falffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint257.iplright
rsfMRI_fcnxpro122_alffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint257.iplright
rsfMRI_fcnxpro122_perafPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint257.iplright
rsfMRI_fcnxpro122_falffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint258.phcright
rsfMRI_fcnxpro122_alffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint258.phcright
rsfMRI_fcnxpro122_perafPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint258.phcright
rsfMRI_fcnxpro122_falffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint259.phcright
rsfMRI_fcnxpro122_alffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint259.phcright
rsfMRI_fcnxpro122_perafPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint259.phcright
rsfMRI_fcnxpro122_falffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint260.phcright
rsfMRI_fcnxpro122_alffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint260.phcright
rsfMRI_fcnxpro122_perafPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint260.phcright
rsfMRI_fcnxpro122_falffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint261.rscright
rsfMRI_fcnxpro122_alffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint261.rscright
rsfMRI_fcnxpro122_perafPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint261.rscright
rsfMRI_fcnxpro122_falffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint262.rscright
rsfMRI_fcnxpro122_alffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint262.rscright
rsfMRI_fcnxpro122_perafPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint262.rscright
rsfMRI_fcnxpro122_falffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint263.iplright
rsfMRI_fcnxpro122_alffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint263.iplright
rsfMRI_fcnxpro122_perafPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint263.iplright
rsfMRI_fcnxpro122_falffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint264.iplright
rsfMRI_fcnxpro122_alffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint264.iplright
rsfMRI_fcnxpro122_perafPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint264.iplright
rsfMRI_fcnxpro122_falffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint265.iplright
rsfMRI_fcnxpro122_alffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint265.iplright
rsfMRI_fcnxpro122_perafPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint265.iplright
rsfMRI_fcnxpro122_falffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint266.iplright
rsfMRI_fcnxpro122_alffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint266.iplright
rsfMRI_fcnxpro122_perafPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint266.iplright
rsfMRI_fcnxpro122_falffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint000.pfcdright
rsfMRI_fcnxpro122_alffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint000.pfcdright
rsfMRI_fcnxpro122_perafPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint000.pfcdright
rsfMRI_fcnxpro122_falffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint001.pfcdright
rsfMRI_fcnxpro122_alffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint001.pfcdright
rsfMRI_fcnxpro122_perafPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint001.pfcdright
rsfMRI_fcnxpro122_falffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint002.pfcdright
rsfMRI_fcnxpro122_alffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint002.pfcdright
rsfMRI_fcnxpro122_perafPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint002.pfcdright
rsfMRI_fcnxpro122_falffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint003.pfcdright
rsfMRI_fcnxpro122_alffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint003.pfcdright
rsfMRI_fcnxpro122_perafPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint003.pfcdright
rsfMRI_fcnxpro122_falffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint004.pfcdright
rsfMRI_fcnxpro122_alffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint004.pfcdright
rsfMRI_fcnxpro122_perafPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint004.pfcdright
rsfMRI_fcnxpro122_falffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint005.pfcdright
rsfMRI_fcnxpro122_alffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint005.pfcdright
rsfMRI_fcnxpro122_perafPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint005.pfcdright
rsfMRI_fcnxpro122_falffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint006.pfcdright
rsfMRI_fcnxpro122_alffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint006.pfcdright
rsfMRI_fcnxpro122_perafPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint006.pfcdright
rsfMRI_fcnxpro122_falffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint007.pfclright
rsfMRI_fcnxpro122_alffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint007.pfclright
rsfMRI_fcnxpro122_perafPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint007.pfclright
rsfMRI_fcnxpro122_falffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint008.pfclright
rsfMRI_fcnxpro122_alffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint008.pfclright
rsfMRI_fcnxpro122_perafPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint008.pfclright
rsfMRI_fcnxpro122_falffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint009.pfcvright
rsfMRI_fcnxpro122_alffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint009.pfcvright
rsfMRI_fcnxpro122_perafPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint009.pfcvright
rsfMRI_fcnxpro122_falffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint010.pfcvright
rsfMRI_fcnxpro122_alffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint010.pfcvright
rsfMRI_fcnxpro122_perafPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint010.pfcvright
rsfMRI_fcnxpro122_falffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint011.pfcvright
rsfMRI_fcnxpro122_alffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint011.pfcvright
rsfMRI_fcnxpro122_perafPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint011.pfcvright
rsfMRI_fcnxpro122_falffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint012.pfcvright
rsfMRI_fcnxpro122_alffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint012.pfcvright
rsfMRI_fcnxpro122_perafPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint012.pfcvright
rsfMRI_fcnxpro122_falffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint013.temppoleright
rsfMRI_fcnxpro122_alffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint013.temppoleright
rsfMRI_fcnxpro122_perafPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint013.temppoleright
rsfMRI_fcnxpro122_falffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint014.tempright
rsfMRI_fcnxpro122_alffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint014.tempright
rsfMRI_fcnxpro122_perafPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint014.tempright
rsfMRI_fcnxpro122_falffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint015.tempright
rsfMRI_fcnxpro122_alffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint015.tempright
rsfMRI_fcnxpro122_perafPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint015.tempright
rsfMRI_fcnxpro122_falffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint016.tempright
rsfMRI_fcnxpro122_alffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint016.tempright
rsfMRI_fcnxpro122_perafPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint016.tempright
rsfMRI_fcnxpro122_falffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint017.tempright
rsfMRI_fcnxpro122_alffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint017.tempright
rsfMRI_fcnxpro122_perafPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint017.tempright
rsfMRI_fcnxpro122_falffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint018.tempright
rsfMRI_fcnxpro122_alffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint018.tempright
rsfMRI_fcnxpro122_perafPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint018.tempright
rsfMRI_fcnxpro122_falffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint019.tempright
rsfMRI_fcnxpro122_alffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint019.tempright
rsfMRI_fcnxpro122_perafPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint019.tempright
rsfMRI_fcnxpro122_falffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint020.tempright
rsfMRI_fcnxpro122_alffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint020.tempright
rsfMRI_fcnxpro122_perafPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint020.tempright
rsfMRI_fcnxpro122_falffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint021.tempright
rsfMRI_fcnxpro122_alffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint021.tempright
rsfMRI_fcnxpro122_perafPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint021.tempright
rsfMRI_fcnxpro122_falffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint022.tempright
rsfMRI_fcnxpro122_alffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint022.tempright
rsfMRI_fcnxpro122_perafPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint022.tempright
rsfMRI_fcnxpro122_falffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint023.tempright
rsfMRI_fcnxpro122_alffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint023.tempright
rsfMRI_fcnxpro122_perafPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint023.tempright
rsfMRI_fcnxpro122_falffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint024.fpoleright
rsfMRI_fcnxpro122_alffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint024.fpoleright
rsfMRI_fcnxpro122_perafPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint024.fpoleright
rsfMRI_fcnxpro122_falffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint025.iplright
rsfMRI_fcnxpro122_alffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint025.iplright
rsfMRI_fcnxpro122_perafPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint025.iplright
rsfMRI_fcnxpro122_falffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint026.iplright
rsfMRI_fcnxpro122_alffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint026.iplright
rsfMRI_fcnxpro122_perafPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint026.iplright
rsfMRI_fcnxpro122_falffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint027.iplright
rsfMRI_fcnxpro122_alffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint027.iplright
rsfMRI_fcnxpro122_perafPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint027.iplright
rsfMRI_fcnxpro122_falffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint028.pccright
rsfMRI_fcnxpro122_alffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint028.pccright
rsfMRI_fcnxpro122_perafPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint028.pccright
rsfMRI_fcnxpro122_falffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint029.pccright
rsfMRI_fcnxpro122_alffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint029.pccright
rsfMRI_fcnxpro122_perafPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint029.pccright
rsfMRI_fcnxpro122_falffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint030.pccright
rsfMRI_fcnxpro122_alffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint030.pccright
rsfMRI_fcnxpro122_perafPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint030.pccright
rsfMRI_fcnxpro122_falffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint031.pccright
rsfMRI_fcnxpro122_alffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint031.pccright
rsfMRI_fcnxpro122_perafPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint031.pccright
rsfMRI_fcnxpro122_falffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint032.pccright
rsfMRI_fcnxpro122_alffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint032.pccright
rsfMRI_fcnxpro122_perafPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint032.pccright
rsfMRI_fcnxpro122_falffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint033.pccright
rsfMRI_fcnxpro122_alffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint033.pccright
rsfMRI_fcnxpro122_perafPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint033.pccright
rsfMRI_fcnxpro122_falffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint034.pccright
rsfMRI_fcnxpro122_alffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint034.pccright
rsfMRI_fcnxpro122_perafPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint034.pccright
rsfMRI_fcnxpro122_falffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint035.pfcdright
rsfMRI_fcnxpro122_alffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint035.pfcdright
rsfMRI_fcnxpro122_perafPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint035.pfcdright
rsfMRI_fcnxpro122_falffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint036.pfcdright
rsfMRI_fcnxpro122_alffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint036.pfcdright
rsfMRI_fcnxpro122_perafPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint036.pfcdright
rsfMRI_fcnxpro122_falffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint037.pfcdright
rsfMRI_fcnxpro122_alffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint037.pfcdright
rsfMRI_fcnxpro122_perafPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint037.pfcdright
rsfMRI_fcnxpro122_falffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint038.pfcdright
rsfMRI_fcnxpro122_alffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint038.pfcdright
rsfMRI_fcnxpro122_perafPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint038.pfcdright
rsfMRI_fcnxpro122_falffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint039.pfcmright
rsfMRI_fcnxpro122_alffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint039.pfcmright
rsfMRI_fcnxpro122_perafPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint039.pfcmright
rsfMRI_fcnxpro122_falffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint040.pfcmright
rsfMRI_fcnxpro122_alffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint040.pfcmright
rsfMRI_fcnxpro122_perafPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint040.pfcmright
rsfMRI_fcnxpro122_falffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint041.pfcmright
rsfMRI_fcnxpro122_alffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint041.pfcmright
rsfMRI_fcnxpro122_perafPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint041.pfcmright
rsfMRI_fcnxpro122_falffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint042.pfcmright
rsfMRI_fcnxpro122_alffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint042.pfcmright
rsfMRI_fcnxpro122_perafPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint042.pfcmright
rsfMRI_fcnxpro122_falffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint043.pfcmright
rsfMRI_fcnxpro122_alffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint043.pfcmright
rsfMRI_fcnxpro122_perafPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint043.pfcmright
rsfMRI_fcnxpro122_falffPoint044_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint044.pcunright
rsfMRI_fcnxpro122_alffPoint044_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint044.pcunright
rsfMRI_fcnxpro122_perafPoint044_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint044.pcunright
rsfMRI_fcnxpro122_falffPoint045_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint045.pcunright
rsfMRI_fcnxpro122_alffPoint045_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint045.pcunright
rsfMRI_fcnxpro122_perafPoint045_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint045.pcunright
rsfMRI_fcnxpro122_falffPoint046_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint046.pcunright
rsfMRI_fcnxpro122_alffPoint046_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint046.pcunright
rsfMRI_fcnxpro122_perafPoint046_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint046.pcunright
rsfMRI_fcnxpro122_falffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint047.pccright
rsfMRI_fcnxpro122_alffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint047.pccright
rsfMRI_fcnxpro122_perafPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint047.pccright
rsfMRI_fcnxpro122_falffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint048.splright
rsfMRI_fcnxpro122_alffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint048.splright
rsfMRI_fcnxpro122_perafPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint048.splright
rsfMRI_fcnxpro122_falffPoint049_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint049.pcunright
rsfMRI_fcnxpro122_alffPoint049_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint049.pcunright
rsfMRI_fcnxpro122_perafPoint049_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint049.pcunright
rsfMRI_fcnxpro122_falffPoint050_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint050.pcunright
rsfMRI_fcnxpro122_alffPoint050_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint050.pcunright
rsfMRI_fcnxpro122_perafPoint050_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint050.pcunright
rsfMRI_fcnxpro122_falffPoint051_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint051.pcunright
rsfMRI_fcnxpro122_alffPoint051_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint051.pcunright
rsfMRI_fcnxpro122_perafPoint051_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint051.pcunright
rsfMRI_fcnxpro122_falffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint052.fpoleright
rsfMRI_fcnxpro122_alffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint052.fpoleright
rsfMRI_fcnxpro122_perafPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint052.fpoleright
rsfMRI_fcnxpro122_falffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint053.fpoleright
rsfMRI_fcnxpro122_alffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint053.fpoleright
rsfMRI_fcnxpro122_perafPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint053.fpoleright
rsfMRI_fcnxpro122_falffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint054.frmedright
rsfMRI_fcnxpro122_alffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint054.frmedright
rsfMRI_fcnxpro122_perafPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint054.frmedright
rsfMRI_fcnxpro122_falffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint055.iplright
rsfMRI_fcnxpro122_alffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint055.iplright
rsfMRI_fcnxpro122_perafPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint055.iplright
rsfMRI_fcnxpro122_falffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint056.ipsright
rsfMRI_fcnxpro122_alffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint056.ipsright
rsfMRI_fcnxpro122_perafPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint056.ipsright
rsfMRI_fcnxpro122_falffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint057.ipsright
rsfMRI_fcnxpro122_alffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint057.ipsright
rsfMRI_fcnxpro122_perafPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint057.ipsright
rsfMRI_fcnxpro122_falffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint058.pfcdright
rsfMRI_fcnxpro122_alffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint058.pfcdright
rsfMRI_fcnxpro122_perafPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint058.pfcdright
rsfMRI_fcnxpro122_falffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint059.pfclright
rsfMRI_fcnxpro122_alffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint059.pfclright
rsfMRI_fcnxpro122_perafPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint059.pfclright
rsfMRI_fcnxpro122_falffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint060.pfcvright
rsfMRI_fcnxpro122_alffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint060.pfcvright
rsfMRI_fcnxpro122_perafPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint060.pfcvright
rsfMRI_fcnxpro122_falffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint061.tempright
rsfMRI_fcnxpro122_alffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint061.tempright
rsfMRI_fcnxpro122_perafPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint061.tempright
rsfMRI_fcnxpro122_falffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint062.tempright
rsfMRI_fcnxpro122_alffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint062.tempright
rsfMRI_fcnxpro122_perafPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint062.tempright
rsfMRI_fcnxpro122_falffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint063.cingmright
rsfMRI_fcnxpro122_alffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint063.cingmright
rsfMRI_fcnxpro122_perafPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint063.cingmright
rsfMRI_fcnxpro122_falffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint064.ipsright
rsfMRI_fcnxpro122_alffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint064.ipsright
rsfMRI_fcnxpro122_perafPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint064.ipsright
rsfMRI_fcnxpro122_falffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint065.ipsright
rsfMRI_fcnxpro122_alffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint065.ipsright
rsfMRI_fcnxpro122_perafPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint065.ipsright
rsfMRI_fcnxpro122_falffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint066.ipsright
rsfMRI_fcnxpro122_alffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint066.ipsright
rsfMRI_fcnxpro122_perafPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint066.ipsright
rsfMRI_fcnxpro122_falffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint067.ipsright
rsfMRI_fcnxpro122_alffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint067.ipsright
rsfMRI_fcnxpro122_perafPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint067.ipsright
rsfMRI_fcnxpro122_falffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint068.ipsright
rsfMRI_fcnxpro122_alffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint068.ipsright
rsfMRI_fcnxpro122_perafPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint068.ipsright
rsfMRI_fcnxpro122_falffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint069.pfcdright
rsfMRI_fcnxpro122_alffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint069.pfcdright
rsfMRI_fcnxpro122_perafPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint069.pfcdright
rsfMRI_fcnxpro122_falffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint070.pfclright
rsfMRI_fcnxpro122_alffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint070.pfclright
rsfMRI_fcnxpro122_perafPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint070.pfclright
rsfMRI_fcnxpro122_falffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint071.pfclright
rsfMRI_fcnxpro122_alffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint071.pfclright
rsfMRI_fcnxpro122_perafPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint071.pfclright
rsfMRI_fcnxpro122_falffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint072.pfclright
rsfMRI_fcnxpro122_alffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint072.pfclright
rsfMRI_fcnxpro122_perafPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint072.pfclright
rsfMRI_fcnxpro122_falffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint073.pfclright
rsfMRI_fcnxpro122_alffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint073.pfclright
rsfMRI_fcnxpro122_perafPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint073.pfclright
rsfMRI_fcnxpro122_falffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint074.pfclright
rsfMRI_fcnxpro122_alffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint074.pfclright
rsfMRI_fcnxpro122_perafPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint074.pfclright
rsfMRI_fcnxpro122_falffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint075.pfclright
rsfMRI_fcnxpro122_alffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint075.pfclright
rsfMRI_fcnxpro122_perafPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint075.pfclright
rsfMRI_fcnxpro122_falffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint076.prcvright
rsfMRI_fcnxpro122_alffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint076.prcvright
rsfMRI_fcnxpro122_perafPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint076.prcvright
rsfMRI_fcnxpro122_falffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint077.prcvright
rsfMRI_fcnxpro122_alffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint077.prcvright
rsfMRI_fcnxpro122_perafPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint077.prcvright
rsfMRI_fcnxpro122_falffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint078.prcvright
rsfMRI_fcnxpro122_alffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint078.prcvright
rsfMRI_fcnxpro122_perafPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint078.prcvright
rsfMRI_fcnxpro122_falffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint079.splright
rsfMRI_fcnxpro122_alffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint079.splright
rsfMRI_fcnxpro122_perafPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint079.splright
rsfMRI_fcnxpro122_falffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint080.tempoccright
rsfMRI_fcnxpro122_alffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint080.tempoccright
rsfMRI_fcnxpro122_perafPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint080.tempoccright
rsfMRI_fcnxpro122_falffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint081.insright
rsfMRI_fcnxpro122_alffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint081.insright
rsfMRI_fcnxpro122_perafPoint081_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint081.insright
rsfMRI_fcnxpro122_falffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint082.phcright
rsfMRI_fcnxpro122_alffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint082.phcright
rsfMRI_fcnxpro122_perafPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint082.phcright
rsfMRI_fcnxpro122_falffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint083.phcright
rsfMRI_fcnxpro122_alffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint083.phcright
rsfMRI_fcnxpro122_perafPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint083.phcright
rsfMRI_fcnxpro122_falffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint084.stright
rsfMRI_fcnxpro122_alffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint084.stright
rsfMRI_fcnxpro122_perafPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint084.stright
rsfMRI_fcnxpro122_falffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint085.temppoleright
rsfMRI_fcnxpro122_alffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint085.temppoleright
rsfMRI_fcnxpro122_perafPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint085.temppoleright
rsfMRI_fcnxpro122_falffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint086.temppoleright
rsfMRI_fcnxpro122_alffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint086.temppoleright
rsfMRI_fcnxpro122_perafPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint086.temppoleright
rsfMRI_fcnxpro122_falffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint087.temppoleright
rsfMRI_fcnxpro122_alffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint087.temppoleright
rsfMRI_fcnxpro122_perafPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint087.temppoleright
rsfMRI_fcnxpro122_falffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint088.temppoleright
rsfMRI_fcnxpro122_alffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint088.temppoleright
rsfMRI_fcnxpro122_perafPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint088.temppoleright
rsfMRI_fcnxpro122_falffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint089.temppoleright
rsfMRI_fcnxpro122_alffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint089.temppoleright
rsfMRI_fcnxpro122_perafPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint089.temppoleright
rsfMRI_fcnxpro122_falffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint090.tempright
rsfMRI_fcnxpro122_alffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint090.tempright
rsfMRI_fcnxpro122_perafPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint090.tempright
rsfMRI_fcnxpro122_falffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint091.tempright
rsfMRI_fcnxpro122_alffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint091.tempright
rsfMRI_fcnxpro122_perafPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint091.tempright
rsfMRI_fcnxpro122_falffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint092.tempright
rsfMRI_fcnxpro122_alffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint092.tempright
rsfMRI_fcnxpro122_perafPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint092.tempright
rsfMRI_fcnxpro122_falffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint093.tempright
rsfMRI_fcnxpro122_alffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint093.tempright
rsfMRI_fcnxpro122_perafPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint093.tempright
rsfMRI_fcnxpro122_falffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint094.fpoleright
rsfMRI_fcnxpro122_alffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint094.fpoleright
rsfMRI_fcnxpro122_perafPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint094.fpoleright
rsfMRI_fcnxpro122_falffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint095.ofcright
rsfMRI_fcnxpro122_alffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint095.ofcright
rsfMRI_fcnxpro122_perafPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint095.ofcright
rsfMRI_fcnxpro122_falffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint096.ofcright
rsfMRI_fcnxpro122_alffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint096.ofcright
rsfMRI_fcnxpro122_perafPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint096.ofcright
rsfMRI_fcnxpro122_falffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint097.ofcright
rsfMRI_fcnxpro122_alffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint097.ofcright
rsfMRI_fcnxpro122_perafPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint097.ofcright
rsfMRI_fcnxpro122_falffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint098.ofcright
rsfMRI_fcnxpro122_alffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint098.ofcright
rsfMRI_fcnxpro122_perafPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint098.ofcright
rsfMRI_fcnxpro122_falffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint099.ofcright
rsfMRI_fcnxpro122_alffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint099.ofcright
rsfMRI_fcnxpro122_perafPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint099.ofcright
rsfMRI_fcnxpro122_falffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint100.ofcright
rsfMRI_fcnxpro122_alffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint100.ofcright
rsfMRI_fcnxpro122_perafPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint100.ofcright
rsfMRI_fcnxpro122_falffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint101.pfcmright
rsfMRI_fcnxpro122_alffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint101.pfcmright
rsfMRI_fcnxpro122_perafPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint101.pfcmright
rsfMRI_fcnxpro122_falffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint102.pfcmright
rsfMRI_fcnxpro122_alffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint102.pfcmright
rsfMRI_fcnxpro122_perafPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint102.pfcmright
rsfMRI_fcnxpro122_falffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint103.frmedright
rsfMRI_fcnxpro122_alffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint103.frmedright
rsfMRI_fcnxpro122_perafPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint103.frmedright
rsfMRI_fcnxpro122_falffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint104.insright
rsfMRI_fcnxpro122_alffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint104.insright
rsfMRI_fcnxpro122_perafPoint104_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint104.insright
rsfMRI_fcnxpro122_falffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint105.insright
rsfMRI_fcnxpro122_alffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint105.insright
rsfMRI_fcnxpro122_perafPoint105_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint105.insright
rsfMRI_fcnxpro122_falffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint106.insright
rsfMRI_fcnxpro122_alffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint106.insright
rsfMRI_fcnxpro122_perafPoint106_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint106.insright
rsfMRI_fcnxpro122_falffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint107.pfclright
rsfMRI_fcnxpro122_alffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint107.pfclright
rsfMRI_fcnxpro122_perafPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint107.pfclright
rsfMRI_fcnxpro122_falffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint108.pfclright
rsfMRI_fcnxpro122_alffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint108.pfclright
rsfMRI_fcnxpro122_perafPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint108.pfclright
rsfMRI_fcnxpro122_falffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint109.pfcmright
rsfMRI_fcnxpro122_alffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint109.pfcmright
rsfMRI_fcnxpro122_perafPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint109.pfcmright
rsfMRI_fcnxpro122_falffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint110.frmedright
rsfMRI_fcnxpro122_alffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint110.frmedright
rsfMRI_fcnxpro122_perafPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint110.frmedright
rsfMRI_fcnxpro122_falffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint111.frmedright
rsfMRI_fcnxpro122_alffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint111.frmedright
rsfMRI_fcnxpro122_perafPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint111.frmedright
rsfMRI_fcnxpro122_falffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint112.frmedright
rsfMRI_fcnxpro122_alffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint112.frmedright
rsfMRI_fcnxpro122_perafPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint112.frmedright
rsfMRI_fcnxpro122_falffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint113.froperright
rsfMRI_fcnxpro122_alffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint113.froperright
rsfMRI_fcnxpro122_perafPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint113.froperright
rsfMRI_fcnxpro122_falffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint114.froperright
rsfMRI_fcnxpro122_alffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint114.froperright
rsfMRI_fcnxpro122_perafPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint114.froperright
rsfMRI_fcnxpro122_falffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint115.iplright
rsfMRI_fcnxpro122_alffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint115.iplright
rsfMRI_fcnxpro122_perafPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint115.iplright
rsfMRI_fcnxpro122_falffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint116.iplright
rsfMRI_fcnxpro122_alffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint116.iplright
rsfMRI_fcnxpro122_perafPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint116.iplright
rsfMRI_fcnxpro122_falffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint117.insright
rsfMRI_fcnxpro122_alffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint117.insright
rsfMRI_fcnxpro122_perafPoint117_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint117.insright
rsfMRI_fcnxpro122_falffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint118.insright
rsfMRI_fcnxpro122_alffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint118.insright
rsfMRI_fcnxpro122_perafPoint118_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint118.insright
rsfMRI_fcnxpro122_falffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint119.insright
rsfMRI_fcnxpro122_alffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint119.insright
rsfMRI_fcnxpro122_perafPoint119_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint119.insright
rsfMRI_fcnxpro122_falffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint120.insright
rsfMRI_fcnxpro122_alffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint120.insright
rsfMRI_fcnxpro122_perafPoint120_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint120.insright
rsfMRI_fcnxpro122_falffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint121.insright
rsfMRI_fcnxpro122_alffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint121.insright
rsfMRI_fcnxpro122_perafPoint121_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint121.insright
rsfMRI_fcnxpro122_falffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint122.splright
rsfMRI_fcnxpro122_alffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint122.splright
rsfMRI_fcnxpro122_perafPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint122.splright
rsfMRI_fcnxpro122_falffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint123.splright
rsfMRI_fcnxpro122_alffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint123.splright
rsfMRI_fcnxpro122_perafPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint123.splright
rsfMRI_fcnxpro122_falffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint124.splright
rsfMRI_fcnxpro122_alffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint124.splright
rsfMRI_fcnxpro122_perafPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint124.splright
rsfMRI_fcnxpro122_falffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint125.iplright
rsfMRI_fcnxpro122_alffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint125.iplright
rsfMRI_fcnxpro122_perafPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint125.iplright
rsfMRI_fcnxpro122_falffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint126.iplright
rsfMRI_fcnxpro122_alffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint126.iplright
rsfMRI_fcnxpro122_perafPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint126.iplright
rsfMRI_fcnxpro122_falffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint127.pfcdright
rsfMRI_fcnxpro122_alffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint127.pfcdright
rsfMRI_fcnxpro122_perafPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint127.pfcdright
rsfMRI_fcnxpro122_falffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint128.postcright
rsfMRI_fcnxpro122_alffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint128.postcright
rsfMRI_fcnxpro122_perafPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint128.postcright
rsfMRI_fcnxpro122_falffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint129.postcright
rsfMRI_fcnxpro122_alffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint129.postcright
rsfMRI_fcnxpro122_perafPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint129.postcright
rsfMRI_fcnxpro122_falffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint130.postcright
rsfMRI_fcnxpro122_alffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint130.postcright
rsfMRI_fcnxpro122_perafPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint130.postcright
rsfMRI_fcnxpro122_falffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint131.prcdright
rsfMRI_fcnxpro122_alffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint131.prcdright
rsfMRI_fcnxpro122_perafPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint131.prcdright
rsfMRI_fcnxpro122_falffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint132.prcdright
rsfMRI_fcnxpro122_alffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint132.prcdright
rsfMRI_fcnxpro122_perafPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint132.prcdright
rsfMRI_fcnxpro122_falffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint133.prcdright
rsfMRI_fcnxpro122_alffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint133.prcdright
rsfMRI_fcnxpro122_perafPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint133.prcdright
rsfMRI_fcnxpro122_falffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint134.splright
rsfMRI_fcnxpro122_alffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint134.splright
rsfMRI_fcnxpro122_perafPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint134.splright
rsfMRI_fcnxpro122_falffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint135.splright
rsfMRI_fcnxpro122_alffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint135.splright
rsfMRI_fcnxpro122_perafPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint135.splright
rsfMRI_fcnxpro122_falffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint136.splright
rsfMRI_fcnxpro122_alffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint136.splright
rsfMRI_fcnxpro122_perafPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint136.splright
rsfMRI_fcnxpro122_falffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint137.splright
rsfMRI_fcnxpro122_alffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint137.splright
rsfMRI_fcnxpro122_perafPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint137.splright
rsfMRI_fcnxpro122_falffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint138.tempoccright
rsfMRI_fcnxpro122_alffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint138.tempoccright
rsfMRI_fcnxpro122_perafPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint138.tempoccright
rsfMRI_fcnxpro122_falffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint139.exstrright
rsfMRI_fcnxpro122_alffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint139.exstrright
rsfMRI_fcnxpro122_perafPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint139.exstrright
rsfMRI_fcnxpro122_falffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint140.exstrright
rsfMRI_fcnxpro122_alffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint140.exstrright
rsfMRI_fcnxpro122_perafPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint140.exstrright
rsfMRI_fcnxpro122_falffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint141.exstrright
rsfMRI_fcnxpro122_alffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint141.exstrright
rsfMRI_fcnxpro122_perafPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint141.exstrright
rsfMRI_fcnxpro122_falffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint142.exstrright
rsfMRI_fcnxpro122_alffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint142.exstrright
rsfMRI_fcnxpro122_perafPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint142.exstrright
rsfMRI_fcnxpro122_falffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint143.ipsright
rsfMRI_fcnxpro122_alffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint143.ipsright
rsfMRI_fcnxpro122_perafPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint143.ipsright
rsfMRI_fcnxpro122_falffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint144.splright
rsfMRI_fcnxpro122_alffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint144.splright
rsfMRI_fcnxpro122_perafPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint144.splright
rsfMRI_fcnxpro122_falffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint145.splright
rsfMRI_fcnxpro122_alffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint145.splright
rsfMRI_fcnxpro122_perafPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint145.splright
rsfMRI_fcnxpro122_falffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint146.splright
rsfMRI_fcnxpro122_alffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint146.splright
rsfMRI_fcnxpro122_perafPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint146.splright
rsfMRI_fcnxpro122_falffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint147.splright
rsfMRI_fcnxpro122_alffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint147.splright
rsfMRI_fcnxpro122_perafPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint147.splright
rsfMRI_fcnxpro122_falffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint148.splright
rsfMRI_fcnxpro122_alffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint148.splright
rsfMRI_fcnxpro122_perafPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint148.splright
rsfMRI_fcnxpro122_falffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint149.splright
rsfMRI_fcnxpro122_alffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint149.splright
rsfMRI_fcnxpro122_perafPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint149.splright
rsfMRI_fcnxpro122_falffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint150.tempoccright
rsfMRI_fcnxpro122_alffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint150.tempoccright
rsfMRI_fcnxpro122_perafPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint150.tempoccright
rsfMRI_fcnxpro122_falffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint151.tempoccright
rsfMRI_fcnxpro122_alffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint151.tempoccright
rsfMRI_fcnxpro122_perafPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint151.tempoccright
rsfMRI_fcnxpro122_falffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint152.tempoccright
rsfMRI_fcnxpro122_alffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint152.tempoccright
rsfMRI_fcnxpro122_perafPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint152.tempoccright
rsfMRI_fcnxpro122_falffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint153.tempoccright
rsfMRI_fcnxpro122_alffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint153.tempoccright
rsfMRI_fcnxpro122_perafPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint153.tempoccright
rsfMRI_fcnxpro122_falffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint154.tempoccright
rsfMRI_fcnxpro122_alffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint154.tempoccright
rsfMRI_fcnxpro122_perafPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint154.tempoccright
rsfMRI_fcnxpro122_falffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint155.tempoccright
rsfMRI_fcnxpro122_alffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint155.tempoccright
rsfMRI_fcnxpro122_perafPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint155.tempoccright
rsfMRI_fcnxpro122_falffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint156.tempoccright
rsfMRI_fcnxpro122_alffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint156.tempoccright
rsfMRI_fcnxpro122_perafPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint156.tempoccright
rsfMRI_fcnxpro122_falffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint157.tempoccright
rsfMRI_fcnxpro122_alffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint157.tempoccright
rsfMRI_fcnxpro122_perafPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint157.tempoccright
rsfMRI_fcnxpro122_falffPoint158_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint158.1right
rsfMRI_fcnxpro122_alffPoint158_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint158.1right
rsfMRI_fcnxpro122_perafPoint158_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint158.1right
rsfMRI_fcnxpro122_falffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint159.2right
rsfMRI_fcnxpro122_alffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint159.2right
rsfMRI_fcnxpro122_perafPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint159.2right
rsfMRI_fcnxpro122_falffPoint160_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint160.3right
rsfMRI_fcnxpro122_alffPoint160_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint160.3right
rsfMRI_fcnxpro122_perafPoint160_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint160.3right
rsfMRI_fcnxpro122_falffPoint161_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint161.4right
rsfMRI_fcnxpro122_alffPoint161_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint161.4right
rsfMRI_fcnxpro122_perafPoint161_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint161.4right
rsfMRI_fcnxpro122_falffPoint162_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint162.5right
rsfMRI_fcnxpro122_alffPoint162_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint162.5right
rsfMRI_fcnxpro122_perafPoint162_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint162.5right
rsfMRI_fcnxpro122_falffPoint163_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint163.6right
rsfMRI_fcnxpro122_alffPoint163_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint163.6right
rsfMRI_fcnxpro122_perafPoint163_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint163.6right
rsfMRI_fcnxpro122_falffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint164.iplright
rsfMRI_fcnxpro122_alffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint164.iplright
rsfMRI_fcnxpro122_perafPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint164.iplright
rsfMRI_fcnxpro122_falffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint165.insright
rsfMRI_fcnxpro122_alffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint165.insright
rsfMRI_fcnxpro122_perafPoint165_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint165.insright
rsfMRI_fcnxpro122_falffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint166.insright
rsfMRI_fcnxpro122_alffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint166.insright
rsfMRI_fcnxpro122_perafPoint166_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint166.insright
rsfMRI_fcnxpro122_falffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint167.paroperright
rsfMRI_fcnxpro122_alffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint167.paroperright
rsfMRI_fcnxpro122_perafPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint167.paroperright
rsfMRI_fcnxpro122_falffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint168.paroperright
rsfMRI_fcnxpro122_alffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint168.paroperright
rsfMRI_fcnxpro122_perafPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint168.paroperright
rsfMRI_fcnxpro122_falffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint169.paroperright
rsfMRI_fcnxpro122_alffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint169.paroperright
rsfMRI_fcnxpro122_perafPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint169.paroperright
rsfMRI_fcnxpro122_falffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint170.stright
rsfMRI_fcnxpro122_alffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint170.stright
rsfMRI_fcnxpro122_perafPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint170.stright
rsfMRI_fcnxpro122_falffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint171.stright
rsfMRI_fcnxpro122_alffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint171.stright
rsfMRI_fcnxpro122_perafPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint171.stright
rsfMRI_fcnxpro122_falffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint172.stright
rsfMRI_fcnxpro122_alffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint172.stright
rsfMRI_fcnxpro122_perafPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint172.stright
rsfMRI_fcnxpro122_falffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint173.stright
rsfMRI_fcnxpro122_alffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint173.stright
rsfMRI_fcnxpro122_perafPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint173.stright
rsfMRI_fcnxpro122_falffPoint174_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint174.1right
rsfMRI_fcnxpro122_alffPoint174_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint174.1right
rsfMRI_fcnxpro122_perafPoint174_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint174.1right
rsfMRI_fcnxpro122_falffPoint175_10right
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint175.10right
rsfMRI_fcnxpro122_alffPoint175_10right
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint175.10right
rsfMRI_fcnxpro122_perafPoint175_10right
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint175.10right
rsfMRI_fcnxpro122_falffPoint176_11right
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint176.11right
rsfMRI_fcnxpro122_alffPoint176_11right
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint176.11right
rsfMRI_fcnxpro122_perafPoint176_11right
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint176.11right
rsfMRI_fcnxpro122_falffPoint177_12right
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint177.12right
rsfMRI_fcnxpro122_alffPoint177_12right
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint177.12right
rsfMRI_fcnxpro122_perafPoint177_12right
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint177.12right
rsfMRI_fcnxpro122_falffPoint178_13right
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint178.13right
rsfMRI_fcnxpro122_alffPoint178_13right
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint178.13right
rsfMRI_fcnxpro122_perafPoint178_13right
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint178.13right
rsfMRI_fcnxpro122_falffPoint179_14right
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint179.14right
rsfMRI_fcnxpro122_alffPoint179_14right
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint179.14right
rsfMRI_fcnxpro122_perafPoint179_14right
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint179.14right
rsfMRI_fcnxpro122_falffPoint180_15right
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint180.15right
rsfMRI_fcnxpro122_alffPoint180_15right
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint180.15right
rsfMRI_fcnxpro122_perafPoint180_15right
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint180.15right
rsfMRI_fcnxpro122_falffPoint181_16right
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint181.16right
rsfMRI_fcnxpro122_alffPoint181_16right
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint181.16right
rsfMRI_fcnxpro122_perafPoint181_16right
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint181.16right
rsfMRI_fcnxpro122_falffPoint182_17right
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint182.17right
rsfMRI_fcnxpro122_alffPoint182_17right
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint182.17right
rsfMRI_fcnxpro122_perafPoint182_17right
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint182.17right
rsfMRI_fcnxpro122_falffPoint183_18right
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint183.18right
rsfMRI_fcnxpro122_alffPoint183_18right
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint183.18right
rsfMRI_fcnxpro122_perafPoint183_18right
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint183.18right
rsfMRI_fcnxpro122_falffPoint184_19right
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint184.19right
rsfMRI_fcnxpro122_alffPoint184_19right
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint184.19right
rsfMRI_fcnxpro122_perafPoint184_19right
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint184.19right
rsfMRI_fcnxpro122_falffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint185.2right
rsfMRI_fcnxpro122_alffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint185.2right
rsfMRI_fcnxpro122_perafPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint185.2right
rsfMRI_fcnxpro122_falffPoint186_20right
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint186.20right
rsfMRI_fcnxpro122_alffPoint186_20right
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint186.20right
rsfMRI_fcnxpro122_perafPoint186_20right
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint186.20right
rsfMRI_fcnxpro122_falffPoint187_21right
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint187.21right
rsfMRI_fcnxpro122_alffPoint187_21right
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint187.21right
rsfMRI_fcnxpro122_perafPoint187_21right
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint187.21right
rsfMRI_fcnxpro122_falffPoint188_22right
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint188.22right
rsfMRI_fcnxpro122_alffPoint188_22right
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint188.22right
rsfMRI_fcnxpro122_perafPoint188_22right
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint188.22right
rsfMRI_fcnxpro122_falffPoint189_23right
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint189.23right
rsfMRI_fcnxpro122_alffPoint189_23right
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint189.23right
rsfMRI_fcnxpro122_perafPoint189_23right
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint189.23right
rsfMRI_fcnxpro122_falffPoint190_24right
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint190.24right
rsfMRI_fcnxpro122_alffPoint190_24right
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint190.24right
rsfMRI_fcnxpro122_perafPoint190_24right
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint190.24right
rsfMRI_fcnxpro122_falffPoint191_25right
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint191.25right
rsfMRI_fcnxpro122_alffPoint191_25right
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint191.25right
rsfMRI_fcnxpro122_perafPoint191_25right
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint191.25right
rsfMRI_fcnxpro122_falffPoint192_26right
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint192.26right
rsfMRI_fcnxpro122_alffPoint192_26right
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint192.26right
rsfMRI_fcnxpro122_perafPoint192_26right
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint192.26right
rsfMRI_fcnxpro122_falffPoint193_27right
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint193.27right
rsfMRI_fcnxpro122_alffPoint193_27right
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint193.27right
rsfMRI_fcnxpro122_perafPoint193_27right
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint193.27right
rsfMRI_fcnxpro122_falffPoint194_28right
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint194.28right
rsfMRI_fcnxpro122_alffPoint194_28right
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint194.28right
rsfMRI_fcnxpro122_perafPoint194_28right
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint194.28right
rsfMRI_fcnxpro122_falffPoint195_29right
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint195.29right
rsfMRI_fcnxpro122_alffPoint195_29right
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint195.29right
rsfMRI_fcnxpro122_perafPoint195_29right
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint195.29right
rsfMRI_fcnxpro122_falffPoint196_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint196.3right
rsfMRI_fcnxpro122_alffPoint196_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint196.3right
rsfMRI_fcnxpro122_perafPoint196_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint196.3right
rsfMRI_fcnxpro122_falffPoint197_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint197.4right
rsfMRI_fcnxpro122_alffPoint197_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint197.4right
rsfMRI_fcnxpro122_perafPoint197_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint197.4right
rsfMRI_fcnxpro122_falffPoint198_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint198.5right
rsfMRI_fcnxpro122_alffPoint198_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint198.5right
rsfMRI_fcnxpro122_perafPoint198_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint198.5right
rsfMRI_fcnxpro122_falffPoint199_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint199.6right
rsfMRI_fcnxpro122_alffPoint199_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint199.6right
rsfMRI_fcnxpro122_perafPoint199_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint199.6right
rsfMRI_fcnxpro122_falffPoint200_7right
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint200.7right
rsfMRI_fcnxpro122_alffPoint200_7right
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint200.7right
rsfMRI_fcnxpro122_perafPoint200_7right
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint200.7right
rsfMRI_fcnxpro122_falffPoint201_8right
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint201.8right
rsfMRI_fcnxpro122_alffPoint201_8right
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint201.8right
rsfMRI_fcnxpro122_perafPoint201_8right
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint201.8right
rsfMRI_fcnxpro122_falffPoint202_9right
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint202.9right
rsfMRI_fcnxpro122_alffPoint202_9right
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint202.9right
rsfMRI_fcnxpro122_perafPoint202_9right
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint202.9right
rsfMRI_fcnxpro122_falffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint203.splright
rsfMRI_fcnxpro122_alffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint203.splright
rsfMRI_fcnxpro122_perafPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint203.splright
rsfMRI_fcnxpro122_falffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint204.exstrright
rsfMRI_fcnxpro122_alffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint204.exstrright
rsfMRI_fcnxpro122_perafPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint204.exstrright
rsfMRI_fcnxpro122_falffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint205.exstrinfright
rsfMRI_fcnxpro122_alffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint205.exstrinfright
rsfMRI_fcnxpro122_perafPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint205.exstrinfright
rsfMRI_fcnxpro122_falffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint206.exstrinfright
rsfMRI_fcnxpro122_alffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint206.exstrinfright
rsfMRI_fcnxpro122_perafPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint206.exstrinfright
rsfMRI_fcnxpro122_falffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint207.exstrinfright
rsfMRI_fcnxpro122_alffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint207.exstrinfright
rsfMRI_fcnxpro122_perafPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint207.exstrinfright
rsfMRI_fcnxpro122_falffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint208.exstrinfright
rsfMRI_fcnxpro122_alffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint208.exstrinfright
rsfMRI_fcnxpro122_perafPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint208.exstrinfright
rsfMRI_fcnxpro122_falffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint209.exstrinfright
rsfMRI_fcnxpro122_alffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint209.exstrinfright
rsfMRI_fcnxpro122_perafPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint209.exstrinfright
rsfMRI_fcnxpro122_falffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint210.exstrsupright
rsfMRI_fcnxpro122_alffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint210.exstrsupright
rsfMRI_fcnxpro122_perafPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint210.exstrsupright
rsfMRI_fcnxpro122_falffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint211.exstrsupright
rsfMRI_fcnxpro122_alffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint211.exstrsupright
rsfMRI_fcnxpro122_perafPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint211.exstrsupright
rsfMRI_fcnxpro122_falffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint212.exstrsupright
rsfMRI_fcnxpro122_alffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint212.exstrsupright
rsfMRI_fcnxpro122_perafPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint212.exstrsupright
rsfMRI_fcnxpro122_falffPoint213_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint213.striateright
rsfMRI_fcnxpro122_alffPoint213_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint213.striateright
rsfMRI_fcnxpro122_perafPoint213_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint213.striateright
rsfMRI_fcnxpro122_falffPoint214_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint214.striateright
rsfMRI_fcnxpro122_alffPoint214_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint214.striateright
rsfMRI_fcnxpro122_perafPoint214_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint214.striateright
rsfMRI_fcnxpro122_falffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint215.exstrinfright
rsfMRI_fcnxpro122_alffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint215.exstrinfright
rsfMRI_fcnxpro122_perafPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint215.exstrinfright
rsfMRI_fcnxpro122_falffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint216.exstrright
rsfMRI_fcnxpro122_alffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint216.exstrright
rsfMRI_fcnxpro122_perafPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint216.exstrright
rsfMRI_fcnxpro122_falffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint217.exstrright
rsfMRI_fcnxpro122_alffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint217.exstrright
rsfMRI_fcnxpro122_perafPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint217.exstrright
rsfMRI_fcnxpro122_falffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint218.exstrright
rsfMRI_fcnxpro122_alffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint218.exstrright
rsfMRI_fcnxpro122_perafPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint218.exstrright
rsfMRI_fcnxpro122_falffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint219.exstrright
rsfMRI_fcnxpro122_alffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint219.exstrright
rsfMRI_fcnxpro122_perafPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint219.exstrright
rsfMRI_fcnxpro122_falffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint220.exstrright
rsfMRI_fcnxpro122_alffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint220.exstrright
rsfMRI_fcnxpro122_perafPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint220.exstrright
rsfMRI_fcnxpro122_falffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint221.exstrright
rsfMRI_fcnxpro122_alffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint221.exstrright
rsfMRI_fcnxpro122_perafPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint221.exstrright
rsfMRI_fcnxpro122_falffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint222.exstrright
rsfMRI_fcnxpro122_alffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint222.exstrright
rsfMRI_fcnxpro122_perafPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint222.exstrright
rsfMRI_fcnxpro122_falffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint223.exstrright
rsfMRI_fcnxpro122_alffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint223.exstrright
rsfMRI_fcnxpro122_perafPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint223.exstrright
rsfMRI_fcnxpro122_falffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint224.exstrright
rsfMRI_fcnxpro122_alffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint224.exstrright
rsfMRI_fcnxpro122_perafPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint224.exstrright
rsfMRI_fcnxpro122_falffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint225.exstrright
rsfMRI_fcnxpro122_alffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint225.exstrright
rsfMRI_fcnxpro122_perafPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint225.exstrright
rsfMRI_fcnxpro122_falffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint226.exstrright
rsfMRI_fcnxpro122_alffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint226.exstrright
rsfMRI_fcnxpro122_perafPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint226.exstrright
rsfMRI_fcnxpro122_falffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint227.exstrright
rsfMRI_fcnxpro122_alffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint227.exstrright
rsfMRI_fcnxpro122_perafPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint227.exstrright
rsfMRI_fcnxpro122_falffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint228.exstrright
rsfMRI_fcnxpro122_alffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint228.exstrright
rsfMRI_fcnxpro122_perafPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint228.exstrright
rsfMRI_fcnxpro122_falffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint229.exstrright
rsfMRI_fcnxpro122_alffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint229.exstrright
rsfMRI_fcnxpro122_perafPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint229.exstrright
rsfMRI_fcnxpro122_falffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint230.exstrright
rsfMRI_fcnxpro122_alffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint230.exstrright
rsfMRI_fcnxpro122_perafPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint230.exstrright
rsfMRI_fcnxpro122_falffPoint231_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint231.striateright
rsfMRI_fcnxpro122_alffPoint231_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint231.striateright
rsfMRI_fcnxpro122_perafPoint231_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint231.striateright
rsfMRI_fcnxpro122_falffPoint232_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint232.striateright
rsfMRI_fcnxpro122_alffPoint232_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint232.striateright
rsfMRI_fcnxpro122_perafPoint232_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint232.striateright
rsfMRI_fcnxpro122_falffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint233.bnstrpuleft
rsfMRI_fcnxpro122_alffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint233.bnstrpuleft
rsfMRI_fcnxpro122_perafPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint233.bnstrpuleft
rsfMRI_fcnxpro122_falffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint234.bnstrcaleft
rsfMRI_fcnxpro122_alffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint234.bnstrcaleft
rsfMRI_fcnxpro122_perafPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint234.bnstrcaleft
rsfMRI_fcnxpro122_falffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint235.bnstrnacleft
rsfMRI_fcnxpro122_alffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint235.bnstrnacleft
rsfMRI_fcnxpro122_perafPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint235.bnstrnacleft
rsfMRI_fcnxpro122_falffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint236.exaleft
rsfMRI_fcnxpro122_alffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint236.exaleft
rsfMRI_fcnxpro122_perafPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint236.exaleft
rsfMRI_fcnxpro122_falffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint237.bngpgpeleft
rsfMRI_fcnxpro122_alffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint237.bngpgpeleft
rsfMRI_fcnxpro122_perafPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint237.bngpgpeleft
rsfMRI_fcnxpro122_falffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint238.bngpgpileft
rsfMRI_fcnxpro122_alffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint238.bngpgpileft
rsfMRI_fcnxpro122_perafPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint238.bngpgpileft
rsfMRI_fcnxpro122_falffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_alffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_perafPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_falffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint240.mtgrnleft
rsfMRI_fcnxpro122_alffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint240.mtgrnleft
rsfMRI_fcnxpro122_perafPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint240.mtgrnleft
rsfMRI_fcnxpro122_falffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_alffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_perafPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_falffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_alffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_perafPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_falffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_alffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_perafPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_falffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint244.bngpvepleft
rsfMRI_fcnxpro122_alffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint244.bngpvepleft
rsfMRI_fcnxpro122_perafPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint244.bngpvepleft
rsfMRI_fcnxpro122_falffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint245.thmethhnleft
rsfMRI_fcnxpro122_alffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint245.thmethhnleft
rsfMRI_fcnxpro122_perafPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint245.thmethhnleft
rsfMRI_fcnxpro122_falffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint246.diehthleft
rsfMRI_fcnxpro122_alffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint246.diehthleft
rsfMRI_fcnxpro122_perafPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint246.diehthleft
rsfMRI_fcnxpro122_falffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint247.diehthmnleft
rsfMRI_fcnxpro122_alffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint247.diehthmnleft
rsfMRI_fcnxpro122_perafPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint247.diehthmnleft
rsfMRI_fcnxpro122_falffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint248.diesthleft
rsfMRI_fcnxpro122_alffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint248.diesthleft
rsfMRI_fcnxpro122_perafPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint248.diesthleft
rsfMRI_fcnxpro122_falffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint249.bnstrpuright
rsfMRI_fcnxpro122_alffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint249.bnstrpuright
rsfMRI_fcnxpro122_perafPoint249_BNSTRPuright
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint249.bnstrpuright
rsfMRI_fcnxpro122_falffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint250.bnstrcaright
rsfMRI_fcnxpro122_alffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint250.bnstrcaright
rsfMRI_fcnxpro122_perafPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint250.bnstrcaright
rsfMRI_fcnxpro122_falffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint251.bnstrnacright
rsfMRI_fcnxpro122_alffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint251.bnstrnacright
rsfMRI_fcnxpro122_perafPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint251.bnstrnacright
rsfMRI_fcnxpro122_falffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint252.exaright
rsfMRI_fcnxpro122_alffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint252.exaright
rsfMRI_fcnxpro122_perafPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint252.exaright
rsfMRI_fcnxpro122_falffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint253.bngpgperight
rsfMRI_fcnxpro122_alffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint253.bngpgperight
rsfMRI_fcnxpro122_perafPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint253.bngpgperight
rsfMRI_fcnxpro122_falffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint254.bngpgpiright
rsfMRI_fcnxpro122_alffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint254.bngpgpiright
rsfMRI_fcnxpro122_perafPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint254.bngpgpiright
rsfMRI_fcnxpro122_falffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint255.mtgsnsncright
rsfMRI_fcnxpro122_alffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint255.mtgsnsncright
rsfMRI_fcnxpro122_perafPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint255.mtgsnsncright
rsfMRI_fcnxpro122_falffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint256.mtgrnright
rsfMRI_fcnxpro122_alffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint256.mtgrnright
rsfMRI_fcnxpro122_perafPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint256.mtgrnright
rsfMRI_fcnxpro122_falffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_alffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_perafPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_falffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_alffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_perafPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_falffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_alffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_perafPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_falffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint260.bngpvepright
rsfMRI_fcnxpro122_alffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint260.bngpvepright
rsfMRI_fcnxpro122_perafPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint260.bngpvepright
rsfMRI_fcnxpro122_falffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint261.thmethhnright
rsfMRI_fcnxpro122_alffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint261.thmethhnright
rsfMRI_fcnxpro122_perafPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint261.thmethhnright
rsfMRI_fcnxpro122_falffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint262.diehthright
rsfMRI_fcnxpro122_alffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint262.diehthright
rsfMRI_fcnxpro122_perafPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint262.diehthright
rsfMRI_fcnxpro122_falffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint263.diehthmnright
rsfMRI_fcnxpro122_alffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint263.diehthmnright
rsfMRI_fcnxpro122_perafPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint263.diehthmnright
rsfMRI_fcnxpro122_falffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint264.diesthright
rsfMRI_fcnxpro122_alffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint264.diesthright
rsfMRI_fcnxpro122_perafPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint264.diesthright
rsfMRI_fcnxpro122_falffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.falffpoint265.referenceregionleft
rsfMRI_fcnxpro122_alffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
left
rsf.p1.alffpoint265.referenceregionleft
rsfMRI_fcnxpro122_perafPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
left
rsf.p1.perafpoint265.referenceregionleft
rsfMRI_fcnxpro122_falffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.falffpoint266.referenceregionright
rsfMRI_fcnxpro122_alffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
right
rsf.p1.alffpoint266.referenceregionright
rsfMRI_fcnxpro122_perafPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
right
rsf.p1.perafpoint266.referenceregionright
rsfMRI_fcnxpro122_DefaultMode_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultmode.mean
rsfMRI_fcnxpro122_Visual_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.visual.mean
rsfMRI_fcnxpro122_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.motion.corrected.mean
rsfMRI_fcnxpro122_PerAF_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.peraf.mean
rsfMRI_fcnxpro122_tsnr_mean
​
restingStatefMRI
mean TSNR in time series
power peterson fMRI meta-analyses
122
​
rsf.p1.tsnr.mean
rsfMRI_fcnxpro122_ssnr_mean
​
restingStatefMRI
mean spatial SNR in mean bold
power peterson fMRI meta-analyses
122
​
rsf.p1.ssnr.mean
rsfMRI_fcnxpro122_dvars_mean
​
restingStatefMRI
mean DVARS
power peterson fMRI meta-analyses
122
​
rsf.p1.dvars.mean
rsfMRI_fcnxpro122_bandpass_freq_0
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
122
​
rsf.p1.bandpass.freq.0
rsfMRI_fcnxpro122_bandpass_freq_1
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
122
​
rsf.p1.bandpass.freq.1
rsfMRI_fcnxpro122_censor
​
restingStatefMRI
ignore
power peterson fMRI meta-analyses
122
​
rsf.p1.censor
rsfMRI_fcnxpro122_spatial_smoothing
​
restingStatefMRI
spatial smoothing parameter
power peterson fMRI meta-analyses
122
​
rsf.p1.spatial.smoothing
rsfMRI_fcnxpro122_outlier_threshold
​
restingStatefMRI
outlier threshold parameter
power peterson fMRI meta-analyses
122
​
rsf.p1.outlier.threshold
rsfMRI_fcnxpro122_FD_threshold
​
restingStatefMRI
FD threshold paramter
power peterson fMRI meta-analyses
122
​
rsf.p1.fd.threshold
rsfMRI_fcnxpro122_high_motion_count
​
restingStatefMRI
high motion count
power peterson fMRI meta-analyses
122
​
rsf.p1.high.motion.count
rsfMRI_fcnxpro122_high_motion_pct
​
restingStatefMRI
percent high motion count
power peterson fMRI meta-analyses
122
​
rsf.p1.high.motion.pct
rsfMRI_fcnxpro122_despiking_count_summary
​
restingStatefMRI
changes made in despiking
power peterson fMRI meta-analyses
122
​
rsf.p1.despiking.count.summary
rsfMRI_fcnxpro122_FD_max
​
restingStatefMRI
max framewise displacement
power peterson fMRI meta-analyses
122
​
rsf.p1.fd.max
rsfMRI_fcnxpro122_FD_mean
​
restingStatefMRI
mean framewise displacement
power peterson fMRI meta-analyses
122
​
rsf.p1.fd.mean
rsfMRI_fcnxpro122_FD_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
122
​
rsf.p1.fd.sd
rsfMRI_fcnxpro122_bold_evr
​
restingStatefMRI
eigenvector ratio for mean bold
power peterson fMRI meta-analyses
122
​
rsf.p1.bold.evr
rsfMRI_fcnxpro122_n_outliers
​
restingStatefMRI
number of outlier volumes
power peterson fMRI meta-analyses
122
​
rsf.p1.n.outliers
rsfMRI_fcnxpro122_nc_wm
​
restingStatefMRI
number of white matter compcor components
power peterson fMRI meta-analyses
122
​
rsf.p1.nc.wm
rsfMRI_fcnxpro122_nc_csf
​
restingStatefMRI
number of csf compcor components
power peterson fMRI meta-analyses
122
​
rsf.p1.nc.csf
rsfMRI_fcnxpro122_minutes_original_data
​
restingStatefMRI
minutes of rs imaging
power peterson fMRI meta-analyses
122
​
rsf.p1.minutes.original.data
rsfMRI_fcnxpro122_minutes_censored_data
​
restingStatefMRI
minutes of rs imaging after censoring
power peterson fMRI meta-analyses
122
​
rsf.p1.minutes.censored.data
rsfMRI_fcnxpro122_TempPar_2_TempPar
Temporo-Parietal to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.temppar
rsfMRI_fcnxpro122_TempPar_2_DefaultC
Temporo-Parietal to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.defaultc
rsfMRI_fcnxpro122_TempPar_2_DefaultB
Temporo-Parietal to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.defaultb
rsfMRI_fcnxpro122_TempPar_2_DefaultA
Temporo-Parietal to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.defaulta
rsfMRI_fcnxpro122_TempPar_2_ContC
Temporo-Parietal to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.contc
rsfMRI_fcnxpro122_TempPar_2_ContB
Temporo-Parietal to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.contb
rsfMRI_fcnxpro122_TempPar_2_ContA
Temporo-Parietal to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.conta
rsfMRI_fcnxpro122_TempPar_2_LimbicA
Temporo-Parietal to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.limbica
rsfMRI_fcnxpro122_TempPar_2_LimbicB
Temporo-Parietal to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.limbicb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnB
Temporo-Parietal to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.salventattnb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnA
Temporo-Parietal to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.salventattna
rsfMRI_fcnxpro122_TempPar_2_DorsAttnB
Temporo-Parietal to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.dorsattnb
rsfMRI_fcnxpro122_TempPar_2_DorsAttnA
Temporo-Parietal to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.dorsattna
rsfMRI_fcnxpro122_TempPar_2_SomMotB
Temporo-Parietal to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.sommotb
rsfMRI_fcnxpro122_TempPar_2_SomMotA
Temporo-Parietal to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.sommota
rsfMRI_fcnxpro122_TempPar_2_VisPeri
Temporo-Parietal to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.visperi
rsfMRI_fcnxpro122_TempPar_2_VisCent
Temporo-Parietal to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.viscent
rsfMRI_fcnxpro122_TempPar_2_Striatum
Temporo-Parietal to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.striatum
rsfMRI_fcnxpro122_TempPar_2_Dopamine
Temporo-Parietal to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.dopamine
rsfMRI_fcnxpro122_TempPar_2_CITLimbic
Temporo-Parietal to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.citlimbic
rsfMRI_fcnxpro122_TempPar_2_BasalGanglia
Temporo-Parietal to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.basalganglia
rsfMRI_fcnxpro122_TempPar_2_MidBrain
Temporo-Parietal to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.temppar.2.midbrain
rsfMRI_fcnxpro122_DefaultC_2_TempPar
Default Mode Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.temppar
rsfMRI_fcnxpro122_DefaultC_2_DefaultC
Default Mode Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.defaultc
rsfMRI_fcnxpro122_DefaultC_2_DefaultB
Default Mode Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.defaultb
rsfMRI_fcnxpro122_DefaultC_2_DefaultA
Default Mode Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.defaulta
rsfMRI_fcnxpro122_DefaultC_2_ContC
Default Mode Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.contc
rsfMRI_fcnxpro122_DefaultC_2_ContB
Default Mode Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.contb
rsfMRI_fcnxpro122_DefaultC_2_ContA
Default Mode Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.conta
rsfMRI_fcnxpro122_DefaultC_2_LimbicA
Default Mode Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.limbica
rsfMRI_fcnxpro122_DefaultC_2_LimbicB
Default Mode Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.limbicb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnB
Default Mode Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.salventattnb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnA
Default Mode Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.salventattna
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnB
Default Mode Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.dorsattnb
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnA
Default Mode Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.dorsattna
rsfMRI_fcnxpro122_DefaultC_2_SomMotB
Default Mode Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.sommotb
rsfMRI_fcnxpro122_DefaultC_2_SomMotA
Default Mode Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.sommota
rsfMRI_fcnxpro122_DefaultC_2_VisPeri
Default Mode Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.visperi
rsfMRI_fcnxpro122_DefaultC_2_VisCent
Default Mode Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.viscent
rsfMRI_fcnxpro122_DefaultC_2_Striatum
Default Mode Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.striatum
rsfMRI_fcnxpro122_DefaultC_2_Dopamine
Default Mode Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.dopamine
rsfMRI_fcnxpro122_DefaultC_2_CITLimbic
Default Mode Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.citlimbic
rsfMRI_fcnxpro122_DefaultC_2_BasalGanglia
Default Mode Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.basalganglia
rsfMRI_fcnxpro122_DefaultC_2_MidBrain
Default Mode Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultc.2.midbrain
rsfMRI_fcnxpro122_DefaultB_2_TempPar
Default Mode Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.temppar
rsfMRI_fcnxpro122_DefaultB_2_DefaultC
Default Mode Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.defaultc
rsfMRI_fcnxpro122_DefaultB_2_DefaultB
Default Mode Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.defaultb
rsfMRI_fcnxpro122_DefaultB_2_DefaultA
Default Mode Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.defaulta
rsfMRI_fcnxpro122_DefaultB_2_ContC
Default Mode Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.contc
rsfMRI_fcnxpro122_DefaultB_2_ContB
Default Mode Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.contb
rsfMRI_fcnxpro122_DefaultB_2_ContA
Default Mode Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.conta
rsfMRI_fcnxpro122_DefaultB_2_LimbicA
Default Mode Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.limbica
rsfMRI_fcnxpro122_DefaultB_2_LimbicB
Default Mode Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.limbicb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnB
Default Mode Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.salventattnb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnA
Default Mode Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.salventattna
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnB
Default Mode Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.dorsattnb
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnA
Default Mode Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.dorsattna
rsfMRI_fcnxpro122_DefaultB_2_SomMotB
Default Mode Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.sommotb
rsfMRI_fcnxpro122_DefaultB_2_SomMotA
Default Mode Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.sommota
rsfMRI_fcnxpro122_DefaultB_2_VisPeri
Default Mode Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.visperi
rsfMRI_fcnxpro122_DefaultB_2_VisCent
Default Mode Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.viscent
rsfMRI_fcnxpro122_DefaultB_2_Striatum
Default Mode Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.striatum
rsfMRI_fcnxpro122_DefaultB_2_Dopamine
Default Mode Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.dopamine
rsfMRI_fcnxpro122_DefaultB_2_CITLimbic
Default Mode Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.citlimbic
rsfMRI_fcnxpro122_DefaultB_2_BasalGanglia
Default Mode Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.basalganglia
rsfMRI_fcnxpro122_DefaultB_2_MidBrain
Default Mode Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaultb.2.midbrain
rsfMRI_fcnxpro122_DefaultA_2_TempPar
Default Mode Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.temppar
rsfMRI_fcnxpro122_DefaultA_2_DefaultC
Default Mode Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.defaultc
rsfMRI_fcnxpro122_DefaultA_2_DefaultB
Default Mode Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.defaultb
rsfMRI_fcnxpro122_DefaultA_2_DefaultA
Default Mode Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.defaulta
rsfMRI_fcnxpro122_DefaultA_2_ContC
Default Mode Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.contc
rsfMRI_fcnxpro122_DefaultA_2_ContB
Default Mode Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.contb
rsfMRI_fcnxpro122_DefaultA_2_ContA
Default Mode Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.conta
rsfMRI_fcnxpro122_DefaultA_2_LimbicA
Default Mode Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.limbica
rsfMRI_fcnxpro122_DefaultA_2_LimbicB
Default Mode Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.limbicb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnB
Default Mode Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.salventattnb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnA
Default Mode Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.salventattna
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnB
Default Mode Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.dorsattnb
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnA
Default Mode Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.dorsattna
rsfMRI_fcnxpro122_DefaultA_2_SomMotB
Default Mode Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.sommotb
rsfMRI_fcnxpro122_DefaultA_2_SomMotA
Default Mode Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.sommota
rsfMRI_fcnxpro122_DefaultA_2_VisPeri
Default Mode Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.visperi
rsfMRI_fcnxpro122_DefaultA_2_VisCent
Default Mode Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.viscent
rsfMRI_fcnxpro122_DefaultA_2_Striatum
Default Mode Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.striatum
rsfMRI_fcnxpro122_DefaultA_2_Dopamine
Default Mode Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.dopamine
rsfMRI_fcnxpro122_DefaultA_2_CITLimbic
Default Mode Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.citlimbic
rsfMRI_fcnxpro122_DefaultA_2_BasalGanglia
Default Mode Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.basalganglia
rsfMRI_fcnxpro122_DefaultA_2_MidBrain
Default Mode Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.defaulta.2.midbrain
rsfMRI_fcnxpro122_ContC_2_TempPar
Frontoparietal Control Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.temppar
rsfMRI_fcnxpro122_ContC_2_DefaultC
Frontoparietal Control Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.defaultc
rsfMRI_fcnxpro122_ContC_2_DefaultB
Frontoparietal Control Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.defaultb
rsfMRI_fcnxpro122_ContC_2_DefaultA
Frontoparietal Control Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.defaulta
rsfMRI_fcnxpro122_ContC_2_ContC
Frontoparietal Control Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.contc
rsfMRI_fcnxpro122_ContC_2_ContB
Frontoparietal Control Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.contb
rsfMRI_fcnxpro122_ContC_2_ContA
Frontoparietal Control Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.conta
rsfMRI_fcnxpro122_ContC_2_LimbicA
Frontoparietal Control Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.limbica
rsfMRI_fcnxpro122_ContC_2_LimbicB
Frontoparietal Control Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.limbicb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnB
Frontoparietal Control Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.salventattnb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnA
Frontoparietal Control Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.salventattna
rsfMRI_fcnxpro122_ContC_2_DorsAttnB
Frontoparietal Control Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.dorsattnb
rsfMRI_fcnxpro122_ContC_2_DorsAttnA
Frontoparietal Control Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.dorsattna
rsfMRI_fcnxpro122_ContC_2_SomMotB
Frontoparietal Control Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.sommotb
rsfMRI_fcnxpro122_ContC_2_SomMotA
Frontoparietal Control Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.sommota
rsfMRI_fcnxpro122_ContC_2_VisPeri
Frontoparietal Control Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.visperi
rsfMRI_fcnxpro122_ContC_2_VisCent
Frontoparietal Control Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.viscent
rsfMRI_fcnxpro122_ContC_2_Striatum
Frontoparietal Control Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.striatum
rsfMRI_fcnxpro122_ContC_2_Dopamine
Frontoparietal Control Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.dopamine
rsfMRI_fcnxpro122_ContC_2_CITLimbic
Frontoparietal Control Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.citlimbic
rsfMRI_fcnxpro122_ContC_2_BasalGanglia
Frontoparietal Control Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.basalganglia
rsfMRI_fcnxpro122_ContC_2_MidBrain
Frontoparietal Control Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contc.2.midbrain
rsfMRI_fcnxpro122_ContB_2_TempPar
Frontoparietal Control Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.temppar
rsfMRI_fcnxpro122_ContB_2_DefaultC
Frontoparietal Control Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.defaultc
rsfMRI_fcnxpro122_ContB_2_DefaultB
Frontoparietal Control Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.defaultb
rsfMRI_fcnxpro122_ContB_2_DefaultA
Frontoparietal Control Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.defaulta
rsfMRI_fcnxpro122_ContB_2_ContC
Frontoparietal Control Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.contc
rsfMRI_fcnxpro122_ContB_2_ContB
Frontoparietal Control Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.contb
rsfMRI_fcnxpro122_ContB_2_ContA
Frontoparietal Control Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.conta
rsfMRI_fcnxpro122_ContB_2_LimbicA
Frontoparietal Control Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.limbica
rsfMRI_fcnxpro122_ContB_2_LimbicB
Frontoparietal Control Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.limbicb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnB
Frontoparietal Control Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.salventattnb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnA
Frontoparietal Control Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.salventattna
rsfMRI_fcnxpro122_ContB_2_DorsAttnB
Frontoparietal Control Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.dorsattnb
rsfMRI_fcnxpro122_ContB_2_DorsAttnA
Frontoparietal Control Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.dorsattna
rsfMRI_fcnxpro122_ContB_2_SomMotB
Frontoparietal Control Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.sommotb
rsfMRI_fcnxpro122_ContB_2_SomMotA
Frontoparietal Control Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.sommota
rsfMRI_fcnxpro122_ContB_2_VisPeri
Frontoparietal Control Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.visperi
rsfMRI_fcnxpro122_ContB_2_VisCent
Frontoparietal Control Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.viscent
rsfMRI_fcnxpro122_ContB_2_Striatum
Frontoparietal Control Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.striatum
rsfMRI_fcnxpro122_ContB_2_Dopamine
Frontoparietal Control Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.dopamine
rsfMRI_fcnxpro122_ContB_2_CITLimbic
Frontoparietal Control Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.citlimbic
rsfMRI_fcnxpro122_ContB_2_BasalGanglia
Frontoparietal Control Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.basalganglia
rsfMRI_fcnxpro122_ContB_2_MidBrain
Frontoparietal Control Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.contb.2.midbrain
rsfMRI_fcnxpro122_ContA_2_TempPar
Frontoparietal Control Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.temppar
rsfMRI_fcnxpro122_ContA_2_DefaultC
Frontoparietal Control Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.defaultc
rsfMRI_fcnxpro122_ContA_2_DefaultB
Frontoparietal Control Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.defaultb
rsfMRI_fcnxpro122_ContA_2_DefaultA
Frontoparietal Control Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.defaulta
rsfMRI_fcnxpro122_ContA_2_ContC
Frontoparietal Control Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.contc
rsfMRI_fcnxpro122_ContA_2_ContB
Frontoparietal Control Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.contb
rsfMRI_fcnxpro122_ContA_2_ContA
Frontoparietal Control Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.conta
rsfMRI_fcnxpro122_ContA_2_LimbicA
Frontoparietal Control Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.limbica
rsfMRI_fcnxpro122_ContA_2_LimbicB
Frontoparietal Control Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.limbicb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnB
Frontoparietal Control Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.salventattnb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnA
Frontoparietal Control Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.salventattna
rsfMRI_fcnxpro122_ContA_2_DorsAttnB
Frontoparietal Control Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.dorsattnb
rsfMRI_fcnxpro122_ContA_2_DorsAttnA
Frontoparietal Control Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.dorsattna
rsfMRI_fcnxpro122_ContA_2_SomMotB
Frontoparietal Control Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.sommotb
rsfMRI_fcnxpro122_ContA_2_SomMotA
Frontoparietal Control Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.sommota
rsfMRI_fcnxpro122_ContA_2_VisPeri
Frontoparietal Control Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.visperi
rsfMRI_fcnxpro122_ContA_2_VisCent
Frontoparietal Control Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.viscent
rsfMRI_fcnxpro122_ContA_2_Striatum
Frontoparietal Control Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.striatum
rsfMRI_fcnxpro122_ContA_2_Dopamine
Frontoparietal Control Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.dopamine
rsfMRI_fcnxpro122_ContA_2_CITLimbic
Frontoparietal Control Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.citlimbic
rsfMRI_fcnxpro122_ContA_2_BasalGanglia
Frontoparietal Control Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.basalganglia
rsfMRI_fcnxpro122_ContA_2_MidBrain
Frontoparietal Control Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.conta.2.midbrain
rsfMRI_fcnxpro122_LimbicA_2_TempPar
Limbic Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.temppar
rsfMRI_fcnxpro122_LimbicA_2_DefaultC
Limbic Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.defaultc
rsfMRI_fcnxpro122_LimbicA_2_DefaultB
Limbic Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.defaultb
rsfMRI_fcnxpro122_LimbicA_2_DefaultA
Limbic Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.defaulta
rsfMRI_fcnxpro122_LimbicA_2_ContC
Limbic Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.contc
rsfMRI_fcnxpro122_LimbicA_2_ContB
Limbic Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.contb
rsfMRI_fcnxpro122_LimbicA_2_ContA
Limbic Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.conta
rsfMRI_fcnxpro122_LimbicA_2_LimbicA
Limbic Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.limbica
rsfMRI_fcnxpro122_LimbicA_2_LimbicB
Limbic Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.limbicb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnB
Limbic Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.salventattnb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnA
Limbic Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.salventattna
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnB
Limbic Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.dorsattnb
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnA
Limbic Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.dorsattna
rsfMRI_fcnxpro122_LimbicA_2_SomMotB
Limbic Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.sommotb
rsfMRI_fcnxpro122_LimbicA_2_SomMotA
Limbic Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.sommota
rsfMRI_fcnxpro122_LimbicA_2_VisPeri
Limbic Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.visperi
rsfMRI_fcnxpro122_LimbicA_2_VisCent
Limbic Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.viscent
rsfMRI_fcnxpro122_LimbicA_2_Striatum
Limbic Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.striatum
rsfMRI_fcnxpro122_LimbicA_2_Dopamine
Limbic Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.dopamine
rsfMRI_fcnxpro122_LimbicA_2_CITLimbic
Limbic Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.citlimbic
rsfMRI_fcnxpro122_LimbicA_2_BasalGanglia
Limbic Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.basalganglia
rsfMRI_fcnxpro122_LimbicA_2_MidBrain
Limbic Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbica.2.midbrain
rsfMRI_fcnxpro122_LimbicB_2_TempPar
Limbic Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.temppar
rsfMRI_fcnxpro122_LimbicB_2_DefaultC
Limbic Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.defaultc
rsfMRI_fcnxpro122_LimbicB_2_DefaultB
Limbic Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.defaultb
rsfMRI_fcnxpro122_LimbicB_2_DefaultA
Limbic Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.defaulta
rsfMRI_fcnxpro122_LimbicB_2_ContC
Limbic Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.contc
rsfMRI_fcnxpro122_LimbicB_2_ContB
Limbic Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.contb
rsfMRI_fcnxpro122_LimbicB_2_ContA
Limbic Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.conta
rsfMRI_fcnxpro122_LimbicB_2_LimbicA
Limbic Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.limbica
rsfMRI_fcnxpro122_LimbicB_2_LimbicB
Limbic Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.limbicb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnB
Limbic Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.salventattnb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnA
Limbic Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.salventattna
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnB
Limbic Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.dorsattnb
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnA
Limbic Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.dorsattna
rsfMRI_fcnxpro122_LimbicB_2_SomMotB
Limbic Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.sommotb
rsfMRI_fcnxpro122_LimbicB_2_SomMotA
Limbic Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.sommota
rsfMRI_fcnxpro122_LimbicB_2_VisPeri
Limbic Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.visperi
rsfMRI_fcnxpro122_LimbicB_2_VisCent
Limbic Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.viscent
rsfMRI_fcnxpro122_LimbicB_2_Striatum
Limbic Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.striatum
rsfMRI_fcnxpro122_LimbicB_2_Dopamine
Limbic Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.dopamine
rsfMRI_fcnxpro122_LimbicB_2_CITLimbic
Limbic Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.citlimbic
rsfMRI_fcnxpro122_LimbicB_2_BasalGanglia
Limbic Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.basalganglia
rsfMRI_fcnxpro122_LimbicB_2_MidBrain
Limbic Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.limbicb.2.midbrain
rsfMRI_fcnxpro122_SalVentAttnB_2_TempPar
Salience/Ventral Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.temppar
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultC
Salience/Ventral Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultB
Salience/Ventral Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultA
Salience/Ventral Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnB_2_ContC
Salience/Ventral Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.contc
rsfMRI_fcnxpro122_SalVentAttnB_2_ContB
Salience/Ventral Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.contb
rsfMRI_fcnxpro122_SalVentAttnB_2_ContA
Salience/Ventral Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.conta
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicA
Salience/Ventral Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.limbica
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicB
Salience/Ventral Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnB
Salience/Ventral Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnA
Salience/Ventral Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnB
Salience/Ventral Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnA
Salience/Ventral Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotB
Salience/Ventral Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotA
Salience/Ventral Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.sommota
rsfMRI_fcnxpro122_SalVentAttnB_2_VisPeri
Salience/Ventral Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.visperi
rsfMRI_fcnxpro122_SalVentAttnB_2_VisCent
Salience/Ventral Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.viscent
rsfMRI_fcnxpro122_SalVentAttnB_2_Striatum
Salience/Ventral Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.striatum
rsfMRI_fcnxpro122_SalVentAttnB_2_Dopamine
Salience/Ventral Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.dopamine
rsfMRI_fcnxpro122_SalVentAttnB_2_CITLimbic
Salience/Ventral Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.citlimbic
rsfMRI_fcnxpro122_SalVentAttnB_2_BasalGanglia
Salience/Ventral Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.basalganglia
rsfMRI_fcnxpro122_SalVentAttnB_2_MidBrain
Salience/Ventral Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattnb.2.midbrain
rsfMRI_fcnxpro122_SalVentAttnA_2_TempPar
Salience/Ventral Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.temppar
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultC
Salience/Ventral Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultB
Salience/Ventral Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultA
Salience/Ventral Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnA_2_ContC
Salience/Ventral Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.contc
rsfMRI_fcnxpro122_SalVentAttnA_2_ContB
Salience/Ventral Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.contb
rsfMRI_fcnxpro122_SalVentAttnA_2_ContA
Salience/Ventral Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.conta
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicA
Salience/Ventral Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.limbica
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicB
Salience/Ventral Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnB
Salience/Ventral Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnA
Salience/Ventral Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnB
Salience/Ventral Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnA
Salience/Ventral Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotB
Salience/Ventral Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotA
Salience/Ventral Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.sommota
rsfMRI_fcnxpro122_SalVentAttnA_2_VisPeri
Salience/Ventral Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.visperi
rsfMRI_fcnxpro122_SalVentAttnA_2_VisCent
Salience/Ventral Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.viscent
rsfMRI_fcnxpro122_SalVentAttnA_2_Striatum
Salience/Ventral Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.striatum
rsfMRI_fcnxpro122_SalVentAttnA_2_Dopamine
Salience/Ventral Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.dopamine
rsfMRI_fcnxpro122_SalVentAttnA_2_CITLimbic
Salience/Ventral Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.citlimbic
rsfMRI_fcnxpro122_SalVentAttnA_2_BasalGanglia
Salience/Ventral Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.basalganglia
rsfMRI_fcnxpro122_SalVentAttnA_2_MidBrain
Salience/Ventral Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.salventattna.2.midbrain
rsfMRI_fcnxpro122_DorsAttnB_2_TempPar
Dorsal Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.temppar
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultC
Dorsal Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.defaultc
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultB
Dorsal Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.defaultb
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultA
Dorsal Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.defaulta
rsfMRI_fcnxpro122_DorsAttnB_2_ContC
Dorsal Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.contc
rsfMRI_fcnxpro122_DorsAttnB_2_ContB
Dorsal Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.contb
rsfMRI_fcnxpro122_DorsAttnB_2_ContA
Dorsal Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.conta
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicA
Dorsal Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.limbica
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicB
Dorsal Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.limbicb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnB
Dorsal Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnA
Dorsal Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.salventattna
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnB
Dorsal Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnA
Dorsal Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotB
Dorsal Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.sommotb
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotA
Dorsal Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.sommota
rsfMRI_fcnxpro122_DorsAttnB_2_VisPeri
Dorsal Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.visperi
rsfMRI_fcnxpro122_DorsAttnB_2_VisCent
Dorsal Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.viscent
rsfMRI_fcnxpro122_DorsAttnB_2_Striatum
Dorsal Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.striatum
rsfMRI_fcnxpro122_DorsAttnB_2_Dopamine
Dorsal Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.dopamine
rsfMRI_fcnxpro122_DorsAttnB_2_CITLimbic
Dorsal Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.citlimbic
rsfMRI_fcnxpro122_DorsAttnB_2_BasalGanglia
Dorsal Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.basalganglia
rsfMRI_fcnxpro122_DorsAttnB_2_MidBrain
Dorsal Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattnb.2.midbrain
rsfMRI_fcnxpro122_DorsAttnA_2_TempPar
Dorsal Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.temppar
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultC
Dorsal Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.defaultc
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultB
Dorsal Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.defaultb
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultA
Dorsal Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.defaulta
rsfMRI_fcnxpro122_DorsAttnA_2_ContC
Dorsal Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.contc
rsfMRI_fcnxpro122_DorsAttnA_2_ContB
Dorsal Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.contb
rsfMRI_fcnxpro122_DorsAttnA_2_ContA
Dorsal Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.conta
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicA
Dorsal Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.limbica
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicB
Dorsal Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.limbicb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnB
Dorsal Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnA
Dorsal Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.salventattna
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnB
Dorsal Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnA
Dorsal Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotB
Dorsal Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.sommotb
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotA
Dorsal Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.sommota
rsfMRI_fcnxpro122_DorsAttnA_2_VisPeri
Dorsal Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.visperi
rsfMRI_fcnxpro122_DorsAttnA_2_VisCent
Dorsal Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.viscent
rsfMRI_fcnxpro122_DorsAttnA_2_Striatum
Dorsal Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.striatum
rsfMRI_fcnxpro122_DorsAttnA_2_Dopamine
Dorsal Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.dopamine
rsfMRI_fcnxpro122_DorsAttnA_2_CITLimbic
Dorsal Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.citlimbic
rsfMRI_fcnxpro122_DorsAttnA_2_BasalGanglia
Dorsal Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.basalganglia
rsfMRI_fcnxpro122_DorsAttnA_2_MidBrain
Dorsal Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dorsattna.2.midbrain
rsfMRI_fcnxpro122_SomMotB_2_TempPar
Somatomotor Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.temppar
rsfMRI_fcnxpro122_SomMotB_2_DefaultC
Somatomotor Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.defaultc
rsfMRI_fcnxpro122_SomMotB_2_DefaultB
Somatomotor Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.defaultb
rsfMRI_fcnxpro122_SomMotB_2_DefaultA
Somatomotor Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.defaulta
rsfMRI_fcnxpro122_SomMotB_2_ContC
Somatomotor Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.contc
rsfMRI_fcnxpro122_SomMotB_2_ContB
Somatomotor Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.contb
rsfMRI_fcnxpro122_SomMotB_2_ContA
Somatomotor Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.conta
rsfMRI_fcnxpro122_SomMotB_2_LimbicA
Somatomotor Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.limbica
rsfMRI_fcnxpro122_SomMotB_2_LimbicB
Somatomotor Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.limbicb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnB
Somatomotor Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.salventattnb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnA
Somatomotor Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.salventattna
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnB
Somatomotor Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.dorsattnb
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnA
Somatomotor Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.dorsattna
rsfMRI_fcnxpro122_SomMotB_2_SomMotB
Somatomotor Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.sommotb
rsfMRI_fcnxpro122_SomMotB_2_SomMotA
Somatomotor Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.sommota
rsfMRI_fcnxpro122_SomMotB_2_VisPeri
Somatomotor Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.visperi
rsfMRI_fcnxpro122_SomMotB_2_VisCent
Somatomotor Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.viscent
rsfMRI_fcnxpro122_SomMotB_2_Striatum
Somatomotor Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.striatum
rsfMRI_fcnxpro122_SomMotB_2_Dopamine
Somatomotor Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.dopamine
rsfMRI_fcnxpro122_SomMotB_2_CITLimbic
Somatomotor Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.citlimbic
rsfMRI_fcnxpro122_SomMotB_2_BasalGanglia
Somatomotor Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.basalganglia
rsfMRI_fcnxpro122_SomMotB_2_MidBrain
Somatomotor Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommotb.2.midbrain
rsfMRI_fcnxpro122_SomMotA_2_TempPar
Somatomotor Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.temppar
rsfMRI_fcnxpro122_SomMotA_2_DefaultC
Somatomotor Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.defaultc
rsfMRI_fcnxpro122_SomMotA_2_DefaultB
Somatomotor Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.defaultb
rsfMRI_fcnxpro122_SomMotA_2_DefaultA
Somatomotor Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.defaulta
rsfMRI_fcnxpro122_SomMotA_2_ContC
Somatomotor Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.contc
rsfMRI_fcnxpro122_SomMotA_2_ContB
Somatomotor Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.contb
rsfMRI_fcnxpro122_SomMotA_2_ContA
Somatomotor Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.conta
rsfMRI_fcnxpro122_SomMotA_2_LimbicA
Somatomotor Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.limbica
rsfMRI_fcnxpro122_SomMotA_2_LimbicB
Somatomotor Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.limbicb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnB
Somatomotor Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.salventattnb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnA
Somatomotor Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.salventattna
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnB
Somatomotor Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.dorsattnb
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnA
Somatomotor Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.dorsattna
rsfMRI_fcnxpro122_SomMotA_2_SomMotB
Somatomotor Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.sommotb
rsfMRI_fcnxpro122_SomMotA_2_SomMotA
Somatomotor Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.sommota
rsfMRI_fcnxpro122_SomMotA_2_VisPeri
Somatomotor Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.visperi
rsfMRI_fcnxpro122_SomMotA_2_VisCent
Somatomotor Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.viscent
rsfMRI_fcnxpro122_SomMotA_2_Striatum
Somatomotor Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.striatum
rsfMRI_fcnxpro122_SomMotA_2_Dopamine
Somatomotor Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.dopamine
rsfMRI_fcnxpro122_SomMotA_2_CITLimbic
Somatomotor Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.citlimbic
rsfMRI_fcnxpro122_SomMotA_2_BasalGanglia
Somatomotor Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.basalganglia
rsfMRI_fcnxpro122_SomMotA_2_MidBrain
Somatomotor Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.sommota.2.midbrain
rsfMRI_fcnxpro122_VisPeri_2_TempPar
Visual Network Peripheral to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.temppar
rsfMRI_fcnxpro122_VisPeri_2_DefaultC
Visual Network Peripheral to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.defaultc
rsfMRI_fcnxpro122_VisPeri_2_DefaultB
Visual Network Peripheral to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.defaultb
rsfMRI_fcnxpro122_VisPeri_2_DefaultA
Visual Network Peripheral to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.defaulta
rsfMRI_fcnxpro122_VisPeri_2_ContC
Visual Network Peripheral to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.contc
rsfMRI_fcnxpro122_VisPeri_2_ContB
Visual Network Peripheral to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.contb
rsfMRI_fcnxpro122_VisPeri_2_ContA
Visual Network Peripheral to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.conta
rsfMRI_fcnxpro122_VisPeri_2_LimbicA
Visual Network Peripheral to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.limbica
rsfMRI_fcnxpro122_VisPeri_2_LimbicB
Visual Network Peripheral to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.limbicb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnB
Visual Network Peripheral to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.salventattnb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnA
Visual Network Peripheral to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.salventattna
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnB
Visual Network Peripheral to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.dorsattnb
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnA
Visual Network Peripheral to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.dorsattna
rsfMRI_fcnxpro122_VisPeri_2_SomMotB
Visual Network Peripheral to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.sommotb
rsfMRI_fcnxpro122_VisPeri_2_SomMotA
Visual Network Peripheral to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.sommota
rsfMRI_fcnxpro122_VisPeri_2_VisPeri
Visual Network Peripheral to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.visperi
rsfMRI_fcnxpro122_VisPeri_2_VisCent
Visual Network Peripheral to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.viscent
rsfMRI_fcnxpro122_VisPeri_2_Striatum
Visual Network Peripheral to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.striatum
rsfMRI_fcnxpro122_VisPeri_2_Dopamine
Visual Network Peripheral to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.dopamine
rsfMRI_fcnxpro122_VisPeri_2_CITLimbic
Visual Network Peripheral to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.citlimbic
rsfMRI_fcnxpro122_VisPeri_2_BasalGanglia
Visual Network Peripheral to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.basalganglia
rsfMRI_fcnxpro122_VisPeri_2_MidBrain
Visual Network Peripheral to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.visperi.2.midbrain
rsfMRI_fcnxpro122_VisCent_2_TempPar
Visual Network Central to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.temppar
rsfMRI_fcnxpro122_VisCent_2_DefaultC
Visual Network Central to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.defaultc
rsfMRI_fcnxpro122_VisCent_2_DefaultB
Visual Network Central to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.defaultb
rsfMRI_fcnxpro122_VisCent_2_DefaultA
Visual Network Central to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.defaulta
rsfMRI_fcnxpro122_VisCent_2_ContC
Visual Network Central to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.contc
rsfMRI_fcnxpro122_VisCent_2_ContB
Visual Network Central to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.contb
rsfMRI_fcnxpro122_VisCent_2_ContA
Visual Network Central to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.conta
rsfMRI_fcnxpro122_VisCent_2_LimbicA
Visual Network Central to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.limbica
rsfMRI_fcnxpro122_VisCent_2_LimbicB
Visual Network Central to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.limbicb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnB
Visual Network Central to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.salventattnb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnA
Visual Network Central to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.salventattna
rsfMRI_fcnxpro122_VisCent_2_DorsAttnB
Visual Network Central to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.dorsattnb
rsfMRI_fcnxpro122_VisCent_2_DorsAttnA
Visual Network Central to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.dorsattna
rsfMRI_fcnxpro122_VisCent_2_SomMotB
Visual Network Central to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.sommotb
rsfMRI_fcnxpro122_VisCent_2_SomMotA
Visual Network Central to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.sommota
rsfMRI_fcnxpro122_VisCent_2_VisPeri
Visual Network Central to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.visperi
rsfMRI_fcnxpro122_VisCent_2_VisCent
Visual Network Central to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.viscent
rsfMRI_fcnxpro122_VisCent_2_Striatum
Visual Network Central to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.striatum
rsfMRI_fcnxpro122_VisCent_2_Dopamine
Visual Network Central to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.dopamine
rsfMRI_fcnxpro122_VisCent_2_CITLimbic
Visual Network Central to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.citlimbic
rsfMRI_fcnxpro122_VisCent_2_BasalGanglia
Visual Network Central to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.basalganglia
rsfMRI_fcnxpro122_VisCent_2_MidBrain
Visual Network Central to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.viscent.2.midbrain
rsfMRI_fcnxpro122_Striatum_2_TempPar
Striatal Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.temppar
rsfMRI_fcnxpro122_Striatum_2_DefaultC
Striatal Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.defaultc
rsfMRI_fcnxpro122_Striatum_2_DefaultB
Striatal Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.defaultb
rsfMRI_fcnxpro122_Striatum_2_DefaultA
Striatal Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.defaulta
rsfMRI_fcnxpro122_Striatum_2_ContC
Striatal Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.contc
rsfMRI_fcnxpro122_Striatum_2_ContB
Striatal Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.contb
rsfMRI_fcnxpro122_Striatum_2_ContA
Striatal Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.conta
rsfMRI_fcnxpro122_Striatum_2_LimbicA
Striatal Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.limbica
rsfMRI_fcnxpro122_Striatum_2_LimbicB
Striatal Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.limbicb
rsfMRI_fcnxpro122_Striatum_2_SalVentAttnB
Striatal Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.salventattnb
rsfMRI_fcnxpro122_Striatum_2_SalVentAttnA
Striatal Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.salventattna
rsfMRI_fcnxpro122_Striatum_2_DorsAttnB
Striatal Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.dorsattnb
rsfMRI_fcnxpro122_Striatum_2_DorsAttnA
Striatal Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.dorsattna
rsfMRI_fcnxpro122_Striatum_2_SomMotB
Striatal Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.sommotb
rsfMRI_fcnxpro122_Striatum_2_SomMotA
Striatal Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.sommota
rsfMRI_fcnxpro122_Striatum_2_VisPeri
Striatal Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.visperi
rsfMRI_fcnxpro122_Striatum_2_VisCent
Striatal Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.viscent
rsfMRI_fcnxpro122_Striatum_2_Striatum
Striatal Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.striatum
rsfMRI_fcnxpro122_Striatum_2_Dopamine
Striatal Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.dopamine
rsfMRI_fcnxpro122_Striatum_2_CITLimbic
Striatal Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.citlimbic
rsfMRI_fcnxpro122_Striatum_2_BasalGanglia
Striatal Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.basalganglia
rsfMRI_fcnxpro122_Striatum_2_MidBrain
Striatal Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.striatum.2.midbrain
rsfMRI_fcnxpro122_Dopamine_2_TempPar
Dopaminergic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.temppar
rsfMRI_fcnxpro122_Dopamine_2_DefaultC
Dopaminergic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.defaultc
rsfMRI_fcnxpro122_Dopamine_2_DefaultB
Dopaminergic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.defaultb
rsfMRI_fcnxpro122_Dopamine_2_DefaultA
Dopaminergic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.defaulta
rsfMRI_fcnxpro122_Dopamine_2_ContC
Dopaminergic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.contc
rsfMRI_fcnxpro122_Dopamine_2_ContB
Dopaminergic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.contb
rsfMRI_fcnxpro122_Dopamine_2_ContA
Dopaminergic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.conta
rsfMRI_fcnxpro122_Dopamine_2_LimbicA
Dopaminergic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.limbica
rsfMRI_fcnxpro122_Dopamine_2_LimbicB
Dopaminergic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.limbicb
rsfMRI_fcnxpro122_Dopamine_2_SalVentAttnB
Dopaminergic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.salventattnb
rsfMRI_fcnxpro122_Dopamine_2_SalVentAttnA
Dopaminergic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.salventattna
rsfMRI_fcnxpro122_Dopamine_2_DorsAttnB
Dopaminergic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.dorsattnb
rsfMRI_fcnxpro122_Dopamine_2_DorsAttnA
Dopaminergic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.dorsattna
rsfMRI_fcnxpro122_Dopamine_2_SomMotB
Dopaminergic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.sommotb
rsfMRI_fcnxpro122_Dopamine_2_SomMotA
Dopaminergic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.sommota
rsfMRI_fcnxpro122_Dopamine_2_VisPeri
Dopaminergic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.visperi
rsfMRI_fcnxpro122_Dopamine_2_VisCent
Dopaminergic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.viscent
rsfMRI_fcnxpro122_Dopamine_2_Striatum
Dopaminergic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.striatum
rsfMRI_fcnxpro122_Dopamine_2_Dopamine
Dopaminergic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.dopamine
rsfMRI_fcnxpro122_Dopamine_2_CITLimbic
Dopaminergic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.citlimbic
rsfMRI_fcnxpro122_Dopamine_2_BasalGanglia
Dopaminergic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.basalganglia
rsfMRI_fcnxpro122_Dopamine_2_MidBrain
Dopaminergic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.dopamine.2.midbrain
rsfMRI_fcnxpro122_CITLimbic_2_TempPar
CIT Atlas Limbic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.temppar
rsfMRI_fcnxpro122_CITLimbic_2_DefaultC
CIT Atlas Limbic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.defaultc
rsfMRI_fcnxpro122_CITLimbic_2_DefaultB
CIT Atlas Limbic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.defaultb
rsfMRI_fcnxpro122_CITLimbic_2_DefaultA
CIT Atlas Limbic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.defaulta
rsfMRI_fcnxpro122_CITLimbic_2_ContC
CIT Atlas Limbic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.contc
rsfMRI_fcnxpro122_CITLimbic_2_ContB
CIT Atlas Limbic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.contb
rsfMRI_fcnxpro122_CITLimbic_2_ContA
CIT Atlas Limbic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.conta
rsfMRI_fcnxpro122_CITLimbic_2_LimbicA
CIT Atlas Limbic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.limbica
rsfMRI_fcnxpro122_CITLimbic_2_LimbicB
CIT Atlas Limbic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.limbicb
rsfMRI_fcnxpro122_CITLimbic_2_SalVentAttnB
CIT Atlas Limbic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.salventattnb
rsfMRI_fcnxpro122_CITLimbic_2_SalVentAttnA
CIT Atlas Limbic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.salventattna
rsfMRI_fcnxpro122_CITLimbic_2_DorsAttnB
CIT Atlas Limbic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.dorsattnb
rsfMRI_fcnxpro122_CITLimbic_2_DorsAttnA
CIT Atlas Limbic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.dorsattna
rsfMRI_fcnxpro122_CITLimbic_2_SomMotB
CIT Atlas Limbic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.sommotb
rsfMRI_fcnxpro122_CITLimbic_2_SomMotA
CIT Atlas Limbic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.sommota
rsfMRI_fcnxpro122_CITLimbic_2_VisPeri
CIT Atlas Limbic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.visperi
rsfMRI_fcnxpro122_CITLimbic_2_VisCent
CIT Atlas Limbic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.viscent
rsfMRI_fcnxpro122_CITLimbic_2_Striatum
CIT Atlas Limbic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.striatum
rsfMRI_fcnxpro122_CITLimbic_2_Dopamine
CIT Atlas Limbic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.dopamine
rsfMRI_fcnxpro122_CITLimbic_2_CITLimbic
CIT Atlas Limbic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.citlimbic
rsfMRI_fcnxpro122_CITLimbic_2_BasalGanglia
CIT Atlas Limbic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.basalganglia
rsfMRI_fcnxpro122_CITLimbic_2_MidBrain
CIT Atlas Limbic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.citlimbic.2.midbrain
rsfMRI_fcnxpro122_BasalGanglia_2_TempPar
Basal Ganglia Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.temppar
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultC
Basal Ganglia Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.defaultc
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultB
Basal Ganglia Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.defaultb
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultA
Basal Ganglia Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.defaulta
rsfMRI_fcnxpro122_BasalGanglia_2_ContC
Basal Ganglia Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.contc
rsfMRI_fcnxpro122_BasalGanglia_2_ContB
Basal Ganglia Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.contb
rsfMRI_fcnxpro122_BasalGanglia_2_ContA
Basal Ganglia Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.conta
rsfMRI_fcnxpro122_BasalGanglia_2_LimbicA
Basal Ganglia Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.limbica
rsfMRI_fcnxpro122_BasalGanglia_2_LimbicB
Basal Ganglia Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.limbicb
rsfMRI_fcnxpro122_BasalGanglia_2_SalVentAttnB
Basal Ganglia Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.salventattnb
rsfMRI_fcnxpro122_BasalGanglia_2_SalVentAttnA
Basal Ganglia Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.salventattna
rsfMRI_fcnxpro122_BasalGanglia_2_DorsAttnB
Basal Ganglia Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.dorsattnb
rsfMRI_fcnxpro122_BasalGanglia_2_DorsAttnA
Basal Ganglia Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.dorsattna
rsfMRI_fcnxpro122_BasalGanglia_2_SomMotB
Basal Ganglia Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.sommotb
rsfMRI_fcnxpro122_BasalGanglia_2_SomMotA
Basal Ganglia Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.sommota
rsfMRI_fcnxpro122_BasalGanglia_2_VisPeri
Basal Ganglia Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.visperi
rsfMRI_fcnxpro122_BasalGanglia_2_VisCent
Basal Ganglia Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.viscent
rsfMRI_fcnxpro122_BasalGanglia_2_Striatum
Basal Ganglia Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.striatum
rsfMRI_fcnxpro122_BasalGanglia_2_Dopamine
Basal Ganglia Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.dopamine
rsfMRI_fcnxpro122_BasalGanglia_2_CITLimbic
Basal Ganglia Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.citlimbic
rsfMRI_fcnxpro122_BasalGanglia_2_BasalGanglia
Basal Ganglia Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.basalganglia
rsfMRI_fcnxpro122_BasalGanglia_2_MidBrain
Basal Ganglia Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.basalganglia.2.midbrain
rsfMRI_fcnxpro122_MidBrain_2_TempPar
Midbrain to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.temppar
rsfMRI_fcnxpro122_MidBrain_2_DefaultC
Midbrain to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.defaultc
rsfMRI_fcnxpro122_MidBrain_2_DefaultB
Midbrain to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.defaultb
rsfMRI_fcnxpro122_MidBrain_2_DefaultA
Midbrain to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.defaulta
rsfMRI_fcnxpro122_MidBrain_2_ContC
Midbrain to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.contc
rsfMRI_fcnxpro122_MidBrain_2_ContB
Midbrain to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.contb
rsfMRI_fcnxpro122_MidBrain_2_ContA
Midbrain to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.conta
rsfMRI_fcnxpro122_MidBrain_2_LimbicA
Midbrain to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.limbica
rsfMRI_fcnxpro122_MidBrain_2_LimbicB
Midbrain to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.limbicb
rsfMRI_fcnxpro122_MidBrain_2_SalVentAttnB
Midbrain to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.salventattnb
rsfMRI_fcnxpro122_MidBrain_2_SalVentAttnA
Midbrain to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.salventattna
rsfMRI_fcnxpro122_MidBrain_2_DorsAttnB
Midbrain to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.dorsattnb
rsfMRI_fcnxpro122_MidBrain_2_DorsAttnA
Midbrain to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.dorsattna
rsfMRI_fcnxpro122_MidBrain_2_SomMotB
Midbrain to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.sommotb
rsfMRI_fcnxpro122_MidBrain_2_SomMotA
Midbrain to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.sommota
rsfMRI_fcnxpro122_MidBrain_2_VisPeri
Midbrain to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.visperi
rsfMRI_fcnxpro122_MidBrain_2_VisCent
Midbrain to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.viscent
rsfMRI_fcnxpro122_MidBrain_2_Striatum
Midbrain to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.striatum
rsfMRI_fcnxpro122_MidBrain_2_Dopamine
Midbrain to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.dopamine
rsfMRI_fcnxpro122_MidBrain_2_CITLimbic
Midbrain to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.citlimbic
rsfMRI_fcnxpro122_MidBrain_2_BasalGanglia
Midbrain to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.basalganglia
rsfMRI_fcnxpro122_MidBrain_2_MidBrain
Midbrain to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
122
​
rsf.p1.midbrain.2.midbrain
rsfMRI_fcnxpro129_paramset
​
restingStatefMRI
parameter id
power peterson fMRI meta-analyses
129
​
rsf.p2.paramset
rsfMRI_fcnxpro129_upsampling
Unknown Core: upsampling
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.upsampling
rsfMRI_fcnxpro129_meanBold_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.meanbold.mean
rsfMRI_fcnxpro129_TempPar_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.mean
rsfMRI_fcnxpro129_DefaultC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.mean
rsfMRI_fcnxpro129_DefaultB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.mean
rsfMRI_fcnxpro129_DefaultA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.mean
rsfMRI_fcnxpro129_ContC_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.mean
rsfMRI_fcnxpro129_ContB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.mean
rsfMRI_fcnxpro129_ContA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.mean
rsfMRI_fcnxpro129_LimbicA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.mean
rsfMRI_fcnxpro129_LimbicB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.mean
rsfMRI_fcnxpro129_SalVentAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.mean
rsfMRI_fcnxpro129_SalVentAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.mean
rsfMRI_fcnxpro129_DorsAttnB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.mean
rsfMRI_fcnxpro129_DorsAttnA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.mean
rsfMRI_fcnxpro129_SomMotB_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.mean
rsfMRI_fcnxpro129_SomMotA_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.mean
rsfMRI_fcnxpro129_VisPeri_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.mean
rsfMRI_fcnxpro129_VisCent_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.mean
rsfMRI_fcnxpro129_Striatum_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.mean
rsfMRI_fcnxpro129_Dopamine_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.mean
rsfMRI_fcnxpro129_CITLimbic_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.mean
rsfMRI_fcnxpro129_BasalGanglia_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.mean
rsfMRI_fcnxpro129_MidBrain_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.mean
rsfMRI_fcnxpro129_fmri_template_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.fmri.template.mean
rsfMRI_fcnxpro129_brainmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.brainmask.mean
rsfMRI_fcnxpro129_gmmask_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.gmmask.mean
rsfMRI_fcnxpro129_alff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.alff.mean
rsfMRI_fcnxpro129_alff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
129
​
rsf.p2.alff.sd
rsfMRI_fcnxpro129_falff_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.falff.mean
rsfMRI_fcnxpro129_falff_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
129
​
rsf.p2.falff.sd
rsfMRI_fcnxpro129_falffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint000.iplleft
rsfMRI_fcnxpro129_alffPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint000.iplleft
rsfMRI_fcnxpro129_perafPoint000_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint000.iplleft
rsfMRI_fcnxpro129_falffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint001.stleft
rsfMRI_fcnxpro129_alffPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint001.stleft
rsfMRI_fcnxpro129_perafPoint001_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint001.stleft
rsfMRI_fcnxpro129_falffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint002.stleft
rsfMRI_fcnxpro129_alffPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint002.stleft
rsfMRI_fcnxpro129_perafPoint002_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint002.stleft
rsfMRI_fcnxpro129_falffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint003.tempoccleft
rsfMRI_fcnxpro129_alffPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint003.tempoccleft
rsfMRI_fcnxpro129_perafPoint003_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint003.tempoccleft
rsfMRI_fcnxpro129_falffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint004.templeft
rsfMRI_fcnxpro129_alffPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint004.templeft
rsfMRI_fcnxpro129_perafPoint004_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint004.templeft
rsfMRI_fcnxpro129_falffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint005.templeft
rsfMRI_fcnxpro129_alffPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint005.templeft
rsfMRI_fcnxpro129_perafPoint005_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint005.templeft
rsfMRI_fcnxpro129_falffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint006.exstrinfleft
rsfMRI_fcnxpro129_alffPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint006.exstrinfleft
rsfMRI_fcnxpro129_perafPoint006_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint006.exstrinfleft
rsfMRI_fcnxpro129_falffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint007.iplleft
rsfMRI_fcnxpro129_alffPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint007.iplleft
rsfMRI_fcnxpro129_perafPoint007_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint007.iplleft
rsfMRI_fcnxpro129_falffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint008.phcleft
rsfMRI_fcnxpro129_alffPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint008.phcleft
rsfMRI_fcnxpro129_perafPoint008_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint008.phcleft
rsfMRI_fcnxpro129_falffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint009.phcleft
rsfMRI_fcnxpro129_alffPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint009.phcleft
rsfMRI_fcnxpro129_perafPoint009_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint009.phcleft
rsfMRI_fcnxpro129_falffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint010.phcleft
rsfMRI_fcnxpro129_alffPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint010.phcleft
rsfMRI_fcnxpro129_perafPoint010_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint010.phcleft
rsfMRI_fcnxpro129_falffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint011.rscleft
rsfMRI_fcnxpro129_alffPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint011.rscleft
rsfMRI_fcnxpro129_perafPoint011_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint011.rscleft
rsfMRI_fcnxpro129_falffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint012.rscleft
rsfMRI_fcnxpro129_alffPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint012.rscleft
rsfMRI_fcnxpro129_perafPoint012_RSCleft
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint012.rscleft
rsfMRI_fcnxpro129_falffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint013.iplleft
rsfMRI_fcnxpro129_alffPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint013.iplleft
rsfMRI_fcnxpro129_perafPoint013_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint013.iplleft
rsfMRI_fcnxpro129_falffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint014.iplleft
rsfMRI_fcnxpro129_alffPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint014.iplleft
rsfMRI_fcnxpro129_perafPoint014_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint014.iplleft
rsfMRI_fcnxpro129_falffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint015.iplleft
rsfMRI_fcnxpro129_alffPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint015.iplleft
rsfMRI_fcnxpro129_perafPoint015_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint015.iplleft
rsfMRI_fcnxpro129_falffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint016.iplleft
rsfMRI_fcnxpro129_alffPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint016.iplleft
rsfMRI_fcnxpro129_perafPoint016_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint016.iplleft
rsfMRI_fcnxpro129_falffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint017.pfcdleft
rsfMRI_fcnxpro129_alffPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint017.pfcdleft
rsfMRI_fcnxpro129_perafPoint017_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint017.pfcdleft
rsfMRI_fcnxpro129_falffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint018.pfcdleft
rsfMRI_fcnxpro129_alffPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint018.pfcdleft
rsfMRI_fcnxpro129_perafPoint018_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint018.pfcdleft
rsfMRI_fcnxpro129_falffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint019.pfcdleft
rsfMRI_fcnxpro129_alffPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint019.pfcdleft
rsfMRI_fcnxpro129_perafPoint019_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint019.pfcdleft
rsfMRI_fcnxpro129_falffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint020.pfcdleft
rsfMRI_fcnxpro129_alffPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint020.pfcdleft
rsfMRI_fcnxpro129_perafPoint020_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint020.pfcdleft
rsfMRI_fcnxpro129_falffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint021.pfcdleft
rsfMRI_fcnxpro129_alffPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint021.pfcdleft
rsfMRI_fcnxpro129_perafPoint021_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint021.pfcdleft
rsfMRI_fcnxpro129_falffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint022.pfcdleft
rsfMRI_fcnxpro129_alffPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint022.pfcdleft
rsfMRI_fcnxpro129_perafPoint022_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint022.pfcdleft
rsfMRI_fcnxpro129_falffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint023.pfcdleft
rsfMRI_fcnxpro129_alffPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint023.pfcdleft
rsfMRI_fcnxpro129_perafPoint023_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint023.pfcdleft
rsfMRI_fcnxpro129_falffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint024.pfclleft
rsfMRI_fcnxpro129_alffPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint024.pfclleft
rsfMRI_fcnxpro129_perafPoint024_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint024.pfclleft
rsfMRI_fcnxpro129_falffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint025.pfclleft
rsfMRI_fcnxpro129_alffPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint025.pfclleft
rsfMRI_fcnxpro129_perafPoint025_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint025.pfclleft
rsfMRI_fcnxpro129_falffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint026.pfcvleft
rsfMRI_fcnxpro129_alffPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint026.pfcvleft
rsfMRI_fcnxpro129_perafPoint026_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint026.pfcvleft
rsfMRI_fcnxpro129_falffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint027.pfcvleft
rsfMRI_fcnxpro129_alffPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint027.pfcvleft
rsfMRI_fcnxpro129_perafPoint027_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint027.pfcvleft
rsfMRI_fcnxpro129_falffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint028.pfcvleft
rsfMRI_fcnxpro129_alffPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint028.pfcvleft
rsfMRI_fcnxpro129_perafPoint028_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint028.pfcvleft
rsfMRI_fcnxpro129_falffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint029.pfcvleft
rsfMRI_fcnxpro129_alffPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint029.pfcvleft
rsfMRI_fcnxpro129_perafPoint029_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint029.pfcvleft
rsfMRI_fcnxpro129_falffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint030.temppoleleft
rsfMRI_fcnxpro129_alffPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint030.temppoleleft
rsfMRI_fcnxpro129_perafPoint030_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint030.temppoleleft
rsfMRI_fcnxpro129_falffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint031.templeft
rsfMRI_fcnxpro129_alffPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint031.templeft
rsfMRI_fcnxpro129_perafPoint031_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint031.templeft
rsfMRI_fcnxpro129_falffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint032.templeft
rsfMRI_fcnxpro129_alffPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint032.templeft
rsfMRI_fcnxpro129_perafPoint032_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint032.templeft
rsfMRI_fcnxpro129_falffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint033.templeft
rsfMRI_fcnxpro129_alffPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint033.templeft
rsfMRI_fcnxpro129_perafPoint033_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint033.templeft
rsfMRI_fcnxpro129_falffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint034.templeft
rsfMRI_fcnxpro129_alffPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint034.templeft
rsfMRI_fcnxpro129_perafPoint034_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint034.templeft
rsfMRI_fcnxpro129_falffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint035.templeft
rsfMRI_fcnxpro129_alffPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint035.templeft
rsfMRI_fcnxpro129_perafPoint035_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint035.templeft
rsfMRI_fcnxpro129_falffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint036.templeft
rsfMRI_fcnxpro129_alffPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint036.templeft
rsfMRI_fcnxpro129_perafPoint036_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint036.templeft
rsfMRI_fcnxpro129_falffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint037.templeft
rsfMRI_fcnxpro129_alffPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint037.templeft
rsfMRI_fcnxpro129_perafPoint037_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint037.templeft
rsfMRI_fcnxpro129_falffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint038.templeft
rsfMRI_fcnxpro129_alffPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint038.templeft
rsfMRI_fcnxpro129_perafPoint038_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint038.templeft
rsfMRI_fcnxpro129_falffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint039.templeft
rsfMRI_fcnxpro129_alffPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint039.templeft
rsfMRI_fcnxpro129_perafPoint039_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint039.templeft
rsfMRI_fcnxpro129_falffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint040.templeft
rsfMRI_fcnxpro129_alffPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint040.templeft
rsfMRI_fcnxpro129_perafPoint040_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint040.templeft
rsfMRI_fcnxpro129_falffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint041.fpoleleft
rsfMRI_fcnxpro129_alffPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint041.fpoleleft
rsfMRI_fcnxpro129_perafPoint041_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint041.fpoleleft
rsfMRI_fcnxpro129_falffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint042.iplleft
rsfMRI_fcnxpro129_alffPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint042.iplleft
rsfMRI_fcnxpro129_perafPoint042_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint042.iplleft
rsfMRI_fcnxpro129_falffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint043.iplleft
rsfMRI_fcnxpro129_alffPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint043.iplleft
rsfMRI_fcnxpro129_perafPoint043_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint043.iplleft
rsfMRI_fcnxpro129_falffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint044.iplleft
rsfMRI_fcnxpro129_alffPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint044.iplleft
rsfMRI_fcnxpro129_perafPoint044_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint044.iplleft
rsfMRI_fcnxpro129_falffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint045.pccleft
rsfMRI_fcnxpro129_alffPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint045.pccleft
rsfMRI_fcnxpro129_perafPoint045_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint045.pccleft
rsfMRI_fcnxpro129_falffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint046.pccleft
rsfMRI_fcnxpro129_alffPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint046.pccleft
rsfMRI_fcnxpro129_perafPoint046_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint046.pccleft
rsfMRI_fcnxpro129_falffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint047.pccleft
rsfMRI_fcnxpro129_alffPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint047.pccleft
rsfMRI_fcnxpro129_perafPoint047_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint047.pccleft
rsfMRI_fcnxpro129_falffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint048.pccleft
rsfMRI_fcnxpro129_alffPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint048.pccleft
rsfMRI_fcnxpro129_perafPoint048_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint048.pccleft
rsfMRI_fcnxpro129_falffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint049.pccleft
rsfMRI_fcnxpro129_alffPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint049.pccleft
rsfMRI_fcnxpro129_perafPoint049_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint049.pccleft
rsfMRI_fcnxpro129_falffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint050.pccleft
rsfMRI_fcnxpro129_alffPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint050.pccleft
rsfMRI_fcnxpro129_perafPoint050_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint050.pccleft
rsfMRI_fcnxpro129_falffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint051.pccleft
rsfMRI_fcnxpro129_alffPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint051.pccleft
rsfMRI_fcnxpro129_perafPoint051_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint051.pccleft
rsfMRI_fcnxpro129_falffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint052.pfcdleft
rsfMRI_fcnxpro129_alffPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint052.pfcdleft
rsfMRI_fcnxpro129_perafPoint052_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint052.pfcdleft
rsfMRI_fcnxpro129_falffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint053.pfcdleft
rsfMRI_fcnxpro129_alffPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint053.pfcdleft
rsfMRI_fcnxpro129_perafPoint053_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint053.pfcdleft
rsfMRI_fcnxpro129_falffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint054.pfcdleft
rsfMRI_fcnxpro129_alffPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint054.pfcdleft
rsfMRI_fcnxpro129_perafPoint054_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint054.pfcdleft
rsfMRI_fcnxpro129_falffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint055.pfcdleft
rsfMRI_fcnxpro129_alffPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint055.pfcdleft
rsfMRI_fcnxpro129_perafPoint055_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint055.pfcdleft
rsfMRI_fcnxpro129_falffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint056.pfcmleft
rsfMRI_fcnxpro129_alffPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint056.pfcmleft
rsfMRI_fcnxpro129_perafPoint056_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint056.pfcmleft
rsfMRI_fcnxpro129_falffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint057.pfcmleft
rsfMRI_fcnxpro129_alffPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint057.pfcmleft
rsfMRI_fcnxpro129_perafPoint057_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint057.pfcmleft
rsfMRI_fcnxpro129_falffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint058.pfcmleft
rsfMRI_fcnxpro129_alffPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint058.pfcmleft
rsfMRI_fcnxpro129_perafPoint058_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint058.pfcmleft
rsfMRI_fcnxpro129_falffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint059.pfcmleft
rsfMRI_fcnxpro129_alffPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint059.pfcmleft
rsfMRI_fcnxpro129_perafPoint059_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint059.pfcmleft
rsfMRI_fcnxpro129_falffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint060.pfcmleft
rsfMRI_fcnxpro129_alffPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint060.pfcmleft
rsfMRI_fcnxpro129_perafPoint060_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint060.pfcmleft
rsfMRI_fcnxpro129_falffPoint061_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint061.pcunleft
rsfMRI_fcnxpro129_alffPoint061_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint061.pcunleft
rsfMRI_fcnxpro129_perafPoint061_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint061.pcunleft
rsfMRI_fcnxpro129_falffPoint062_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint062.pcunleft
rsfMRI_fcnxpro129_alffPoint062_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint062.pcunleft
rsfMRI_fcnxpro129_perafPoint062_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint062.pcunleft
rsfMRI_fcnxpro129_falffPoint063_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint063.pcunleft
rsfMRI_fcnxpro129_alffPoint063_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint063.pcunleft
rsfMRI_fcnxpro129_perafPoint063_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint063.pcunleft
rsfMRI_fcnxpro129_falffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint064.pccleft
rsfMRI_fcnxpro129_alffPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint064.pccleft
rsfMRI_fcnxpro129_perafPoint064_PCCleft
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint064.pccleft
rsfMRI_fcnxpro129_falffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint065.splleft
rsfMRI_fcnxpro129_alffPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint065.splleft
rsfMRI_fcnxpro129_perafPoint065_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint065.splleft
rsfMRI_fcnxpro129_falffPoint066_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint066.pcunleft
rsfMRI_fcnxpro129_alffPoint066_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint066.pcunleft
rsfMRI_fcnxpro129_perafPoint066_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint066.pcunleft
rsfMRI_fcnxpro129_falffPoint067_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint067.pcunleft
rsfMRI_fcnxpro129_alffPoint067_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint067.pcunleft
rsfMRI_fcnxpro129_perafPoint067_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint067.pcunleft
rsfMRI_fcnxpro129_falffPoint068_pCunleft
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint068.pcunleft
rsfMRI_fcnxpro129_alffPoint068_pCunleft
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint068.pcunleft
rsfMRI_fcnxpro129_perafPoint068_pCunleft
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint068.pcunleft
rsfMRI_fcnxpro129_falffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint069.fpoleleft
rsfMRI_fcnxpro129_alffPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint069.fpoleleft
rsfMRI_fcnxpro129_perafPoint069_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint069.fpoleleft
rsfMRI_fcnxpro129_falffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint070.fpoleleft
rsfMRI_fcnxpro129_alffPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint070.fpoleleft
rsfMRI_fcnxpro129_perafPoint070_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint070.fpoleleft
rsfMRI_fcnxpro129_falffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint071.frmedleft
rsfMRI_fcnxpro129_alffPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint071.frmedleft
rsfMRI_fcnxpro129_perafPoint071_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint071.frmedleft
rsfMRI_fcnxpro129_falffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint072.iplleft
rsfMRI_fcnxpro129_alffPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint072.iplleft
rsfMRI_fcnxpro129_perafPoint072_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint072.iplleft
rsfMRI_fcnxpro129_falffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint073.ipsleft
rsfMRI_fcnxpro129_alffPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint073.ipsleft
rsfMRI_fcnxpro129_perafPoint073_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint073.ipsleft
rsfMRI_fcnxpro129_falffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint074.ipsleft
rsfMRI_fcnxpro129_alffPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint074.ipsleft
rsfMRI_fcnxpro129_perafPoint074_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint074.ipsleft
rsfMRI_fcnxpro129_falffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint075.pfcdleft
rsfMRI_fcnxpro129_alffPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint075.pfcdleft
rsfMRI_fcnxpro129_perafPoint075_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint075.pfcdleft
rsfMRI_fcnxpro129_falffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint076.pfclleft
rsfMRI_fcnxpro129_alffPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint076.pfclleft
rsfMRI_fcnxpro129_perafPoint076_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint076.pfclleft
rsfMRI_fcnxpro129_falffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint077.pfcvleft
rsfMRI_fcnxpro129_alffPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint077.pfcvleft
rsfMRI_fcnxpro129_perafPoint077_PFCvleft
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint077.pfcvleft
rsfMRI_fcnxpro129_falffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint078.templeft
rsfMRI_fcnxpro129_alffPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint078.templeft
rsfMRI_fcnxpro129_perafPoint078_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint078.templeft
rsfMRI_fcnxpro129_falffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint079.templeft
rsfMRI_fcnxpro129_alffPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint079.templeft
rsfMRI_fcnxpro129_perafPoint079_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint079.templeft
rsfMRI_fcnxpro129_falffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint080.cingmleft
rsfMRI_fcnxpro129_alffPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint080.cingmleft
rsfMRI_fcnxpro129_perafPoint080_Cingmleft
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint080.cingmleft
rsfMRI_fcnxpro129_falffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint081.ipsleft
rsfMRI_fcnxpro129_alffPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint081.ipsleft
rsfMRI_fcnxpro129_perafPoint081_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint081.ipsleft
rsfMRI_fcnxpro129_falffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint082.ipsleft
rsfMRI_fcnxpro129_alffPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint082.ipsleft
rsfMRI_fcnxpro129_perafPoint082_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint082.ipsleft
rsfMRI_fcnxpro129_falffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint083.ipsleft
rsfMRI_fcnxpro129_alffPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint083.ipsleft
rsfMRI_fcnxpro129_perafPoint083_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint083.ipsleft
rsfMRI_fcnxpro129_falffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint084.ipsleft
rsfMRI_fcnxpro129_alffPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint084.ipsleft
rsfMRI_fcnxpro129_perafPoint084_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint084.ipsleft
rsfMRI_fcnxpro129_falffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint085.ipsleft
rsfMRI_fcnxpro129_alffPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint085.ipsleft
rsfMRI_fcnxpro129_perafPoint085_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint085.ipsleft
rsfMRI_fcnxpro129_falffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint086.pfcdleft
rsfMRI_fcnxpro129_alffPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint086.pfcdleft
rsfMRI_fcnxpro129_perafPoint086_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint086.pfcdleft
rsfMRI_fcnxpro129_falffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint087.pfclleft
rsfMRI_fcnxpro129_alffPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint087.pfclleft
rsfMRI_fcnxpro129_perafPoint087_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint087.pfclleft
rsfMRI_fcnxpro129_falffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint088.pfclleft
rsfMRI_fcnxpro129_alffPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint088.pfclleft
rsfMRI_fcnxpro129_perafPoint088_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint088.pfclleft
rsfMRI_fcnxpro129_falffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint089.pfclleft
rsfMRI_fcnxpro129_alffPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint089.pfclleft
rsfMRI_fcnxpro129_perafPoint089_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint089.pfclleft
rsfMRI_fcnxpro129_falffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint090.pfclleft
rsfMRI_fcnxpro129_alffPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint090.pfclleft
rsfMRI_fcnxpro129_perafPoint090_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint090.pfclleft
rsfMRI_fcnxpro129_falffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint091.pfclleft
rsfMRI_fcnxpro129_alffPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint091.pfclleft
rsfMRI_fcnxpro129_perafPoint091_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint091.pfclleft
rsfMRI_fcnxpro129_falffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint092.pfclleft
rsfMRI_fcnxpro129_alffPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint092.pfclleft
rsfMRI_fcnxpro129_perafPoint092_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint092.pfclleft
rsfMRI_fcnxpro129_falffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint093.prcvleft
rsfMRI_fcnxpro129_alffPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint093.prcvleft
rsfMRI_fcnxpro129_perafPoint093_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint093.prcvleft
rsfMRI_fcnxpro129_falffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint094.prcvleft
rsfMRI_fcnxpro129_alffPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint094.prcvleft
rsfMRI_fcnxpro129_perafPoint094_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint094.prcvleft
rsfMRI_fcnxpro129_falffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint095.prcvleft
rsfMRI_fcnxpro129_alffPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint095.prcvleft
rsfMRI_fcnxpro129_perafPoint095_PrCvleft
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint095.prcvleft
rsfMRI_fcnxpro129_falffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint096.splleft
rsfMRI_fcnxpro129_alffPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint096.splleft
rsfMRI_fcnxpro129_perafPoint096_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint096.splleft
rsfMRI_fcnxpro129_falffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint097.tempoccleft
rsfMRI_fcnxpro129_alffPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint097.tempoccleft
rsfMRI_fcnxpro129_perafPoint097_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint097.tempoccleft
rsfMRI_fcnxpro129_falffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint098.insleft
rsfMRI_fcnxpro129_alffPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint098.insleft
rsfMRI_fcnxpro129_perafPoint098_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint098.insleft
rsfMRI_fcnxpro129_falffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint099.phcleft
rsfMRI_fcnxpro129_alffPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint099.phcleft
rsfMRI_fcnxpro129_perafPoint099_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint099.phcleft
rsfMRI_fcnxpro129_falffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint100.phcleft
rsfMRI_fcnxpro129_alffPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint100.phcleft
rsfMRI_fcnxpro129_perafPoint100_PHCleft
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint100.phcleft
rsfMRI_fcnxpro129_falffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint101.stleft
rsfMRI_fcnxpro129_alffPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint101.stleft
rsfMRI_fcnxpro129_perafPoint101_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint101.stleft
rsfMRI_fcnxpro129_falffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint102.temppoleleft
rsfMRI_fcnxpro129_alffPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint102.temppoleleft
rsfMRI_fcnxpro129_perafPoint102_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint102.temppoleleft
rsfMRI_fcnxpro129_falffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint103.temppoleleft
rsfMRI_fcnxpro129_alffPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint103.temppoleleft
rsfMRI_fcnxpro129_perafPoint103_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint103.temppoleleft
rsfMRI_fcnxpro129_falffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint104.temppoleleft
rsfMRI_fcnxpro129_alffPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint104.temppoleleft
rsfMRI_fcnxpro129_perafPoint104_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint104.temppoleleft
rsfMRI_fcnxpro129_falffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint105.temppoleleft
rsfMRI_fcnxpro129_alffPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint105.temppoleleft
rsfMRI_fcnxpro129_perafPoint105_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint105.temppoleleft
rsfMRI_fcnxpro129_falffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint106.temppoleleft
rsfMRI_fcnxpro129_alffPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint106.temppoleleft
rsfMRI_fcnxpro129_perafPoint106_TempPoleleft
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint106.temppoleleft
rsfMRI_fcnxpro129_falffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint107.templeft
rsfMRI_fcnxpro129_alffPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint107.templeft
rsfMRI_fcnxpro129_perafPoint107_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint107.templeft
rsfMRI_fcnxpro129_falffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint108.templeft
rsfMRI_fcnxpro129_alffPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint108.templeft
rsfMRI_fcnxpro129_perafPoint108_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint108.templeft
rsfMRI_fcnxpro129_falffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint109.templeft
rsfMRI_fcnxpro129_alffPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint109.templeft
rsfMRI_fcnxpro129_perafPoint109_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint109.templeft
rsfMRI_fcnxpro129_falffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint110.templeft
rsfMRI_fcnxpro129_alffPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint110.templeft
rsfMRI_fcnxpro129_perafPoint110_Templeft
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint110.templeft
rsfMRI_fcnxpro129_falffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint111.fpoleleft
rsfMRI_fcnxpro129_alffPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint111.fpoleleft
rsfMRI_fcnxpro129_perafPoint111_FPoleleft
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint111.fpoleleft
rsfMRI_fcnxpro129_falffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint112.ofcleft
rsfMRI_fcnxpro129_alffPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint112.ofcleft
rsfMRI_fcnxpro129_perafPoint112_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint112.ofcleft
rsfMRI_fcnxpro129_falffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint113.ofcleft
rsfMRI_fcnxpro129_alffPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint113.ofcleft
rsfMRI_fcnxpro129_perafPoint113_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint113.ofcleft
rsfMRI_fcnxpro129_falffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint114.ofcleft
rsfMRI_fcnxpro129_alffPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint114.ofcleft
rsfMRI_fcnxpro129_perafPoint114_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint114.ofcleft
rsfMRI_fcnxpro129_falffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint115.ofcleft
rsfMRI_fcnxpro129_alffPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint115.ofcleft
rsfMRI_fcnxpro129_perafPoint115_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint115.ofcleft
rsfMRI_fcnxpro129_falffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint116.ofcleft
rsfMRI_fcnxpro129_alffPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint116.ofcleft
rsfMRI_fcnxpro129_perafPoint116_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint116.ofcleft
rsfMRI_fcnxpro129_falffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint117.ofcleft
rsfMRI_fcnxpro129_alffPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint117.ofcleft
rsfMRI_fcnxpro129_perafPoint117_OFCleft
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint117.ofcleft
rsfMRI_fcnxpro129_falffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint118.pfcmleft
rsfMRI_fcnxpro129_alffPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint118.pfcmleft
rsfMRI_fcnxpro129_perafPoint118_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint118.pfcmleft
rsfMRI_fcnxpro129_falffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint119.pfcmleft
rsfMRI_fcnxpro129_alffPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint119.pfcmleft
rsfMRI_fcnxpro129_perafPoint119_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint119.pfcmleft
rsfMRI_fcnxpro129_falffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint120.frmedleft
rsfMRI_fcnxpro129_alffPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint120.frmedleft
rsfMRI_fcnxpro129_perafPoint120_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint120.frmedleft
rsfMRI_fcnxpro129_falffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint121.insleft
rsfMRI_fcnxpro129_alffPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint121.insleft
rsfMRI_fcnxpro129_perafPoint121_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint121.insleft
rsfMRI_fcnxpro129_falffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint122.insleft
rsfMRI_fcnxpro129_alffPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint122.insleft
rsfMRI_fcnxpro129_perafPoint122_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint122.insleft
rsfMRI_fcnxpro129_falffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint123.insleft
rsfMRI_fcnxpro129_alffPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint123.insleft
rsfMRI_fcnxpro129_perafPoint123_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint123.insleft
rsfMRI_fcnxpro129_falffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint124.pfclleft
rsfMRI_fcnxpro129_alffPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint124.pfclleft
rsfMRI_fcnxpro129_perafPoint124_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint124.pfclleft
rsfMRI_fcnxpro129_falffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint125.pfclleft
rsfMRI_fcnxpro129_alffPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint125.pfclleft
rsfMRI_fcnxpro129_perafPoint125_PFClleft
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint125.pfclleft
rsfMRI_fcnxpro129_falffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint126.pfcmleft
rsfMRI_fcnxpro129_alffPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint126.pfcmleft
rsfMRI_fcnxpro129_perafPoint126_PFCmleft
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint126.pfcmleft
rsfMRI_fcnxpro129_falffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint127.frmedleft
rsfMRI_fcnxpro129_alffPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint127.frmedleft
rsfMRI_fcnxpro129_perafPoint127_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint127.frmedleft
rsfMRI_fcnxpro129_falffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint128.frmedleft
rsfMRI_fcnxpro129_alffPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint128.frmedleft
rsfMRI_fcnxpro129_perafPoint128_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint128.frmedleft
rsfMRI_fcnxpro129_falffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint129.frmedleft
rsfMRI_fcnxpro129_alffPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint129.frmedleft
rsfMRI_fcnxpro129_perafPoint129_FrMedleft
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint129.frmedleft
rsfMRI_fcnxpro129_falffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint130.froperleft
rsfMRI_fcnxpro129_alffPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint130.froperleft
rsfMRI_fcnxpro129_perafPoint130_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint130.froperleft
rsfMRI_fcnxpro129_falffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint131.froperleft
rsfMRI_fcnxpro129_alffPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint131.froperleft
rsfMRI_fcnxpro129_perafPoint131_FrOperleft
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint131.froperleft
rsfMRI_fcnxpro129_falffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint132.iplleft
rsfMRI_fcnxpro129_alffPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint132.iplleft
rsfMRI_fcnxpro129_perafPoint132_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint132.iplleft
rsfMRI_fcnxpro129_falffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint133.iplleft
rsfMRI_fcnxpro129_alffPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint133.iplleft
rsfMRI_fcnxpro129_perafPoint133_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint133.iplleft
rsfMRI_fcnxpro129_falffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint134.insleft
rsfMRI_fcnxpro129_alffPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint134.insleft
rsfMRI_fcnxpro129_perafPoint134_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint134.insleft
rsfMRI_fcnxpro129_falffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint135.insleft
rsfMRI_fcnxpro129_alffPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint135.insleft
rsfMRI_fcnxpro129_perafPoint135_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint135.insleft
rsfMRI_fcnxpro129_falffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint136.insleft
rsfMRI_fcnxpro129_alffPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint136.insleft
rsfMRI_fcnxpro129_perafPoint136_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint136.insleft
rsfMRI_fcnxpro129_falffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint137.insleft
rsfMRI_fcnxpro129_alffPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint137.insleft
rsfMRI_fcnxpro129_perafPoint137_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint137.insleft
rsfMRI_fcnxpro129_falffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint138.insleft
rsfMRI_fcnxpro129_alffPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint138.insleft
rsfMRI_fcnxpro129_perafPoint138_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint138.insleft
rsfMRI_fcnxpro129_falffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint139.splleft
rsfMRI_fcnxpro129_alffPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint139.splleft
rsfMRI_fcnxpro129_perafPoint139_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint139.splleft
rsfMRI_fcnxpro129_falffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint140.splleft
rsfMRI_fcnxpro129_alffPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint140.splleft
rsfMRI_fcnxpro129_perafPoint140_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint140.splleft
rsfMRI_fcnxpro129_falffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint141.splleft
rsfMRI_fcnxpro129_alffPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint141.splleft
rsfMRI_fcnxpro129_perafPoint141_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint141.splleft
rsfMRI_fcnxpro129_falffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint142.iplleft
rsfMRI_fcnxpro129_alffPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint142.iplleft
rsfMRI_fcnxpro129_perafPoint142_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint142.iplleft
rsfMRI_fcnxpro129_falffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint143.iplleft
rsfMRI_fcnxpro129_alffPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint143.iplleft
rsfMRI_fcnxpro129_perafPoint143_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint143.iplleft
rsfMRI_fcnxpro129_falffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint144.pfcdleft
rsfMRI_fcnxpro129_alffPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint144.pfcdleft
rsfMRI_fcnxpro129_perafPoint144_PFCdleft
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint144.pfcdleft
rsfMRI_fcnxpro129_falffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint145.postcleft
rsfMRI_fcnxpro129_alffPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint145.postcleft
rsfMRI_fcnxpro129_perafPoint145_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint145.postcleft
rsfMRI_fcnxpro129_falffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint146.postcleft
rsfMRI_fcnxpro129_alffPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint146.postcleft
rsfMRI_fcnxpro129_perafPoint146_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint146.postcleft
rsfMRI_fcnxpro129_falffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint147.postcleft
rsfMRI_fcnxpro129_alffPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint147.postcleft
rsfMRI_fcnxpro129_perafPoint147_PostCleft
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint147.postcleft
rsfMRI_fcnxpro129_falffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint148.prcdleft
rsfMRI_fcnxpro129_alffPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint148.prcdleft
rsfMRI_fcnxpro129_perafPoint148_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint148.prcdleft
rsfMRI_fcnxpro129_falffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint149.prcdleft
rsfMRI_fcnxpro129_alffPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint149.prcdleft
rsfMRI_fcnxpro129_perafPoint149_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint149.prcdleft
rsfMRI_fcnxpro129_falffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint150.prcdleft
rsfMRI_fcnxpro129_alffPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint150.prcdleft
rsfMRI_fcnxpro129_perafPoint150_PrCdleft
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint150.prcdleft
rsfMRI_fcnxpro129_falffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint151.splleft
rsfMRI_fcnxpro129_alffPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint151.splleft
rsfMRI_fcnxpro129_perafPoint151_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint151.splleft
rsfMRI_fcnxpro129_falffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint152.splleft
rsfMRI_fcnxpro129_alffPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint152.splleft
rsfMRI_fcnxpro129_perafPoint152_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint152.splleft
rsfMRI_fcnxpro129_falffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint153.splleft
rsfMRI_fcnxpro129_alffPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint153.splleft
rsfMRI_fcnxpro129_perafPoint153_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint153.splleft
rsfMRI_fcnxpro129_falffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint154.splleft
rsfMRI_fcnxpro129_alffPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint154.splleft
rsfMRI_fcnxpro129_perafPoint154_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint154.splleft
rsfMRI_fcnxpro129_falffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint155.tempoccleft
rsfMRI_fcnxpro129_alffPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint155.tempoccleft
rsfMRI_fcnxpro129_perafPoint155_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint155.tempoccleft
rsfMRI_fcnxpro129_falffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint156.exstrleft
rsfMRI_fcnxpro129_alffPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint156.exstrleft
rsfMRI_fcnxpro129_perafPoint156_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint156.exstrleft
rsfMRI_fcnxpro129_falffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint157.exstrleft
rsfMRI_fcnxpro129_alffPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint157.exstrleft
rsfMRI_fcnxpro129_perafPoint157_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint157.exstrleft
rsfMRI_fcnxpro129_falffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint158.exstrleft
rsfMRI_fcnxpro129_alffPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint158.exstrleft
rsfMRI_fcnxpro129_perafPoint158_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint158.exstrleft
rsfMRI_fcnxpro129_falffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint159.exstrleft
rsfMRI_fcnxpro129_alffPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint159.exstrleft
rsfMRI_fcnxpro129_perafPoint159_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint159.exstrleft
rsfMRI_fcnxpro129_falffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint160.ipsleft
rsfMRI_fcnxpro129_alffPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint160.ipsleft
rsfMRI_fcnxpro129_perafPoint160_IPSleft
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint160.ipsleft
rsfMRI_fcnxpro129_falffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint161.splleft
rsfMRI_fcnxpro129_alffPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint161.splleft
rsfMRI_fcnxpro129_perafPoint161_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint161.splleft
rsfMRI_fcnxpro129_falffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint162.splleft
rsfMRI_fcnxpro129_alffPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint162.splleft
rsfMRI_fcnxpro129_perafPoint162_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint162.splleft
rsfMRI_fcnxpro129_falffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint163.splleft
rsfMRI_fcnxpro129_alffPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint163.splleft
rsfMRI_fcnxpro129_perafPoint163_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint163.splleft
rsfMRI_fcnxpro129_falffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint164.splleft
rsfMRI_fcnxpro129_alffPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint164.splleft
rsfMRI_fcnxpro129_perafPoint164_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint164.splleft
rsfMRI_fcnxpro129_falffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint165.splleft
rsfMRI_fcnxpro129_alffPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint165.splleft
rsfMRI_fcnxpro129_perafPoint165_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint165.splleft
rsfMRI_fcnxpro129_falffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint166.splleft
rsfMRI_fcnxpro129_alffPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint166.splleft
rsfMRI_fcnxpro129_perafPoint166_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint166.splleft
rsfMRI_fcnxpro129_falffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint167.tempoccleft
rsfMRI_fcnxpro129_alffPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint167.tempoccleft
rsfMRI_fcnxpro129_perafPoint167_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint167.tempoccleft
rsfMRI_fcnxpro129_falffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint168.tempoccleft
rsfMRI_fcnxpro129_alffPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint168.tempoccleft
rsfMRI_fcnxpro129_perafPoint168_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint168.tempoccleft
rsfMRI_fcnxpro129_falffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint169.tempoccleft
rsfMRI_fcnxpro129_alffPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint169.tempoccleft
rsfMRI_fcnxpro129_perafPoint169_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint169.tempoccleft
rsfMRI_fcnxpro129_falffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint170.tempoccleft
rsfMRI_fcnxpro129_alffPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint170.tempoccleft
rsfMRI_fcnxpro129_perafPoint170_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint170.tempoccleft
rsfMRI_fcnxpro129_falffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint171.tempoccleft
rsfMRI_fcnxpro129_alffPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint171.tempoccleft
rsfMRI_fcnxpro129_perafPoint171_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint171.tempoccleft
rsfMRI_fcnxpro129_falffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint172.tempoccleft
rsfMRI_fcnxpro129_alffPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint172.tempoccleft
rsfMRI_fcnxpro129_perafPoint172_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint172.tempoccleft
rsfMRI_fcnxpro129_falffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint173.tempoccleft
rsfMRI_fcnxpro129_alffPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint173.tempoccleft
rsfMRI_fcnxpro129_perafPoint173_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint173.tempoccleft
rsfMRI_fcnxpro129_falffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint174.tempoccleft
rsfMRI_fcnxpro129_alffPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint174.tempoccleft
rsfMRI_fcnxpro129_perafPoint174_TempOccleft
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint174.tempoccleft
rsfMRI_fcnxpro129_falffPoint175_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint175.1left
rsfMRI_fcnxpro129_alffPoint175_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint175.1left
rsfMRI_fcnxpro129_perafPoint175_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint175.1left
rsfMRI_fcnxpro129_falffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint176.2left
rsfMRI_fcnxpro129_alffPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint176.2left
rsfMRI_fcnxpro129_perafPoint176_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint176.2left
rsfMRI_fcnxpro129_falffPoint177_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint177.3left
rsfMRI_fcnxpro129_alffPoint177_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint177.3left
rsfMRI_fcnxpro129_perafPoint177_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint177.3left
rsfMRI_fcnxpro129_falffPoint178_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint178.4left
rsfMRI_fcnxpro129_alffPoint178_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint178.4left
rsfMRI_fcnxpro129_perafPoint178_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint178.4left
rsfMRI_fcnxpro129_falffPoint179_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint179.5left
rsfMRI_fcnxpro129_alffPoint179_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint179.5left
rsfMRI_fcnxpro129_perafPoint179_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint179.5left
rsfMRI_fcnxpro129_falffPoint180_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint180.6left
rsfMRI_fcnxpro129_alffPoint180_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint180.6left
rsfMRI_fcnxpro129_perafPoint180_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint180.6left
rsfMRI_fcnxpro129_falffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint181.iplleft
rsfMRI_fcnxpro129_alffPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint181.iplleft
rsfMRI_fcnxpro129_perafPoint181_IPLleft
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint181.iplleft
rsfMRI_fcnxpro129_falffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint182.insleft
rsfMRI_fcnxpro129_alffPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint182.insleft
rsfMRI_fcnxpro129_perafPoint182_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint182.insleft
rsfMRI_fcnxpro129_falffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint183.insleft
rsfMRI_fcnxpro129_alffPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint183.insleft
rsfMRI_fcnxpro129_perafPoint183_Insleft
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint183.insleft
rsfMRI_fcnxpro129_falffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint184.paroperleft
rsfMRI_fcnxpro129_alffPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint184.paroperleft
rsfMRI_fcnxpro129_perafPoint184_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint184.paroperleft
rsfMRI_fcnxpro129_falffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint185.paroperleft
rsfMRI_fcnxpro129_alffPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint185.paroperleft
rsfMRI_fcnxpro129_perafPoint185_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint185.paroperleft
rsfMRI_fcnxpro129_falffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint186.paroperleft
rsfMRI_fcnxpro129_alffPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint186.paroperleft
rsfMRI_fcnxpro129_perafPoint186_ParOperleft
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint186.paroperleft
rsfMRI_fcnxpro129_falffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint187.stleft
rsfMRI_fcnxpro129_alffPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint187.stleft
rsfMRI_fcnxpro129_perafPoint187_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint187.stleft
rsfMRI_fcnxpro129_falffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint188.stleft
rsfMRI_fcnxpro129_alffPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint188.stleft
rsfMRI_fcnxpro129_perafPoint188_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint188.stleft
rsfMRI_fcnxpro129_falffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint189.stleft
rsfMRI_fcnxpro129_alffPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint189.stleft
rsfMRI_fcnxpro129_perafPoint189_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint189.stleft
rsfMRI_fcnxpro129_falffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint190.stleft
rsfMRI_fcnxpro129_alffPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint190.stleft
rsfMRI_fcnxpro129_perafPoint190_STleft
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint190.stleft
rsfMRI_fcnxpro129_falffPoint191_1left
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint191.1left
rsfMRI_fcnxpro129_alffPoint191_1left
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint191.1left
rsfMRI_fcnxpro129_perafPoint191_1left
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint191.1left
rsfMRI_fcnxpro129_falffPoint192_10left
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint192.10left
rsfMRI_fcnxpro129_alffPoint192_10left
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint192.10left
rsfMRI_fcnxpro129_perafPoint192_10left
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint192.10left
rsfMRI_fcnxpro129_falffPoint193_11left
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint193.11left
rsfMRI_fcnxpro129_alffPoint193_11left
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint193.11left
rsfMRI_fcnxpro129_perafPoint193_11left
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint193.11left
rsfMRI_fcnxpro129_falffPoint194_12left
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint194.12left
rsfMRI_fcnxpro129_alffPoint194_12left
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint194.12left
rsfMRI_fcnxpro129_perafPoint194_12left
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint194.12left
rsfMRI_fcnxpro129_falffPoint195_13left
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint195.13left
rsfMRI_fcnxpro129_alffPoint195_13left
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint195.13left
rsfMRI_fcnxpro129_perafPoint195_13left
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint195.13left
rsfMRI_fcnxpro129_falffPoint196_14left
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint196.14left
rsfMRI_fcnxpro129_alffPoint196_14left
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint196.14left
rsfMRI_fcnxpro129_perafPoint196_14left
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint196.14left
rsfMRI_fcnxpro129_falffPoint197_15left
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint197.15left
rsfMRI_fcnxpro129_alffPoint197_15left
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint197.15left
rsfMRI_fcnxpro129_perafPoint197_15left
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint197.15left
rsfMRI_fcnxpro129_falffPoint198_16left
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint198.16left
rsfMRI_fcnxpro129_alffPoint198_16left
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint198.16left
rsfMRI_fcnxpro129_perafPoint198_16left
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint198.16left
rsfMRI_fcnxpro129_falffPoint199_17left
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint199.17left
rsfMRI_fcnxpro129_alffPoint199_17left
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint199.17left
rsfMRI_fcnxpro129_perafPoint199_17left
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint199.17left
rsfMRI_fcnxpro129_falffPoint200_18left
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint200.18left
rsfMRI_fcnxpro129_alffPoint200_18left
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint200.18left
rsfMRI_fcnxpro129_perafPoint200_18left
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint200.18left
rsfMRI_fcnxpro129_falffPoint201_19left
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint201.19left
rsfMRI_fcnxpro129_alffPoint201_19left
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint201.19left
rsfMRI_fcnxpro129_perafPoint201_19left
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint201.19left
rsfMRI_fcnxpro129_falffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint202.2left
rsfMRI_fcnxpro129_alffPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint202.2left
rsfMRI_fcnxpro129_perafPoint202_2left
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint202.2left
rsfMRI_fcnxpro129_falffPoint203_20left
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint203.20left
rsfMRI_fcnxpro129_alffPoint203_20left
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint203.20left
rsfMRI_fcnxpro129_perafPoint203_20left
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint203.20left
rsfMRI_fcnxpro129_falffPoint204_21left
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint204.21left
rsfMRI_fcnxpro129_alffPoint204_21left
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint204.21left
rsfMRI_fcnxpro129_perafPoint204_21left
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint204.21left
rsfMRI_fcnxpro129_falffPoint205_22left
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint205.22left
rsfMRI_fcnxpro129_alffPoint205_22left
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint205.22left
rsfMRI_fcnxpro129_perafPoint205_22left
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint205.22left
rsfMRI_fcnxpro129_falffPoint206_23left
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint206.23left
rsfMRI_fcnxpro129_alffPoint206_23left
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint206.23left
rsfMRI_fcnxpro129_perafPoint206_23left
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint206.23left
rsfMRI_fcnxpro129_falffPoint207_24left
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint207.24left
rsfMRI_fcnxpro129_alffPoint207_24left
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint207.24left
rsfMRI_fcnxpro129_perafPoint207_24left
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint207.24left
rsfMRI_fcnxpro129_falffPoint208_25left
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint208.25left
rsfMRI_fcnxpro129_alffPoint208_25left
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint208.25left
rsfMRI_fcnxpro129_perafPoint208_25left
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint208.25left
rsfMRI_fcnxpro129_falffPoint209_26left
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint209.26left
rsfMRI_fcnxpro129_alffPoint209_26left
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint209.26left
rsfMRI_fcnxpro129_perafPoint209_26left
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint209.26left
rsfMRI_fcnxpro129_falffPoint210_27left
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint210.27left
rsfMRI_fcnxpro129_alffPoint210_27left
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint210.27left
rsfMRI_fcnxpro129_perafPoint210_27left
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint210.27left
rsfMRI_fcnxpro129_falffPoint211_28left
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint211.28left
rsfMRI_fcnxpro129_alffPoint211_28left
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint211.28left
rsfMRI_fcnxpro129_perafPoint211_28left
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint211.28left
rsfMRI_fcnxpro129_falffPoint212_29left
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint212.29left
rsfMRI_fcnxpro129_alffPoint212_29left
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint212.29left
rsfMRI_fcnxpro129_perafPoint212_29left
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint212.29left
rsfMRI_fcnxpro129_falffPoint213_3left
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint213.3left
rsfMRI_fcnxpro129_alffPoint213_3left
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint213.3left
rsfMRI_fcnxpro129_perafPoint213_3left
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint213.3left
rsfMRI_fcnxpro129_falffPoint214_4left
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint214.4left
rsfMRI_fcnxpro129_alffPoint214_4left
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint214.4left
rsfMRI_fcnxpro129_perafPoint214_4left
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint214.4left
rsfMRI_fcnxpro129_falffPoint215_5left
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint215.5left
rsfMRI_fcnxpro129_alffPoint215_5left
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint215.5left
rsfMRI_fcnxpro129_perafPoint215_5left
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint215.5left
rsfMRI_fcnxpro129_falffPoint216_6left
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint216.6left
rsfMRI_fcnxpro129_alffPoint216_6left
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint216.6left
rsfMRI_fcnxpro129_perafPoint216_6left
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint216.6left
rsfMRI_fcnxpro129_falffPoint217_7left
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint217.7left
rsfMRI_fcnxpro129_alffPoint217_7left
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint217.7left
rsfMRI_fcnxpro129_perafPoint217_7left
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint217.7left
rsfMRI_fcnxpro129_falffPoint218_8left
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint218.8left
rsfMRI_fcnxpro129_alffPoint218_8left
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint218.8left
rsfMRI_fcnxpro129_perafPoint218_8left
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint218.8left
rsfMRI_fcnxpro129_falffPoint219_9left
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint219.9left
rsfMRI_fcnxpro129_alffPoint219_9left
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint219.9left
rsfMRI_fcnxpro129_perafPoint219_9left
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint219.9left
rsfMRI_fcnxpro129_falffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint220.splleft
rsfMRI_fcnxpro129_alffPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint220.splleft
rsfMRI_fcnxpro129_perafPoint220_SPLleft
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint220.splleft
rsfMRI_fcnxpro129_falffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint221.exstrleft
rsfMRI_fcnxpro129_alffPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint221.exstrleft
rsfMRI_fcnxpro129_perafPoint221_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint221.exstrleft
rsfMRI_fcnxpro129_falffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint222.exstrinfleft
rsfMRI_fcnxpro129_alffPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint222.exstrinfleft
rsfMRI_fcnxpro129_perafPoint222_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint222.exstrinfleft
rsfMRI_fcnxpro129_falffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint223.exstrinfleft
rsfMRI_fcnxpro129_alffPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint223.exstrinfleft
rsfMRI_fcnxpro129_perafPoint223_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint223.exstrinfleft
rsfMRI_fcnxpro129_falffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint224.exstrinfleft
rsfMRI_fcnxpro129_alffPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint224.exstrinfleft
rsfMRI_fcnxpro129_perafPoint224_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint224.exstrinfleft
rsfMRI_fcnxpro129_falffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint225.exstrinfleft
rsfMRI_fcnxpro129_alffPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint225.exstrinfleft
rsfMRI_fcnxpro129_perafPoint225_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint225.exstrinfleft
rsfMRI_fcnxpro129_falffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint226.exstrinfleft
rsfMRI_fcnxpro129_alffPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint226.exstrinfleft
rsfMRI_fcnxpro129_perafPoint226_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint226.exstrinfleft
rsfMRI_fcnxpro129_falffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint227.exstrsupleft
rsfMRI_fcnxpro129_alffPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint227.exstrsupleft
rsfMRI_fcnxpro129_perafPoint227_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint227.exstrsupleft
rsfMRI_fcnxpro129_falffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint228.exstrsupleft
rsfMRI_fcnxpro129_alffPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint228.exstrsupleft
rsfMRI_fcnxpro129_perafPoint228_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint228.exstrsupleft
rsfMRI_fcnxpro129_falffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint229.exstrsupleft
rsfMRI_fcnxpro129_alffPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint229.exstrsupleft
rsfMRI_fcnxpro129_perafPoint229_ExStrSupleft
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint229.exstrsupleft
rsfMRI_fcnxpro129_falffPoint230_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint230.striateleft
rsfMRI_fcnxpro129_alffPoint230_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint230.striateleft
rsfMRI_fcnxpro129_perafPoint230_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint230.striateleft
rsfMRI_fcnxpro129_falffPoint231_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint231.striateleft
rsfMRI_fcnxpro129_alffPoint231_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint231.striateleft
rsfMRI_fcnxpro129_perafPoint231_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint231.striateleft
rsfMRI_fcnxpro129_falffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint232.exstrinfleft
rsfMRI_fcnxpro129_alffPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint232.exstrinfleft
rsfMRI_fcnxpro129_perafPoint232_ExStrInfleft
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint232.exstrinfleft
rsfMRI_fcnxpro129_falffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint233.exstrleft
rsfMRI_fcnxpro129_alffPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint233.exstrleft
rsfMRI_fcnxpro129_perafPoint233_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint233.exstrleft
rsfMRI_fcnxpro129_falffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint234.exstrleft
rsfMRI_fcnxpro129_alffPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint234.exstrleft
rsfMRI_fcnxpro129_perafPoint234_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint234.exstrleft
rsfMRI_fcnxpro129_falffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint235.exstrleft
rsfMRI_fcnxpro129_alffPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint235.exstrleft
rsfMRI_fcnxpro129_perafPoint235_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint235.exstrleft
rsfMRI_fcnxpro129_falffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint236.exstrleft
rsfMRI_fcnxpro129_alffPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint236.exstrleft
rsfMRI_fcnxpro129_perafPoint236_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint236.exstrleft
rsfMRI_fcnxpro129_falffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint237.exstrleft
rsfMRI_fcnxpro129_alffPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint237.exstrleft
rsfMRI_fcnxpro129_perafPoint237_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint237.exstrleft
rsfMRI_fcnxpro129_falffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint238.exstrleft
rsfMRI_fcnxpro129_alffPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint238.exstrleft
rsfMRI_fcnxpro129_perafPoint238_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint238.exstrleft
rsfMRI_fcnxpro129_falffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint239.exstrleft
rsfMRI_fcnxpro129_alffPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint239.exstrleft
rsfMRI_fcnxpro129_perafPoint239_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint239.exstrleft
rsfMRI_fcnxpro129_falffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint240.exstrleft
rsfMRI_fcnxpro129_alffPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint240.exstrleft
rsfMRI_fcnxpro129_perafPoint240_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint240.exstrleft
rsfMRI_fcnxpro129_falffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint241.exstrleft
rsfMRI_fcnxpro129_alffPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint241.exstrleft
rsfMRI_fcnxpro129_perafPoint241_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint241.exstrleft
rsfMRI_fcnxpro129_falffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint242.exstrleft
rsfMRI_fcnxpro129_alffPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint242.exstrleft
rsfMRI_fcnxpro129_perafPoint242_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint242.exstrleft
rsfMRI_fcnxpro129_falffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint243.exstrleft
rsfMRI_fcnxpro129_alffPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint243.exstrleft
rsfMRI_fcnxpro129_perafPoint243_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint243.exstrleft
rsfMRI_fcnxpro129_falffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint244.exstrleft
rsfMRI_fcnxpro129_alffPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint244.exstrleft
rsfMRI_fcnxpro129_perafPoint244_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint244.exstrleft
rsfMRI_fcnxpro129_falffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint245.exstrleft
rsfMRI_fcnxpro129_alffPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint245.exstrleft
rsfMRI_fcnxpro129_perafPoint245_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint245.exstrleft
rsfMRI_fcnxpro129_falffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint246.exstrleft
rsfMRI_fcnxpro129_alffPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint246.exstrleft
rsfMRI_fcnxpro129_perafPoint246_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint246.exstrleft
rsfMRI_fcnxpro129_falffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint247.exstrleft
rsfMRI_fcnxpro129_alffPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint247.exstrleft
rsfMRI_fcnxpro129_perafPoint247_ExStrleft
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint247.exstrleft
rsfMRI_fcnxpro129_falffPoint248_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint248.striateleft
rsfMRI_fcnxpro129_alffPoint248_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint248.striateleft
rsfMRI_fcnxpro129_perafPoint248_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint248.striateleft
rsfMRI_fcnxpro129_falffPoint249_Striateleft
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint249.striateleft
rsfMRI_fcnxpro129_alffPoint249_Striateleft
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint249.striateleft
rsfMRI_fcnxpro129_perafPoint249_Striateleft
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint249.striateleft
rsfMRI_fcnxpro129_falffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint250.iplright
rsfMRI_fcnxpro129_alffPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint250.iplright
rsfMRI_fcnxpro129_perafPoint250_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint250.iplright
rsfMRI_fcnxpro129_falffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint251.stright
rsfMRI_fcnxpro129_alffPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint251.stright
rsfMRI_fcnxpro129_perafPoint251_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint251.stright
rsfMRI_fcnxpro129_falffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint252.stright
rsfMRI_fcnxpro129_alffPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint252.stright
rsfMRI_fcnxpro129_perafPoint252_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint252.stright
rsfMRI_fcnxpro129_falffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint253.tempoccright
rsfMRI_fcnxpro129_alffPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint253.tempoccright
rsfMRI_fcnxpro129_perafPoint253_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint253.tempoccright
rsfMRI_fcnxpro129_falffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint254.tempright
rsfMRI_fcnxpro129_alffPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint254.tempright
rsfMRI_fcnxpro129_perafPoint254_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint254.tempright
rsfMRI_fcnxpro129_falffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint255.tempright
rsfMRI_fcnxpro129_alffPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint255.tempright
rsfMRI_fcnxpro129_perafPoint255_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint255.tempright
rsfMRI_fcnxpro129_falffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint256.exstrinfright
rsfMRI_fcnxpro129_alffPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint256.exstrinfright
rsfMRI_fcnxpro129_perafPoint256_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint256.exstrinfright
rsfMRI_fcnxpro129_falffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint257.iplright
rsfMRI_fcnxpro129_alffPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint257.iplright
rsfMRI_fcnxpro129_perafPoint257_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint257.iplright
rsfMRI_fcnxpro129_falffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint258.phcright
rsfMRI_fcnxpro129_alffPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint258.phcright
rsfMRI_fcnxpro129_perafPoint258_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint258.phcright
rsfMRI_fcnxpro129_falffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint259.phcright
rsfMRI_fcnxpro129_alffPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint259.phcright
rsfMRI_fcnxpro129_perafPoint259_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint259.phcright
rsfMRI_fcnxpro129_falffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint260.phcright
rsfMRI_fcnxpro129_alffPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint260.phcright
rsfMRI_fcnxpro129_perafPoint260_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint260.phcright
rsfMRI_fcnxpro129_falffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint261.rscright
rsfMRI_fcnxpro129_alffPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint261.rscright
rsfMRI_fcnxpro129_perafPoint261_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint261.rscright
rsfMRI_fcnxpro129_falffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint262.rscright
rsfMRI_fcnxpro129_alffPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint262.rscright
rsfMRI_fcnxpro129_perafPoint262_RSCright
Unknown Core: rsc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint262.rscright
rsfMRI_fcnxpro129_falffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint263.iplright
rsfMRI_fcnxpro129_alffPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint263.iplright
rsfMRI_fcnxpro129_perafPoint263_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint263.iplright
rsfMRI_fcnxpro129_falffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint264.iplright
rsfMRI_fcnxpro129_alffPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint264.iplright
rsfMRI_fcnxpro129_perafPoint264_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint264.iplright
rsfMRI_fcnxpro129_falffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint265.iplright
rsfMRI_fcnxpro129_alffPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint265.iplright
rsfMRI_fcnxpro129_perafPoint265_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint265.iplright
rsfMRI_fcnxpro129_falffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint266.iplright
rsfMRI_fcnxpro129_alffPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint266.iplright
rsfMRI_fcnxpro129_perafPoint266_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint266.iplright
rsfMRI_fcnxpro129_falffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint000.pfcdright
rsfMRI_fcnxpro129_alffPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint000.pfcdright
rsfMRI_fcnxpro129_perafPoint000_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint000.pfcdright
rsfMRI_fcnxpro129_falffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint001.pfcdright
rsfMRI_fcnxpro129_alffPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint001.pfcdright
rsfMRI_fcnxpro129_perafPoint001_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint001.pfcdright
rsfMRI_fcnxpro129_falffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint002.pfcdright
rsfMRI_fcnxpro129_alffPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint002.pfcdright
rsfMRI_fcnxpro129_perafPoint002_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint002.pfcdright
rsfMRI_fcnxpro129_falffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint003.pfcdright
rsfMRI_fcnxpro129_alffPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint003.pfcdright
rsfMRI_fcnxpro129_perafPoint003_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint003.pfcdright
rsfMRI_fcnxpro129_falffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint004.pfcdright
rsfMRI_fcnxpro129_alffPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint004.pfcdright
rsfMRI_fcnxpro129_perafPoint004_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint004.pfcdright
rsfMRI_fcnxpro129_falffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint005.pfcdright
rsfMRI_fcnxpro129_alffPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint005.pfcdright
rsfMRI_fcnxpro129_perafPoint005_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint005.pfcdright
rsfMRI_fcnxpro129_falffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint006.pfcdright
rsfMRI_fcnxpro129_alffPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint006.pfcdright
rsfMRI_fcnxpro129_perafPoint006_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint006.pfcdright
rsfMRI_fcnxpro129_falffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint007.pfclright
rsfMRI_fcnxpro129_alffPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint007.pfclright
rsfMRI_fcnxpro129_perafPoint007_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint007.pfclright
rsfMRI_fcnxpro129_falffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint008.pfclright
rsfMRI_fcnxpro129_alffPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint008.pfclright
rsfMRI_fcnxpro129_perafPoint008_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint008.pfclright
rsfMRI_fcnxpro129_falffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint009.pfcvright
rsfMRI_fcnxpro129_alffPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint009.pfcvright
rsfMRI_fcnxpro129_perafPoint009_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint009.pfcvright
rsfMRI_fcnxpro129_falffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint010.pfcvright
rsfMRI_fcnxpro129_alffPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint010.pfcvright
rsfMRI_fcnxpro129_perafPoint010_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint010.pfcvright
rsfMRI_fcnxpro129_falffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint011.pfcvright
rsfMRI_fcnxpro129_alffPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint011.pfcvright
rsfMRI_fcnxpro129_perafPoint011_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint011.pfcvright
rsfMRI_fcnxpro129_falffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint012.pfcvright
rsfMRI_fcnxpro129_alffPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint012.pfcvright
rsfMRI_fcnxpro129_perafPoint012_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint012.pfcvright
rsfMRI_fcnxpro129_falffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint013.temppoleright
rsfMRI_fcnxpro129_alffPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint013.temppoleright
rsfMRI_fcnxpro129_perafPoint013_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint013.temppoleright
rsfMRI_fcnxpro129_falffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint014.tempright
rsfMRI_fcnxpro129_alffPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint014.tempright
rsfMRI_fcnxpro129_perafPoint014_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint014.tempright
rsfMRI_fcnxpro129_falffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint015.tempright
rsfMRI_fcnxpro129_alffPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint015.tempright
rsfMRI_fcnxpro129_perafPoint015_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint015.tempright
rsfMRI_fcnxpro129_falffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint016.tempright
rsfMRI_fcnxpro129_alffPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint016.tempright
rsfMRI_fcnxpro129_perafPoint016_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint016.tempright
rsfMRI_fcnxpro129_falffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint017.tempright
rsfMRI_fcnxpro129_alffPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint017.tempright
rsfMRI_fcnxpro129_perafPoint017_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint017.tempright
rsfMRI_fcnxpro129_falffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint018.tempright
rsfMRI_fcnxpro129_alffPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint018.tempright
rsfMRI_fcnxpro129_perafPoint018_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint018.tempright
rsfMRI_fcnxpro129_falffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint019.tempright
rsfMRI_fcnxpro129_alffPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint019.tempright
rsfMRI_fcnxpro129_perafPoint019_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint019.tempright
rsfMRI_fcnxpro129_falffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint020.tempright
rsfMRI_fcnxpro129_alffPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint020.tempright
rsfMRI_fcnxpro129_perafPoint020_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint020.tempright
rsfMRI_fcnxpro129_falffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint021.tempright
rsfMRI_fcnxpro129_alffPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint021.tempright
rsfMRI_fcnxpro129_perafPoint021_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint021.tempright
rsfMRI_fcnxpro129_falffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint022.tempright
rsfMRI_fcnxpro129_alffPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint022.tempright
rsfMRI_fcnxpro129_perafPoint022_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint022.tempright
rsfMRI_fcnxpro129_falffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint023.tempright
rsfMRI_fcnxpro129_alffPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint023.tempright
rsfMRI_fcnxpro129_perafPoint023_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint023.tempright
rsfMRI_fcnxpro129_falffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint024.fpoleright
rsfMRI_fcnxpro129_alffPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint024.fpoleright
rsfMRI_fcnxpro129_perafPoint024_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint024.fpoleright
rsfMRI_fcnxpro129_falffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint025.iplright
rsfMRI_fcnxpro129_alffPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint025.iplright
rsfMRI_fcnxpro129_perafPoint025_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint025.iplright
rsfMRI_fcnxpro129_falffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint026.iplright
rsfMRI_fcnxpro129_alffPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint026.iplright
rsfMRI_fcnxpro129_perafPoint026_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint026.iplright
rsfMRI_fcnxpro129_falffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint027.iplright
rsfMRI_fcnxpro129_alffPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint027.iplright
rsfMRI_fcnxpro129_perafPoint027_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint027.iplright
rsfMRI_fcnxpro129_falffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint028.pccright
rsfMRI_fcnxpro129_alffPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint028.pccright
rsfMRI_fcnxpro129_perafPoint028_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint028.pccright
rsfMRI_fcnxpro129_falffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint029.pccright
rsfMRI_fcnxpro129_alffPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint029.pccright
rsfMRI_fcnxpro129_perafPoint029_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint029.pccright
rsfMRI_fcnxpro129_falffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint030.pccright
rsfMRI_fcnxpro129_alffPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint030.pccright
rsfMRI_fcnxpro129_perafPoint030_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint030.pccright
rsfMRI_fcnxpro129_falffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint031.pccright
rsfMRI_fcnxpro129_alffPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint031.pccright
rsfMRI_fcnxpro129_perafPoint031_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint031.pccright
rsfMRI_fcnxpro129_falffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint032.pccright
rsfMRI_fcnxpro129_alffPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint032.pccright
rsfMRI_fcnxpro129_perafPoint032_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint032.pccright
rsfMRI_fcnxpro129_falffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint033.pccright
rsfMRI_fcnxpro129_alffPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint033.pccright
rsfMRI_fcnxpro129_perafPoint033_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint033.pccright
rsfMRI_fcnxpro129_falffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint034.pccright
rsfMRI_fcnxpro129_alffPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint034.pccright
rsfMRI_fcnxpro129_perafPoint034_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint034.pccright
rsfMRI_fcnxpro129_falffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint035.pfcdright
rsfMRI_fcnxpro129_alffPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint035.pfcdright
rsfMRI_fcnxpro129_perafPoint035_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint035.pfcdright
rsfMRI_fcnxpro129_falffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint036.pfcdright
rsfMRI_fcnxpro129_alffPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint036.pfcdright
rsfMRI_fcnxpro129_perafPoint036_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint036.pfcdright
rsfMRI_fcnxpro129_falffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint037.pfcdright
rsfMRI_fcnxpro129_alffPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint037.pfcdright
rsfMRI_fcnxpro129_perafPoint037_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint037.pfcdright
rsfMRI_fcnxpro129_falffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint038.pfcdright
rsfMRI_fcnxpro129_alffPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint038.pfcdright
rsfMRI_fcnxpro129_perafPoint038_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint038.pfcdright
rsfMRI_fcnxpro129_falffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint039.pfcmright
rsfMRI_fcnxpro129_alffPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint039.pfcmright
rsfMRI_fcnxpro129_perafPoint039_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint039.pfcmright
rsfMRI_fcnxpro129_falffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint040.pfcmright
rsfMRI_fcnxpro129_alffPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint040.pfcmright
rsfMRI_fcnxpro129_perafPoint040_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint040.pfcmright
rsfMRI_fcnxpro129_falffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint041.pfcmright
rsfMRI_fcnxpro129_alffPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint041.pfcmright
rsfMRI_fcnxpro129_perafPoint041_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint041.pfcmright
rsfMRI_fcnxpro129_falffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint042.pfcmright
rsfMRI_fcnxpro129_alffPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint042.pfcmright
rsfMRI_fcnxpro129_perafPoint042_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint042.pfcmright
rsfMRI_fcnxpro129_falffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint043.pfcmright
rsfMRI_fcnxpro129_alffPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint043.pfcmright
rsfMRI_fcnxpro129_perafPoint043_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint043.pfcmright
rsfMRI_fcnxpro129_falffPoint044_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint044.pcunright
rsfMRI_fcnxpro129_alffPoint044_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint044.pcunright
rsfMRI_fcnxpro129_perafPoint044_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint044.pcunright
rsfMRI_fcnxpro129_falffPoint045_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint045.pcunright
rsfMRI_fcnxpro129_alffPoint045_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint045.pcunright
rsfMRI_fcnxpro129_perafPoint045_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint045.pcunright
rsfMRI_fcnxpro129_falffPoint046_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint046.pcunright
rsfMRI_fcnxpro129_alffPoint046_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint046.pcunright
rsfMRI_fcnxpro129_perafPoint046_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint046.pcunright
rsfMRI_fcnxpro129_falffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint047.pccright
rsfMRI_fcnxpro129_alffPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint047.pccright
rsfMRI_fcnxpro129_perafPoint047_PCCright
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint047.pccright
rsfMRI_fcnxpro129_falffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint048.splright
rsfMRI_fcnxpro129_alffPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint048.splright
rsfMRI_fcnxpro129_perafPoint048_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint048.splright
rsfMRI_fcnxpro129_falffPoint049_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint049.pcunright
rsfMRI_fcnxpro129_alffPoint049_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint049.pcunright
rsfMRI_fcnxpro129_perafPoint049_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint049.pcunright
rsfMRI_fcnxpro129_falffPoint050_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint050.pcunright
rsfMRI_fcnxpro129_alffPoint050_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint050.pcunright
rsfMRI_fcnxpro129_perafPoint050_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint050.pcunright
rsfMRI_fcnxpro129_falffPoint051_pCunright
Precuneus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint051.pcunright
rsfMRI_fcnxpro129_alffPoint051_pCunright
Precuneus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint051.pcunright
rsfMRI_fcnxpro129_perafPoint051_pCunright
Precuneus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint051.pcunright
rsfMRI_fcnxpro129_falffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint052.fpoleright
rsfMRI_fcnxpro129_alffPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint052.fpoleright
rsfMRI_fcnxpro129_perafPoint052_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint052.fpoleright
rsfMRI_fcnxpro129_falffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint053.fpoleright
rsfMRI_fcnxpro129_alffPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint053.fpoleright
rsfMRI_fcnxpro129_perafPoint053_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint053.fpoleright
rsfMRI_fcnxpro129_falffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint054.frmedright
rsfMRI_fcnxpro129_alffPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint054.frmedright
rsfMRI_fcnxpro129_perafPoint054_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint054.frmedright
rsfMRI_fcnxpro129_falffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint055.iplright
rsfMRI_fcnxpro129_alffPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint055.iplright
rsfMRI_fcnxpro129_perafPoint055_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint055.iplright
rsfMRI_fcnxpro129_falffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint056.ipsright
rsfMRI_fcnxpro129_alffPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint056.ipsright
rsfMRI_fcnxpro129_perafPoint056_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint056.ipsright
rsfMRI_fcnxpro129_falffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint057.ipsright
rsfMRI_fcnxpro129_alffPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint057.ipsright
rsfMRI_fcnxpro129_perafPoint057_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint057.ipsright
rsfMRI_fcnxpro129_falffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint058.pfcdright
rsfMRI_fcnxpro129_alffPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint058.pfcdright
rsfMRI_fcnxpro129_perafPoint058_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint058.pfcdright
rsfMRI_fcnxpro129_falffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint059.pfclright
rsfMRI_fcnxpro129_alffPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint059.pfclright
rsfMRI_fcnxpro129_perafPoint059_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint059.pfclright
rsfMRI_fcnxpro129_falffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint060.pfcvright
rsfMRI_fcnxpro129_alffPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint060.pfcvright
rsfMRI_fcnxpro129_perafPoint060_PFCvright
Ventral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint060.pfcvright
rsfMRI_fcnxpro129_falffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint061.tempright
rsfMRI_fcnxpro129_alffPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint061.tempright
rsfMRI_fcnxpro129_perafPoint061_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint061.tempright
rsfMRI_fcnxpro129_falffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint062.tempright
rsfMRI_fcnxpro129_alffPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint062.tempright
rsfMRI_fcnxpro129_perafPoint062_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint062.tempright
rsfMRI_fcnxpro129_falffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint063.cingmright
rsfMRI_fcnxpro129_alffPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint063.cingmright
rsfMRI_fcnxpro129_perafPoint063_Cingmright
Unknown Core: cingm
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint063.cingmright
rsfMRI_fcnxpro129_falffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint064.ipsright
rsfMRI_fcnxpro129_alffPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint064.ipsright
rsfMRI_fcnxpro129_perafPoint064_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint064.ipsright
rsfMRI_fcnxpro129_falffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint065.ipsright
rsfMRI_fcnxpro129_alffPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint065.ipsright
rsfMRI_fcnxpro129_perafPoint065_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint065.ipsright
rsfMRI_fcnxpro129_falffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint066.ipsright
rsfMRI_fcnxpro129_alffPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint066.ipsright
rsfMRI_fcnxpro129_perafPoint066_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint066.ipsright
rsfMRI_fcnxpro129_falffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint067.ipsright
rsfMRI_fcnxpro129_alffPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint067.ipsright
rsfMRI_fcnxpro129_perafPoint067_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint067.ipsright
rsfMRI_fcnxpro129_falffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint068.ipsright
rsfMRI_fcnxpro129_alffPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint068.ipsright
rsfMRI_fcnxpro129_perafPoint068_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint068.ipsright
rsfMRI_fcnxpro129_falffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint069.pfcdright
rsfMRI_fcnxpro129_alffPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint069.pfcdright
rsfMRI_fcnxpro129_perafPoint069_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint069.pfcdright
rsfMRI_fcnxpro129_falffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint070.pfclright
rsfMRI_fcnxpro129_alffPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint070.pfclright
rsfMRI_fcnxpro129_perafPoint070_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint070.pfclright
rsfMRI_fcnxpro129_falffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint071.pfclright
rsfMRI_fcnxpro129_alffPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint071.pfclright
rsfMRI_fcnxpro129_perafPoint071_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint071.pfclright
rsfMRI_fcnxpro129_falffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint072.pfclright
rsfMRI_fcnxpro129_alffPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint072.pfclright
rsfMRI_fcnxpro129_perafPoint072_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint072.pfclright
rsfMRI_fcnxpro129_falffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint073.pfclright
rsfMRI_fcnxpro129_alffPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint073.pfclright
rsfMRI_fcnxpro129_perafPoint073_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint073.pfclright
rsfMRI_fcnxpro129_falffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint074.pfclright
rsfMRI_fcnxpro129_alffPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint074.pfclright
rsfMRI_fcnxpro129_perafPoint074_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint074.pfclright
rsfMRI_fcnxpro129_falffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint075.pfclright
rsfMRI_fcnxpro129_alffPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint075.pfclright
rsfMRI_fcnxpro129_perafPoint075_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint075.pfclright
rsfMRI_fcnxpro129_falffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint076.prcvright
rsfMRI_fcnxpro129_alffPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint076.prcvright
rsfMRI_fcnxpro129_perafPoint076_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint076.prcvright
rsfMRI_fcnxpro129_falffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint077.prcvright
rsfMRI_fcnxpro129_alffPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint077.prcvright
rsfMRI_fcnxpro129_perafPoint077_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint077.prcvright
rsfMRI_fcnxpro129_falffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint078.prcvright
rsfMRI_fcnxpro129_alffPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint078.prcvright
rsfMRI_fcnxpro129_perafPoint078_PrCvright
Unknown Core: prcv
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint078.prcvright
rsfMRI_fcnxpro129_falffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint079.splright
rsfMRI_fcnxpro129_alffPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint079.splright
rsfMRI_fcnxpro129_perafPoint079_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint079.splright
rsfMRI_fcnxpro129_falffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint080.tempoccright
rsfMRI_fcnxpro129_alffPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint080.tempoccright
rsfMRI_fcnxpro129_perafPoint080_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint080.tempoccright
rsfMRI_fcnxpro129_falffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint081.insright
rsfMRI_fcnxpro129_alffPoint081_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint081.insright
rsfMRI_fcnxpro129_perafPoint081_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint081.insright
rsfMRI_fcnxpro129_falffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint082.phcright
rsfMRI_fcnxpro129_alffPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint082.phcright
rsfMRI_fcnxpro129_perafPoint082_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint082.phcright
rsfMRI_fcnxpro129_falffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint083.phcright
rsfMRI_fcnxpro129_alffPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint083.phcright
rsfMRI_fcnxpro129_perafPoint083_PHCright
Parahippocampal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint083.phcright
rsfMRI_fcnxpro129_falffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint084.stright
rsfMRI_fcnxpro129_alffPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint084.stright
rsfMRI_fcnxpro129_perafPoint084_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint084.stright
rsfMRI_fcnxpro129_falffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint085.temppoleright
rsfMRI_fcnxpro129_alffPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint085.temppoleright
rsfMRI_fcnxpro129_perafPoint085_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint085.temppoleright
rsfMRI_fcnxpro129_falffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint086.temppoleright
rsfMRI_fcnxpro129_alffPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint086.temppoleright
rsfMRI_fcnxpro129_perafPoint086_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint086.temppoleright
rsfMRI_fcnxpro129_falffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint087.temppoleright
rsfMRI_fcnxpro129_alffPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint087.temppoleright
rsfMRI_fcnxpro129_perafPoint087_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint087.temppoleright
rsfMRI_fcnxpro129_falffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint088.temppoleright
rsfMRI_fcnxpro129_alffPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint088.temppoleright
rsfMRI_fcnxpro129_perafPoint088_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint088.temppoleright
rsfMRI_fcnxpro129_falffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint089.temppoleright
rsfMRI_fcnxpro129_alffPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint089.temppoleright
rsfMRI_fcnxpro129_perafPoint089_TempPoleright
Temporal Pole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint089.temppoleright
rsfMRI_fcnxpro129_falffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint090.tempright
rsfMRI_fcnxpro129_alffPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint090.tempright
rsfMRI_fcnxpro129_perafPoint090_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint090.tempright
rsfMRI_fcnxpro129_falffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint091.tempright
rsfMRI_fcnxpro129_alffPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint091.tempright
rsfMRI_fcnxpro129_perafPoint091_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint091.tempright
rsfMRI_fcnxpro129_falffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint092.tempright
rsfMRI_fcnxpro129_alffPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint092.tempright
rsfMRI_fcnxpro129_perafPoint092_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint092.tempright
rsfMRI_fcnxpro129_falffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint093.tempright
rsfMRI_fcnxpro129_alffPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint093.tempright
rsfMRI_fcnxpro129_perafPoint093_Tempright
Unknown Core: temp
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint093.tempright
rsfMRI_fcnxpro129_falffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint094.fpoleright
rsfMRI_fcnxpro129_alffPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint094.fpoleright
rsfMRI_fcnxpro129_perafPoint094_FPoleright
Unknown Core: fpole
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint094.fpoleright
rsfMRI_fcnxpro129_falffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint095.ofcright
rsfMRI_fcnxpro129_alffPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint095.ofcright
rsfMRI_fcnxpro129_perafPoint095_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint095.ofcright
rsfMRI_fcnxpro129_falffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint096.ofcright
rsfMRI_fcnxpro129_alffPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint096.ofcright
rsfMRI_fcnxpro129_perafPoint096_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint096.ofcright
rsfMRI_fcnxpro129_falffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint097.ofcright
rsfMRI_fcnxpro129_alffPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint097.ofcright
rsfMRI_fcnxpro129_perafPoint097_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint097.ofcright
rsfMRI_fcnxpro129_falffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint098.ofcright
rsfMRI_fcnxpro129_alffPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint098.ofcright
rsfMRI_fcnxpro129_perafPoint098_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint098.ofcright
rsfMRI_fcnxpro129_falffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint099.ofcright
rsfMRI_fcnxpro129_alffPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint099.ofcright
rsfMRI_fcnxpro129_perafPoint099_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint099.ofcright
rsfMRI_fcnxpro129_falffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint100.ofcright
rsfMRI_fcnxpro129_alffPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint100.ofcright
rsfMRI_fcnxpro129_perafPoint100_OFCright
Unknown Core: ofc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint100.ofcright
rsfMRI_fcnxpro129_falffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint101.pfcmright
rsfMRI_fcnxpro129_alffPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint101.pfcmright
rsfMRI_fcnxpro129_perafPoint101_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint101.pfcmright
rsfMRI_fcnxpro129_falffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint102.pfcmright
rsfMRI_fcnxpro129_alffPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint102.pfcmright
rsfMRI_fcnxpro129_perafPoint102_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint102.pfcmright
rsfMRI_fcnxpro129_falffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint103.frmedright
rsfMRI_fcnxpro129_alffPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint103.frmedright
rsfMRI_fcnxpro129_perafPoint103_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint103.frmedright
rsfMRI_fcnxpro129_falffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint104.insright
rsfMRI_fcnxpro129_alffPoint104_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint104.insright
rsfMRI_fcnxpro129_perafPoint104_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint104.insright
rsfMRI_fcnxpro129_falffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint105.insright
rsfMRI_fcnxpro129_alffPoint105_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint105.insright
rsfMRI_fcnxpro129_perafPoint105_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint105.insright
rsfMRI_fcnxpro129_falffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint106.insright
rsfMRI_fcnxpro129_alffPoint106_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint106.insright
rsfMRI_fcnxpro129_perafPoint106_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint106.insright
rsfMRI_fcnxpro129_falffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint107.pfclright
rsfMRI_fcnxpro129_alffPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint107.pfclright
rsfMRI_fcnxpro129_perafPoint107_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint107.pfclright
rsfMRI_fcnxpro129_falffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint108.pfclright
rsfMRI_fcnxpro129_alffPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint108.pfclright
rsfMRI_fcnxpro129_perafPoint108_PFClright
Lateral Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint108.pfclright
rsfMRI_fcnxpro129_falffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint109.pfcmright
rsfMRI_fcnxpro129_alffPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint109.pfcmright
rsfMRI_fcnxpro129_perafPoint109_PFCmright
Medial Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint109.pfcmright
rsfMRI_fcnxpro129_falffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint110.frmedright
rsfMRI_fcnxpro129_alffPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint110.frmedright
rsfMRI_fcnxpro129_perafPoint110_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint110.frmedright
rsfMRI_fcnxpro129_falffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint111.frmedright
rsfMRI_fcnxpro129_alffPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint111.frmedright
rsfMRI_fcnxpro129_perafPoint111_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint111.frmedright
rsfMRI_fcnxpro129_falffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint112.frmedright
rsfMRI_fcnxpro129_alffPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint112.frmedright
rsfMRI_fcnxpro129_perafPoint112_FrMedright
Medial Frontal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint112.frmedright
rsfMRI_fcnxpro129_falffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint113.froperright
rsfMRI_fcnxpro129_alffPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint113.froperright
rsfMRI_fcnxpro129_perafPoint113_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint113.froperright
rsfMRI_fcnxpro129_falffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint114.froperright
rsfMRI_fcnxpro129_alffPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint114.froperright
rsfMRI_fcnxpro129_perafPoint114_FrOperright
Frontal Operculum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint114.froperright
rsfMRI_fcnxpro129_falffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint115.iplright
rsfMRI_fcnxpro129_alffPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint115.iplright
rsfMRI_fcnxpro129_perafPoint115_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint115.iplright
rsfMRI_fcnxpro129_falffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint116.iplright
rsfMRI_fcnxpro129_alffPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint116.iplright
rsfMRI_fcnxpro129_perafPoint116_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint116.iplright
rsfMRI_fcnxpro129_falffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint117.insright
rsfMRI_fcnxpro129_alffPoint117_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint117.insright
rsfMRI_fcnxpro129_perafPoint117_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint117.insright
rsfMRI_fcnxpro129_falffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint118.insright
rsfMRI_fcnxpro129_alffPoint118_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint118.insright
rsfMRI_fcnxpro129_perafPoint118_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint118.insright
rsfMRI_fcnxpro129_falffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint119.insright
rsfMRI_fcnxpro129_alffPoint119_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint119.insright
rsfMRI_fcnxpro129_perafPoint119_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint119.insright
rsfMRI_fcnxpro129_falffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint120.insright
rsfMRI_fcnxpro129_alffPoint120_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint120.insright
rsfMRI_fcnxpro129_perafPoint120_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint120.insright
rsfMRI_fcnxpro129_falffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint121.insright
rsfMRI_fcnxpro129_alffPoint121_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint121.insright
rsfMRI_fcnxpro129_perafPoint121_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint121.insright
rsfMRI_fcnxpro129_falffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint122.splright
rsfMRI_fcnxpro129_alffPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint122.splright
rsfMRI_fcnxpro129_perafPoint122_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint122.splright
rsfMRI_fcnxpro129_falffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint123.splright
rsfMRI_fcnxpro129_alffPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint123.splright
rsfMRI_fcnxpro129_perafPoint123_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint123.splright
rsfMRI_fcnxpro129_falffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint124.splright
rsfMRI_fcnxpro129_alffPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint124.splright
rsfMRI_fcnxpro129_perafPoint124_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint124.splright
rsfMRI_fcnxpro129_falffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint125.iplright
rsfMRI_fcnxpro129_alffPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint125.iplright
rsfMRI_fcnxpro129_perafPoint125_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint125.iplright
rsfMRI_fcnxpro129_falffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint126.iplright
rsfMRI_fcnxpro129_alffPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint126.iplright
rsfMRI_fcnxpro129_perafPoint126_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint126.iplright
rsfMRI_fcnxpro129_falffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint127.pfcdright
rsfMRI_fcnxpro129_alffPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint127.pfcdright
rsfMRI_fcnxpro129_perafPoint127_PFCdright
Dorsal Prefrontal Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint127.pfcdright
rsfMRI_fcnxpro129_falffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint128.postcright
rsfMRI_fcnxpro129_alffPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint128.postcright
rsfMRI_fcnxpro129_perafPoint128_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint128.postcright
rsfMRI_fcnxpro129_falffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint129.postcright
rsfMRI_fcnxpro129_alffPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint129.postcright
rsfMRI_fcnxpro129_perafPoint129_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint129.postcright
rsfMRI_fcnxpro129_falffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint130.postcright
rsfMRI_fcnxpro129_alffPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint130.postcright
rsfMRI_fcnxpro129_perafPoint130_PostCright
Unknown Core: postc
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint130.postcright
rsfMRI_fcnxpro129_falffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint131.prcdright
rsfMRI_fcnxpro129_alffPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint131.prcdright
rsfMRI_fcnxpro129_perafPoint131_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint131.prcdright
rsfMRI_fcnxpro129_falffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint132.prcdright
rsfMRI_fcnxpro129_alffPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint132.prcdright
rsfMRI_fcnxpro129_perafPoint132_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint132.prcdright
rsfMRI_fcnxpro129_falffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint133.prcdright
rsfMRI_fcnxpro129_alffPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint133.prcdright
rsfMRI_fcnxpro129_perafPoint133_PrCdright
Unknown Core: prcd
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint133.prcdright
rsfMRI_fcnxpro129_falffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint134.splright
rsfMRI_fcnxpro129_alffPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint134.splright
rsfMRI_fcnxpro129_perafPoint134_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint134.splright
rsfMRI_fcnxpro129_falffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint135.splright
rsfMRI_fcnxpro129_alffPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint135.splright
rsfMRI_fcnxpro129_perafPoint135_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint135.splright
rsfMRI_fcnxpro129_falffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint136.splright
rsfMRI_fcnxpro129_alffPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint136.splright
rsfMRI_fcnxpro129_perafPoint136_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint136.splright
rsfMRI_fcnxpro129_falffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint137.splright
rsfMRI_fcnxpro129_alffPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint137.splright
rsfMRI_fcnxpro129_perafPoint137_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint137.splright
rsfMRI_fcnxpro129_falffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint138.tempoccright
rsfMRI_fcnxpro129_alffPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint138.tempoccright
rsfMRI_fcnxpro129_perafPoint138_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint138.tempoccright
rsfMRI_fcnxpro129_falffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint139.exstrright
rsfMRI_fcnxpro129_alffPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint139.exstrright
rsfMRI_fcnxpro129_perafPoint139_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint139.exstrright
rsfMRI_fcnxpro129_falffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint140.exstrright
rsfMRI_fcnxpro129_alffPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint140.exstrright
rsfMRI_fcnxpro129_perafPoint140_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint140.exstrright
rsfMRI_fcnxpro129_falffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint141.exstrright
rsfMRI_fcnxpro129_alffPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint141.exstrright
rsfMRI_fcnxpro129_perafPoint141_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint141.exstrright
rsfMRI_fcnxpro129_falffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint142.exstrright
rsfMRI_fcnxpro129_alffPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint142.exstrright
rsfMRI_fcnxpro129_perafPoint142_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint142.exstrright
rsfMRI_fcnxpro129_falffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint143.ipsright
rsfMRI_fcnxpro129_alffPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint143.ipsright
rsfMRI_fcnxpro129_perafPoint143_IPSright
Unknown Core: ips
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint143.ipsright
rsfMRI_fcnxpro129_falffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint144.splright
rsfMRI_fcnxpro129_alffPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint144.splright
rsfMRI_fcnxpro129_perafPoint144_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint144.splright
rsfMRI_fcnxpro129_falffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint145.splright
rsfMRI_fcnxpro129_alffPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint145.splright
rsfMRI_fcnxpro129_perafPoint145_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint145.splright
rsfMRI_fcnxpro129_falffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint146.splright
rsfMRI_fcnxpro129_alffPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint146.splright
rsfMRI_fcnxpro129_perafPoint146_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint146.splright
rsfMRI_fcnxpro129_falffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint147.splright
rsfMRI_fcnxpro129_alffPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint147.splright
rsfMRI_fcnxpro129_perafPoint147_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint147.splright
rsfMRI_fcnxpro129_falffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint148.splright
rsfMRI_fcnxpro129_alffPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint148.splright
rsfMRI_fcnxpro129_perafPoint148_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint148.splright
rsfMRI_fcnxpro129_falffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint149.splright
rsfMRI_fcnxpro129_alffPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint149.splright
rsfMRI_fcnxpro129_perafPoint149_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint149.splright
rsfMRI_fcnxpro129_falffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint150.tempoccright
rsfMRI_fcnxpro129_alffPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint150.tempoccright
rsfMRI_fcnxpro129_perafPoint150_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint150.tempoccright
rsfMRI_fcnxpro129_falffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint151.tempoccright
rsfMRI_fcnxpro129_alffPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint151.tempoccright
rsfMRI_fcnxpro129_perafPoint151_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint151.tempoccright
rsfMRI_fcnxpro129_falffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint152.tempoccright
rsfMRI_fcnxpro129_alffPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint152.tempoccright
rsfMRI_fcnxpro129_perafPoint152_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint152.tempoccright
rsfMRI_fcnxpro129_falffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint153.tempoccright
rsfMRI_fcnxpro129_alffPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint153.tempoccright
rsfMRI_fcnxpro129_perafPoint153_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint153.tempoccright
rsfMRI_fcnxpro129_falffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint154.tempoccright
rsfMRI_fcnxpro129_alffPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint154.tempoccright
rsfMRI_fcnxpro129_perafPoint154_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint154.tempoccright
rsfMRI_fcnxpro129_falffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint155.tempoccright
rsfMRI_fcnxpro129_alffPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint155.tempoccright
rsfMRI_fcnxpro129_perafPoint155_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint155.tempoccright
rsfMRI_fcnxpro129_falffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint156.tempoccright
rsfMRI_fcnxpro129_alffPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint156.tempoccright
rsfMRI_fcnxpro129_perafPoint156_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint156.tempoccright
rsfMRI_fcnxpro129_falffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint157.tempoccright
rsfMRI_fcnxpro129_alffPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint157.tempoccright
rsfMRI_fcnxpro129_perafPoint157_TempOccright
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint157.tempoccright
rsfMRI_fcnxpro129_falffPoint158_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint158.1right
rsfMRI_fcnxpro129_alffPoint158_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint158.1right
rsfMRI_fcnxpro129_perafPoint158_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint158.1right
rsfMRI_fcnxpro129_falffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint159.2right
rsfMRI_fcnxpro129_alffPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint159.2right
rsfMRI_fcnxpro129_perafPoint159_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint159.2right
rsfMRI_fcnxpro129_falffPoint160_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint160.3right
rsfMRI_fcnxpro129_alffPoint160_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint160.3right
rsfMRI_fcnxpro129_perafPoint160_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint160.3right
rsfMRI_fcnxpro129_falffPoint161_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint161.4right
rsfMRI_fcnxpro129_alffPoint161_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint161.4right
rsfMRI_fcnxpro129_perafPoint161_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint161.4right
rsfMRI_fcnxpro129_falffPoint162_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint162.5right
rsfMRI_fcnxpro129_alffPoint162_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint162.5right
rsfMRI_fcnxpro129_perafPoint162_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint162.5right
rsfMRI_fcnxpro129_falffPoint163_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint163.6right
rsfMRI_fcnxpro129_alffPoint163_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint163.6right
rsfMRI_fcnxpro129_perafPoint163_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint163.6right
rsfMRI_fcnxpro129_falffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint164.iplright
rsfMRI_fcnxpro129_alffPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint164.iplright
rsfMRI_fcnxpro129_perafPoint164_IPLright
Inferior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint164.iplright
rsfMRI_fcnxpro129_falffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint165.insright
rsfMRI_fcnxpro129_alffPoint165_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint165.insright
rsfMRI_fcnxpro129_perafPoint165_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint165.insright
rsfMRI_fcnxpro129_falffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint166.insright
rsfMRI_fcnxpro129_alffPoint166_Insright
Unknown Core: ins
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint166.insright
rsfMRI_fcnxpro129_perafPoint166_Insright
Unknown Core: ins
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint166.insright
rsfMRI_fcnxpro129_falffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint167.paroperright
rsfMRI_fcnxpro129_alffPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint167.paroperright
rsfMRI_fcnxpro129_perafPoint167_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint167.paroperright
rsfMRI_fcnxpro129_falffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint168.paroperright
rsfMRI_fcnxpro129_alffPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint168.paroperright
rsfMRI_fcnxpro129_perafPoint168_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint168.paroperright
rsfMRI_fcnxpro129_falffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint169.paroperright
rsfMRI_fcnxpro129_alffPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint169.paroperright
rsfMRI_fcnxpro129_perafPoint169_ParOperright
Unknown Core: paroper
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint169.paroperright
rsfMRI_fcnxpro129_falffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint170.stright
rsfMRI_fcnxpro129_alffPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint170.stright
rsfMRI_fcnxpro129_perafPoint170_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint170.stright
rsfMRI_fcnxpro129_falffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint171.stright
rsfMRI_fcnxpro129_alffPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint171.stright
rsfMRI_fcnxpro129_perafPoint171_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint171.stright
rsfMRI_fcnxpro129_falffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint172.stright
rsfMRI_fcnxpro129_alffPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint172.stright
rsfMRI_fcnxpro129_perafPoint172_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint172.stright
rsfMRI_fcnxpro129_falffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint173.stright
rsfMRI_fcnxpro129_alffPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint173.stright
rsfMRI_fcnxpro129_perafPoint173_STright
Superior Temporal Gyrus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint173.stright
rsfMRI_fcnxpro129_falffPoint174_1right
Unknown Core: 1
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint174.1right
rsfMRI_fcnxpro129_alffPoint174_1right
Unknown Core: 1
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint174.1right
rsfMRI_fcnxpro129_perafPoint174_1right
Unknown Core: 1
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint174.1right
rsfMRI_fcnxpro129_falffPoint175_10right
Unknown Core: 10
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint175.10right
rsfMRI_fcnxpro129_alffPoint175_10right
Unknown Core: 10
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint175.10right
rsfMRI_fcnxpro129_perafPoint175_10right
Unknown Core: 10
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint175.10right
rsfMRI_fcnxpro129_falffPoint176_11right
Unknown Core: 11
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint176.11right
rsfMRI_fcnxpro129_alffPoint176_11right
Unknown Core: 11
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint176.11right
rsfMRI_fcnxpro129_perafPoint176_11right
Unknown Core: 11
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint176.11right
rsfMRI_fcnxpro129_falffPoint177_12right
Unknown Core: 12
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint177.12right
rsfMRI_fcnxpro129_alffPoint177_12right
Unknown Core: 12
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint177.12right
rsfMRI_fcnxpro129_perafPoint177_12right
Unknown Core: 12
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint177.12right
rsfMRI_fcnxpro129_falffPoint178_13right
Unknown Core: 13
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint178.13right
rsfMRI_fcnxpro129_alffPoint178_13right
Unknown Core: 13
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint178.13right
rsfMRI_fcnxpro129_perafPoint178_13right
Unknown Core: 13
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint178.13right
rsfMRI_fcnxpro129_falffPoint179_14right
Unknown Core: 14
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint179.14right
rsfMRI_fcnxpro129_alffPoint179_14right
Unknown Core: 14
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint179.14right
rsfMRI_fcnxpro129_perafPoint179_14right
Unknown Core: 14
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint179.14right
rsfMRI_fcnxpro129_falffPoint180_15right
Unknown Core: 15
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint180.15right
rsfMRI_fcnxpro129_alffPoint180_15right
Unknown Core: 15
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint180.15right
rsfMRI_fcnxpro129_perafPoint180_15right
Unknown Core: 15
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint180.15right
rsfMRI_fcnxpro129_falffPoint181_16right
Unknown Core: 16
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint181.16right
rsfMRI_fcnxpro129_alffPoint181_16right
Unknown Core: 16
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint181.16right
rsfMRI_fcnxpro129_perafPoint181_16right
Unknown Core: 16
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint181.16right
rsfMRI_fcnxpro129_falffPoint182_17right
Unknown Core: 17
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint182.17right
rsfMRI_fcnxpro129_alffPoint182_17right
Unknown Core: 17
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint182.17right
rsfMRI_fcnxpro129_perafPoint182_17right
Unknown Core: 17
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint182.17right
rsfMRI_fcnxpro129_falffPoint183_18right
Unknown Core: 18
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint183.18right
rsfMRI_fcnxpro129_alffPoint183_18right
Unknown Core: 18
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint183.18right
rsfMRI_fcnxpro129_perafPoint183_18right
Unknown Core: 18
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint183.18right
rsfMRI_fcnxpro129_falffPoint184_19right
Unknown Core: 19
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint184.19right
rsfMRI_fcnxpro129_alffPoint184_19right
Unknown Core: 19
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint184.19right
rsfMRI_fcnxpro129_perafPoint184_19right
Unknown Core: 19
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint184.19right
rsfMRI_fcnxpro129_falffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint185.2right
rsfMRI_fcnxpro129_alffPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint185.2right
rsfMRI_fcnxpro129_perafPoint185_2right
Global to Global
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint185.2right
rsfMRI_fcnxpro129_falffPoint186_20right
Unknown Core: 20
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint186.20right
rsfMRI_fcnxpro129_alffPoint186_20right
Unknown Core: 20
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint186.20right
rsfMRI_fcnxpro129_perafPoint186_20right
Unknown Core: 20
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint186.20right
rsfMRI_fcnxpro129_falffPoint187_21right
Unknown Core: 21
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint187.21right
rsfMRI_fcnxpro129_alffPoint187_21right
Unknown Core: 21
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint187.21right
rsfMRI_fcnxpro129_perafPoint187_21right
Unknown Core: 21
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint187.21right
rsfMRI_fcnxpro129_falffPoint188_22right
Unknown Core: 22
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint188.22right
rsfMRI_fcnxpro129_alffPoint188_22right
Unknown Core: 22
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint188.22right
rsfMRI_fcnxpro129_perafPoint188_22right
Unknown Core: 22
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint188.22right
rsfMRI_fcnxpro129_falffPoint189_23right
Unknown Core: 23
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint189.23right
rsfMRI_fcnxpro129_alffPoint189_23right
Unknown Core: 23
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint189.23right
rsfMRI_fcnxpro129_perafPoint189_23right
Unknown Core: 23
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint189.23right
rsfMRI_fcnxpro129_falffPoint190_24right
Unknown Core: 24
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint190.24right
rsfMRI_fcnxpro129_alffPoint190_24right
Unknown Core: 24
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint190.24right
rsfMRI_fcnxpro129_perafPoint190_24right
Unknown Core: 24
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint190.24right
rsfMRI_fcnxpro129_falffPoint191_25right
Unknown Core: 25
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint191.25right
rsfMRI_fcnxpro129_alffPoint191_25right
Unknown Core: 25
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint191.25right
rsfMRI_fcnxpro129_perafPoint191_25right
Unknown Core: 25
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint191.25right
rsfMRI_fcnxpro129_falffPoint192_26right
Unknown Core: 26
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint192.26right
rsfMRI_fcnxpro129_alffPoint192_26right
Unknown Core: 26
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint192.26right
rsfMRI_fcnxpro129_perafPoint192_26right
Unknown Core: 26
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint192.26right
rsfMRI_fcnxpro129_falffPoint193_27right
Unknown Core: 27
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint193.27right
rsfMRI_fcnxpro129_alffPoint193_27right
Unknown Core: 27
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint193.27right
rsfMRI_fcnxpro129_perafPoint193_27right
Unknown Core: 27
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint193.27right
rsfMRI_fcnxpro129_falffPoint194_28right
Unknown Core: 28
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint194.28right
rsfMRI_fcnxpro129_alffPoint194_28right
Unknown Core: 28
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint194.28right
rsfMRI_fcnxpro129_perafPoint194_28right
Unknown Core: 28
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint194.28right
rsfMRI_fcnxpro129_falffPoint195_29right
Unknown Core: 29
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint195.29right
rsfMRI_fcnxpro129_alffPoint195_29right
Unknown Core: 29
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint195.29right
rsfMRI_fcnxpro129_perafPoint195_29right
Unknown Core: 29
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint195.29right
rsfMRI_fcnxpro129_falffPoint196_3right
Unknown Core: 3
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint196.3right
rsfMRI_fcnxpro129_alffPoint196_3right
Unknown Core: 3
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint196.3right
rsfMRI_fcnxpro129_perafPoint196_3right
Unknown Core: 3
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint196.3right
rsfMRI_fcnxpro129_falffPoint197_4right
Unknown Core: 4
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint197.4right
rsfMRI_fcnxpro129_alffPoint197_4right
Unknown Core: 4
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint197.4right
rsfMRI_fcnxpro129_perafPoint197_4right
Unknown Core: 4
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint197.4right
rsfMRI_fcnxpro129_falffPoint198_5right
Unknown Core: 5
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint198.5right
rsfMRI_fcnxpro129_alffPoint198_5right
Unknown Core: 5
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint198.5right
rsfMRI_fcnxpro129_perafPoint198_5right
Unknown Core: 5
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint198.5right
rsfMRI_fcnxpro129_falffPoint199_6right
Unknown Core: 6
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint199.6right
rsfMRI_fcnxpro129_alffPoint199_6right
Unknown Core: 6
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint199.6right
rsfMRI_fcnxpro129_perafPoint199_6right
Unknown Core: 6
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint199.6right
rsfMRI_fcnxpro129_falffPoint200_7right
Unknown Core: 7
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint200.7right
rsfMRI_fcnxpro129_alffPoint200_7right
Unknown Core: 7
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint200.7right
rsfMRI_fcnxpro129_perafPoint200_7right
Unknown Core: 7
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint200.7right
rsfMRI_fcnxpro129_falffPoint201_8right
Unknown Core: 8
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint201.8right
rsfMRI_fcnxpro129_alffPoint201_8right
Unknown Core: 8
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint201.8right
rsfMRI_fcnxpro129_perafPoint201_8right
Unknown Core: 8
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint201.8right
rsfMRI_fcnxpro129_falffPoint202_9right
Unknown Core: 9
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint202.9right
rsfMRI_fcnxpro129_alffPoint202_9right
Unknown Core: 9
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint202.9right
rsfMRI_fcnxpro129_perafPoint202_9right
Unknown Core: 9
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint202.9right
rsfMRI_fcnxpro129_falffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint203.splright
rsfMRI_fcnxpro129_alffPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint203.splright
rsfMRI_fcnxpro129_perafPoint203_SPLright
Superior Parietal Lobule
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint203.splright
rsfMRI_fcnxpro129_falffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint204.exstrright
rsfMRI_fcnxpro129_alffPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint204.exstrright
rsfMRI_fcnxpro129_perafPoint204_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint204.exstrright
rsfMRI_fcnxpro129_falffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint205.exstrinfright
rsfMRI_fcnxpro129_alffPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint205.exstrinfright
rsfMRI_fcnxpro129_perafPoint205_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint205.exstrinfright
rsfMRI_fcnxpro129_falffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint206.exstrinfright
rsfMRI_fcnxpro129_alffPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint206.exstrinfright
rsfMRI_fcnxpro129_perafPoint206_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint206.exstrinfright
rsfMRI_fcnxpro129_falffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint207.exstrinfright
rsfMRI_fcnxpro129_alffPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint207.exstrinfright
rsfMRI_fcnxpro129_perafPoint207_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint207.exstrinfright
rsfMRI_fcnxpro129_falffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint208.exstrinfright
rsfMRI_fcnxpro129_alffPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint208.exstrinfright
rsfMRI_fcnxpro129_perafPoint208_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint208.exstrinfright
rsfMRI_fcnxpro129_falffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint209.exstrinfright
rsfMRI_fcnxpro129_alffPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint209.exstrinfright
rsfMRI_fcnxpro129_perafPoint209_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint209.exstrinfright
rsfMRI_fcnxpro129_falffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint210.exstrsupright
rsfMRI_fcnxpro129_alffPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint210.exstrsupright
rsfMRI_fcnxpro129_perafPoint210_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint210.exstrsupright
rsfMRI_fcnxpro129_falffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint211.exstrsupright
rsfMRI_fcnxpro129_alffPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint211.exstrsupright
rsfMRI_fcnxpro129_perafPoint211_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint211.exstrsupright
rsfMRI_fcnxpro129_falffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint212.exstrsupright
rsfMRI_fcnxpro129_alffPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint212.exstrsupright
rsfMRI_fcnxpro129_perafPoint212_ExStrSupright
Unknown Core: exstrsup
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint212.exstrsupright
rsfMRI_fcnxpro129_falffPoint213_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint213.striateright
rsfMRI_fcnxpro129_alffPoint213_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint213.striateright
rsfMRI_fcnxpro129_perafPoint213_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint213.striateright
rsfMRI_fcnxpro129_falffPoint214_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint214.striateright
rsfMRI_fcnxpro129_alffPoint214_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint214.striateright
rsfMRI_fcnxpro129_perafPoint214_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint214.striateright
rsfMRI_fcnxpro129_falffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint215.exstrinfright
rsfMRI_fcnxpro129_alffPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint215.exstrinfright
rsfMRI_fcnxpro129_perafPoint215_ExStrInfright
Unknown Core: exstrinf
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint215.exstrinfright
rsfMRI_fcnxpro129_falffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint216.exstrright
rsfMRI_fcnxpro129_alffPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint216.exstrright
rsfMRI_fcnxpro129_perafPoint216_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint216.exstrright
rsfMRI_fcnxpro129_falffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint217.exstrright
rsfMRI_fcnxpro129_alffPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint217.exstrright
rsfMRI_fcnxpro129_perafPoint217_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint217.exstrright
rsfMRI_fcnxpro129_falffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint218.exstrright
rsfMRI_fcnxpro129_alffPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint218.exstrright
rsfMRI_fcnxpro129_perafPoint218_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint218.exstrright
rsfMRI_fcnxpro129_falffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint219.exstrright
rsfMRI_fcnxpro129_alffPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint219.exstrright
rsfMRI_fcnxpro129_perafPoint219_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint219.exstrright
rsfMRI_fcnxpro129_falffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint220.exstrright
rsfMRI_fcnxpro129_alffPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint220.exstrright
rsfMRI_fcnxpro129_perafPoint220_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint220.exstrright
rsfMRI_fcnxpro129_falffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint221.exstrright
rsfMRI_fcnxpro129_alffPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint221.exstrright
rsfMRI_fcnxpro129_perafPoint221_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint221.exstrright
rsfMRI_fcnxpro129_falffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint222.exstrright
rsfMRI_fcnxpro129_alffPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint222.exstrright
rsfMRI_fcnxpro129_perafPoint222_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint222.exstrright
rsfMRI_fcnxpro129_falffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint223.exstrright
rsfMRI_fcnxpro129_alffPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint223.exstrright
rsfMRI_fcnxpro129_perafPoint223_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint223.exstrright
rsfMRI_fcnxpro129_falffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint224.exstrright
rsfMRI_fcnxpro129_alffPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint224.exstrright
rsfMRI_fcnxpro129_perafPoint224_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint224.exstrright
rsfMRI_fcnxpro129_falffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint225.exstrright
rsfMRI_fcnxpro129_alffPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint225.exstrright
rsfMRI_fcnxpro129_perafPoint225_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint225.exstrright
rsfMRI_fcnxpro129_falffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint226.exstrright
rsfMRI_fcnxpro129_alffPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint226.exstrright
rsfMRI_fcnxpro129_perafPoint226_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint226.exstrright
rsfMRI_fcnxpro129_falffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint227.exstrright
rsfMRI_fcnxpro129_alffPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint227.exstrright
rsfMRI_fcnxpro129_perafPoint227_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint227.exstrright
rsfMRI_fcnxpro129_falffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint228.exstrright
rsfMRI_fcnxpro129_alffPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint228.exstrright
rsfMRI_fcnxpro129_perafPoint228_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint228.exstrright
rsfMRI_fcnxpro129_falffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint229.exstrright
rsfMRI_fcnxpro129_alffPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint229.exstrright
rsfMRI_fcnxpro129_perafPoint229_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint229.exstrright
rsfMRI_fcnxpro129_falffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint230.exstrright
rsfMRI_fcnxpro129_alffPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint230.exstrright
rsfMRI_fcnxpro129_perafPoint230_ExStrright
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint230.exstrright
rsfMRI_fcnxpro129_falffPoint231_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint231.striateright
rsfMRI_fcnxpro129_alffPoint231_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint231.striateright
rsfMRI_fcnxpro129_perafPoint231_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint231.striateright
rsfMRI_fcnxpro129_falffPoint232_Striateright
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint232.striateright
rsfMRI_fcnxpro129_alffPoint232_Striateright
striate cortex
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint232.striateright
rsfMRI_fcnxpro129_perafPoint232_Striateright
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint232.striateright
rsfMRI_fcnxpro129_falffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint233.bnstrpuleft
rsfMRI_fcnxpro129_alffPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint233.bnstrpuleft
rsfMRI_fcnxpro129_perafPoint233_BNSTRPuleft
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint233.bnstrpuleft
rsfMRI_fcnxpro129_falffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint234.bnstrcaleft
rsfMRI_fcnxpro129_alffPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint234.bnstrcaleft
rsfMRI_fcnxpro129_perafPoint234_BNSTRCaleft
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint234.bnstrcaleft
rsfMRI_fcnxpro129_falffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint235.bnstrnacleft
rsfMRI_fcnxpro129_alffPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint235.bnstrnacleft
rsfMRI_fcnxpro129_perafPoint235_BNSTRNACleft
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint235.bnstrnacleft
rsfMRI_fcnxpro129_falffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint236.exaleft
rsfMRI_fcnxpro129_alffPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint236.exaleft
rsfMRI_fcnxpro129_perafPoint236_EXAleft
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint236.exaleft
rsfMRI_fcnxpro129_falffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint237.bngpgpeleft
rsfMRI_fcnxpro129_alffPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint237.bngpgpeleft
rsfMRI_fcnxpro129_perafPoint237_BNGPGPeleft
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint237.bngpgpeleft
rsfMRI_fcnxpro129_falffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint238.bngpgpileft
rsfMRI_fcnxpro129_alffPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint238.bngpgpileft
rsfMRI_fcnxpro129_perafPoint238_BNGPGPileft
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint238.bngpgpileft
rsfMRI_fcnxpro129_falffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint239.mtgsnsncleft
rsfMRI_fcnxpro129_alffPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint239.mtgsnsncleft
rsfMRI_fcnxpro129_perafPoint239_MTgSNSNcleft
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint239.mtgsnsncleft
rsfMRI_fcnxpro129_falffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint240.mtgrnleft
rsfMRI_fcnxpro129_alffPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint240.mtgrnleft
rsfMRI_fcnxpro129_perafPoint240_MTgRNleft
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint240.mtgrnleft
rsfMRI_fcnxpro129_falffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro129_alffPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro129_perafPoint241_MTgSNSNrleft
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint241.mtgsnsnrleft
rsfMRI_fcnxpro129_falffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro129_alffPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro129_perafPoint242_MTgVTRPBPleft
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro129_falffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro129_alffPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro129_perafPoint243_MTgVTRVTAleft
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro129_falffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint244.bngpvepleft
rsfMRI_fcnxpro129_alffPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint244.bngpvepleft
rsfMRI_fcnxpro129_perafPoint244_BNGPVePleft
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint244.bngpvepleft
rsfMRI_fcnxpro129_falffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint245.thmethhnleft
rsfMRI_fcnxpro129_alffPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint245.thmethhnleft
rsfMRI_fcnxpro129_perafPoint245_THMETHHNleft
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint245.thmethhnleft
rsfMRI_fcnxpro129_falffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint246.diehthleft
rsfMRI_fcnxpro129_alffPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint246.diehthleft
rsfMRI_fcnxpro129_perafPoint246_DieHTHleft
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint246.diehthleft
rsfMRI_fcnxpro129_falffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint247.diehthmnleft
rsfMRI_fcnxpro129_alffPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint247.diehthmnleft
rsfMRI_fcnxpro129_perafPoint247_DieHTHMNleft
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint247.diehthmnleft
rsfMRI_fcnxpro129_falffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint248.diesthleft
rsfMRI_fcnxpro129_alffPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint248.diesthleft
rsfMRI_fcnxpro129_perafPoint248_DieSTHleft
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint248.diesthleft
rsfMRI_fcnxpro129_falffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint249.bnstrpuright
rsfMRI_fcnxpro129_alffPoint249_BNSTRPuright
Putamen
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint249.bnstrpuright
rsfMRI_fcnxpro129_perafPoint249_BNSTRPuright
Putamen
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint249.bnstrpuright
rsfMRI_fcnxpro129_falffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint250.bnstrcaright
rsfMRI_fcnxpro129_alffPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint250.bnstrcaright
rsfMRI_fcnxpro129_perafPoint250_BNSTRCaright
Caudate Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint250.bnstrcaright
rsfMRI_fcnxpro129_falffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint251.bnstrnacright
rsfMRI_fcnxpro129_alffPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint251.bnstrnacright
rsfMRI_fcnxpro129_perafPoint251_BNSTRNACright
Nucleus Accumbens
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint251.bnstrnacright
rsfMRI_fcnxpro129_falffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint252.exaright
rsfMRI_fcnxpro129_alffPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint252.exaright
rsfMRI_fcnxpro129_perafPoint252_EXAright
Extended Amygdala
restingStatefMRI
ignore
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint252.exaright
rsfMRI_fcnxpro129_falffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint253.bngpgperight
rsfMRI_fcnxpro129_alffPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint253.bngpgperight
rsfMRI_fcnxpro129_perafPoint253_BNGPGPeright
Globus Pallidus External
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint253.bngpgperight
rsfMRI_fcnxpro129_falffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint254.bngpgpiright
rsfMRI_fcnxpro129_alffPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint254.bngpgpiright
rsfMRI_fcnxpro129_perafPoint254_BNGPGPiright
Globus Pallidus Internal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint254.bngpgpiright
rsfMRI_fcnxpro129_falffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint255.mtgsnsncright
rsfMRI_fcnxpro129_alffPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint255.mtgsnsncright
rsfMRI_fcnxpro129_perafPoint255_MTgSNSNcright
Substantia Nigra Compacta
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint255.mtgsnsncright
rsfMRI_fcnxpro129_falffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint256.mtgrnright
rsfMRI_fcnxpro129_alffPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint256.mtgrnright
rsfMRI_fcnxpro129_perafPoint256_MTgRNright
Red Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint256.mtgrnright
rsfMRI_fcnxpro129_falffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint257.mtgsnsnrright
rsfMRI_fcnxpro129_alffPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint257.mtgsnsnrright
rsfMRI_fcnxpro129_perafPoint257_MTgSNSNrright
Substantia Nigra Reticulata
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint257.mtgsnsnrright
rsfMRI_fcnxpro129_falffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro129_alffPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro129_perafPoint258_MTgVTRPBPright
Parabrachial Pigmented Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint258.mtgvtrpbpright
rsfMRI_fcnxpro129_falffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro129_alffPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro129_perafPoint259_MTgVTRVTAright
Ventral Tegmental Area
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint259.mtgvtrvtaright
rsfMRI_fcnxpro129_falffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint260.bngpvepright
rsfMRI_fcnxpro129_alffPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint260.bngpvepright
rsfMRI_fcnxpro129_perafPoint260_BNGPVePright
Ventral Pallidum
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint260.bngpvepright
rsfMRI_fcnxpro129_falffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint261.thmethhnright
rsfMRI_fcnxpro129_alffPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint261.thmethhnright
rsfMRI_fcnxpro129_perafPoint261_THMETHHNright
Thalamus Habenular Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint261.thmethhnright
rsfMRI_fcnxpro129_falffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint262.diehthright
rsfMRI_fcnxpro129_alffPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint262.diehthright
rsfMRI_fcnxpro129_perafPoint262_DieHTHright
Hypothalamus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint262.diehthright
rsfMRI_fcnxpro129_falffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint263.diehthmnright
rsfMRI_fcnxpro129_alffPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint263.diehthmnright
rsfMRI_fcnxpro129_perafPoint263_DieHTHMNright
Diencephalon / Hypothalamus Mammillary Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint263.diehthmnright
rsfMRI_fcnxpro129_falffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint264.diesthright
rsfMRI_fcnxpro129_alffPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint264.diesthright
rsfMRI_fcnxpro129_perafPoint264_DieSTHright
Diencephalon / Subthalamic Nucleus
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint264.diesthright
rsfMRI_fcnxpro129_falffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.falffpoint265.referenceregionleft
rsfMRI_fcnxpro129_alffPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
left
rsf.p2.alffpoint265.referenceregionleft
rsfMRI_fcnxpro129_perafPoint265_ReferenceRegionleft
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
left
rsf.p2.perafpoint265.referenceregionleft
rsfMRI_fcnxpro129_falffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.falffpoint266.referenceregionright
rsfMRI_fcnxpro129_alffPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
right
rsf.p2.alffpoint266.referenceregionright
rsfMRI_fcnxpro129_perafPoint266_ReferenceRegionright
Reference Region
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
right
rsf.p2.perafpoint266.referenceregionright
rsfMRI_fcnxpro129_DefaultMode_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultmode.mean
rsfMRI_fcnxpro129_Visual_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.visual.mean
rsfMRI_fcnxpro129_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.motion.corrected.mean
rsfMRI_fcnxpro129_PerAF_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.peraf.mean
rsfMRI_fcnxpro129_tsnr_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.tsnr.mean
rsfMRI_fcnxpro129_ssnr_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.ssnr.mean
rsfMRI_fcnxpro129_dvars_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.dvars.mean
rsfMRI_fcnxpro129_bandpass_freq_0
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
129
​
rsf.p2.bandpass.freq.0
rsfMRI_fcnxpro129_bandpass_freq_1
​
restingStatefMRI
band pass frequency limit
power peterson fMRI meta-analyses
129
​
rsf.p2.bandpass.freq.1
rsfMRI_fcnxpro129_censor
Unknown Core: censor
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.censor
rsfMRI_fcnxpro129_spatial_smoothing
Unknown Core: spatial smoothing
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.spatial.smoothing
rsfMRI_fcnxpro129_outlier_threshold
Unknown Core: outlier threshold
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.outlier.threshold
rsfMRI_fcnxpro129_FD_threshold
Unknown Core: threshold
restingStatefMRI
motion statistic on framewise displacement
power peterson fMRI meta-analyses
129
​
rsf.p2.fd.threshold
rsfMRI_fcnxpro129_high_motion_count
Unknown Core: high motion count
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.high.motion.count
rsfMRI_fcnxpro129_high_motion_pct
Unknown Core: high motion pct
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.high.motion.pct
rsfMRI_fcnxpro129_despiking_count_summary
Unknown Core: despiking count summary
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.despiking.count.summary
rsfMRI_fcnxpro129_FD_max
​
restingStatefMRI
max framewise displacement
power peterson fMRI meta-analyses
129
​
rsf.p2.fd.max
rsfMRI_fcnxpro129_FD_mean
​
restingStatefMRI
mean framewise displacement
power peterson fMRI meta-analyses
129
​
rsf.p2.fd.mean
rsfMRI_fcnxpro129_FD_sd
​
restingStatefMRI
global sd of image
power peterson fMRI meta-analyses
129
​
rsf.p2.fd.sd
rsfMRI_fcnxpro129_bold_evr
Unknown Core: bold
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.bold.evr
rsfMRI_fcnxpro129_n_outliers
Unknown Core: n outliers
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.n.outliers
rsfMRI_fcnxpro129_nc_wm
Unknown Core: nc wm
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.nc.wm
rsfMRI_fcnxpro129_nc_csf
Cerebrospinal Fluid
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.nc.csf
rsfMRI_fcnxpro129_minutes_original_data
Unknown Core: minutes original data
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.minutes.original.data
rsfMRI_fcnxpro129_minutes_censored_data
Unknown Core: minutes censored data
restingStatefMRI
Unknown
power peterson fMRI meta-analyses
129
​
rsf.p2.minutes.censored.data
rsfMRI_fcnxpro129_TempPar_2_TempPar
Temporo-Parietal to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.temppar
rsfMRI_fcnxpro129_TempPar_2_DefaultC
Temporo-Parietal to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.defaultc
rsfMRI_fcnxpro129_TempPar_2_DefaultB
Temporo-Parietal to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.defaultb
rsfMRI_fcnxpro129_TempPar_2_DefaultA
Temporo-Parietal to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.defaulta
rsfMRI_fcnxpro129_TempPar_2_ContC
Temporo-Parietal to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.contc
rsfMRI_fcnxpro129_TempPar_2_ContB
Temporo-Parietal to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.contb
rsfMRI_fcnxpro129_TempPar_2_ContA
Temporo-Parietal to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.conta
rsfMRI_fcnxpro129_TempPar_2_LimbicA
Temporo-Parietal to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.limbica
rsfMRI_fcnxpro129_TempPar_2_LimbicB
Temporo-Parietal to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.limbicb
rsfMRI_fcnxpro129_TempPar_2_SalVentAttnB
Temporo-Parietal to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.salventattnb
rsfMRI_fcnxpro129_TempPar_2_SalVentAttnA
Temporo-Parietal to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.salventattna
rsfMRI_fcnxpro129_TempPar_2_DorsAttnB
Temporo-Parietal to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.dorsattnb
rsfMRI_fcnxpro129_TempPar_2_DorsAttnA
Temporo-Parietal to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.dorsattna
rsfMRI_fcnxpro129_TempPar_2_SomMotB
Temporo-Parietal to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.sommotb
rsfMRI_fcnxpro129_TempPar_2_SomMotA
Temporo-Parietal to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.sommota
rsfMRI_fcnxpro129_TempPar_2_VisPeri
Temporo-Parietal to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.visperi
rsfMRI_fcnxpro129_TempPar_2_VisCent
Temporo-Parietal to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.viscent
rsfMRI_fcnxpro129_TempPar_2_Striatum
Temporo-Parietal to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.striatum
rsfMRI_fcnxpro129_TempPar_2_Dopamine
Temporo-Parietal to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.dopamine
rsfMRI_fcnxpro129_TempPar_2_CITLimbic
Temporo-Parietal to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.citlimbic
rsfMRI_fcnxpro129_TempPar_2_BasalGanglia
Temporo-Parietal to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.basalganglia
rsfMRI_fcnxpro129_TempPar_2_MidBrain
Temporo-Parietal to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.temppar.2.midbrain
rsfMRI_fcnxpro129_DefaultC_2_TempPar
Default Mode Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.temppar
rsfMRI_fcnxpro129_DefaultC_2_DefaultC
Default Mode Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.defaultc
rsfMRI_fcnxpro129_DefaultC_2_DefaultB
Default Mode Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.defaultb
rsfMRI_fcnxpro129_DefaultC_2_DefaultA
Default Mode Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.defaulta
rsfMRI_fcnxpro129_DefaultC_2_ContC
Default Mode Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.contc
rsfMRI_fcnxpro129_DefaultC_2_ContB
Default Mode Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.contb
rsfMRI_fcnxpro129_DefaultC_2_ContA
Default Mode Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.conta
rsfMRI_fcnxpro129_DefaultC_2_LimbicA
Default Mode Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.limbica
rsfMRI_fcnxpro129_DefaultC_2_LimbicB
Default Mode Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.limbicb
rsfMRI_fcnxpro129_DefaultC_2_SalVentAttnB
Default Mode Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.salventattnb
rsfMRI_fcnxpro129_DefaultC_2_SalVentAttnA
Default Mode Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.salventattna
rsfMRI_fcnxpro129_DefaultC_2_DorsAttnB
Default Mode Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.dorsattnb
rsfMRI_fcnxpro129_DefaultC_2_DorsAttnA
Default Mode Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.dorsattna
rsfMRI_fcnxpro129_DefaultC_2_SomMotB
Default Mode Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.sommotb
rsfMRI_fcnxpro129_DefaultC_2_SomMotA
Default Mode Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.sommota
rsfMRI_fcnxpro129_DefaultC_2_VisPeri
Default Mode Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.visperi
rsfMRI_fcnxpro129_DefaultC_2_VisCent
Default Mode Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.viscent
rsfMRI_fcnxpro129_DefaultC_2_Striatum
Default Mode Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.striatum
rsfMRI_fcnxpro129_DefaultC_2_Dopamine
Default Mode Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.dopamine
rsfMRI_fcnxpro129_DefaultC_2_CITLimbic
Default Mode Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.citlimbic
rsfMRI_fcnxpro129_DefaultC_2_BasalGanglia
Default Mode Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.basalganglia
rsfMRI_fcnxpro129_DefaultC_2_MidBrain
Default Mode Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultc.2.midbrain
rsfMRI_fcnxpro129_DefaultB_2_TempPar
Default Mode Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.temppar
rsfMRI_fcnxpro129_DefaultB_2_DefaultC
Default Mode Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.defaultc
rsfMRI_fcnxpro129_DefaultB_2_DefaultB
Default Mode Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.defaultb
rsfMRI_fcnxpro129_DefaultB_2_DefaultA
Default Mode Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.defaulta
rsfMRI_fcnxpro129_DefaultB_2_ContC
Default Mode Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.contc
rsfMRI_fcnxpro129_DefaultB_2_ContB
Default Mode Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.contb
rsfMRI_fcnxpro129_DefaultB_2_ContA
Default Mode Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.conta
rsfMRI_fcnxpro129_DefaultB_2_LimbicA
Default Mode Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.limbica
rsfMRI_fcnxpro129_DefaultB_2_LimbicB
Default Mode Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.limbicb
rsfMRI_fcnxpro129_DefaultB_2_SalVentAttnB
Default Mode Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.salventattnb
rsfMRI_fcnxpro129_DefaultB_2_SalVentAttnA
Default Mode Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.salventattna
rsfMRI_fcnxpro129_DefaultB_2_DorsAttnB
Default Mode Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.dorsattnb
rsfMRI_fcnxpro129_DefaultB_2_DorsAttnA
Default Mode Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.dorsattna
rsfMRI_fcnxpro129_DefaultB_2_SomMotB
Default Mode Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.sommotb
rsfMRI_fcnxpro129_DefaultB_2_SomMotA
Default Mode Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.sommota
rsfMRI_fcnxpro129_DefaultB_2_VisPeri
Default Mode Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.visperi
rsfMRI_fcnxpro129_DefaultB_2_VisCent
Default Mode Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.viscent
rsfMRI_fcnxpro129_DefaultB_2_Striatum
Default Mode Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.striatum
rsfMRI_fcnxpro129_DefaultB_2_Dopamine
Default Mode Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.dopamine
rsfMRI_fcnxpro129_DefaultB_2_CITLimbic
Default Mode Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.citlimbic
rsfMRI_fcnxpro129_DefaultB_2_BasalGanglia
Default Mode Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.basalganglia
rsfMRI_fcnxpro129_DefaultB_2_MidBrain
Default Mode Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaultb.2.midbrain
rsfMRI_fcnxpro129_DefaultA_2_TempPar
Default Mode Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.temppar
rsfMRI_fcnxpro129_DefaultA_2_DefaultC
Default Mode Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.defaultc
rsfMRI_fcnxpro129_DefaultA_2_DefaultB
Default Mode Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.defaultb
rsfMRI_fcnxpro129_DefaultA_2_DefaultA
Default Mode Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.defaulta
rsfMRI_fcnxpro129_DefaultA_2_ContC
Default Mode Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.contc
rsfMRI_fcnxpro129_DefaultA_2_ContB
Default Mode Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.contb
rsfMRI_fcnxpro129_DefaultA_2_ContA
Default Mode Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.conta
rsfMRI_fcnxpro129_DefaultA_2_LimbicA
Default Mode Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.limbica
rsfMRI_fcnxpro129_DefaultA_2_LimbicB
Default Mode Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.limbicb
rsfMRI_fcnxpro129_DefaultA_2_SalVentAttnB
Default Mode Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.salventattnb
rsfMRI_fcnxpro129_DefaultA_2_SalVentAttnA
Default Mode Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.salventattna
rsfMRI_fcnxpro129_DefaultA_2_DorsAttnB
Default Mode Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.dorsattnb
rsfMRI_fcnxpro129_DefaultA_2_DorsAttnA
Default Mode Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.dorsattna
rsfMRI_fcnxpro129_DefaultA_2_SomMotB
Default Mode Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.sommotb
rsfMRI_fcnxpro129_DefaultA_2_SomMotA
Default Mode Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.sommota
rsfMRI_fcnxpro129_DefaultA_2_VisPeri
Default Mode Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.visperi
rsfMRI_fcnxpro129_DefaultA_2_VisCent
Default Mode Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.viscent
rsfMRI_fcnxpro129_DefaultA_2_Striatum
Default Mode Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.striatum
rsfMRI_fcnxpro129_DefaultA_2_Dopamine
Default Mode Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.dopamine
rsfMRI_fcnxpro129_DefaultA_2_CITLimbic
Default Mode Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.citlimbic
rsfMRI_fcnxpro129_DefaultA_2_BasalGanglia
Default Mode Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.basalganglia
rsfMRI_fcnxpro129_DefaultA_2_MidBrain
Default Mode Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.defaulta.2.midbrain
rsfMRI_fcnxpro129_ContC_2_TempPar
Frontoparietal Control Network C to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.temppar
rsfMRI_fcnxpro129_ContC_2_DefaultC
Frontoparietal Control Network C to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.defaultc
rsfMRI_fcnxpro129_ContC_2_DefaultB
Frontoparietal Control Network C to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.defaultb
rsfMRI_fcnxpro129_ContC_2_DefaultA
Frontoparietal Control Network C to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.defaulta
rsfMRI_fcnxpro129_ContC_2_ContC
Frontoparietal Control Network C to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.contc
rsfMRI_fcnxpro129_ContC_2_ContB
Frontoparietal Control Network C to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.contb
rsfMRI_fcnxpro129_ContC_2_ContA
Frontoparietal Control Network C to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.conta
rsfMRI_fcnxpro129_ContC_2_LimbicA
Frontoparietal Control Network C to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.limbica
rsfMRI_fcnxpro129_ContC_2_LimbicB
Frontoparietal Control Network C to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.limbicb
rsfMRI_fcnxpro129_ContC_2_SalVentAttnB
Frontoparietal Control Network C to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.salventattnb
rsfMRI_fcnxpro129_ContC_2_SalVentAttnA
Frontoparietal Control Network C to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.salventattna
rsfMRI_fcnxpro129_ContC_2_DorsAttnB
Frontoparietal Control Network C to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.dorsattnb
rsfMRI_fcnxpro129_ContC_2_DorsAttnA
Frontoparietal Control Network C to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.dorsattna
rsfMRI_fcnxpro129_ContC_2_SomMotB
Frontoparietal Control Network C to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.sommotb
rsfMRI_fcnxpro129_ContC_2_SomMotA
Frontoparietal Control Network C to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.sommota
rsfMRI_fcnxpro129_ContC_2_VisPeri
Frontoparietal Control Network C to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.visperi
rsfMRI_fcnxpro129_ContC_2_VisCent
Frontoparietal Control Network C to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.viscent
rsfMRI_fcnxpro129_ContC_2_Striatum
Frontoparietal Control Network C to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.striatum
rsfMRI_fcnxpro129_ContC_2_Dopamine
Frontoparietal Control Network C to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.dopamine
rsfMRI_fcnxpro129_ContC_2_CITLimbic
Frontoparietal Control Network C to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.citlimbic
rsfMRI_fcnxpro129_ContC_2_BasalGanglia
Frontoparietal Control Network C to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.basalganglia
rsfMRI_fcnxpro129_ContC_2_MidBrain
Frontoparietal Control Network C to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contc.2.midbrain
rsfMRI_fcnxpro129_ContB_2_TempPar
Frontoparietal Control Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.temppar
rsfMRI_fcnxpro129_ContB_2_DefaultC
Frontoparietal Control Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.defaultc
rsfMRI_fcnxpro129_ContB_2_DefaultB
Frontoparietal Control Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.defaultb
rsfMRI_fcnxpro129_ContB_2_DefaultA
Frontoparietal Control Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.defaulta
rsfMRI_fcnxpro129_ContB_2_ContC
Frontoparietal Control Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.contc
rsfMRI_fcnxpro129_ContB_2_ContB
Frontoparietal Control Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.contb
rsfMRI_fcnxpro129_ContB_2_ContA
Frontoparietal Control Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.conta
rsfMRI_fcnxpro129_ContB_2_LimbicA
Frontoparietal Control Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.limbica
rsfMRI_fcnxpro129_ContB_2_LimbicB
Frontoparietal Control Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.limbicb
rsfMRI_fcnxpro129_ContB_2_SalVentAttnB
Frontoparietal Control Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.salventattnb
rsfMRI_fcnxpro129_ContB_2_SalVentAttnA
Frontoparietal Control Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.salventattna
rsfMRI_fcnxpro129_ContB_2_DorsAttnB
Frontoparietal Control Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.dorsattnb
rsfMRI_fcnxpro129_ContB_2_DorsAttnA
Frontoparietal Control Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.dorsattna
rsfMRI_fcnxpro129_ContB_2_SomMotB
Frontoparietal Control Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.sommotb
rsfMRI_fcnxpro129_ContB_2_SomMotA
Frontoparietal Control Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.sommota
rsfMRI_fcnxpro129_ContB_2_VisPeri
Frontoparietal Control Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.visperi
rsfMRI_fcnxpro129_ContB_2_VisCent
Frontoparietal Control Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.viscent
rsfMRI_fcnxpro129_ContB_2_Striatum
Frontoparietal Control Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.striatum
rsfMRI_fcnxpro129_ContB_2_Dopamine
Frontoparietal Control Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.dopamine
rsfMRI_fcnxpro129_ContB_2_CITLimbic
Frontoparietal Control Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.citlimbic
rsfMRI_fcnxpro129_ContB_2_BasalGanglia
Frontoparietal Control Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.basalganglia
rsfMRI_fcnxpro129_ContB_2_MidBrain
Frontoparietal Control Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.contb.2.midbrain
rsfMRI_fcnxpro129_ContA_2_TempPar
Frontoparietal Control Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.temppar
rsfMRI_fcnxpro129_ContA_2_DefaultC
Frontoparietal Control Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.defaultc
rsfMRI_fcnxpro129_ContA_2_DefaultB
Frontoparietal Control Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.defaultb
rsfMRI_fcnxpro129_ContA_2_DefaultA
Frontoparietal Control Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.defaulta
rsfMRI_fcnxpro129_ContA_2_ContC
Frontoparietal Control Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.contc
rsfMRI_fcnxpro129_ContA_2_ContB
Frontoparietal Control Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.contb
rsfMRI_fcnxpro129_ContA_2_ContA
Frontoparietal Control Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.conta
rsfMRI_fcnxpro129_ContA_2_LimbicA
Frontoparietal Control Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.limbica
rsfMRI_fcnxpro129_ContA_2_LimbicB
Frontoparietal Control Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.limbicb
rsfMRI_fcnxpro129_ContA_2_SalVentAttnB
Frontoparietal Control Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.salventattnb
rsfMRI_fcnxpro129_ContA_2_SalVentAttnA
Frontoparietal Control Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.salventattna
rsfMRI_fcnxpro129_ContA_2_DorsAttnB
Frontoparietal Control Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.dorsattnb
rsfMRI_fcnxpro129_ContA_2_DorsAttnA
Frontoparietal Control Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.dorsattna
rsfMRI_fcnxpro129_ContA_2_SomMotB
Frontoparietal Control Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.sommotb
rsfMRI_fcnxpro129_ContA_2_SomMotA
Frontoparietal Control Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.sommota
rsfMRI_fcnxpro129_ContA_2_VisPeri
Frontoparietal Control Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.visperi
rsfMRI_fcnxpro129_ContA_2_VisCent
Frontoparietal Control Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.viscent
rsfMRI_fcnxpro129_ContA_2_Striatum
Frontoparietal Control Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.striatum
rsfMRI_fcnxpro129_ContA_2_Dopamine
Frontoparietal Control Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.dopamine
rsfMRI_fcnxpro129_ContA_2_CITLimbic
Frontoparietal Control Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.citlimbic
rsfMRI_fcnxpro129_ContA_2_BasalGanglia
Frontoparietal Control Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.basalganglia
rsfMRI_fcnxpro129_ContA_2_MidBrain
Frontoparietal Control Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.conta.2.midbrain
rsfMRI_fcnxpro129_LimbicA_2_TempPar
Limbic Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.temppar
rsfMRI_fcnxpro129_LimbicA_2_DefaultC
Limbic Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.defaultc
rsfMRI_fcnxpro129_LimbicA_2_DefaultB
Limbic Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.defaultb
rsfMRI_fcnxpro129_LimbicA_2_DefaultA
Limbic Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.defaulta
rsfMRI_fcnxpro129_LimbicA_2_ContC
Limbic Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.contc
rsfMRI_fcnxpro129_LimbicA_2_ContB
Limbic Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.contb
rsfMRI_fcnxpro129_LimbicA_2_ContA
Limbic Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.conta
rsfMRI_fcnxpro129_LimbicA_2_LimbicA
Limbic Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.limbica
rsfMRI_fcnxpro129_LimbicA_2_LimbicB
Limbic Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.limbicb
rsfMRI_fcnxpro129_LimbicA_2_SalVentAttnB
Limbic Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.salventattnb
rsfMRI_fcnxpro129_LimbicA_2_SalVentAttnA
Limbic Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.salventattna
rsfMRI_fcnxpro129_LimbicA_2_DorsAttnB
Limbic Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.dorsattnb
rsfMRI_fcnxpro129_LimbicA_2_DorsAttnA
Limbic Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.dorsattna
rsfMRI_fcnxpro129_LimbicA_2_SomMotB
Limbic Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.sommotb
rsfMRI_fcnxpro129_LimbicA_2_SomMotA
Limbic Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.sommota
rsfMRI_fcnxpro129_LimbicA_2_VisPeri
Limbic Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.visperi
rsfMRI_fcnxpro129_LimbicA_2_VisCent
Limbic Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.viscent
rsfMRI_fcnxpro129_LimbicA_2_Striatum
Limbic Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.striatum
rsfMRI_fcnxpro129_LimbicA_2_Dopamine
Limbic Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.dopamine
rsfMRI_fcnxpro129_LimbicA_2_CITLimbic
Limbic Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.citlimbic
rsfMRI_fcnxpro129_LimbicA_2_BasalGanglia
Limbic Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.basalganglia
rsfMRI_fcnxpro129_LimbicA_2_MidBrain
Limbic Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbica.2.midbrain
rsfMRI_fcnxpro129_LimbicB_2_TempPar
Limbic Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.temppar
rsfMRI_fcnxpro129_LimbicB_2_DefaultC
Limbic Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.defaultc
rsfMRI_fcnxpro129_LimbicB_2_DefaultB
Limbic Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.defaultb
rsfMRI_fcnxpro129_LimbicB_2_DefaultA
Limbic Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.defaulta
rsfMRI_fcnxpro129_LimbicB_2_ContC
Limbic Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.contc
rsfMRI_fcnxpro129_LimbicB_2_ContB
Limbic Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.contb
rsfMRI_fcnxpro129_LimbicB_2_ContA
Limbic Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.conta
rsfMRI_fcnxpro129_LimbicB_2_LimbicA
Limbic Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.limbica
rsfMRI_fcnxpro129_LimbicB_2_LimbicB
Limbic Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.limbicb
rsfMRI_fcnxpro129_LimbicB_2_SalVentAttnB
Limbic Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.salventattnb
rsfMRI_fcnxpro129_LimbicB_2_SalVentAttnA
Limbic Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.salventattna
rsfMRI_fcnxpro129_LimbicB_2_DorsAttnB
Limbic Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.dorsattnb
rsfMRI_fcnxpro129_LimbicB_2_DorsAttnA
Limbic Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.dorsattna
rsfMRI_fcnxpro129_LimbicB_2_SomMotB
Limbic Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.sommotb
rsfMRI_fcnxpro129_LimbicB_2_SomMotA
Limbic Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.sommota
rsfMRI_fcnxpro129_LimbicB_2_VisPeri
Limbic Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.visperi
rsfMRI_fcnxpro129_LimbicB_2_VisCent
Limbic Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.viscent
rsfMRI_fcnxpro129_LimbicB_2_Striatum
Limbic Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.striatum
rsfMRI_fcnxpro129_LimbicB_2_Dopamine
Limbic Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.dopamine
rsfMRI_fcnxpro129_LimbicB_2_CITLimbic
Limbic Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.citlimbic
rsfMRI_fcnxpro129_LimbicB_2_BasalGanglia
Limbic Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.basalganglia
rsfMRI_fcnxpro129_LimbicB_2_MidBrain
Limbic Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.limbicb.2.midbrain
rsfMRI_fcnxpro129_SalVentAttnB_2_TempPar
Salience/Ventral Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.temppar
rsfMRI_fcnxpro129_SalVentAttnB_2_DefaultC
Salience/Ventral Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.defaultc
rsfMRI_fcnxpro129_SalVentAttnB_2_DefaultB
Salience/Ventral Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.defaultb
rsfMRI_fcnxpro129_SalVentAttnB_2_DefaultA
Salience/Ventral Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.defaulta
rsfMRI_fcnxpro129_SalVentAttnB_2_ContC
Salience/Ventral Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.contc
rsfMRI_fcnxpro129_SalVentAttnB_2_ContB
Salience/Ventral Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.contb
rsfMRI_fcnxpro129_SalVentAttnB_2_ContA
Salience/Ventral Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.conta
rsfMRI_fcnxpro129_SalVentAttnB_2_LimbicA
Salience/Ventral Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.limbica
rsfMRI_fcnxpro129_SalVentAttnB_2_LimbicB
Salience/Ventral Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.limbicb
rsfMRI_fcnxpro129_SalVentAttnB_2_SalVentAttnB
Salience/Ventral Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.salventattnb
rsfMRI_fcnxpro129_SalVentAttnB_2_SalVentAttnA
Salience/Ventral Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.salventattna
rsfMRI_fcnxpro129_SalVentAttnB_2_DorsAttnB
Salience/Ventral Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.dorsattnb
rsfMRI_fcnxpro129_SalVentAttnB_2_DorsAttnA
Salience/Ventral Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.dorsattna
rsfMRI_fcnxpro129_SalVentAttnB_2_SomMotB
Salience/Ventral Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.sommotb
rsfMRI_fcnxpro129_SalVentAttnB_2_SomMotA
Salience/Ventral Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.sommota
rsfMRI_fcnxpro129_SalVentAttnB_2_VisPeri
Salience/Ventral Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.visperi
rsfMRI_fcnxpro129_SalVentAttnB_2_VisCent
Salience/Ventral Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.viscent
rsfMRI_fcnxpro129_SalVentAttnB_2_Striatum
Salience/Ventral Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.striatum
rsfMRI_fcnxpro129_SalVentAttnB_2_Dopamine
Salience/Ventral Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.dopamine
rsfMRI_fcnxpro129_SalVentAttnB_2_CITLimbic
Salience/Ventral Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.citlimbic
rsfMRI_fcnxpro129_SalVentAttnB_2_BasalGanglia
Salience/Ventral Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.basalganglia
rsfMRI_fcnxpro129_SalVentAttnB_2_MidBrain
Salience/Ventral Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattnb.2.midbrain
rsfMRI_fcnxpro129_SalVentAttnA_2_TempPar
Salience/Ventral Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.temppar
rsfMRI_fcnxpro129_SalVentAttnA_2_DefaultC
Salience/Ventral Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.defaultc
rsfMRI_fcnxpro129_SalVentAttnA_2_DefaultB
Salience/Ventral Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.defaultb
rsfMRI_fcnxpro129_SalVentAttnA_2_DefaultA
Salience/Ventral Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.defaulta
rsfMRI_fcnxpro129_SalVentAttnA_2_ContC
Salience/Ventral Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.contc
rsfMRI_fcnxpro129_SalVentAttnA_2_ContB
Salience/Ventral Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.contb
rsfMRI_fcnxpro129_SalVentAttnA_2_ContA
Salience/Ventral Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.conta
rsfMRI_fcnxpro129_SalVentAttnA_2_LimbicA
Salience/Ventral Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.limbica
rsfMRI_fcnxpro129_SalVentAttnA_2_LimbicB
Salience/Ventral Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.limbicb
rsfMRI_fcnxpro129_SalVentAttnA_2_SalVentAttnB
Salience/Ventral Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.salventattnb
rsfMRI_fcnxpro129_SalVentAttnA_2_SalVentAttnA
Salience/Ventral Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.salventattna
rsfMRI_fcnxpro129_SalVentAttnA_2_DorsAttnB
Salience/Ventral Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.dorsattnb
rsfMRI_fcnxpro129_SalVentAttnA_2_DorsAttnA
Salience/Ventral Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.dorsattna
rsfMRI_fcnxpro129_SalVentAttnA_2_SomMotB
Salience/Ventral Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.sommotb
rsfMRI_fcnxpro129_SalVentAttnA_2_SomMotA
Salience/Ventral Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.sommota
rsfMRI_fcnxpro129_SalVentAttnA_2_VisPeri
Salience/Ventral Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.visperi
rsfMRI_fcnxpro129_SalVentAttnA_2_VisCent
Salience/Ventral Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.viscent
rsfMRI_fcnxpro129_SalVentAttnA_2_Striatum
Salience/Ventral Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.striatum
rsfMRI_fcnxpro129_SalVentAttnA_2_Dopamine
Salience/Ventral Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.dopamine
rsfMRI_fcnxpro129_SalVentAttnA_2_CITLimbic
Salience/Ventral Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.citlimbic
rsfMRI_fcnxpro129_SalVentAttnA_2_BasalGanglia
Salience/Ventral Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.basalganglia
rsfMRI_fcnxpro129_SalVentAttnA_2_MidBrain
Salience/Ventral Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.salventattna.2.midbrain
rsfMRI_fcnxpro129_DorsAttnB_2_TempPar
Dorsal Attention Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.temppar
rsfMRI_fcnxpro129_DorsAttnB_2_DefaultC
Dorsal Attention Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.defaultc
rsfMRI_fcnxpro129_DorsAttnB_2_DefaultB
Dorsal Attention Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.defaultb
rsfMRI_fcnxpro129_DorsAttnB_2_DefaultA
Dorsal Attention Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.defaulta
rsfMRI_fcnxpro129_DorsAttnB_2_ContC
Dorsal Attention Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.contc
rsfMRI_fcnxpro129_DorsAttnB_2_ContB
Dorsal Attention Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.contb
rsfMRI_fcnxpro129_DorsAttnB_2_ContA
Dorsal Attention Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.conta
rsfMRI_fcnxpro129_DorsAttnB_2_LimbicA
Dorsal Attention Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.limbica
rsfMRI_fcnxpro129_DorsAttnB_2_LimbicB
Dorsal Attention Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.limbicb
rsfMRI_fcnxpro129_DorsAttnB_2_SalVentAttnB
Dorsal Attention Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.salventattnb
rsfMRI_fcnxpro129_DorsAttnB_2_SalVentAttnA
Dorsal Attention Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.salventattna
rsfMRI_fcnxpro129_DorsAttnB_2_DorsAttnB
Dorsal Attention Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.dorsattnb
rsfMRI_fcnxpro129_DorsAttnB_2_DorsAttnA
Dorsal Attention Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.dorsattna
rsfMRI_fcnxpro129_DorsAttnB_2_SomMotB
Dorsal Attention Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.sommotb
rsfMRI_fcnxpro129_DorsAttnB_2_SomMotA
Dorsal Attention Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.sommota
rsfMRI_fcnxpro129_DorsAttnB_2_VisPeri
Dorsal Attention Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.visperi
rsfMRI_fcnxpro129_DorsAttnB_2_VisCent
Dorsal Attention Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.viscent
rsfMRI_fcnxpro129_DorsAttnB_2_Striatum
Dorsal Attention Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.striatum
rsfMRI_fcnxpro129_DorsAttnB_2_Dopamine
Dorsal Attention Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.dopamine
rsfMRI_fcnxpro129_DorsAttnB_2_CITLimbic
Dorsal Attention Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.citlimbic
rsfMRI_fcnxpro129_DorsAttnB_2_BasalGanglia
Dorsal Attention Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.basalganglia
rsfMRI_fcnxpro129_DorsAttnB_2_MidBrain
Dorsal Attention Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattnb.2.midbrain
rsfMRI_fcnxpro129_DorsAttnA_2_TempPar
Dorsal Attention Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.temppar
rsfMRI_fcnxpro129_DorsAttnA_2_DefaultC
Dorsal Attention Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.defaultc
rsfMRI_fcnxpro129_DorsAttnA_2_DefaultB
Dorsal Attention Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.defaultb
rsfMRI_fcnxpro129_DorsAttnA_2_DefaultA
Dorsal Attention Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.defaulta
rsfMRI_fcnxpro129_DorsAttnA_2_ContC
Dorsal Attention Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.contc
rsfMRI_fcnxpro129_DorsAttnA_2_ContB
Dorsal Attention Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.contb
rsfMRI_fcnxpro129_DorsAttnA_2_ContA
Dorsal Attention Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.conta
rsfMRI_fcnxpro129_DorsAttnA_2_LimbicA
Dorsal Attention Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.limbica
rsfMRI_fcnxpro129_DorsAttnA_2_LimbicB
Dorsal Attention Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.limbicb
rsfMRI_fcnxpro129_DorsAttnA_2_SalVentAttnB
Dorsal Attention Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.salventattnb
rsfMRI_fcnxpro129_DorsAttnA_2_SalVentAttnA
Dorsal Attention Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.salventattna
rsfMRI_fcnxpro129_DorsAttnA_2_DorsAttnB
Dorsal Attention Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.dorsattnb
rsfMRI_fcnxpro129_DorsAttnA_2_DorsAttnA
Dorsal Attention Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.dorsattna
rsfMRI_fcnxpro129_DorsAttnA_2_SomMotB
Dorsal Attention Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.sommotb
rsfMRI_fcnxpro129_DorsAttnA_2_SomMotA
Dorsal Attention Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.sommota
rsfMRI_fcnxpro129_DorsAttnA_2_VisPeri
Dorsal Attention Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.visperi
rsfMRI_fcnxpro129_DorsAttnA_2_VisCent
Dorsal Attention Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.viscent
rsfMRI_fcnxpro129_DorsAttnA_2_Striatum
Dorsal Attention Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.striatum
rsfMRI_fcnxpro129_DorsAttnA_2_Dopamine
Dorsal Attention Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.dopamine
rsfMRI_fcnxpro129_DorsAttnA_2_CITLimbic
Dorsal Attention Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.citlimbic
rsfMRI_fcnxpro129_DorsAttnA_2_BasalGanglia
Dorsal Attention Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.basalganglia
rsfMRI_fcnxpro129_DorsAttnA_2_MidBrain
Dorsal Attention Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dorsattna.2.midbrain
rsfMRI_fcnxpro129_SomMotB_2_TempPar
Somatomotor Network B to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.temppar
rsfMRI_fcnxpro129_SomMotB_2_DefaultC
Somatomotor Network B to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.defaultc
rsfMRI_fcnxpro129_SomMotB_2_DefaultB
Somatomotor Network B to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.defaultb
rsfMRI_fcnxpro129_SomMotB_2_DefaultA
Somatomotor Network B to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.defaulta
rsfMRI_fcnxpro129_SomMotB_2_ContC
Somatomotor Network B to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.contc
rsfMRI_fcnxpro129_SomMotB_2_ContB
Somatomotor Network B to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.contb
rsfMRI_fcnxpro129_SomMotB_2_ContA
Somatomotor Network B to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.conta
rsfMRI_fcnxpro129_SomMotB_2_LimbicA
Somatomotor Network B to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.limbica
rsfMRI_fcnxpro129_SomMotB_2_LimbicB
Somatomotor Network B to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.limbicb
rsfMRI_fcnxpro129_SomMotB_2_SalVentAttnB
Somatomotor Network B to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.salventattnb
rsfMRI_fcnxpro129_SomMotB_2_SalVentAttnA
Somatomotor Network B to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.salventattna
rsfMRI_fcnxpro129_SomMotB_2_DorsAttnB
Somatomotor Network B to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.dorsattnb
rsfMRI_fcnxpro129_SomMotB_2_DorsAttnA
Somatomotor Network B to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.dorsattna
rsfMRI_fcnxpro129_SomMotB_2_SomMotB
Somatomotor Network B to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.sommotb
rsfMRI_fcnxpro129_SomMotB_2_SomMotA
Somatomotor Network B to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.sommota
rsfMRI_fcnxpro129_SomMotB_2_VisPeri
Somatomotor Network B to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.visperi
rsfMRI_fcnxpro129_SomMotB_2_VisCent
Somatomotor Network B to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.viscent
rsfMRI_fcnxpro129_SomMotB_2_Striatum
Somatomotor Network B to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.striatum
rsfMRI_fcnxpro129_SomMotB_2_Dopamine
Somatomotor Network B to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.dopamine
rsfMRI_fcnxpro129_SomMotB_2_CITLimbic
Somatomotor Network B to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.citlimbic
rsfMRI_fcnxpro129_SomMotB_2_BasalGanglia
Somatomotor Network B to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.basalganglia
rsfMRI_fcnxpro129_SomMotB_2_MidBrain
Somatomotor Network B to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommotb.2.midbrain
rsfMRI_fcnxpro129_SomMotA_2_TempPar
Somatomotor Network A to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.temppar
rsfMRI_fcnxpro129_SomMotA_2_DefaultC
Somatomotor Network A to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.defaultc
rsfMRI_fcnxpro129_SomMotA_2_DefaultB
Somatomotor Network A to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.defaultb
rsfMRI_fcnxpro129_SomMotA_2_DefaultA
Somatomotor Network A to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.defaulta
rsfMRI_fcnxpro129_SomMotA_2_ContC
Somatomotor Network A to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.contc
rsfMRI_fcnxpro129_SomMotA_2_ContB
Somatomotor Network A to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.contb
rsfMRI_fcnxpro129_SomMotA_2_ContA
Somatomotor Network A to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.conta
rsfMRI_fcnxpro129_SomMotA_2_LimbicA
Somatomotor Network A to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.limbica
rsfMRI_fcnxpro129_SomMotA_2_LimbicB
Somatomotor Network A to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.limbicb
rsfMRI_fcnxpro129_SomMotA_2_SalVentAttnB
Somatomotor Network A to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.salventattnb
rsfMRI_fcnxpro129_SomMotA_2_SalVentAttnA
Somatomotor Network A to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.salventattna
rsfMRI_fcnxpro129_SomMotA_2_DorsAttnB
Somatomotor Network A to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.dorsattnb
rsfMRI_fcnxpro129_SomMotA_2_DorsAttnA
Somatomotor Network A to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.dorsattna
rsfMRI_fcnxpro129_SomMotA_2_SomMotB
Somatomotor Network A to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.sommotb
rsfMRI_fcnxpro129_SomMotA_2_SomMotA
Somatomotor Network A to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.sommota
rsfMRI_fcnxpro129_SomMotA_2_VisPeri
Somatomotor Network A to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.visperi
rsfMRI_fcnxpro129_SomMotA_2_VisCent
Somatomotor Network A to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.viscent
rsfMRI_fcnxpro129_SomMotA_2_Striatum
Somatomotor Network A to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.striatum
rsfMRI_fcnxpro129_SomMotA_2_Dopamine
Somatomotor Network A to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.dopamine
rsfMRI_fcnxpro129_SomMotA_2_CITLimbic
Somatomotor Network A to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.citlimbic
rsfMRI_fcnxpro129_SomMotA_2_BasalGanglia
Somatomotor Network A to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.basalganglia
rsfMRI_fcnxpro129_SomMotA_2_MidBrain
Somatomotor Network A to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.sommota.2.midbrain
rsfMRI_fcnxpro129_VisPeri_2_TempPar
Visual Network Peripheral to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.temppar
rsfMRI_fcnxpro129_VisPeri_2_DefaultC
Visual Network Peripheral to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.defaultc
rsfMRI_fcnxpro129_VisPeri_2_DefaultB
Visual Network Peripheral to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.defaultb
rsfMRI_fcnxpro129_VisPeri_2_DefaultA
Visual Network Peripheral to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.defaulta
rsfMRI_fcnxpro129_VisPeri_2_ContC
Visual Network Peripheral to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.contc
rsfMRI_fcnxpro129_VisPeri_2_ContB
Visual Network Peripheral to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.contb
rsfMRI_fcnxpro129_VisPeri_2_ContA
Visual Network Peripheral to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.conta
rsfMRI_fcnxpro129_VisPeri_2_LimbicA
Visual Network Peripheral to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.limbica
rsfMRI_fcnxpro129_VisPeri_2_LimbicB
Visual Network Peripheral to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.limbicb
rsfMRI_fcnxpro129_VisPeri_2_SalVentAttnB
Visual Network Peripheral to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.salventattnb
rsfMRI_fcnxpro129_VisPeri_2_SalVentAttnA
Visual Network Peripheral to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.salventattna
rsfMRI_fcnxpro129_VisPeri_2_DorsAttnB
Visual Network Peripheral to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.dorsattnb
rsfMRI_fcnxpro129_VisPeri_2_DorsAttnA
Visual Network Peripheral to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.dorsattna
rsfMRI_fcnxpro129_VisPeri_2_SomMotB
Visual Network Peripheral to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.sommotb
rsfMRI_fcnxpro129_VisPeri_2_SomMotA
Visual Network Peripheral to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.sommota
rsfMRI_fcnxpro129_VisPeri_2_VisPeri
Visual Network Peripheral to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.visperi
rsfMRI_fcnxpro129_VisPeri_2_VisCent
Visual Network Peripheral to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.viscent
rsfMRI_fcnxpro129_VisPeri_2_Striatum
Visual Network Peripheral to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.striatum
rsfMRI_fcnxpro129_VisPeri_2_Dopamine
Visual Network Peripheral to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.dopamine
rsfMRI_fcnxpro129_VisPeri_2_CITLimbic
Visual Network Peripheral to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.citlimbic
rsfMRI_fcnxpro129_VisPeri_2_BasalGanglia
Visual Network Peripheral to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.basalganglia
rsfMRI_fcnxpro129_VisPeri_2_MidBrain
Visual Network Peripheral to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.visperi.2.midbrain
rsfMRI_fcnxpro129_VisCent_2_TempPar
Visual Network Central to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.temppar
rsfMRI_fcnxpro129_VisCent_2_DefaultC
Visual Network Central to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.defaultc
rsfMRI_fcnxpro129_VisCent_2_DefaultB
Visual Network Central to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.defaultb
rsfMRI_fcnxpro129_VisCent_2_DefaultA
Visual Network Central to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.defaulta
rsfMRI_fcnxpro129_VisCent_2_ContC
Visual Network Central to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.contc
rsfMRI_fcnxpro129_VisCent_2_ContB
Visual Network Central to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.contb
rsfMRI_fcnxpro129_VisCent_2_ContA
Visual Network Central to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.conta
rsfMRI_fcnxpro129_VisCent_2_LimbicA
Visual Network Central to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.limbica
rsfMRI_fcnxpro129_VisCent_2_LimbicB
Visual Network Central to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.limbicb
rsfMRI_fcnxpro129_VisCent_2_SalVentAttnB
Visual Network Central to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.salventattnb
rsfMRI_fcnxpro129_VisCent_2_SalVentAttnA
Visual Network Central to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.salventattna
rsfMRI_fcnxpro129_VisCent_2_DorsAttnB
Visual Network Central to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.dorsattnb
rsfMRI_fcnxpro129_VisCent_2_DorsAttnA
Visual Network Central to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.dorsattna
rsfMRI_fcnxpro129_VisCent_2_SomMotB
Visual Network Central to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.sommotb
rsfMRI_fcnxpro129_VisCent_2_SomMotA
Visual Network Central to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.sommota
rsfMRI_fcnxpro129_VisCent_2_VisPeri
Visual Network Central to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.visperi
rsfMRI_fcnxpro129_VisCent_2_VisCent
Visual Network Central to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.viscent
rsfMRI_fcnxpro129_VisCent_2_Striatum
Visual Network Central to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.striatum
rsfMRI_fcnxpro129_VisCent_2_Dopamine
Visual Network Central to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.dopamine
rsfMRI_fcnxpro129_VisCent_2_CITLimbic
Visual Network Central to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.citlimbic
rsfMRI_fcnxpro129_VisCent_2_BasalGanglia
Visual Network Central to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.basalganglia
rsfMRI_fcnxpro129_VisCent_2_MidBrain
Visual Network Central to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.viscent.2.midbrain
rsfMRI_fcnxpro129_Striatum_2_TempPar
Striatal Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.temppar
rsfMRI_fcnxpro129_Striatum_2_DefaultC
Striatal Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.defaultc
rsfMRI_fcnxpro129_Striatum_2_DefaultB
Striatal Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.defaultb
rsfMRI_fcnxpro129_Striatum_2_DefaultA
Striatal Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.defaulta
rsfMRI_fcnxpro129_Striatum_2_ContC
Striatal Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.contc
rsfMRI_fcnxpro129_Striatum_2_ContB
Striatal Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.contb
rsfMRI_fcnxpro129_Striatum_2_ContA
Striatal Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.conta
rsfMRI_fcnxpro129_Striatum_2_LimbicA
Striatal Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.limbica
rsfMRI_fcnxpro129_Striatum_2_LimbicB
Striatal Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.limbicb
rsfMRI_fcnxpro129_Striatum_2_SalVentAttnB
Striatal Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.salventattnb
rsfMRI_fcnxpro129_Striatum_2_SalVentAttnA
Striatal Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.salventattna
rsfMRI_fcnxpro129_Striatum_2_DorsAttnB
Striatal Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.dorsattnb
rsfMRI_fcnxpro129_Striatum_2_DorsAttnA
Striatal Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.dorsattna
rsfMRI_fcnxpro129_Striatum_2_SomMotB
Striatal Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.sommotb
rsfMRI_fcnxpro129_Striatum_2_SomMotA
Striatal Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.sommota
rsfMRI_fcnxpro129_Striatum_2_VisPeri
Striatal Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.visperi
rsfMRI_fcnxpro129_Striatum_2_VisCent
Striatal Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.viscent
rsfMRI_fcnxpro129_Striatum_2_Striatum
Striatal Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.striatum
rsfMRI_fcnxpro129_Striatum_2_Dopamine
Striatal Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.dopamine
rsfMRI_fcnxpro129_Striatum_2_CITLimbic
Striatal Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.citlimbic
rsfMRI_fcnxpro129_Striatum_2_BasalGanglia
Striatal Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.basalganglia
rsfMRI_fcnxpro129_Striatum_2_MidBrain
Striatal Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.striatum.2.midbrain
rsfMRI_fcnxpro129_Dopamine_2_TempPar
Dopaminergic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.temppar
rsfMRI_fcnxpro129_Dopamine_2_DefaultC
Dopaminergic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.defaultc
rsfMRI_fcnxpro129_Dopamine_2_DefaultB
Dopaminergic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.defaultb
rsfMRI_fcnxpro129_Dopamine_2_DefaultA
Dopaminergic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.defaulta
rsfMRI_fcnxpro129_Dopamine_2_ContC
Dopaminergic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.contc
rsfMRI_fcnxpro129_Dopamine_2_ContB
Dopaminergic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.contb
rsfMRI_fcnxpro129_Dopamine_2_ContA
Dopaminergic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.conta
rsfMRI_fcnxpro129_Dopamine_2_LimbicA
Dopaminergic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.limbica
rsfMRI_fcnxpro129_Dopamine_2_LimbicB
Dopaminergic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.limbicb
rsfMRI_fcnxpro129_Dopamine_2_SalVentAttnB
Dopaminergic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.salventattnb
rsfMRI_fcnxpro129_Dopamine_2_SalVentAttnA
Dopaminergic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.salventattna
rsfMRI_fcnxpro129_Dopamine_2_DorsAttnB
Dopaminergic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.dorsattnb
rsfMRI_fcnxpro129_Dopamine_2_DorsAttnA
Dopaminergic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.dorsattna
rsfMRI_fcnxpro129_Dopamine_2_SomMotB
Dopaminergic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.sommotb
rsfMRI_fcnxpro129_Dopamine_2_SomMotA
Dopaminergic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.sommota
rsfMRI_fcnxpro129_Dopamine_2_VisPeri
Dopaminergic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.visperi
rsfMRI_fcnxpro129_Dopamine_2_VisCent
Dopaminergic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.viscent
rsfMRI_fcnxpro129_Dopamine_2_Striatum
Dopaminergic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.striatum
rsfMRI_fcnxpro129_Dopamine_2_Dopamine
Dopaminergic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.dopamine
rsfMRI_fcnxpro129_Dopamine_2_CITLimbic
Dopaminergic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.citlimbic
rsfMRI_fcnxpro129_Dopamine_2_BasalGanglia
Dopaminergic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.basalganglia
rsfMRI_fcnxpro129_Dopamine_2_MidBrain
Dopaminergic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.dopamine.2.midbrain
rsfMRI_fcnxpro129_CITLimbic_2_TempPar
CIT Atlas Limbic Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.temppar
rsfMRI_fcnxpro129_CITLimbic_2_DefaultC
CIT Atlas Limbic Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.defaultc
rsfMRI_fcnxpro129_CITLimbic_2_DefaultB
CIT Atlas Limbic Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.defaultb
rsfMRI_fcnxpro129_CITLimbic_2_DefaultA
CIT Atlas Limbic Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.defaulta
rsfMRI_fcnxpro129_CITLimbic_2_ContC
CIT Atlas Limbic Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.contc
rsfMRI_fcnxpro129_CITLimbic_2_ContB
CIT Atlas Limbic Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.contb
rsfMRI_fcnxpro129_CITLimbic_2_ContA
CIT Atlas Limbic Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.conta
rsfMRI_fcnxpro129_CITLimbic_2_LimbicA
CIT Atlas Limbic Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.limbica
rsfMRI_fcnxpro129_CITLimbic_2_LimbicB
CIT Atlas Limbic Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.limbicb
rsfMRI_fcnxpro129_CITLimbic_2_SalVentAttnB
CIT Atlas Limbic Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.salventattnb
rsfMRI_fcnxpro129_CITLimbic_2_SalVentAttnA
CIT Atlas Limbic Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.salventattna
rsfMRI_fcnxpro129_CITLimbic_2_DorsAttnB
CIT Atlas Limbic Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.dorsattnb
rsfMRI_fcnxpro129_CITLimbic_2_DorsAttnA
CIT Atlas Limbic Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.dorsattna
rsfMRI_fcnxpro129_CITLimbic_2_SomMotB
CIT Atlas Limbic Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.sommotb
rsfMRI_fcnxpro129_CITLimbic_2_SomMotA
CIT Atlas Limbic Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.sommota
rsfMRI_fcnxpro129_CITLimbic_2_VisPeri
CIT Atlas Limbic Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.visperi
rsfMRI_fcnxpro129_CITLimbic_2_VisCent
CIT Atlas Limbic Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.viscent
rsfMRI_fcnxpro129_CITLimbic_2_Striatum
CIT Atlas Limbic Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.striatum
rsfMRI_fcnxpro129_CITLimbic_2_Dopamine
CIT Atlas Limbic Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.dopamine
rsfMRI_fcnxpro129_CITLimbic_2_CITLimbic
CIT Atlas Limbic Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.citlimbic
rsfMRI_fcnxpro129_CITLimbic_2_BasalGanglia
CIT Atlas Limbic Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.basalganglia
rsfMRI_fcnxpro129_CITLimbic_2_MidBrain
CIT Atlas Limbic Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.citlimbic.2.midbrain
rsfMRI_fcnxpro129_BasalGanglia_2_TempPar
Basal Ganglia Network to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.temppar
rsfMRI_fcnxpro129_BasalGanglia_2_DefaultC
Basal Ganglia Network to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.defaultc
rsfMRI_fcnxpro129_BasalGanglia_2_DefaultB
Basal Ganglia Network to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.defaultb
rsfMRI_fcnxpro129_BasalGanglia_2_DefaultA
Basal Ganglia Network to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.defaulta
rsfMRI_fcnxpro129_BasalGanglia_2_ContC
Basal Ganglia Network to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.contc
rsfMRI_fcnxpro129_BasalGanglia_2_ContB
Basal Ganglia Network to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.contb
rsfMRI_fcnxpro129_BasalGanglia_2_ContA
Basal Ganglia Network to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.conta
rsfMRI_fcnxpro129_BasalGanglia_2_LimbicA
Basal Ganglia Network to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.limbica
rsfMRI_fcnxpro129_BasalGanglia_2_LimbicB
Basal Ganglia Network to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.limbicb
rsfMRI_fcnxpro129_BasalGanglia_2_SalVentAttnB
Basal Ganglia Network to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.salventattnb
rsfMRI_fcnxpro129_BasalGanglia_2_SalVentAttnA
Basal Ganglia Network to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.salventattna
rsfMRI_fcnxpro129_BasalGanglia_2_DorsAttnB
Basal Ganglia Network to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.dorsattnb
rsfMRI_fcnxpro129_BasalGanglia_2_DorsAttnA
Basal Ganglia Network to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.dorsattna
rsfMRI_fcnxpro129_BasalGanglia_2_SomMotB
Basal Ganglia Network to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.sommotb
rsfMRI_fcnxpro129_BasalGanglia_2_SomMotA
Basal Ganglia Network to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.sommota
rsfMRI_fcnxpro129_BasalGanglia_2_VisPeri
Basal Ganglia Network to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.visperi
rsfMRI_fcnxpro129_BasalGanglia_2_VisCent
Basal Ganglia Network to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.viscent
rsfMRI_fcnxpro129_BasalGanglia_2_Striatum
Basal Ganglia Network to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.striatum
rsfMRI_fcnxpro129_BasalGanglia_2_Dopamine
Basal Ganglia Network to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.dopamine
rsfMRI_fcnxpro129_BasalGanglia_2_CITLimbic
Basal Ganglia Network to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.citlimbic
rsfMRI_fcnxpro129_BasalGanglia_2_BasalGanglia
Basal Ganglia Network to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.basalganglia
rsfMRI_fcnxpro129_BasalGanglia_2_MidBrain
Basal Ganglia Network to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.basalganglia.2.midbrain
rsfMRI_fcnxpro129_MidBrain_2_TempPar
Midbrain to Temporo-Parietal
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.temppar
rsfMRI_fcnxpro129_MidBrain_2_DefaultC
Midbrain to Default Mode Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.defaultc
rsfMRI_fcnxpro129_MidBrain_2_DefaultB
Midbrain to Default Mode Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.defaultb
rsfMRI_fcnxpro129_MidBrain_2_DefaultA
Midbrain to Default Mode Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.defaulta
rsfMRI_fcnxpro129_MidBrain_2_ContC
Midbrain to Frontoparietal Control Network C
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.contc
rsfMRI_fcnxpro129_MidBrain_2_ContB
Midbrain to Frontoparietal Control Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.contb
rsfMRI_fcnxpro129_MidBrain_2_ContA
Midbrain to Frontoparietal Control Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.conta
rsfMRI_fcnxpro129_MidBrain_2_LimbicA
Midbrain to Limbic Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.limbica
rsfMRI_fcnxpro129_MidBrain_2_LimbicB
Midbrain to Limbic Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.limbicb
rsfMRI_fcnxpro129_MidBrain_2_SalVentAttnB
Midbrain to Salience/Ventral Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.salventattnb
rsfMRI_fcnxpro129_MidBrain_2_SalVentAttnA
Midbrain to Salience/Ventral Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.salventattna
rsfMRI_fcnxpro129_MidBrain_2_DorsAttnB
Midbrain to Dorsal Attention Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.dorsattnb
rsfMRI_fcnxpro129_MidBrain_2_DorsAttnA
Midbrain to Dorsal Attention Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.dorsattna
rsfMRI_fcnxpro129_MidBrain_2_SomMotB
Midbrain to Somatomotor Network B
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.sommotb
rsfMRI_fcnxpro129_MidBrain_2_SomMotA
Midbrain to Somatomotor Network A
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.sommota
rsfMRI_fcnxpro129_MidBrain_2_VisPeri
Midbrain to Visual Network Peripheral
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.visperi
rsfMRI_fcnxpro129_MidBrain_2_VisCent
Midbrain to Visual Network Central
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.viscent
rsfMRI_fcnxpro129_MidBrain_2_Striatum
Midbrain to Striatal Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.striatum
rsfMRI_fcnxpro129_MidBrain_2_Dopamine
Midbrain to Dopaminergic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.dopamine
rsfMRI_fcnxpro129_MidBrain_2_CITLimbic
Midbrain to CIT Atlas Limbic Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.citlimbic
rsfMRI_fcnxpro129_MidBrain_2_BasalGanglia
Midbrain to Basal Ganglia Network
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.basalganglia
rsfMRI_fcnxpro129_MidBrain_2_MidBrain
Midbrain to Midbrain
restingStatefMRI
Connectivity
power peterson fMRI meta-analyses
129
​
rsf.p2.midbrain.2.midbrain
NM2DMT_mean_bn_gp_gpe_left
Globus Pallidus External
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.gp.gpe.left
NM2DMT_mean_bn_gp_gpe_right
Globus Pallidus External
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.gp.gpe.right
NM2DMT_mean_bn_gp_gpi_left
Globus Pallidus Internal
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.gp.gpi.left
NM2DMT_mean_bn_gp_gpi_right
Globus Pallidus Internal
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.gp.gpi.right
NM2DMT_mean_bn_str_pu_left
Putamen
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.str.pu.left
NM2DMT_mean_bn_str_pu_right
Putamen
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.str.pu.right
NM2DMT_mean_mtg_rn_left
Red Nucleus
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.mtg.rn.left
NM2DMT_mean_mtg_rn_right
Red Nucleus
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.mtg.rn.right
NM2DMT_mean_mtg_sn_snc_left
Substantia Nigra Compacta
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.snc.left
NM2DMT_mean_mtg_sn_snc_right
Substantia Nigra Compacta
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.snc.right
NM2DMT_mean_mtg_sn_snr_left
Substantia Nigra Reticulata
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.snr.left
NM2DMT_mean_mtg_sn_snr_right
Substantia Nigra Reticulata
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.snr.right
NM2DMT_mean_referenceregion_left
Reference Region
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.referenceregion.left
NM2DMT_mean_referenceregion_right
Reference Region
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.referenceregion.right
NM2DMT_NM_avg_mean
Unknown Core: nm avg
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.iavg.mean
NM2DMT_NM_avg_cropped_mean
Unknown Core: nm avg cropped
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.iavg.cropped.mean
NM2DMT_NM_labels_mean
Unknown Core: nm labels
Neuromelanin
Mean Intensity
ANTs
​
​
nm.labels.mean
NM2DMT_NM_midbrainROI_mean
Unknown Core: nm midbrainroi
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.midbrainroi.mean
NM2DMT_t1_to_NM_mean
Unknown Core: t1 to nm
Neuromelanin
Mean Intensity
ANTs
​
​
nm2dmt.t1.to.nm.mean
NM2DMT_t1_to_NM_transform_mean
Unknown Core: t1 to nm transform
Neuromelanin
Mean Intensity
ANTs
​
​
nm2dmt.t1.to.nm.transform.mean
NM2DMT_NM_volume_substantianigra
Unknown Core: nm volume substantianigra
Neuromelanin
geometry.volume
ANTs
​
​
nm.vol.sn
NM2DMT_NM_volume_substantianigra_2std
Unknown Core: nm volume substantianigra 2std
Neuromelanin
geometry.volume
ANTs
​
​
nm.vol.sn.2std
NM2DMT_NM_intmean_substantianigra_2std
Unknown Core: nm intmean substantianigra 2std
Neuromelanin
Unknown
ANTs
​
​
nm.iavg.sn.2std
NM2DMT_NM_intsum_substantianigra_2std
Unknown Core: nm intsum substantianigra 2std
Neuromelanin
Unknown
ANTs
​
​
nm.isum.sn.2std
NM2DMT_NM_volume_substantianigra_3std
Unknown Core: nm volume substantianigra 3std
Neuromelanin
geometry.volume
ANTs
​
​
nm.vol.sn.3std
NM2DMT_NM_volume_substantianigra_4std
Unknown Core: nm volume substantianigra 4std
Neuromelanin
geometry.volume
ANTs
​
​
nm.vol.sn.4std
NM2DMT_NM_q0pt05
Unknown Core: nm q0pt05
Neuromelanin
Unknown
ANTs
​
​
nm.q0pt05
NM2DMT_NM_q0pt10
Unknown Core: nm q0pt10
Neuromelanin
Unknown
ANTs
​
​
nm.q0pt10
NM2DMT_NM_q0pt90
Unknown Core: nm q0pt90
Neuromelanin
Unknown
ANTs
​
​
nm.q0pt90
NM2DMT_NM_q0pt95
Unknown Core: nm q0pt95
Neuromelanin
Unknown
ANTs
​
​
nm.q0pt95
NM2DMT_NM_substantianigra_z_coordinate
Unknown Core: nm substantianigra z coordinate
Neuromelanin
Estimate of the normalize (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab
ANTs
​
​
nm.sn.z.coordinate
NM2DMT_NM_evr
Unknown Core: nm
Neuromelanin
QC
ANTs
​
​
nm.evr
NM2DMT_NM_count
Unknown Core: nm count
Neuromelanin
count of neuromelanin scans that were averaged at this date
ANTs
​
​
nm.count
DTI_mean_fa.anterior_corona_radiata.left.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.cor.rad.left
DTI_mean_fa.anterior_corona_radiata.right.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.cor.rad.right
DTI_mean_fa.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.int.cap.left
DTI_mean_fa.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.int.cap.right
DTI_mean_fa.body_of_corpus_callosum.jhu_icbm_labels_1mm
Body of Corpus Callosum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.body.of.corpus.callosum
DTI_mean_fa.cerebral_peduncle.left.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cerebral.peduncle.left
DTI_mean_fa.cerebral_peduncle.right.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cerebral.peduncle.right
DTI_mean_fa.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.cingulate.gyrus.left
DTI_mean_fa.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.cingulate.gyrus.right
DTI_mean_fa.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.hippocampus.left
DTI_mean_fa.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.hippocampus.right
DTI_mean_fa.corticospinal_tract.left.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.corticospinal.tract.left
DTI_mean_fa.corticospinal_tract.right.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.corticospinal.tract.right
DTI_mean_fa.external_capsule.left.jhu_icbm_labels_1mm
External Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ext.cap.left
DTI_mean_fa.external_capsule.right.jhu_icbm_labels_1mm
External Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ext.cap.right
DTI_mean_fa.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
Fornix
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.fornix.column.and.body.of.fornix
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.fornixleft
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.fornixright
DTI_mean_fa.genu_of_corpus_callosum.jhu_icbm_labels_1mm
Genu of Corpus Callosum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.genu.of.corpus.callosum
DTI_mean_fa.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.cereb.ped.left
DTI_mean_fa.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.cereb.ped.right
DTI_mean_fa.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.frnt.occ.fasciculus.left
DTI_mean_fa.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.frnt.occ.fasciculus.right
DTI_mean_fa.medial_lemniscus.left.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.medial.lemniscus.left
DTI_mean_fa.medial_lemniscus.right.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.medial.lemniscus.right
DTI_mean_fa.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
Middle Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.middle.cereb.ped
DTI_mean_fa.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
Pontine Crossing Tract
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.pontine.crossing.tract.a.part.of.mcp
DTI_mean_fa.posterior_corona_radiata.left.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.cor.rad.left
DTI_mean_fa.posterior_corona_radiata.right.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.cor.rad.right
DTI_mean_fa.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.int.cap.left
DTI_mean_fa.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.int.cap.right
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.thalamic.radiation.left
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.thalamic.radiation.right
DTI_mean_fa.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.rent.int.cap.left
DTI_mean_fa.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.rent.int.cap.right
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ilf.and.ifoleft
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ilf.and.iforight
DTI_mean_fa.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
Splenium of Corpus Callosum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.splenium.of.corpus.callosum
DTI_mean_fa.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cereb.ped.left
DTI_mean_fa.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cereb.ped.right
DTI_mean_fa.superior_corona_radiata.left.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cor.rad.left
DTI_mean_fa.superior_corona_radiata.right.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cor.rad.right
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.frnt.occ.fasc.left
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.frnt.occ.fasc.right
DTI_mean_fa.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.l.fasc.left
DTI_mean_fa.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.l.fasc.right
DTI_mean_fa.tapetum.left.jhu_icbm_labels_1mm
Tapetum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.tapetum.left
DTI_mean_fa.tapetum.right.jhu_icbm_labels_1mm
Tapetum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.tapetum.right
DTI_mean_fa.uncinate_fasciculus.left.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.uncinate.fasciculus.left
DTI_mean_fa.uncinate_fasciculus.right.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.uncinate.fasciculus.right
DTI_mean_fa.unclassified.jhu_icbm_labels_1mm
Unclassified
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.unclassified
DTI_mean_md.anterior_corona_radiata.left.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.cor.rad.left
DTI_mean_md.anterior_corona_radiata.right.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.cor.rad.right
DTI_mean_md.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.int.cap.left
DTI_mean_md.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.int.cap.right
DTI_mean_md.body_of_corpus_callosum.jhu_icbm_labels_1mm
Body of Corpus Callosum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.body.of.corpus.callosum
DTI_mean_md.cerebral_peduncle.left.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cerebral.peduncle.left
DTI_mean_md.cerebral_peduncle.right.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cerebral.peduncle.right
DTI_mean_md.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.cingulate.gyrus.left
DTI_mean_md.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.cingulate.gyrus.right
DTI_mean_md.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.hippocampus.left
DTI_mean_md.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.hippocampus.right
DTI_mean_md.corticospinal_tract.left.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.corticospinal.tract.left
DTI_mean_md.corticospinal_tract.right.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.corticospinal.tract.right
DTI_mean_md.external_capsule.left.jhu_icbm_labels_1mm
External Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ext.cap.left
DTI_mean_md.external_capsule.right.jhu_icbm_labels_1mm
External Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ext.cap.right
DTI_mean_md.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
Fornix
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.fornix.column.and.body.of.fornix
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.fornixleft
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.fornixright
DTI_mean_md.genu_of_corpus_callosum.jhu_icbm_labels_1mm
Genu of Corpus Callosum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.genu.of.corpus.callosum
DTI_mean_md.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.cereb.ped.left
DTI_mean_md.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.cereb.ped.right
DTI_mean_md.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.frnt.occ.fasciculus.left
DTI_mean_md.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.frnt.occ.fasciculus.right
DTI_mean_md.medial_lemniscus.left.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.medial.lemniscus.left
DTI_mean_md.medial_lemniscus.right.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.medial.lemniscus.right
DTI_mean_md.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
Middle Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.middle.cereb.ped
DTI_mean_md.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
Pontine Crossing Tract
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.pontine.crossing.tract.a.part.of.mcp
DTI_mean_md.posterior_corona_radiata.left.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.cor.rad.left
DTI_mean_md.posterior_corona_radiata.right.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.cor.rad.right
DTI_mean_md.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.int.cap.left
DTI_mean_md.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.int.cap.right
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.thalamic.radiation.left
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.thalamic.radiation.right
DTI_mean_md.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.rent.int.cap.left
DTI_mean_md.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.rent.int.cap.right
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ilf.and.ifoleft
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ilf.and.iforight
DTI_mean_md.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
Splenium of Corpus Callosum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.splenium.of.corpus.callosum
DTI_mean_md.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cereb.ped.left
DTI_mean_md.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cereb.ped.right
DTI_mean_md.superior_corona_radiata.left.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cor.rad.left
DTI_mean_md.superior_corona_radiata.right.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cor.rad.right
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.frnt.occ.fasc.left
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.frnt.occ.fasc.right
DTI_mean_md.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.l.fasc.left
DTI_mean_md.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.l.fasc.right
DTI_mean_md.tapetum.left.jhu_icbm_labels_1mm
Tapetum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.tapetum.left
DTI_mean_md.tapetum.right.jhu_icbm_labels_1mm
Tapetum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.tapetum.right
DTI_mean_md.uncinate_fasciculus.left.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.uncinate.fasciculus.left
DTI_mean_md.uncinate_fasciculus.right.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.uncinate.fasciculus.right
DTI_mean_md.unclassified.jhu_icbm_labels_1mm
Unclassified
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.unclassified
DTI_mean_fa_background
Background Signal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.background
DTI_mean_fa_left_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.caudal.ant.cingulate
DTI_mean_fa_left_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.caudal.middle.frontal
DTI_mean_fa_left_cuneus
Cuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.cuneus
DTI_mean_fa_left_entorhinal
Entorhinal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.entorhinal
DTI_mean_fa_left_fusiform
Fusiform Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.fusiform
DTI_mean_fa_left_inferior_parietal
Inferior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.inf.parietal
DTI_mean_fa_left_inferior_temporal
Inferior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.inf.temporal
DTI_mean_fa_left_insula
Insula
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.insula
DTI_mean_fa_left_isthmus_cingulate
Isthmus Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.isthmus.cingulate
DTI_mean_fa_left_lateral_occipital
Lateral Occipital Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.lateral.occipital
DTI_mean_fa_left_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.lateral.orbitofrontal
DTI_mean_fa_left_lingual
Lingual Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.lingual
DTI_mean_fa_left_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.medial.orbitofrontal
DTI_mean_fa_left_middle_temporal
Middle Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.middle.temporal
DTI_mean_fa_left_paracentral
Paracentral Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.paracent
DTI_mean_fa_left_parahippocampal
Parahippocampal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.parahippocampal
DTI_mean_fa_left_pars_opercularis
Pars Opercularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.pars.opercularis
DTI_mean_fa_left_pars_orbitalis
Pars Orbitalis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.pars.orbitalis
DTI_mean_fa_left_pars_triangularis
Pars Triangularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.pars.triangularis
DTI_mean_fa_left_pericalcarine
Pericalcarine Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.pericalcarine
DTI_mean_fa_left_postcentral
Postcentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.postcent
DTI_mean_fa_left_posterior_cingulate
Posterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.post.cingulate
DTI_mean_fa_left_precentral
Precentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.precent
DTI_mean_fa_left_precuneus
Precuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.precuneus
DTI_mean_fa_left_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.rostral.ant.cingulate
DTI_mean_fa_left_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.rostral.middle.frontal
DTI_mean_fa_left_superior_frontal
Superior Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.sup.frontal
DTI_mean_fa_left_superior_parietal
Superior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.sup.parietal
DTI_mean_fa_left_superior_temporal
Superior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.sup.temporal
DTI_mean_fa_left_supramarginal
Supramarginal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.supramarginal
DTI_mean_fa_left_transverse_temporal
Transverse Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.left.transverse.temporal
DTI_mean_fa_right_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.caudal.ant.cingulate
DTI_mean_fa_right_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.caudal.middle.frontal
DTI_mean_fa_right_cuneus
Cuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.cuneus
DTI_mean_fa_right_entorhinal
Entorhinal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.entorhinal
DTI_mean_fa_right_fusiform
Fusiform Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.fusiform
DTI_mean_fa_right_inferior_parietal
Inferior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.inf.parietal
DTI_mean_fa_right_inferior_temporal
Inferior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.inf.temporal
DTI_mean_fa_right_insula
Insula
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.insula
DTI_mean_fa_right_isthmus_cingulate
Isthmus Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.isthmus.cingulate
DTI_mean_fa_right_lateral_occipital
Lateral Occipital Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.lateral.occipital
DTI_mean_fa_right_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.lateral.orbitofrontal
DTI_mean_fa_right_lingual
Lingual Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.lingual
DTI_mean_fa_right_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.medial.orbitofrontal
DTI_mean_fa_right_middle_temporal
Middle Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.middle.temporal
DTI_mean_fa_right_paracentral
Paracentral Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.paracent
DTI_mean_fa_right_parahippocampal
Parahippocampal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.parahippocampal
DTI_mean_fa_right_pars_opercularis
Pars Opercularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.pars.opercularis
DTI_mean_fa_right_pars_orbitalis
Pars Orbitalis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.pars.orbitalis
DTI_mean_fa_right_pars_triangularis
Pars Triangularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.pars.triangularis
DTI_mean_fa_right_pericalcarine
Pericalcarine Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.pericalcarine
DTI_mean_fa_right_postcentral
Postcentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.postcent
DTI_mean_fa_right_posterior_cingulate
Posterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.post.cingulate
DTI_mean_fa_right_precentral
Precentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.precent
DTI_mean_fa_right_precuneus
Precuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.precuneus
DTI_mean_fa_right_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.rostral.ant.cingulate
DTI_mean_fa_right_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.rostral.middle.frontal
DTI_mean_fa_right_superior_frontal
Superior Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.sup.frontal
DTI_mean_fa_right_superior_parietal
Superior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.sup.parietal
DTI_mean_fa_right_superior_temporal
Superior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.sup.temporal
DTI_mean_fa_right_supramarginal
Supramarginal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.supramarginal
DTI_mean_fa_right_transverse_temporal
Transverse Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.right.transverse.temporal
DTI_volume_fa_background
Background Signal
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.background
DTI_volume_fa_left_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.caudal.ant.cingulate
DTI_volume_fa_left_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.caudal.middle.frontal
DTI_volume_fa_left_cuneus
Cuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.cuneus
DTI_volume_fa_left_entorhinal
Entorhinal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.entorhinal
DTI_volume_fa_left_fusiform
Fusiform Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.fusiform
DTI_volume_fa_left_inferior_parietal
Inferior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.inf.parietal
DTI_volume_fa_left_inferior_temporal
Inferior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.inf.temporal
DTI_volume_fa_left_insula
Insula
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.insula
DTI_volume_fa_left_isthmus_cingulate
Isthmus Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.isthmus.cingulate
DTI_volume_fa_left_lateral_occipital
Lateral Occipital Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.lateral.occipital
DTI_volume_fa_left_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.lateral.orbitofrontal
DTI_volume_fa_left_lingual
Lingual Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.lingual
DTI_volume_fa_left_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.medial.orbitofrontal
DTI_volume_fa_left_middle_temporal
Middle Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.middle.temporal
DTI_volume_fa_left_paracentral
Paracentral Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.paracent
DTI_volume_fa_left_parahippocampal
Parahippocampal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.parahippocampal
DTI_volume_fa_left_pars_opercularis
Pars Opercularis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.pars.opercularis
DTI_volume_fa_left_pars_orbitalis
Pars Orbitalis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.pars.orbitalis
DTI_volume_fa_left_pars_triangularis
Pars Triangularis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.pars.triangularis
DTI_volume_fa_left_pericalcarine
Pericalcarine Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.pericalcarine
DTI_volume_fa_left_postcentral
Postcentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.postcent
DTI_volume_fa_left_posterior_cingulate
Posterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.post.cingulate
DTI_volume_fa_left_precentral
Precentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.precent
DTI_volume_fa_left_precuneus
Precuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.precuneus
DTI_volume_fa_left_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.rostral.ant.cingulate
DTI_volume_fa_left_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.rostral.middle.frontal
DTI_volume_fa_left_superior_frontal
Superior Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.sup.frontal
DTI_volume_fa_left_superior_parietal
Superior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.sup.parietal
DTI_volume_fa_left_superior_temporal
Superior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.sup.temporal
DTI_volume_fa_left_supramarginal
Supramarginal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.supramarginal
DTI_volume_fa_left_transverse_temporal
Transverse Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.left.transverse.temporal
DTI_volume_fa_right_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.caudal.ant.cingulate
DTI_volume_fa_right_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.caudal.middle.frontal
DTI_volume_fa_right_cuneus
Cuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.cuneus
DTI_volume_fa_right_entorhinal
Entorhinal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.entorhinal
DTI_volume_fa_right_fusiform
Fusiform Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.fusiform
DTI_volume_fa_right_inferior_parietal
Inferior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.inf.parietal
DTI_volume_fa_right_inferior_temporal
Inferior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.inf.temporal
DTI_volume_fa_right_insula
Insula
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.insula
DTI_volume_fa_right_isthmus_cingulate
Isthmus Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.isthmus.cingulate
DTI_volume_fa_right_lateral_occipital
Lateral Occipital Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.lateral.occipital
DTI_volume_fa_right_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.lateral.orbitofrontal
DTI_volume_fa_right_lingual
Lingual Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.lingual
DTI_volume_fa_right_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.medial.orbitofrontal
DTI_volume_fa_right_middle_temporal
Middle Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.middle.temporal
DTI_volume_fa_right_paracentral
Paracentral Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.paracent
DTI_volume_fa_right_parahippocampal
Parahippocampal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.parahippocampal
DTI_volume_fa_right_pars_opercularis
Pars Opercularis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.pars.opercularis
DTI_volume_fa_right_pars_orbitalis
Pars Orbitalis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.pars.orbitalis
DTI_volume_fa_right_pars_triangularis
Pars Triangularis
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.pars.triangularis
DTI_volume_fa_right_pericalcarine
Pericalcarine Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.pericalcarine
DTI_volume_fa_right_postcentral
Postcentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.postcent
DTI_volume_fa_right_posterior_cingulate
Posterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.post.cingulate
DTI_volume_fa_right_precentral
Precentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.precent
DTI_volume_fa_right_precuneus
Precuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.precuneus
DTI_volume_fa_right_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.rostral.ant.cingulate
DTI_volume_fa_right_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.rostral.middle.frontal
DTI_volume_fa_right_superior_frontal
Superior Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.sup.frontal
DTI_volume_fa_right_superior_parietal
Superior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.sup.parietal
DTI_volume_fa_right_superior_temporal
Superior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.sup.temporal
DTI_volume_fa_right_supramarginal
Supramarginal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.supramarginal
DTI_volume_fa_right_transverse_temporal
Transverse Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.right.transverse.temporal
DTI_mean_fa_deep_bn_gp_gpe_left
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpe.left
DTI_mean_fa_deep_bn_gp_gpe_right
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpe.right
DTI_mean_fa_deep_bn_gp_gpi_left
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpi.left
DTI_mean_fa_deep_bn_gp_gpi_right
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpi.right
DTI_mean_fa_deep_bn_str_ca_left
Caudate Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.ca.left
DTI_mean_fa_deep_bn_str_ca_right
Caudate Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.ca.right
DTI_mean_fa_deep_bn_str_pu_left
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.pu.left
DTI_mean_fa_deep_bn_str_pu_right
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.pu.right
DTI_mean_fa_deep_mtg_rn_left
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.mtg.rn.left
DTI_mean_fa_deep_mtg_rn_right
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.mtg.rn.right
DTI_mean_fa_deep_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.snc.left
DTI_mean_fa_deep_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.snc.right
DTI_mean_fa_deep_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.deep.snr.left
DTI_mean_fa_deep_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.deep.snr.right
DTI_mean_fa_deep_referenceregion_left
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.referenceregion.left
DTI_mean_fa_deep_referenceregion_right
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.referenceregion.right
DTI_volume_fa_deep_bn_gp_gpe_left
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.gp.gpe.left
DTI_volume_fa_deep_bn_gp_gpe_right
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.gp.gpe.right
DTI_volume_fa_deep_bn_gp_gpi_left
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.gp.gpi.left
DTI_volume_fa_deep_bn_gp_gpi_right
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.gp.gpi.right
DTI_volume_fa_deep_bn_str_ca_left
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.str.ca.left
DTI_volume_fa_deep_bn_str_ca_right
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.str.ca.right
DTI_volume_fa_deep_bn_str_pu_left
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.str.pu.left
DTI_volume_fa_deep_bn_str_pu_right
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.bn.str.pu.right
DTI_volume_fa_deep_mtg_rn_left
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.mtg.rn.left
DTI_volume_fa_deep_mtg_rn_right
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.mtg.rn.right
DTI_volume_fa_deep_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.snc.left
DTI_volume_fa_deep_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.snc.right
DTI_volume_fa_deep_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.fa.deep.snr.left
DTI_volume_fa_deep_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.fa.deep.snr.right
DTI_volume_fa_deep_referenceregion_left
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.referenceregion.left
DTI_volume_fa_deep_referenceregion_right
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.deep.referenceregion.right
DTI_mean_fa_bn_gp_gpe_left
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpe.left
DTI_mean_fa_bn_gp_gpe_right
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpe.right
DTI_mean_fa_bn_gp_gpi_left
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpi.left
DTI_mean_fa_bn_gp_gpi_right
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpi.right
DTI_mean_fa_bn_gp_vep_left
Ventral Pallidum
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.vep.left
DTI_mean_fa_bn_gp_vep_right
Ventral Pallidum
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.vep.right
DTI_mean_fa_bn_str_ca_left
Caudate Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.ca.left
DTI_mean_fa_bn_str_ca_right
Caudate Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.ca.right
DTI_mean_fa_bn_str_nac_left
Nucleus Accumbens
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.nac.left
DTI_mean_fa_bn_str_nac_right
Nucleus Accumbens
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.nac.right
DTI_mean_fa_bn_str_pu_left
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.pu.left
DTI_mean_fa_bn_str_pu_right
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.pu.right
DTI_mean_fa_die_hth_left
Diencephalon / Hypothalamus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth.left
DTI_mean_fa_die_hth_mn_left
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth.mn.left
DTI_mean_fa_die_hth_mn_right
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth.mn.right
DTI_mean_fa_die_hth_right
Diencephalon / Hypothalamus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth.right
DTI_mean_fa_die_sth_left
Subthalamic Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.sth.left
DTI_mean_fa_die_sth_right
Subthalamic Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.sth.right
DTI_mean_fa_exa_left
Extended Amygdala
DTI
fractional anisotropy
ANTs
​
​
dti.fa.exa.left
DTI_mean_fa_exa_right
Extended Amygdala
DTI
fractional anisotropy
ANTs
​
​
dti.fa.exa.right
DTI_mean_fa_mtg_rn_left
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.rn.left
DTI_mean_fa_mtg_rn_right
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.rn.right
DTI_mean_fa_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.snc.left
DTI_mean_fa_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.snc.right
DTI_mean_fa_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.snr.left
DTI_mean_fa_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.snr.right
DTI_mean_fa_mtg_vtr_pbp_left
Parabrachial Pigmented Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.pbp.left
DTI_mean_fa_mtg_vtr_pbp_right
Parabrachial Pigmented Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.pbp.right
DTI_mean_fa_mtg_vtr_vta_left
Ventral Tegmental Area
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.vta.left
DTI_mean_fa_mtg_vtr_vta_right
Ventral Tegmental Area
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.vta.right
DTI_mean_fa_referenceregion_left
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.referenceregion.left
DTI_mean_fa_referenceregion_right
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.referenceregion.right
DTI_mean_fa_thm_eth_hn_left
Thalamus Habenular Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.thm.eth.hn.left
DTI_mean_fa_thm_eth_hn_right
Thalamus Habenular Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.thm.eth.hn.right
DTI_volume_fa_bn_gp_gpe_left
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.gpe.left
DTI_volume_fa_bn_gp_gpe_right
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.gpe.right
DTI_volume_fa_bn_gp_gpi_left
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.gpi.left
DTI_volume_fa_bn_gp_gpi_right
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.gpi.right
DTI_volume_fa_bn_gp_vep_left
Ventral Pallidum
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.vep.left
DTI_volume_fa_bn_gp_vep_right
Ventral Pallidum
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.gp.vep.right
DTI_volume_fa_bn_str_ca_left
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.ca.left
DTI_volume_fa_bn_str_ca_right
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.ca.right
DTI_volume_fa_bn_str_nac_left
Nucleus Accumbens
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.nac.left
DTI_volume_fa_bn_str_nac_right
Nucleus Accumbens
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.nac.right
DTI_volume_fa_bn_str_pu_left
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.pu.left
DTI_volume_fa_bn_str_pu_right
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.bn.str.pu.right
DTI_volume_fa_die_hth_left
Diencephalon / Hypothalamus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.hth.left
DTI_volume_fa_die_hth_mn_left
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.hth.mn.left
DTI_volume_fa_die_hth_mn_right
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.hth.mn.right
DTI_volume_fa_die_hth_right
Diencephalon / Hypothalamus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.hth.right
DTI_volume_fa_die_sth_left
Subthalamic Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.sth.left
DTI_volume_fa_die_sth_right
Subthalamic Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.die.sth.right
DTI_volume_fa_exa_left
Extended Amygdala
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.exa.left
DTI_volume_fa_exa_right
Extended Amygdala
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.exa.right
DTI_volume_fa_mtg_rn_left
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.rn.left
DTI_volume_fa_mtg_rn_right
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.rn.right
DTI_volume_fa_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.snc.left
DTI_volume_fa_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.snc.right
DTI_volume_fa_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.fa.snr.left
DTI_volume_fa_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.fa.snr.right
DTI_volume_fa_mtg_vtr_pbp_left
Parabrachial Pigmented Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.vtr.pbp.left
DTI_volume_fa_mtg_vtr_pbp_right
Parabrachial Pigmented Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.vtr.pbp.right
DTI_volume_fa_mtg_vtr_vta_left
Ventral Tegmental Area
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.vtr.vta.left
DTI_volume_fa_mtg_vtr_vta_right
Ventral Tegmental Area
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.mtg.vtr.vta.right
DTI_volume_fa_referenceregion_left
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.referenceregion.left
DTI_volume_fa_referenceregion_right
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.referenceregion.right
DTI_volume_fa_thm_eth_hn_left
Thalamus Habenular Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.thm.eth.hn.left
DTI_volume_fa_thm_eth_hn_right
Thalamus Habenular Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.fa.thm.eth.hn.right
DTI_mean_fa_ch13_left
Basal Forebrain Ch13
DTI
fractional anisotropy
BF
​
​
dti.fa.ch13.left
DTI_mean_fa_ch13_right
Basal Forebrain Ch13
DTI
fractional anisotropy
BF
​
​
dti.fa.ch13.right
DTI_mean_fa_nbm_left_ant
Anterior Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.left.ant
DTI_mean_fa_nbm_left_mid
Middle Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.left.mid
DTI_mean_fa_nbm_left_pos
Posterior Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.left.pos
DTI_mean_fa_nbm_right_ant
Anterior Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.right.ant
DTI_mean_fa_nbm_right_mid
Middle Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.right.mid
DTI_mean_fa_nbm_right_pos
Posterior Basal Nucleus of Meynert
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.right.pos
DTI_volume_fa_ch13_left
Basal Forebrain Ch13
DTI
geometry.volume
BF
​
​
dti.vol.fa.ch13.left
DTI_volume_fa_ch13_right
Basal Forebrain Ch13
DTI
geometry.volume
BF
​
​
dti.vol.fa.ch13.right
DTI_volume_fa_nbm_left_ant
Anterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.left.ant
DTI_volume_fa_nbm_left_mid
Middle Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.left.mid
DTI_volume_fa_nbm_left_pos
Posterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.left.pos
DTI_volume_fa_nbm_right_ant
Anterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.right.ant
DTI_volume_fa_nbm_right_mid
Middle Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.right.mid
DTI_volume_fa_nbm_right_pos
Posterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.fa.nbm.right.pos
DTI_mean_md_background
Background Signal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.background
DTI_mean_md_left_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.caudal.ant.cingulate
DTI_mean_md_left_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.caudal.middle.frontal
DTI_mean_md_left_cuneus
Cuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.cuneus
DTI_mean_md_left_entorhinal
Entorhinal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.entorhinal
DTI_mean_md_left_fusiform
Fusiform Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.fusiform
DTI_mean_md_left_inferior_parietal
Inferior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.inf.parietal
DTI_mean_md_left_inferior_temporal
Inferior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.inf.temporal
DTI_mean_md_left_insula
Insula
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.insula
DTI_mean_md_left_isthmus_cingulate
Isthmus Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.isthmus.cingulate
DTI_mean_md_left_lateral_occipital
Lateral Occipital Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.lateral.occipital
DTI_mean_md_left_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.lateral.orbitofrontal
DTI_mean_md_left_lingual
Lingual Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.lingual
DTI_mean_md_left_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.medial.orbitofrontal
DTI_mean_md_left_middle_temporal
Middle Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.middle.temporal
DTI_mean_md_left_paracentral
Paracentral Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.paracent
DTI_mean_md_left_parahippocampal
Parahippocampal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.parahippocampal
DTI_mean_md_left_pars_opercularis
Pars Opercularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.pars.opercularis
DTI_mean_md_left_pars_orbitalis
Pars Orbitalis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.pars.orbitalis
DTI_mean_md_left_pars_triangularis
Pars Triangularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.pars.triangularis
DTI_mean_md_left_pericalcarine
Pericalcarine Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.pericalcarine
DTI_mean_md_left_postcentral
Postcentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.postcent
DTI_mean_md_left_posterior_cingulate
Posterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.post.cingulate
DTI_mean_md_left_precentral
Precentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.precent
DTI_mean_md_left_precuneus
Precuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.precuneus
DTI_mean_md_left_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.rostral.ant.cingulate
DTI_mean_md_left_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.rostral.middle.frontal
DTI_mean_md_left_superior_frontal
Superior Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.sup.frontal
DTI_mean_md_left_superior_parietal
Superior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.sup.parietal
DTI_mean_md_left_superior_temporal
Superior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.sup.temporal
DTI_mean_md_left_supramarginal
Supramarginal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.supramarginal
DTI_mean_md_left_transverse_temporal
Transverse Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.left.transverse.temporal
DTI_mean_md_right_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.caudal.ant.cingulate
DTI_mean_md_right_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.caudal.middle.frontal
DTI_mean_md_right_cuneus
Cuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.cuneus
DTI_mean_md_right_entorhinal
Entorhinal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.entorhinal
DTI_mean_md_right_fusiform
Fusiform Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.fusiform
DTI_mean_md_right_inferior_parietal
Inferior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.inf.parietal
DTI_mean_md_right_inferior_temporal
Inferior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.inf.temporal
DTI_mean_md_right_insula
Insula
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.insula
DTI_mean_md_right_isthmus_cingulate
Isthmus Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.isthmus.cingulate
DTI_mean_md_right_lateral_occipital
Lateral Occipital Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.lateral.occipital
DTI_mean_md_right_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.lateral.orbitofrontal
DTI_mean_md_right_lingual
Lingual Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.lingual
DTI_mean_md_right_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.medial.orbitofrontal
DTI_mean_md_right_middle_temporal
Middle Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.middle.temporal
DTI_mean_md_right_paracentral
Paracentral Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.paracent
DTI_mean_md_right_parahippocampal
Parahippocampal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.parahippocampal
DTI_mean_md_right_pars_opercularis
Pars Opercularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.pars.opercularis
DTI_mean_md_right_pars_orbitalis
Pars Orbitalis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.pars.orbitalis
DTI_mean_md_right_pars_triangularis
Pars Triangularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.pars.triangularis
DTI_mean_md_right_pericalcarine
Pericalcarine Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.pericalcarine
DTI_mean_md_right_postcentral
Postcentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.postcent
DTI_mean_md_right_posterior_cingulate
Posterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.post.cingulate
DTI_mean_md_right_precentral
Precentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.precent
DTI_mean_md_right_precuneus
Precuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.precuneus
DTI_mean_md_right_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.rostral.ant.cingulate
DTI_mean_md_right_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.rostral.middle.frontal
DTI_mean_md_right_superior_frontal
Superior Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.sup.frontal
DTI_mean_md_right_superior_parietal
Superior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.sup.parietal
DTI_mean_md_right_superior_temporal
Superior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.sup.temporal
DTI_mean_md_right_supramarginal
Supramarginal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.supramarginal
DTI_mean_md_right_transverse_temporal
Transverse Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.right.transverse.temporal
DTI_volume_md_background
Background Signal
DTI
geometry.volume
ANTs
​
​
dti.vol.md.background
DTI_volume_md_left_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.caudal.ant.cingulate
DTI_volume_md_left_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.caudal.middle.frontal
DTI_volume_md_left_cuneus
Cuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.cuneus
DTI_volume_md_left_entorhinal
Entorhinal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.entorhinal
DTI_volume_md_left_fusiform
Fusiform Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.fusiform
DTI_volume_md_left_inferior_parietal
Inferior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.inf.parietal
DTI_volume_md_left_inferior_temporal
Inferior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.inf.temporal
DTI_volume_md_left_insula
Insula
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.insula
DTI_volume_md_left_isthmus_cingulate
Isthmus Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.isthmus.cingulate
DTI_volume_md_left_lateral_occipital
Lateral Occipital Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.lateral.occipital
DTI_volume_md_left_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.lateral.orbitofrontal
DTI_volume_md_left_lingual
Lingual Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.lingual
DTI_volume_md_left_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.medial.orbitofrontal
DTI_volume_md_left_middle_temporal
Middle Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.middle.temporal
DTI_volume_md_left_paracentral
Paracentral Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.paracent
DTI_volume_md_left_parahippocampal
Parahippocampal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.parahippocampal
DTI_volume_md_left_pars_opercularis
Pars Opercularis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.pars.opercularis
DTI_volume_md_left_pars_orbitalis
Pars Orbitalis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.pars.orbitalis
DTI_volume_md_left_pars_triangularis
Pars Triangularis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.pars.triangularis
DTI_volume_md_left_pericalcarine
Pericalcarine Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.pericalcarine
DTI_volume_md_left_postcentral
Postcentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.postcent
DTI_volume_md_left_posterior_cingulate
Posterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.post.cingulate
DTI_volume_md_left_precentral
Precentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.precent
DTI_volume_md_left_precuneus
Precuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.precuneus
DTI_volume_md_left_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.rostral.ant.cingulate
DTI_volume_md_left_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.rostral.middle.frontal
DTI_volume_md_left_superior_frontal
Superior Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.sup.frontal
DTI_volume_md_left_superior_parietal
Superior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.sup.parietal
DTI_volume_md_left_superior_temporal
Superior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.sup.temporal
DTI_volume_md_left_supramarginal
Supramarginal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.supramarginal
DTI_volume_md_left_transverse_temporal
Transverse Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.left.transverse.temporal
DTI_volume_md_right_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.caudal.ant.cingulate
DTI_volume_md_right_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.caudal.middle.frontal
DTI_volume_md_right_cuneus
Cuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.cuneus
DTI_volume_md_right_entorhinal
Entorhinal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.entorhinal
DTI_volume_md_right_fusiform
Fusiform Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.fusiform
DTI_volume_md_right_inferior_parietal
Inferior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.inf.parietal
DTI_volume_md_right_inferior_temporal
Inferior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.inf.temporal
DTI_volume_md_right_insula
Insula
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.insula
DTI_volume_md_right_isthmus_cingulate
Isthmus Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.isthmus.cingulate
DTI_volume_md_right_lateral_occipital
Lateral Occipital Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.lateral.occipital
DTI_volume_md_right_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.lateral.orbitofrontal
DTI_volume_md_right_lingual
Lingual Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.lingual
DTI_volume_md_right_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.medial.orbitofrontal
DTI_volume_md_right_middle_temporal
Middle Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.middle.temporal
DTI_volume_md_right_paracentral
Paracentral Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.paracent
DTI_volume_md_right_parahippocampal
Parahippocampal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.parahippocampal
DTI_volume_md_right_pars_opercularis
Pars Opercularis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.pars.opercularis
DTI_volume_md_right_pars_orbitalis
Pars Orbitalis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.pars.orbitalis
DTI_volume_md_right_pars_triangularis
Pars Triangularis
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.pars.triangularis
DTI_volume_md_right_pericalcarine
Pericalcarine Cortex
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.pericalcarine
DTI_volume_md_right_postcentral
Postcentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.postcent
DTI_volume_md_right_posterior_cingulate
Posterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.post.cingulate
DTI_volume_md_right_precentral
Precentral Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.precent
DTI_volume_md_right_precuneus
Precuneus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.precuneus
DTI_volume_md_right_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.rostral.ant.cingulate
DTI_volume_md_right_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.rostral.middle.frontal
DTI_volume_md_right_superior_frontal
Superior Frontal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.sup.frontal
DTI_volume_md_right_superior_parietal
Superior Parietal Lobule
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.sup.parietal
DTI_volume_md_right_superior_temporal
Superior Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.sup.temporal
DTI_volume_md_right_supramarginal
Supramarginal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.supramarginal
DTI_volume_md_right_transverse_temporal
Transverse Temporal Gyrus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.right.transverse.temporal
DTI_mean_md_deep_bn_gp_gpe_left
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpe.left
DTI_mean_md_deep_bn_gp_gpe_right
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpe.right
DTI_mean_md_deep_bn_gp_gpi_left
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpi.left
DTI_mean_md_deep_bn_gp_gpi_right
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpi.right
DTI_mean_md_deep_bn_str_ca_left
Caudate Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.ca.left
DTI_mean_md_deep_bn_str_ca_right
Caudate Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.ca.right
DTI_mean_md_deep_bn_str_pu_left
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.pu.left
DTI_mean_md_deep_bn_str_pu_right
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.pu.right
DTI_mean_md_deep_mtg_rn_left
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.mtg.rn.left
DTI_mean_md_deep_mtg_rn_right
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.mtg.rn.right
DTI_mean_md_deep_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.snc.left
DTI_mean_md_deep_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.snc.right
DTI_mean_md_deep_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.deep.snr.left
DTI_mean_md_deep_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.deep.snr.right
DTI_mean_md_deep_referenceregion_left
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.referenceregion.left
DTI_mean_md_deep_referenceregion_right
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.referenceregion.right
DTI_volume_md_deep_bn_gp_gpe_left
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.gp.gpe.left
DTI_volume_md_deep_bn_gp_gpe_right
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.gp.gpe.right
DTI_volume_md_deep_bn_gp_gpi_left
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.gp.gpi.left
DTI_volume_md_deep_bn_gp_gpi_right
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.gp.gpi.right
DTI_volume_md_deep_bn_str_ca_left
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.str.ca.left
DTI_volume_md_deep_bn_str_ca_right
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.str.ca.right
DTI_volume_md_deep_bn_str_pu_left
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.str.pu.left
DTI_volume_md_deep_bn_str_pu_right
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.bn.str.pu.right
DTI_volume_md_deep_mtg_rn_left
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.mtg.rn.left
DTI_volume_md_deep_mtg_rn_right
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.mtg.rn.right
DTI_volume_md_deep_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.snc.left
DTI_volume_md_deep_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.snc.right
DTI_volume_md_deep_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.md.deep.snr.left
DTI_volume_md_deep_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.md.deep.snr.right
DTI_volume_md_deep_referenceregion_left
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.referenceregion.left
DTI_volume_md_deep_referenceregion_right
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.md.deep.referenceregion.right
DTI_mean_md_bn_gp_gpe_left
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpe.left
DTI_mean_md_bn_gp_gpe_right
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpe.right
DTI_mean_md_bn_gp_gpi_left
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpi.left
DTI_mean_md_bn_gp_gpi_right
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpi.right
DTI_mean_md_bn_gp_vep_left
Ventral Pallidum
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.vep.left
DTI_mean_md_bn_gp_vep_right
Ventral Pallidum
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.vep.right
DTI_mean_md_bn_str_ca_left
Caudate Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.ca.left
DTI_mean_md_bn_str_ca_right
Caudate Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.ca.right
DTI_mean_md_bn_str_nac_left
Nucleus Accumbens
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.nac.left
DTI_mean_md_bn_str_nac_right
Nucleus Accumbens
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.nac.right
DTI_mean_md_bn_str_pu_left
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.pu.left
DTI_mean_md_bn_str_pu_right
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.pu.right
DTI_mean_md_die_hth_left
Diencephalon / Hypothalamus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth.left
DTI_mean_md_die_hth_mn_left
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth.mn.left
DTI_mean_md_die_hth_mn_right
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth.mn.right
DTI_mean_md_die_hth_right
Diencephalon / Hypothalamus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth.right
DTI_mean_md_die_sth_left
Subthalamic Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.sth.left
DTI_mean_md_die_sth_right
Subthalamic Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.sth.right
DTI_mean_md_exa_left
Extended Amygdala
DTI
mean diffusion
ANTs
​
​
dti.mean.md.exa.left
DTI_mean_md_exa_right
Extended Amygdala
DTI
mean diffusion
ANTs
​
​
dti.mean.md.exa.right
DTI_mean_md_mtg_rn_left
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.rn.left
DTI_mean_md_mtg_rn_right
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.rn.right
DTI_mean_md_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.snc.left
DTI_mean_md_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.snc.right
DTI_mean_md_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.snr.left
DTI_mean_md_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.snr.right
DTI_mean_md_mtg_vtr_pbp_left
Parabrachial Pigmented Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.pbp.left
DTI_mean_md_mtg_vtr_pbp_right
Parabrachial Pigmented Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.pbp.right
DTI_mean_md_mtg_vtr_vta_left
Ventral Tegmental Area
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.vta.left
DTI_mean_md_mtg_vtr_vta_right
Ventral Tegmental Area
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.vta.right
DTI_mean_md_referenceregion_left
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.referenceregion.left
DTI_mean_md_referenceregion_right
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.referenceregion.right
DTI_mean_md_thm_eth_hn_left
Thalamus Habenular Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.thm.eth.hn.left
DTI_mean_md_thm_eth_hn_right
Thalamus Habenular Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.thm.eth.hn.right
DTI_volume_md_bn_gp_gpe_left
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.gpe.left
DTI_volume_md_bn_gp_gpe_right
Globus Pallidus External
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.gpe.right
DTI_volume_md_bn_gp_gpi_left
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.gpi.left
DTI_volume_md_bn_gp_gpi_right
Globus Pallidus Internal
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.gpi.right
DTI_volume_md_bn_gp_vep_left
Ventral Pallidum
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.vep.left
DTI_volume_md_bn_gp_vep_right
Ventral Pallidum
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.gp.vep.right
DTI_volume_md_bn_str_ca_left
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.ca.left
DTI_volume_md_bn_str_ca_right
Caudate Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.ca.right
DTI_volume_md_bn_str_nac_left
Nucleus Accumbens
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.nac.left
DTI_volume_md_bn_str_nac_right
Nucleus Accumbens
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.nac.right
DTI_volume_md_bn_str_pu_left
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.pu.left
DTI_volume_md_bn_str_pu_right
Putamen
DTI
geometry.volume
ANTs
​
​
dti.vol.md.bn.str.pu.right
DTI_volume_md_die_hth_left
Diencephalon / Hypothalamus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.hth.left
DTI_volume_md_die_hth_mn_left
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.hth.mn.left
DTI_volume_md_die_hth_mn_right
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.hth.mn.right
DTI_volume_md_die_hth_right
Diencephalon / Hypothalamus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.hth.right
DTI_volume_md_die_sth_left
Subthalamic Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.sth.left
DTI_volume_md_die_sth_right
Subthalamic Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.die.sth.right
DTI_volume_md_exa_left
Extended Amygdala
DTI
geometry.volume
ANTs
​
​
dti.vol.md.exa.left
DTI_volume_md_exa_right
Extended Amygdala
DTI
geometry.volume
ANTs
​
​
dti.vol.md.exa.right
DTI_volume_md_mtg_rn_left
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.rn.left
DTI_volume_md_mtg_rn_right
Red Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.rn.right
DTI_volume_md_mtg_sn_snc_left
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.md.snc.left
DTI_volume_md_mtg_sn_snc_right
Substantia Nigra Compacta
DTI
geometry.volume
ANTs
​
​
dti.vol.md.snc.right
DTI_volume_md_mtg_sn_snr_left
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.md.snr.left
DTI_volume_md_mtg_sn_snr_right
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.vol.md.snr.right
DTI_volume_md_mtg_vtr_pbp_left
Parabrachial Pigmented Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.vtr.pbp.left
DTI_volume_md_mtg_vtr_pbp_right
Parabrachial Pigmented Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.vtr.pbp.right
DTI_volume_md_mtg_vtr_vta_left
Ventral Tegmental Area
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.vtr.vta.left
DTI_volume_md_mtg_vtr_vta_right
Ventral Tegmental Area
DTI
geometry.volume
ANTs
​
​
dti.vol.md.mtg.vtr.vta.right
DTI_volume_md_referenceregion_left
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.md.referenceregion.left
DTI_volume_md_referenceregion_right
Reference Region
DTI
geometry.volume
ANTs
​
​
dti.vol.md.referenceregion.right
DTI_volume_md_thm_eth_hn_left
Thalamus Habenular Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.thm.eth.hn.left
DTI_volume_md_thm_eth_hn_right
Thalamus Habenular Nucleus
DTI
geometry.volume
ANTs
​
​
dti.vol.md.thm.eth.hn.right
DTI_mean_md_ch13_left
Basal Forebrain Ch13
DTI
mean diffusion
BF
​
​
dti.mean.md.ch13.left
DTI_mean_md_ch13_right
Basal Forebrain Ch13
DTI
mean diffusion
BF
​
​
dti.mean.md.ch13.right
DTI_mean_md_nbm_left_ant
Anterior Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.left.ant
DTI_mean_md_nbm_left_mid
Middle Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.left.mid
DTI_mean_md_nbm_left_pos
Posterior Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.left.pos
DTI_mean_md_nbm_right_ant
Anterior Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.right.ant
DTI_mean_md_nbm_right_mid
Middle Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.right.mid
DTI_mean_md_nbm_right_pos
Posterior Basal Nucleus of Meynert
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.right.pos
DTI_volume_md_ch13_left
Basal Forebrain Ch13
DTI
geometry.volume
BF
​
​
dti.vol.md.ch13.left
DTI_volume_md_ch13_right
Basal Forebrain Ch13
DTI
geometry.volume
BF
​
​
dti.vol.md.ch13.right
DTI_volume_md_nbm_left_ant
Anterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.left.ant
DTI_volume_md_nbm_left_mid
Middle Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.left.mid
DTI_volume_md_nbm_left_pos
Posterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.left.pos
DTI_volume_md_nbm_right_ant
Anterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.right.ant
DTI_volume_md_nbm_right_mid
Middle Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.right.mid
DTI_volume_md_nbm_right_pos
Posterior Basal Nucleus of Meynert
DTI
geometry.volume
BF
​
​
dti.vol.md.nbm.right.pos
DTI_dti_tsnr_b0_mean
Unknown Core: dti tsnr b0
DTI
QC
ANTs
​
​
dti.dti.tsnr.b0.mean
DTI_dti_tsnr_dwi_mean
Unknown Core: dti tsnr dwi
DTI
QC
ANTs
​
​
dti.dti.tsnr.dwi.mean
DTI_dti_dvars_b0_mean
Unknown Core: dti dvars b0
DTI
QC
ANTs
​
​
dti.dti.dvars.b0.mean
DTI_dti_dvars_dwi_mean
Unknown Core: dti dvars dwi
DTI
QC
ANTs
​
​
dti.dti.dvars.dwi.mean
DTI_dti_ssnr_b0_mean
Unknown Core: dti ssnr b0
DTI
QC
ANTs
​
​
dti.dti.ssnr.b0.mean
DTI_dti_ssnr_dwi_mean
Unknown Core: dti ssnr dwi
DTI
QC
ANTs
​
​
dti.dti.ssnr.dwi.mean
DTI_dti_fa_evr
Unknown Core: dti evr
DTI
QC
ANTs
​
​
dti.dti.fa.evr
DTI_dti_fa_SNR
Unknown Core: dti snr
DTI
QC
ANTs
​
​
dti.dti.fa.snr
DTI_dti_high_motion_count
Unknown Core: dti high motion count
DTI
QC
ANTs
​
​
dti.dti.high.motion.count
DTI_dti_FD_mean
​
DTI
mean framewise displacement
ANTs
​
​
dti.dti.fd.mean
DTI_dti_FD_max
​
DTI
max framewise displacement
ANTs
​
​
dti.dti.fd.max
DTI_dti_FD_sd
Unknown Core: dti sd
DTI
motion statistic on framewise displacement
ANTs
​
​
dti.dti.fd.sd
NM2DMT_mean_bn_str_ca_right
Caudate Nucleus
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.str.ca.right
NM2DMT_mean_bn_str_ca_left
Caudate Nucleus
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm2dmt.mean.bn.str.ca.left
NM2DMT_NM_avg_signaltonoise
Unknown Core: nm avg signaltonoise
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.iavg.signaltonoise
NM2DMT_NM_avg_substantianigra
Unknown Core: nm avg substantianigra
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.iavg.sn
NM2DMT_NM_std_substantianigra
Unknown Core: nm std substantianigra
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.std.sn
NM2DMT_NM_avg_refregion
Unknown Core: nm avg refregion
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.iavg.refregion
NM2DMT_NM_std_refregion
Unknown Core: nm std refregion
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.std.refregion
NM2DMT_NM_min
Unknown Core: nm min
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.min
NM2DMT_NM_max
Unknown Core: nm max
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.max
NM2DMT_NM_mean
Unknown Core: nm
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.mean
NM2DMT_NM_sd
Unknown Core: nm sd
Neuromelanin
Neuromelanin signal summary
ANTs
​
​
nm.sd
T1Hier_volLRAVGcrus_icerebellum
Cerebellum Crus I
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgcrus.icerebellum
T1Hier_volLRAVGcrus_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgcrus.iicerebellum
T1Hier_volLRAVGiiicerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgiiicerebellum
T1Hier_volLRAVGivcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgivcerebellum
T1Hier_volLRAVGixcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgixcerebellum
T1Hier_volLRAVGi_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgi.iicerebellum
T1Hier_volLRAVGvcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgvcerebellum
T1Hier_volLRAVGvicerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgvicerebellum
T1Hier_volLRAVGviibcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgviibcerebellum
T1Hier_volLRAVGviiiacerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgviiiacerebellum
T1Hier_volLRAVGviiibcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgviiibcerebellum
T1Hier_volLRAVGxcerebellum
Cerebellum
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vollravgxcerebellum
T1Hier_areaLRAVGcrus_icerebellum
Cerebellum Crus I
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgcrus.icerebellum
T1Hier_areaLRAVGcrus_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgcrus.iicerebellum
T1Hier_areaLRAVGiiicerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgiiicerebellum
T1Hier_areaLRAVGivcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgivcerebellum
T1Hier_areaLRAVGixcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgixcerebellum
T1Hier_areaLRAVGi_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgi.iicerebellum
T1Hier_areaLRAVGvcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgvcerebellum
T1Hier_areaLRAVGvicerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgvicerebellum
T1Hier_areaLRAVGviibcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgviibcerebellum
T1Hier_areaLRAVGviiiacerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgviiiacerebellum
T1Hier_areaLRAVGviiibcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgviiibcerebellum
T1Hier_areaLRAVGxcerebellum
Cerebellum
T1 hierarchical processing
geometry.area
ANTs
​
​
t1.arealravgxcerebellum
T1Hier_thkLRAVGcrus_icerebellum
Cerebellum Crus I
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgcrus.icerebellum
T1Hier_thkLRAVGcrus_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgcrus.iicerebellum
T1Hier_thkLRAVGiiicerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgiiicerebellum
T1Hier_thkLRAVGivcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgivcerebellum
T1Hier_thkLRAVGixcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgixcerebellum
T1Hier_thkLRAVGi_iicerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgi.iicerebellum
T1Hier_thkLRAVGvcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgvcerebellum
T1Hier_thkLRAVGvicerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgvicerebellum
T1Hier_thkLRAVGviibcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgviibcerebellum
T1Hier_thkLRAVGviiiacerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgviiiacerebellum
T1Hier_thkLRAVGviiibcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgviiibcerebellum
T1Hier_thkLRAVGxcerebellum
Cerebellum
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thklravgxcerebellum
T1w_mean_LRAVG_caudal_anterior_cingulate
Caudal Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.caudal.ant.cingulate
T1w_mean_LRAVG_caudal_middle_frontal
Caudal Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.caudal.middle.frontal
T1w_mean_LRAVG_cuneus
Cuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.cuneus
T1w_mean_LRAVG_entorhinal
Entorhinal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.entorhinal
T1w_mean_LRAVG_fusiform
Fusiform Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.fusiform
T1w_mean_LRAVG_inferior_parietal
Inferior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.inf.parietal
T1w_mean_LRAVG_inferior_temporal
Inferior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.inf.temporal
T1w_mean_LRAVG_insula
Insula
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.insula
T1w_mean_LRAVG_isthmus_cingulate
Isthmus Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.isthmus.cingulate
T1w_mean_LRAVG_lateral_occipital
Lateral Occipital Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.lateral.occipital
T1w_mean_LRAVG_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.lateral.orbitofrontal
T1w_mean_LRAVG_lingual
Lingual Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.lingual
T1w_mean_LRAVG_medial_orbitofrontal
Medial Orbitofrontal Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.medial.orbitofrontal
T1w_mean_LRAVG_middle_temporal
Middle Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.middle.temporal
T1w_mean_LRAVG_paracentral
Paracentral Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.paracent
T1w_mean_LRAVG_parahippocampal
Parahippocampal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.parahippocampal
T1w_mean_LRAVG_pars_opercularis
Pars Opercularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.pars.opercularis
T1w_mean_LRAVG_pars_orbitalis
Pars Orbitalis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.pars.orbitalis
T1w_mean_LRAVG_pars_triangularis
Pars Triangularis
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.pars.triangularis
T1w_mean_LRAVG_pericalcarine
Pericalcarine Cortex
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.pericalcarine
T1w_mean_LRAVG_postcentral
Postcentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.postcent
T1w_mean_LRAVG_posterior_cingulate
Posterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.post.cingulate
T1w_mean_LRAVG_precentral
Precentral Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.precent
T1w_mean_LRAVG_precuneus
Precuneus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.precuneus
T1w_mean_LRAVG_rostral_anterior_cingulate
Rostral Anterior Cingulate
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.rostral.ant.cingulate
T1w_mean_LRAVG_rostral_middle_frontal
Rostral Middle Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.rostral.middle.frontal
T1w_mean_LRAVG_superior_frontal
Superior Frontal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.sup.frontal
T1w_mean_LRAVG_superior_parietal
Superior Parietal Lobule
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.sup.parietal
T1w_mean_LRAVG_superior_temporal
Superior Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.sup.temporal
T1w_mean_LRAVG_supramarginal
Supramarginal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.supramarginal
T1w_mean_LRAVG_transverse_temporal
Transverse Temporal Gyrus
T1 DiReCT thickness processing
Regional average of DiReCT estimated thickness
ANTs
​
​
t1vth.transverse.temporal
T1Hier_vol_LRAVG_ca1mtl
CA1
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.ca1mtl
T1Hier_vol_LRAVG_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.dg.ca3mtl
T1Hier_vol_LRAVG_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.alecmtl
T1Hier_vol_LRAVG_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.pmecmtl
T1Hier_vol_LRAVG_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.parahippocampalmtl
T1Hier_vol_LRAVG_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.perirhinalmtl
T1Hier_vol_LRAVG_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.volume
MTL
​
​
t1.vol.subiculummtl
T1Hier_area_LRAVG_ca1mtl
CA1
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.ca1mtl
T1Hier_area_LRAVG_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.dg.ca3mtl
T1Hier_area_LRAVG_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.alecmtl
T1Hier_area_LRAVG_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.pmecmtl
T1Hier_area_LRAVG_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.parahippocampalmtl
T1Hier_area_LRAVG_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.perirhinalmtl
T1Hier_area_LRAVG_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.area
MTL
​
​
t1.area.subiculummtl
T1Hier_thk_LRAVG_ca1mtl
CA1
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.ca1mtl
T1Hier_thk_LRAVG_dg.ca3mtl
Dentate Gyrus/CA3
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.dg.ca3mtl
T1Hier_thk_LRAVG_alecmtl
Anterolateral Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.alecmtl
T1Hier_thk_LRAVG_pmecmtl
Posteromedial Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.pmecmtl
T1Hier_thk_LRAVG_parahippocampalmtl
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.parahippocampalmtl
T1Hier_thk_LRAVG_perirhinalmtl
Perirhinal Cortex
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.perirhinalmtl
T1Hier_thk_LRAVG_subiculummtl
Medial Temporal Lobe
T1 hierarchical processing
geometry.thickness
MTL
​
​
t1.thk.subiculummtl
T1Hier_vol_LRAVG_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.caudal.ant.cingulate.ctx
T1Hier_vol_LRAVG_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.caudal.middle.frontal.ctx
T1Hier_vol_LRAVG_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.cuneus.ctx
T1Hier_vol_LRAVG_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.entorhinal.ctx
T1Hier_vol_LRAVG_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.fusiform.ctx
T1Hier_vol_LRAVG_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.inf.parietal.ctx
T1Hier_vol_LRAVG_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.inf.temporal.ctx
T1Hier_vol_LRAVG_insuladktcortex
Insula
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.insula.ctx
T1Hier_vol_LRAVG_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.isthmus.cingulate.ctx
T1Hier_vol_LRAVG_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.lateral.occipital.ctx
T1Hier_vol_LRAVG_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.lateral.orbitofrontal.ctx
T1Hier_vol_LRAVG_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.lingual.ctx
T1Hier_vol_LRAVG_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.medial.orbitofrontal.ctx
T1Hier_vol_LRAVG_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.middle.temporal.ctx
T1Hier_vol_LRAVG_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.paracent.ctx
T1Hier_vol_LRAVG_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.parahippocampal.ctx
T1Hier_vol_LRAVG_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.pars.opercularis.ctx
T1Hier_vol_LRAVG_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.pars.orbitalis.ctx
T1Hier_vol_LRAVG_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.pars.triangularis.ctx
T1Hier_vol_LRAVG_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.pericalcarine.ctx
T1Hier_vol_LRAVG_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.postcent.ctx
T1Hier_vol_LRAVG_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.post.cingulate.ctx
T1Hier_vol_LRAVG_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.precent.ctx
T1Hier_vol_LRAVG_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.precuneus.ctx
T1Hier_vol_LRAVG_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.rostral.ant.cingulate.ctx
T1Hier_vol_LRAVG_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.rostral.middle.frontal.ctx
T1Hier_vol_LRAVG_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.sup.frontal.ctx
T1Hier_vol_LRAVG_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.sup.parietal.ctx
T1Hier_vol_LRAVG_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.sup.temporal.ctx
T1Hier_vol_LRAVG_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.supramarginal.ctx
T1Hier_vol_LRAVG_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.volume
desikan-killiany-tourville
​
​
t1.vol.transverse.temporal.ctx
T1Hier_thk_LRAVG_caudal_anterior_cingulatedktcortex
Caudal Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.caudal.ant.cingulate.ctx
T1Hier_thk_LRAVG_caudal_middle_frontaldktcortex
Caudal Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.caudal.middle.frontal.ctx
T1Hier_thk_LRAVG_cuneusdktcortex
Cuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.cuneus.ctx
T1Hier_thk_LRAVG_entorhinaldktcortex
Entorhinal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.entorhinal.ctx
T1Hier_thk_LRAVG_fusiformdktcortex
Fusiform Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.fusiform.ctx
T1Hier_thk_LRAVG_inferior_parietaldktcortex
Inferior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.inf.parietal.ctx
T1Hier_thk_LRAVG_inferior_temporaldktcortex
Inferior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.inf.temporal.ctx
T1Hier_thk_LRAVG_insuladktcortex
Insula
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.insula.ctx
T1Hier_thk_LRAVG_isthmus_cingulatedktcortex
Isthmus Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.isthmus.cingulate.ctx
T1Hier_thk_LRAVG_lateral_occipitaldktcortex
Lateral Occipital Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.lateral.occipital.ctx
T1Hier_thk_LRAVG_lateral_orbitofrontaldktcortex
Lateral Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.lateral.orbitofrontal.ctx
T1Hier_thk_LRAVG_lingualdktcortex
Lingual Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.lingual.ctx
T1Hier_thk_LRAVG_medial_orbitofrontaldktcortex
Medial Orbitofrontal Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.medial.orbitofrontal.ctx
T1Hier_thk_LRAVG_middle_temporaldktcortex
Middle Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.middle.temporal.ctx
T1Hier_thk_LRAVG_paracentraldktcortex
Paracentral Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.paracent.ctx
T1Hier_thk_LRAVG_parahippocampaldktcortex
Parahippocampal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.parahippocampal.ctx
T1Hier_thk_LRAVG_pars_opercularisdktcortex
Pars Opercularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.pars.opercularis.ctx
T1Hier_thk_LRAVG_pars_orbitalisdktcortex
Pars Orbitalis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.pars.orbitalis.ctx
T1Hier_thk_LRAVG_pars_triangularisdktcortex
Pars Triangularis
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.pars.triangularis.ctx
T1Hier_thk_LRAVG_pericalcarinedktcortex
Pericalcarine Cortex
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.pericalcarine.ctx
T1Hier_thk_LRAVG_postcentraldktcortex
Postcentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.postcent.ctx
T1Hier_thk_LRAVG_posterior_cingulatedktcortex
Posterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.post.cingulate.ctx
T1Hier_thk_LRAVG_precentraldktcortex
Precentral Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.precent.ctx
T1Hier_thk_LRAVG_precuneusdktcortex
Precuneus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.precuneus.ctx
T1Hier_thk_LRAVG_rostral_anterior_cingulatedktcortex
Rostral Anterior Cingulate
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.rostral.ant.cingulate.ctx
T1Hier_thk_LRAVG_rostral_middle_frontaldktcortex
Rostral Middle Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.rostral.middle.frontal.ctx
T1Hier_thk_LRAVG_superior_frontaldktcortex
Superior Frontal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.sup.frontal.ctx
T1Hier_thk_LRAVG_superior_parietaldktcortex
Superior Parietal Lobule
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.sup.parietal.ctx
T1Hier_thk_LRAVG_superior_temporaldktcortex
Superior Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.sup.temporal.ctx
T1Hier_thk_LRAVG_supramarginaldktcortex
Supramarginal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.supramarginal.ctx
T1Hier_thk_LRAVG_transverse_temporaldktcortex
Transverse Temporal Gyrus
T1 hierarchical processing
geometry.thickness
desikan-killiany-tourville
​
​
t1.thk.transverse.temporal.ctx
T1Hier_vol_ch13_LRAVGbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.ch13bf
T1Hier_vol_nbm_LRAVG_antbf
Nucleus Basalis of Meynert Anterior
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.antbf
T1Hier_vol_nbm_LRAVG_midbf
Nucleus Basalis of Meynert Middle
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.midbf
T1Hier_vol_nbm_LRAVG_posbf
Nucleus Basalis of Meynert Posterior
T1 hierarchical processing
geometry.volume
BF
​
​
t1.vol.nbm.posbf
T1Hier_thk_ch13_LRAVGbf
Basal Forebrain Ch13
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.ch13bf
T1Hier_thk_nbm_LRAVG_antbf
Nucleus Basalis of Meynert Anterior
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.antbf
T1Hier_thk_nbm_LRAVG_midbf
Nucleus Basalis of Meynert Middle
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.midbf
T1Hier_thk_nbm_LRAVG_posbf
Nucleus Basalis of Meynert Posterior
T1 hierarchical processing
geometry.thickness
BF
​
​
t1.thk.nbm.posbf
T1Hier_vol_bn_gp_gpe_LRAVGcit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpe
T1Hier_vol_bn_gp_gpi_LRAVGcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpi
T1Hier_vol_bn_gp_vep_LRAVGcit168
Ventral Pallidum
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.vep
T1Hier_vol_bn_str_nac_LRAVGcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.nac
T1Hier_vol_bn_str_pu_LRAVGcit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pu
T1Hier_vol_die_hth_LRAVGcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth
T1Hier_vol_die_hth_mn_LRAVGcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.hth.mn
T1Hier_vol_die_sth_LRAVGcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.die.sth
T1Hier_vol_exa_LRAVGcit168
Extended Amygdala
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.exa
T1Hier_vol_mtg_rn_LRAVGcit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rn
T1Hier_vol_mtg_sn_snc_LRAVGcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.snc
T1Hier_vol_mtg_sn_snr_LRAVGcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snr
T1Hier_vol_mtg_vtr_pbp_LRAVGcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.pbp
T1Hier_vol_mtg_vtr_vta_LRAVGcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.vtr.vta
T1Hier_vol_referenceregion_LRAVGcit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregion
T1Hier_vol_thm_eth_hn_LRAVGcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.thm.eth.hn
T1Hier_thk_bn_gp_gpe_LRAVGcit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpe
T1Hier_thk_bn_gp_gpi_LRAVGcit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpi
T1Hier_thk_bn_gp_vep_LRAVGcit168
Ventral Pallidum
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.vep
T1Hier_thk_bn_str_nac_LRAVGcit168
Nucleus Accumbens
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.nac
T1Hier_thk_bn_str_pu_LRAVGcit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pu
T1Hier_thk_die_hth_LRAVGcit168
Diencephalon / Hypothalamus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth
T1Hier_thk_die_hth_mn_LRAVGcit168
Diencephalon / Hypothalamus Mammillary Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.hth.mn
T1Hier_thk_die_sth_LRAVGcit168
Subthalamic Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.die.sth
T1Hier_thk_exa_LRAVGcit168
Extended Amygdala
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.exa
T1Hier_thk_mtg_rn_LRAVGcit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rn
T1Hier_thk_mtg_sn_snc_LRAVGcit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.snc
T1Hier_thk_mtg_sn_snr_LRAVGcit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snr
T1Hier_thk_mtg_vtr_pbp_LRAVGcit168
Parabrachial Pigmented Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.pbp
T1Hier_thk_mtg_vtr_vta_LRAVGcit168
Ventral Tegmental Area
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.vtr.vta
T1Hier_thk_referenceregion_LRAVGcit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregion
T1Hier_thk_thm_eth_hn_LRAVGcit168
Thalamus Habenular Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.thm.eth.hn
T1Hier_vol_bn_gp_gpe_LRAVGdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpedp.
T1Hier_vol_bn_gp_gpi_LRAVGdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.gp.gpidp.
T1Hier_vol_bn_str_ca_LRAVGdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.cadp.
T1Hier_vol_bn_str_pu_LRAVGdeep_cit168
Putamen
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.bn.str.pudp.
T1Hier_vol_mtg_rn_LRAVGdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.mtg.rndp.
T1Hier_vol_mtg_sn_snc_LRAVGdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.sncdp.
T1Hier_vol_mtg_sn_snr_LRAVGdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.vol.snrdp.
T1Hier_vol_referenceregion_LRAVGdeep_cit168
Reference Region
T1 hierarchical processing
geometry.volume
CIT168
​
​
t1.vol.referenceregiondp.
T1Hier_thk_bn_gp_gpe_LRAVGdeep_cit168
Globus Pallidus External
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpedp.
T1Hier_thk_bn_gp_gpi_LRAVGdeep_cit168
Globus Pallidus Internal
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.gp.gpidp.
T1Hier_thk_bn_str_ca_LRAVGdeep_cit168
Caudate Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.cadp.
T1Hier_thk_bn_str_pu_LRAVGdeep_cit168
Putamen
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.bn.str.pudp.
T1Hier_thk_mtg_rn_LRAVGdeep_cit168
Red Nucleus
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.mtg.rndp.
T1Hier_thk_mtg_sn_snc_LRAVGdeep_cit168
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.sncdp.
T1Hier_thk_mtg_sn_snr_LRAVGdeep_cit168
Substantia Nigra Reticulata
T1 hierarchical processing
QC
CIT168
​
​
t1.thk.snrdp.
T1Hier_thk_referenceregion_LRAVGdeep_cit168
Reference Region
T1 hierarchical processing
geometry.thickness
CIT168
​
​
t1.thk.referenceregiondp.
T1Hier_vol_mtg_sn_snc_LRAVGsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.sncsnseg
T1Hier_vol_mtg_sn_snr_LRAVGsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.vol.snrsnseg
T1Hier_vol_referenceregion_LRAVGsnseg
Reference Region
T1 hierarchical processing
geometry.volume
ANTs
​
​
t1.vol.referenceregionsnseg
T1Hier_thk_mtg_sn_snc_LRAVGsnseg
Substantia Nigra Compacta
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.sncsnseg
T1Hier_thk_mtg_sn_snr_LRAVGsnseg
Substantia Nigra Reticulata
T1 hierarchical processing
QC
ANTs
​
​
t1.thk.snrsnseg
T1Hier_thk_referenceregion_LRAVGsnseg
Reference Region
T1 hierarchical processing
geometry.thickness
ANTs
​
​
t1.thk.referenceregionsnseg
rsfMRI_fcnxpro134_falffPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
​
rsf.p3.falffpoint047.pcclravg
rsfMRI_fcnxpro134_perafPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
​
rsf.p3.perafpoint047.pcclravg
rsfMRI_fcnxpro134_falffPoint121_InsLRAVG
Insula
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
​
rsf.p3.falffpoint121.inslravg
rsfMRI_fcnxpro134_perafPoint121_InsLRAVG
Insula
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
​
rsf.p3.perafpoint121.inslravg
rsfMRI_fcnxpro134_falffPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
​
rsf.p3.falffpoint155.tempocclravg
rsfMRI_fcnxpro134_perafPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
​
rsf.p3.perafpoint155.tempocclravg
rsfMRI_fcnxpro134_falffPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
​
rsf.p3.falffpoint221.exstrlravg
rsfMRI_fcnxpro134_perafPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
​
rsf.p3.perafpoint221.exstrlravg
rsfMRI_fcnxpro134_falffPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
134
​
rsf.p3.falffpoint231.striatelravg
rsfMRI_fcnxpro134_perafPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
134
​
rsf.p3.perafpoint231.striatelravg
rsfMRI_fcnxpro122_falffPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
​
rsf.p1.falffpoint047.pcclravg
rsfMRI_fcnxpro122_perafPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
​
rsf.p1.perafpoint047.pcclravg
rsfMRI_fcnxpro122_falffPoint121_InsLRAVG
Insula
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
​
rsf.p1.falffpoint121.inslravg
rsfMRI_fcnxpro122_perafPoint121_InsLRAVG
Insula
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
​
rsf.p1.perafpoint121.inslravg
rsfMRI_fcnxpro122_falffPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
​
rsf.p1.falffpoint155.tempocclravg
rsfMRI_fcnxpro122_perafPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
​
rsf.p1.perafpoint155.tempocclravg
rsfMRI_fcnxpro122_falffPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
​
rsf.p1.falffpoint221.exstrlravg
rsfMRI_fcnxpro122_perafPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
​
rsf.p1.perafpoint221.exstrlravg
rsfMRI_fcnxpro122_falffPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
122
​
rsf.p1.falffpoint231.striatelravg
rsfMRI_fcnxpro122_perafPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
122
​
rsf.p1.perafpoint231.striatelravg
rsfMRI_fcnxpro129_falffPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
​
rsf.p2.falffpoint047.pcclravg
rsfMRI_fcnxpro129_perafPoint047_PCCLRAVG
Posterior Cingulate Cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
​
rsf.p2.perafpoint047.pcclravg
rsfMRI_fcnxpro129_falffPoint121_InsLRAVG
Insula
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
​
rsf.p2.falffpoint121.inslravg
rsfMRI_fcnxpro129_perafPoint121_InsLRAVG
Insula
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
​
rsf.p2.perafpoint121.inslravg
rsfMRI_fcnxpro129_falffPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
​
rsf.p2.falffpoint155.tempocclravg
rsfMRI_fcnxpro129_perafPoint155_TempOccLRAVG
Temporo-Occipital
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
​
rsf.p2.perafpoint155.tempocclravg
rsfMRI_fcnxpro129_falffPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
​
rsf.p2.falffpoint221.exstrlravg
rsfMRI_fcnxpro129_perafPoint221_ExStrLRAVG
Extra-Striatal
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
​
rsf.p2.perafpoint221.exstrlravg
rsfMRI_fcnxpro129_falffPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Fractional Amplitude of Low Frequency Fluctuations
power peterson fMRI meta-analyses
129
​
rsf.p2.falffpoint231.striatelravg
rsfMRI_fcnxpro129_perafPoint231_StriateLRAVG
striate cortex
restingStatefMRI
Percent Absolute Fluctuation
power peterson fMRI meta-analyses
129
​
rsf.p2.perafpoint231.striatelravg
DTI_mean_fa.anterior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.cor.rad
DTI_mean_fa.anterior_limb_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ant.int.cap
DTI_mean_fa.cerebral_peduncle.LRAVG.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cerebral.peduncle
DTI_mean_fa.cingulum_.cingulate_gyrus..LRAVG.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.cingulate.gyrus
DTI_mean_fa.cingulum_.hippocampus..LRAVG.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.cingulum.hippocampus
DTI_mean_fa.corticospinal_tract.LRAVG.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.corticospinal.tract
DTI_mean_fa.external_capsule.LRAVG.jhu_icbm_labels_1mm
External Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ext.cap
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..LRAVG.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.fornixlravg
DTI_mean_fa.inferior_cerebellar_peduncle.LRAVG.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.cereb.ped
DTI_mean_fa.inferior_fronto.occipital_fasciculus.LRAVG.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.inf.frnt.occ.fasciculus
DTI_mean_fa.medial_lemniscus.LRAVG.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.medial.lemniscus
DTI_mean_fa.posterior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.cor.rad
DTI_mean_fa.posterior_limb_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.int.cap
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..LRAVG.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.post.thalamic.radiation
DTI_mean_fa.retrolenticular_part_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.rent.int.cap.
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..LRAVG.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.ilf.and.ifolravg
DTI_mean_fa.superior_cerebellar_peduncle.LRAVG.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cereb.ped
DTI_mean_fa.superior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.cor.rad
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..LRAVG.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.frnt.occ.fasc
DTI_mean_fa.superior_longitudinal_fasciculus.LRAVG.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.sup.l.fasc
DTI_mean_fa.tapetum.LRAVG.jhu_icbm_labels_1mm
Tapetum
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.tapetum
DTI_mean_fa.uncinate_fasciculus.LRAVG.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
fractional anisotropy
johns hopkins white matter
​
​
dti.fa.uncinate.fasciculus
DTI_mean_md.anterior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Anterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.cor.rad
DTI_mean_md.anterior_limb_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Anterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ant.int.cap
DTI_mean_md.cerebral_peduncle.LRAVG.jhu_icbm_labels_1mm
Cerebral Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cerebral.peduncle
DTI_mean_md.cingulum_.cingulate_gyrus..LRAVG.jhu_icbm_labels_1mm
Cingulum Cingulate Gyrus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.cingulate.gyrus
DTI_mean_md.cingulum_.hippocampus..LRAVG.jhu_icbm_labels_1mm
Cingulum Hippocampus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.cingulum.hippocampus
DTI_mean_md.corticospinal_tract.LRAVG.jhu_icbm_labels_1mm
Corticospinal Tract
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.corticospinal.tract
DTI_mean_md.external_capsule.LRAVG.jhu_icbm_labels_1mm
External Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ext.cap
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..LRAVG.jhu_icbm_labels_1mm
Fornix cres/Stria Terminalis
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.fornixlravg
DTI_mean_md.inferior_cerebellar_peduncle.LRAVG.jhu_icbm_labels_1mm
Inferior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.cereb.ped
DTI_mean_md.inferior_fronto.occipital_fasciculus.LRAVG.jhu_icbm_labels_1mm
Inferior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.inf.frnt.occ.fasciculus
DTI_mean_md.medial_lemniscus.LRAVG.jhu_icbm_labels_1mm
Medial Lemniscus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.medial.lemniscus
DTI_mean_md.posterior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Posterior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.cor.rad
DTI_mean_md.posterior_limb_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Posterior Limb of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.int.cap
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..LRAVG.jhu_icbm_labels_1mm
Posterior Thalamic Radiation
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.post.thalamic.radiation
DTI_mean_md.retrolenticular_part_of_internal_capsule.LRAVG.jhu_icbm_labels_1mm
Retrolenticular Part of Internal Capsule
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.rent.int.cap.
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..LRAVG.jhu_icbm_labels_1mm
Sagittal Stratum including IFOF/ILF
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.ilf.and.ifolravg
DTI_mean_md.superior_cerebellar_peduncle.LRAVG.jhu_icbm_labels_1mm
Superior Cerebellar Peduncle
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cereb.ped
DTI_mean_md.superior_corona_radiata.LRAVG.jhu_icbm_labels_1mm
Superior Corona Radiata
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.cor.rad
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..LRAVG.jhu_icbm_labels_1mm
Superior Fronto-Occipital Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.frnt.occ.fasc
DTI_mean_md.superior_longitudinal_fasciculus.LRAVG.jhu_icbm_labels_1mm
Superior Longitudinal Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.sup.l.fasc
DTI_mean_md.tapetum.LRAVG.jhu_icbm_labels_1mm
Tapetum
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.tapetum
DTI_mean_md.uncinate_fasciculus.LRAVG.jhu_icbm_labels_1mm
Uncinate Fasciculus
DTI
mean diffusion
johns hopkins white matter
​
​
dti.mean.md.uncinate.fasciculus
DTI_mean_fa_LRAVG_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.caudal.ant.cingulate
DTI_mean_fa_LRAVG_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.caudal.middle.frontal
DTI_mean_fa_LRAVG_cuneus
Cuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.cuneus
DTI_mean_fa_LRAVG_entorhinal
Entorhinal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.entorhinal
DTI_mean_fa_LRAVG_fusiform
Fusiform Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.fusiform
DTI_mean_fa_LRAVG_inferior_parietal
Inferior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.inf.parietal
DTI_mean_fa_LRAVG_inferior_temporal
Inferior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.inf.temporal
DTI_mean_fa_LRAVG_insula
Insula
DTI
fractional anisotropy
ANTs
​
​
dti.fa.insula
DTI_mean_fa_LRAVG_isthmus_cingulate
Isthmus Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.isthmus.cingulate
DTI_mean_fa_LRAVG_lateral_occipital
Lateral Occipital Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.lateral.occipital
DTI_mean_fa_LRAVG_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.lateral.orbitofrontal
DTI_mean_fa_LRAVG_lingual
Lingual Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.lingual
DTI_mean_fa_LRAVG_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.medial.orbitofrontal
DTI_mean_fa_LRAVG_middle_temporal
Middle Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.middle.temporal
DTI_mean_fa_LRAVG_paracentral
Paracentral Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.paracent
DTI_mean_fa_LRAVG_parahippocampal
Parahippocampal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.parahippocampal
DTI_mean_fa_LRAVG_pars_opercularis
Pars Opercularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.pars.opercularis
DTI_mean_fa_LRAVG_pars_orbitalis
Pars Orbitalis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.pars.orbitalis
DTI_mean_fa_LRAVG_pars_triangularis
Pars Triangularis
DTI
fractional anisotropy
ANTs
​
​
dti.fa.pars.triangularis
DTI_mean_fa_LRAVG_pericalcarine
Pericalcarine Cortex
DTI
fractional anisotropy
ANTs
​
​
dti.fa.pericalcarine
DTI_mean_fa_LRAVG_postcentral
Postcentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.postcent
DTI_mean_fa_LRAVG_posterior_cingulate
Posterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.post.cingulate
DTI_mean_fa_LRAVG_precentral
Precentral Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.precent
DTI_mean_fa_LRAVG_precuneus
Precuneus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.precuneus
DTI_mean_fa_LRAVG_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
fractional anisotropy
ANTs
​
​
dti.fa.rostral.ant.cingulate
DTI_mean_fa_LRAVG_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.rostral.middle.frontal
DTI_mean_fa_LRAVG_superior_frontal
Superior Frontal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.sup.frontal
DTI_mean_fa_LRAVG_superior_parietal
Superior Parietal Lobule
DTI
fractional anisotropy
ANTs
​
​
dti.fa.sup.parietal
DTI_mean_fa_LRAVG_superior_temporal
Superior Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.sup.temporal
DTI_mean_fa_LRAVG_supramarginal
Supramarginal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.supramarginal
DTI_mean_fa_LRAVG_transverse_temporal
Transverse Temporal Gyrus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.transverse.temporal
DTI_mean_fa_deep_bn_gp_gpe_LRAVG
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpe
DTI_mean_fa_deep_bn_gp_gpi_LRAVG
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.gp.gpi
DTI_mean_fa_deep_bn_str_ca_LRAVG
Caudate Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.ca
DTI_mean_fa_deep_bn_str_pu_LRAVG
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.bn.str.pu
DTI_mean_fa_deep_mtg_rn_LRAVG
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.mtg.rn
DTI_mean_fa_deep_mtg_sn_snc_LRAVG
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.snc
DTI_mean_fa_deep_mtg_sn_snr_LRAVG
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.deep.snr
DTI_mean_fa_deep_referenceregion_LRAVG
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.deep.referenceregion
DTI_mean_fa_bn_gp_gpe_LRAVG
Globus Pallidus External
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpe
DTI_mean_fa_bn_gp_gpi_LRAVG
Globus Pallidus Internal
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.gpi
DTI_mean_fa_bn_gp_vep_LRAVG
Ventral Pallidum
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.gp.vep
DTI_mean_fa_bn_str_nac_LRAVG
Nucleus Accumbens
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.nac
DTI_mean_fa_bn_str_pu_LRAVG
Putamen
DTI
fractional anisotropy
ANTs
​
​
dti.fa.bn.str.pu
DTI_mean_fa_die_hth_LRAVG
Diencephalon / Hypothalamus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth
DTI_mean_fa_die_hth_mn_LRAVG
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.hth.mn
DTI_mean_fa_die_sth_LRAVG
Subthalamic Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.die.sth
DTI_mean_fa_exa_LRAVG
Extended Amygdala
DTI
fractional anisotropy
ANTs
​
​
dti.fa.exa
DTI_mean_fa_mtg_rn_LRAVG
Red Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.rn
DTI_mean_fa_mtg_sn_snc_LRAVG
Substantia Nigra Compacta
DTI
fractional anisotropy
ANTs
​
​
dti.fa.snc
DTI_mean_fa_mtg_sn_snr_LRAVG
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.fa.snr
DTI_mean_fa_mtg_vtr_pbp_LRAVG
Parabrachial Pigmented Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.pbp
DTI_mean_fa_mtg_vtr_vta_LRAVG
Ventral Tegmental Area
DTI
fractional anisotropy
ANTs
​
​
dti.fa.mtg.vtr.vta
DTI_mean_fa_referenceregion_LRAVG
Reference Region
DTI
fractional anisotropy
ANTs
​
​
dti.fa.referenceregion
DTI_mean_fa_thm_eth_hn_LRAVG
Thalamus Habenular Nucleus
DTI
fractional anisotropy
ANTs
​
​
dti.fa.thm.eth.hn
DTI_mean_fa_ch13_LRAVG
Basal Forebrain Ch13
DTI
fractional anisotropy
BF
​
​
dti.fa.ch13
DTI_mean_fa_nbm_LRAVG_ant
Nucleus Basalis of Meynert Anterior
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.ant
DTI_mean_fa_nbm_LRAVG_mid
Nucleus Basalis of Meynert Middle
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.mid
DTI_mean_fa_nbm_LRAVG_pos
Nucleus Basalis of Meynert Posterior
DTI
fractional anisotropy
BF
​
​
dti.fa.nbm.pos
DTI_mean_md_LRAVG_caudal_anterior_cingulate
Caudal Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.caudal.ant.cingulate
DTI_mean_md_LRAVG_caudal_middle_frontal
Caudal Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.caudal.middle.frontal
DTI_mean_md_LRAVG_cuneus
Cuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.cuneus
DTI_mean_md_LRAVG_entorhinal
Entorhinal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.entorhinal
DTI_mean_md_LRAVG_fusiform
Fusiform Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.fusiform
DTI_mean_md_LRAVG_inferior_parietal
Inferior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.inf.parietal
DTI_mean_md_LRAVG_inferior_temporal
Inferior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.inf.temporal
DTI_mean_md_LRAVG_insula
Insula
DTI
mean diffusion
ANTs
​
​
dti.mean.md.insula
DTI_mean_md_LRAVG_isthmus_cingulate
Isthmus Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.isthmus.cingulate
DTI_mean_md_LRAVG_lateral_occipital
Lateral Occipital Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.lateral.occipital
DTI_mean_md_LRAVG_lateral_orbitofrontal
Lateral Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.lateral.orbitofrontal
DTI_mean_md_LRAVG_lingual
Lingual Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.lingual
DTI_mean_md_LRAVG_medial_orbitofrontal
Medial Orbitofrontal Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.medial.orbitofrontal
DTI_mean_md_LRAVG_middle_temporal
Middle Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.middle.temporal
DTI_mean_md_LRAVG_paracentral
Paracentral Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.paracent
DTI_mean_md_LRAVG_parahippocampal
Parahippocampal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.parahippocampal
DTI_mean_md_LRAVG_pars_opercularis
Pars Opercularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.pars.opercularis
DTI_mean_md_LRAVG_pars_orbitalis
Pars Orbitalis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.pars.orbitalis
DTI_mean_md_LRAVG_pars_triangularis
Pars Triangularis
DTI
mean diffusion
ANTs
​
​
dti.mean.md.pars.triangularis
DTI_mean_md_LRAVG_pericalcarine
Pericalcarine Cortex
DTI
mean diffusion
ANTs
​
​
dti.mean.md.pericalcarine
DTI_mean_md_LRAVG_postcentral
Postcentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.postcent
DTI_mean_md_LRAVG_posterior_cingulate
Posterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.post.cingulate
DTI_mean_md_LRAVG_precentral
Precentral Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.precent
DTI_mean_md_LRAVG_precuneus
Precuneus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.precuneus
DTI_mean_md_LRAVG_rostral_anterior_cingulate
Rostral Anterior Cingulate
DTI
mean diffusion
ANTs
​
​
dti.mean.md.rostral.ant.cingulate
DTI_mean_md_LRAVG_rostral_middle_frontal
Rostral Middle Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.rostral.middle.frontal
DTI_mean_md_LRAVG_superior_frontal
Superior Frontal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.sup.frontal
DTI_mean_md_LRAVG_superior_parietal
Superior Parietal Lobule
DTI
mean diffusion
ANTs
​
​
dti.mean.md.sup.parietal
DTI_mean_md_LRAVG_superior_temporal
Superior Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.sup.temporal
DTI_mean_md_LRAVG_supramarginal
Supramarginal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.supramarginal
DTI_mean_md_LRAVG_transverse_temporal
Transverse Temporal Gyrus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.transverse.temporal
DTI_mean_md_deep_bn_gp_gpe_LRAVG
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpe
DTI_mean_md_deep_bn_gp_gpi_LRAVG
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.gp.gpi
DTI_mean_md_deep_bn_str_ca_LRAVG
Caudate Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.ca
DTI_mean_md_deep_bn_str_pu_LRAVG
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.bn.str.pu
DTI_mean_md_deep_mtg_rn_LRAVG
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.mtg.rn
DTI_mean_md_deep_mtg_sn_snc_LRAVG
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.snc
DTI_mean_md_deep_mtg_sn_snr_LRAVG
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.deep.snr
DTI_mean_md_deep_referenceregion_LRAVG
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.deep.referenceregion
DTI_mean_md_bn_gp_gpe_LRAVG
Globus Pallidus External
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpe
DTI_mean_md_bn_gp_gpi_LRAVG
Globus Pallidus Internal
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.gpi
DTI_mean_md_bn_gp_vep_LRAVG
Ventral Pallidum
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.gp.vep
DTI_mean_md_bn_str_nac_LRAVG
Nucleus Accumbens
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.nac
DTI_mean_md_bn_str_pu_LRAVG
Putamen
DTI
mean diffusion
ANTs
​
​
dti.mean.md.bn.str.pu
DTI_mean_md_die_hth_LRAVG
Diencephalon / Hypothalamus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth
DTI_mean_md_die_hth_mn_LRAVG
Diencephalon / Hypothalamus Mammillary Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.hth.mn
DTI_mean_md_die_sth_LRAVG
Subthalamic Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.die.sth
DTI_mean_md_exa_LRAVG
Extended Amygdala
DTI
mean diffusion
ANTs
​
​
dti.mean.md.exa
DTI_mean_md_mtg_rn_LRAVG
Red Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.rn
DTI_mean_md_mtg_sn_snc_LRAVG
Substantia Nigra Compacta
DTI
mean diffusion
ANTs
​
​
dti.mean.md.snc
DTI_mean_md_mtg_sn_snr_LRAVG
Substantia Nigra Reticulata
DTI
QC
ANTs
​
​
dti.mean.md.snr
DTI_mean_md_mtg_vtr_pbp_LRAVG
Parabrachial Pigmented Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.pbp
DTI_mean_md_mtg_vtr_vta_LRAVG
Ventral Tegmental Area
DTI
mean diffusion
ANTs
​
​
dti.mean.md.mtg.vtr.vta
DTI_mean_md_referenceregion_LRAVG
Reference Region
DTI
mean diffusion
ANTs
​
​
dti.mean.md.referenceregion
DTI_mean_md_thm_eth_hn_LRAVG
Thalamus Habenular Nucleus
DTI
mean diffusion
ANTs
​
​
dti.mean.md.thm.eth.hn
DTI_mean_md_ch13_LRAVG
Basal Forebrain Ch13
DTI
mean diffusion
BF
​
​
dti.mean.md.ch13
DTI_mean_md_nbm_LRAVG_ant
Nucleus Basalis of Meynert Anterior
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.ant
DTI_mean_md_nbm_LRAVG_mid
Nucleus Basalis of Meynert Middle
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.mid
DTI_mean_md_nbm_LRAVG_pos
Nucleus Basalis of Meynert Posterior
DTI
mean diffusion
BF
​
​
dti.mean.md.nbm.pos
snr_
signal to noise
​
QC
ANTs
​
​
snr.
bandp
bandpass filter
​
​
ANTs
​
​
bandp
_mean
mean of image
​
​
ANTs
​
​
.mean
censor
censoring schema
​
​
ANTs
​
​
censor
smooth
smoothing amount
​
​
ANTs
​
​
smooth
outlier
outlier amount
​
​
ANTs
​
​
outlier
motion
motion related
​
​
ANTs
​
​
motion
FD
framewise displacement
​
motion statistic on framewise displacement
ANTs
​
​
fd
despik
despiking count
​
​
ANTs
​
​
despik
_nc_
number of compcor components
​
​
ANTs
​
​
.nc.
_evr
eigenvalue ratio
​
QC
ANTs
​
​
.evr
minut
minutes
​
​
ANTs
​
​
minut
left
laterality l
​
​
ANTs
​
​
left
right
laterality r
​
​
ANTs
​
​
right
paramset
​
​
parameter id
ANTs
​
​
paramset
_sd
standard deviation
​
​
ANTs
​
​
.sd
upsampling
upsampling amount
​
​
ANTs
​
​
upsampling
mhdist
mahalanobis distance
​
​
ANTs
​
​
mhdist
RandBasis
random basis projection
​
​
ANTs
​
​
randbasis
templateL1
template L1 distance
​
​
ANTs
​
​
templatel1
T1Hier_resnetGrade
AI T1 grading
T1 hierarchical processing
​
ANTs
​
​
t1.resnetgrade
msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
msk.vol
T2Flair_msk_vol
Mask Volume
Flair
geometry.volume
ANTs
​
​
t2flair.msk.vol
NM1_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
nm1.msk.vol
NM2_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
nm2.msk.vol
NM3_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
nm3.msk.vol
NM4_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
nm4.msk.vol
NM5_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
nm5.msk.vol
DTI1_msk_vol
Mask Volume
DTI
geometry.volume
ANTs
​
​
dti1.msk.vol
DTI2_msk_vol
Mask Volume
DTI
geometry.volume
ANTs
​
​
dti2.msk.vol
rsf1_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
rsf1.msk.vol
rsf2_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
rsf2.msk.vol
rsf3_msk_vol
Mask Volume
​
geometry.volume
ANTs
​
​
rsf3.msk.vol
reflection_err
​
​
QC - similarity measurements
ANTs
​
​
reflection.err
T2Flair_reflection_err
T2-FLAIR
Flair
​
ANTs
​
​
t2flair.reflection.err
NM1_reflection_err
​
​
​
ANTs
​
​
nm1.reflection.err
NM2_reflection_err
​
​
​
ANTs
​
​
nm2.reflection.err
NM3_reflection_err
​
​
​
ANTs
​
​
nm3.reflection.err
NM4_reflection_err
​
​
​
ANTs
​
​
nm4.reflection.err
NM5_reflection_err
​
​
​
ANTs
​
​
nm5.reflection.err
DTI1_reflection_err
​
DTI
​
ANTs
​
​
dti1.reflection.err
DTI2_reflection_err
​
DTI
​
ANTs
​
​
dti2.reflection.err
rsf1_reflection_err
​
​
​
ANTs
​
​
rsf1.reflection.err
rsf2_reflection_err
​
​
​
ANTs
​
​
rsf2.reflection.err
rsf3_reflection_err
​
​
​
ANTs
​
​
rsf3.reflection.err
psnr
Peak Signal to Noise Ratio
​
QC - similarity measurements
ANTs
​
​
psnr
T2Flair_psnr
T2-FLAIR Peak Signal to Noise Ratio
Flair
QC
ANTs
​
​
t2flair.psnr
NM1_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
nm1.psnr
NM2_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
nm2.psnr
NM3_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
nm3.psnr
NM4_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
nm4.psnr
NM5_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
nm5.psnr
DTI1_psnr
Peak Signal to Noise Ratio
DTI
QC
ANTs
​
​
dti1.psnr
DTI2_psnr
Peak Signal to Noise Ratio
DTI
QC
ANTs
​
​
dti2.psnr
rsf1_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
rsf1.psnr
rsf2_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
rsf2.psnr
rsf3_psnr
Peak Signal to Noise Ratio
​
QC
ANTs
​
​
rsf3.psnr
T1Hier_evratio
T1
T1 hierarchical processing
QC
ANTs
​
​
t1.evratio
T2Flair_wmh_evr
T2-FLAIR Explained Variance Ratio
Flair
QC
ANTs
​
​
t2flair.wmh.evr
rsfMRI_fcnxpro134_bold_evr
rs-fMRI Explained Variance Ratio
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.bold.evr
rsfMRI_fcnxpro122_bold_evr
​
restingStatefMRI
eigenvector ratio for mean bold
power peterson fMRI meta-analyses
122
​
rsf.p1.bold.evr
rsfMRI_fcnxpro129_bold_evr
rs-fMRI Explained Variance Ratio
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.bold.evr
NM2DMT_NM_evr
NM-DMT Explained Variance Ratio
Neuromelanin
QC
ANTs
​
​
nm.evr
T2Flair_flair_evr
T2-FLAIR Explained Variance Ratio
Flair
QC
ANTs
​
​
t2flair.flair.evr
DTI_dti_fa_evr
DTI Fractional Anisotropy
DTI
QC
ANTs
​
​
dti.dti.fa.evr
cnr
Contrast to Noise Ratio
​
QC - noise/contrast
ANTs
​
​
cnr
T2Flair_cnr
T2-FLAIR Contrast to Noise Ratio
Flair
QC
ANTs
​
​
t2flair.cnr
NM1_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
nm1.cnr
NM2_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
nm2.cnr
NM3_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
nm3.cnr
NM4_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
nm4.cnr
NM5_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
nm5.cnr
DTI1_cnr
Contrast to Noise Ratio
DTI
QC
ANTs
​
​
dti1.cnr
DTI2_cnr
Contrast to Noise Ratio
DTI
QC
ANTs
​
​
dti2.cnr
rsf1_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
rsf1.cnr
rsf2_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
rsf2.cnr
rsf3_cnr
Contrast to Noise Ratio
​
QC
ANTs
​
​
rsf3.cnr
rsfMRI_fcnxpro134_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
134
​
rsf.p3.motion.corrected.mean
rsfMRI_fcnxpro134_high_motion_count
rs-fMRI
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.high.motion.count
rsfMRI_fcnxpro134_high_motion_pct
rs-fMRI
restingStatefMRI
QC
power peterson fMRI meta-analyses
134
​
rsf.p3.high.motion.pct
rsfMRI_fcnxpro122_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
122
​
rsf.p1.motion.corrected.mean
rsfMRI_fcnxpro122_high_motion_count
​
restingStatefMRI
high motion count
power peterson fMRI meta-analyses
122
​
rsf.p1.high.motion.count
rsfMRI_fcnxpro122_high_motion_pct
​
restingStatefMRI
percent high motion count
power peterson fMRI meta-analyses
122
​
rsf.p1.high.motion.pct
rsfMRI_fcnxpro129_motion_corrected_mean
​
restingStatefMRI
global mean of image
power peterson fMRI meta-analyses
129
​
rsf.p2.motion.corrected.mean
rsfMRI_fcnxpro129_high_motion_count
rs-fMRI
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.high.motion.count
rsfMRI_fcnxpro129_high_motion_pct
rs-fMRI
restingStatefMRI
QC
power peterson fMRI meta-analyses
129
​
rsf.p2.high.motion.pct
DTI_dti_high_motion_count
DTI
DTI
QC
ANTs
​
​
dti.dti.high.motion.count
rsfMRI_fcnxpro134_minutes_original_data
rs-fMRI
restingStatefMRI
​
power peterson fMRI meta-analyses
134
​
rsf.p3.minutes.original.data
rsfMRI_fcnxpro134_minutes_censored_data
rs-fMRI
restingStatefMRI
​
power peterson fMRI meta-analyses
134
​
rsf.p3.minutes.censored.data
rsfMRI_fcnxpro122_minutes_original_data
​
restingStatefMRI
minutes of rs imaging
power peterson fMRI meta-analyses
122
​
rsf.p1.minutes.original.data
rsfMRI_fcnxpro122_minutes_censored_data
​
restingStatefMRI
minutes of rs imaging after censoring
power peterson fMRI meta-analyses
122
​
rsf.p1.minutes.censored.data
rsfMRI_fcnxpro129_minutes_original_data
rs-fMRI
restingStatefMRI
​
power peterson fMRI meta-analyses
129
​
rsf.p2.minutes.original.data
rsfMRI_fcnxpro129_minutes_censored_data
rs-fMRI
restingStatefMRI
​
power peterson fMRI meta-analyses
129
​
rsf.p2.minutes.censored.data

## Joining with clinical data: PPMI

We provide an example of how to join derived `ANTsPyMM` summary data with clinical variables from PPMI.

    library( subtyper)
    ?merge_ppmi_imaging_clinical_demographic_data